﻿
""" 
 ************************************************************************************************
 **                                                                                            **
 **  File: GeodatabaseSettings.py                                                              **
 **  Copyright (c) January 2018 by Leidos                                                      **
 **  Produced under U.S. Government contract W5J9CQ-12-D-0004  Task Order: 072         **
 **  As per DFARS, the U.S. Government is granted unlimited rights to use this work            **
 **  in any manner and for any purpose.                                                        **
 **                                                                                            **
 **  Summary:  Provide a python class that can operate on an ArcGIS geodatabase API-like       ** 
 **                                                                                            **
 **  Developed by Leidos, Inc., High Resolution ISR Systems Division, Geospatial Programs      **
 **                                                                                            **
 **  Development History:                                                                      **
 **  January 2018 - Annette Filer
 **                                                                                            **
 **                                                                                            **
 *****
 """


import sys
import os
import copy


current_include_source = "Any"
current_include_target = "GGDM 3.0"

common_fields = [
    ('FCSubType', 'FCSubType', 'transform_FCSubtype'),
    ('ObjectID', None, None), 
    ('GLOBALID', None, None)  
]

common_geom_fields =  [
    (None, 'FCSubType', None),
    ('SHAPE@', 'SHAPE@', None)
    ]

common_Pnt_fields = copy.deepcopy(common_geom_fields)

common_Crv_fields = [
    ('SHAPE@Length', 'SHAPE@Length', None) 
    ] + copy.deepcopy(common_geom_fields)

common_Srf_fields = [
    ('SHAPE@Length', 'SHAPE@Length', None),
    ('SHAPE@Area', 'SHAPE@Area', None)
    ] + copy.deepcopy(common_geom_fields)

# ('GLOBALID', 'GLOBALID', None)
common_fields_ignore = ['shape@', 'shape@length', 'shape@area', 'fcsubtype', 'objectid', 'globalid']


# A dictionary of fields and values for default restriction information item
RestrictionInfoTargetDefaultFieldValues = {
    'CCN':'No Information',
    'CDR':'No Information',
    'F_CODE':'ZI002',
    'SAX_RY2':'noInformation',
    'SAX_RS1':'No Information',
    'SAX_RS2':'No Information',
    'SAX_RX9':'No Information',
    'SAX_RS4':'noInformation',
    'SAX_RS5':'No Information',
    'SAX_RS6':'noInformation',
    'SAX_RS8':'No Information',
    'SAX_RS9':'No Information',
    'SAX_RY0':'No Information',
    'SAX_RX1':'noInformation',
    'SAX_RX2':'noInformation',
    'SAX_RY1':'noInformation',
    'SAX_RX5':'noInformation',
    'SAX_RX7':'noInformation',
    'SAX_RX6':'noInformation',
    'UFI':'A9593791-4AE9-4180-8E1E-9CB3D239DEE5'
}

RestrictionInfoTblFields = [
]


RestrictionInfoMetaConvertSubsetFields = [
    ]


RestrictionInfoFCSubsetFields = [
    ]

EntityCollectionTargetDefaultFieldValues = {
    'FCSubType':132721,
    'AHA':-999999,
    'AVA':-999999,
    'DQS':'No Information',
    'EQS':-999999,
    'EVA':-999999,
    'F_CODE':'ZI039',
    'HVA':-999999,
    'MDE':'noInformation',
    'OTH':'noInformation',
    'RCG':-999999,
    'SCVN':'No Information',
    'UFI':'noInformation',
    'ZI001_SDP':'No Information',
    'ZI001_SPS':-999999,
    'ZI001_VSC':-999999,
    'ZI001_VSD':'noInformation',
    'ZI001_VSN':'No Information',
    'ZI004_PRE':'No Information'
    }

# It is critical that the target fields match the destination AND if
# the source is not actually present, the default value is set. We must
# have a value or the metadata processing code will fail. This can be very
# subtle. For instance ZI004_PRE is only in the MetadataSrf feature class.
# but we need to operate based on each feature and ZI004_PRE is not
# on individual features. The source should then be the source fields
# that are present on each feature, not the metadata entity itself.
# To process the metadata entity directly, use MetadataSrfFields.
EntityCollectionFields = [
    ]


# These fields are examined in each source feature instance
# and they are used to extend the information in the
# Entity Collection Metadata records found in MetadataSrf
EntityCollectionMetaConvertSubsetFields = [
    ]

# These fields may be in each feature class instance and should
# be matched to a record in Entity Collection Metadata (MetadataSrf)
# if possible. Where there is no destination in each feature class
# in GGDM, the target is none.
EntityCollectionFCSubsetFields = [
    ]


DatasetSrfFields = [
    ]

DatasetSrfResourceInfoFields = [
    ]

DatasetTargetDefaultFieldValues = {
    'FCSubType':121591,
    'AHA':-999999,
    'AVA':-999999,
    'CID':'No Information',
    'CPS':-999999,
    'DQS':'No Information',
    'EQS':-999999,
    'ETS':-999999,
    'ETZ':'No Information',
    'EVA':-999999,
    'F_CODE':'ZI031',
    'FURL':'noInformation',
    'HVA':-999999,
    'HZD':-999999,
    'MDE':'noInformation',
    'MEM':'No Information',
    'OTH':'noInformation',
    'RCG':-999999,
    'RTL':'No Information',
    'SCVN':'noInformation',
    'URI':'noInformation',
    'VDT':-999999,
    'ZI002_UFI':'noInformation',
    'ZI020_GE4':'noInformation',
    'ZI020_GE42':'noInformation',
    'ZI020_GE43':'noInformation',
    'ZI020_GE44':'noInformation',
    'ZSAX_RS0':'U',
    'ZSAX_RX0':'noInformation',
    'ZSAX_RX3':'noInformation',
    'ZSAX_RX4':'noInformation'
    }


# These are the common metadata fields that are on all geometric features. we group them
# to ensure all translations are done in the same way. OTH and MEM are included so that
# they are also processed consistently.
# (except some of these are not on Dataset (ResourceSrf), which is processed separately.
common_metadata_translate_fields = [
    (None,'ZI002_UFI','transform_find_restriction_info_id'),
    (None,'ZI039S_UFI','transform_find_entity_collection_id'),
    (None,'ZI031S_URI','transform_find_dataset_id'),
    (None,'OTH','transform_OTH'),
    (None,'ZI006_MEM','transform_MEM')
    ]





