﻿
""" 
 ************************************************************************************************
 **                                                                                            **
 **  File: __DoTestsOfTransforms.py                                                            **
 **  Copyright (c) September 2018 by Leidos                                                    **
 **  Produced under U.S. Government contract W5J9CQ-12-D-0004  Task Order: 073                 **
 **  As per DFARS, the U.S. Government is granted unlimited rights to use this work            **
 **  in any manner and for any purpose.                                                        **
 **                                                                                            **
 **  Summary:   This file provides the starting operations point for the transform tests       **
 **                                                                                            **
 **  Developed by Leidos, Inc., High Resolution ISR Systems Division, Geospatial Programs      **
 **                                                                                            **
 **  Development History:                                                                      **
 **  9/27/2018 / Annette Janett Filer                                                          **
 **                                                                                            **
 **                                                                                            **
 ************************************************************************************************
"""



import sys
import os
import copy

import arcpy
import uuid
import glob
import uuid
import traceback


from TranslateConfig import *
from FieldTransformerFunctions import *
from PrimaryTranslationFunctions import *



xformsrc = dict()
xformsrc['AHA'] = dict()
xformsrc['APT'] = dict()
xformsrc['ASU'] = dict()
xformsrc['AVA'] = dict()
xformsrc['BOT'] = dict()
xformsrc['BSC'] = dict()
xformsrc['BST'] = dict()
xformsrc['CCN'] = dict()
xformsrc['CDR'] = dict()
xformsrc['CIW'] = dict()
xformsrc['COS'] = dict()
xformsrc['CPA'] = dict()
xformsrc['CPS'] = dict()
xformsrc['CVT'] = dict()
xformsrc['DFU'] = dict()
xformsrc['DMF'] = dict()
xformsrc['DQS'] = dict()
xformsrc['DWT'] = dict()
xformsrc['EQC'] = dict()
xformsrc['EQS'] = dict()
xformsrc['ESC'] = dict()
xformsrc['ETS'] = dict()
xformsrc['F_CODE'] = dict()
xformsrc['FCSubtype'] = dict()
xformsrc['FFN'] = dict()
xformsrc['FUFI'] = dict()
xformsrc['FURL'] = dict()
xformsrc['FURL2'] = dict()
xformsrc['FURL3'] = dict()
xformsrc['GWS'] = dict()
xformsrc['HZD'] = dict()
xformsrc['IC2'] = dict()
xformsrc['ISS'] = dict()
xformsrc['LDC'] = dict()
xformsrc['LMC'] = dict()
xformsrc['LVN'] = dict()
xformsrc['MDFC'] = dict()
xformsrc['MDSP'] = dict()
xformsrc['MDY'] = dict()
xformsrc['MZN'] = dict()
xformsrc['OTH'] = dict()
xformsrc['PMP'] = dict()
xformsrc['PMPR'] = dict()
xformsrc['PPO'] = dict()
xformsrc['RIN_ROI'] = dict()
xformsrc['RTN_ROI'] = dict()
xformsrc['SAX_RS1'] = dict()
xformsrc['SAX_RS2'] = dict()
xformsrc['SINU'] = dict()
xformsrc['SRE'] = dict()
xformsrc['SSR'] = dict()
xformsrc['SUY'] = dict()
xformsrc['TRS'] = dict()
xformsrc['TSSM'] = dict()
xformsrc['TWS'] = dict()
xformsrc['UFI'] = dict()
xformsrc['VDT'] = dict()
xformsrc['VEG'] = dict()
xformsrc['VLM'] = dict()
xformsrc['VLMC'] = dict()
xformsrc['VLMU'] = dict()
xformsrc['VTI'] = dict()
xformsrc['VTIC'] = dict()
xformsrc['VTIU'] = dict()
xformsrc['WCSD'] = dict()
xformsrc['WDWL'] = dict()
xformsrc['WPUP'] = dict()
xformsrc['WWM'] = dict()
xformsrc['ZI001_ACC'] = dict()
xformsrc['ZI001_NSD'] = dict()
xformsrc['ZI001_NSN'] = dict()
xformsrc['ZI001_NSP'] = dict()
xformsrc['ZI001_SDP'] = dict()
xformsrc['ZI001_SPS'] = dict()
xformsrc['ZI001_SRT'] = dict()
xformsrc['ZI001_SSD'] = dict()
xformsrc['ZI001_SSN'] = dict()
xformsrc['ZI001_SSY'] = dict()
xformsrc['ZI001_VSC'] = dict()
xformsrc['ZI002_CCN'] = dict()
xformsrc['ZI002_UFI'] = dict()
xformsrc['ZI004_RCG'] = dict()
xformsrc['ZI013_FMM'] = dict()
xformsrc['ZI013_PIG'] = dict()
xformsrc['ZI016_WTC'] = dict()
xformsrc['ZI020_GE4'] = dict()
xformsrc['ZI024_HYP'] = dict()
xformsrc['ZI024_WTNO'] = dict()
xformsrc['ZI031S_URI'] = dict()
xformsrc['ZI039S_UFI'] = dict()
xformsrc['ZVH_VDT'] = dict()


xformsrc['APT']['transformlist'] = ['transform_APT']
xformsrc['ASU']['transformlist'] = ['transform_ASU']
xformsrc['BOT']['transformlist'] = ['transform_BSC']
xformsrc['BSC']['transformlist'] = ['transform_BOT','transform_UBC_from_BSC']
xformsrc['BST']['transformlist'] = ['transform_BST']
xformsrc['CCN']['transformlist'] = ['transform_find_restriction_info_id']
xformsrc['CDR']['transformlist'] = ['transform_find_restriction_info_id']
xformsrc['CIW']['transformlist'] = ['transform_CIW_to_ZI016_WTC']
xformsrc['COS']['transformlist'] = ['transform_COS']
xformsrc['CPA']['transformlist'] = ['transform_SUYfromCPA']
xformsrc['CPS']['transformlist'] = ['transformCPScodelist2CPSenumvalue','transformCPSenumeration2CPScodelist']
xformsrc['CVT']['transformlist'] = ['transform_Industry_F_CODE','transform_Industry_FCSubtype','transform_CVT']
xformsrc['DFU']['transformlist'] = ['transformDFU_to_DWT']
xformsrc['DMF']['transformlist'] = ['transform_WRDB_F_CODE','transform_FCSubtype']
xformsrc['DWT']['transformlist'] = ['transformDWT_to_DFU']
xformsrc['EQC']['transformlist'] = ['transformEQCtoEQS','transform_no_target_save_to_oth']
xformsrc['EQS']['transformlist'] = ['transformEQSinteger2EQCcodelist','transformEQStoEQC']
xformsrc['ESC']['transformlist'] = ['transform_ESC']
xformsrc['ETS']['transformlist'] = ['transformETScodelist2ETSenumvalue','transformETSenumeration2ETScodelist']
#xformsrc['F_CODE']['transformlist'] = ['transform_get_from_entity_collection_table','transformMetadataSrfCollectionSrf_F_CODE','transform_CollectionSrfMetadataSrf_F_CODE','transform_Hypsography_F_CODE']
#xformsrc['FCSubtype']['transformlist'] = ['transformMetadataSrfCollectionSrf_FCSubtype','transform_CollectionSrfMetadataSrf_FCSubtype','transform_Hypsography_FCSubtype','transform_Structure_FCSubtype']
#xformsrc['F_CODE']['transformlist'] = ['transformMetadataSrfCollectionSrf_F_CODE','transform_CollectionSrfMetadataSrf_F_CODE','transform_Hypsography_F_CODE']
#xformsrc['FCSubtype']['transformlist'] = ['transformMetadataSrfCollectionSrf_FCSubtype','transform_CollectionSrfMetadataSrf_FCSubtype','transform_Hypsography_FCSubtype','transform_Structure_FCSubtype']
xformsrc['FFN']['transformlist'] = ['transform_ZI037_REL','transform_FFN']
xformsrc['FUFI']['transformlist'] = ['transform_set_FUFI_to_UFI_when_needed']
xformsrc['FURL']['transformlist'] = ['transform_combine_FURL']
xformsrc['FURL2']['transformlist'] = ['transform_combine_FURL']
xformsrc['FURL3']['transformlist'] = ['transform_combine_FURL']
xformsrc['GWS']['transformlist'] = ['transform_GWS']
xformsrc['HZD']['transformlist'] = ['transformHZDcodelist2HZDenumvalue','transformHZDenumeration2HZDcodelist']
xformsrc['IC2']['transformlist'] = ['transform_GE4_from_IC2','transform_GE4_from_IC2_Dataset']
xformsrc['ISS']['transformlist'] = ['transform_LMC']
xformsrc['LDC']['transformlist'] = ['transform_LDC']
xformsrc['LMC']['transformlist'] = ['transform_ISS']
xformsrc['LVN']['transformlist'] = ['transform_LVN']
xformsrc['MDFC']['transformlist'] = ['transform_MFY']
xformsrc['MDSP']['transformlist'] = ['transform_MDSP','transform_MEL','transform_MDSP_MEL']
xformsrc['MDY']['transformlist'] = ['transform_MDFC']
xformsrc['MZN']['transformlist'] = ['transform_MZN']
xformsrc['OTH']['transformlist'] = ['transform_TRS','transformMoveOTHOnlyIfMetaAttribute']
xformsrc['PMP']['transformlist'] = ['transform_PMP','transform_PMPR']
xformsrc['PMPR']['transformlist'] = ['transform_PMP']
xformsrc['PPO']['transformlist'] = ['transform_PPO']
xformsrc['RIN_ROI']['transformlist'] = ['transform_RTN_ROI_from_RIN_ROI']
xformsrc['RTN_ROI']['transformlist'] = ['transform_RIN_ROI_from_RTN_ROI']
xformsrc['SAX_RS1']['transformlist'] = ['transform_find_restriction_info_id']
xformsrc['SAX_RS2']['transformlist'] = ['transform_find_restriction_info_id']
xformsrc['SINU']['transformlist'] = ['transform_SINU_PSN']
xformsrc['SRE']['transformlist'] = ['transform_SRE']
xformsrc['SSR']['transformlist'] = ['transform_SSR']
xformsrc['SUY']['transformlist'] = ['transform_CPAfromSUY']
xformsrc['TRS']['transformlist'] = ['transform_FFN_932_and_TRS','transform_LOC','transform_LUN','transform_TRS_to_LUN','transform_TRS_to_PTG']
xformsrc['TSSM']['transformlist'] = ['transform_TSSM']
xformsrc['TWS']['transformlist'] = ['transform_VEG']
xformsrc['UFI']['transformlist'] = ['transform_set_UFI']
xformsrc['VDT']['transformlist'] = ['transformVDTcodelist2VDTenumvalue','transformVDTenumeration2VDTcodelist']
xformsrc['ZVH_VDT']['transformlist'] = ['transformVDTcodelist2VDTenumvalue','transformVDTenumeration2VDTcodelist']
xformsrc['VEG']['transformlist'] = ['transform_TWS']
xformsrc['VLM']['transformlist'] = ['transform_VLM_from_nonInterval']
xformsrc['VLMC']['transformlist'] = ['transform_VLM_fromInterval']
xformsrc['VLMU']['transformlist'] = ['transform_VLM_fromInterval']
xformsrc['VTI']['transformlist'] = ['transform_VTI_toInterval']
xformsrc['VTIC']['transformlist'] = ['transform_VTI_fromInterval']
xformsrc['VTIU']['transformlist'] = ['transform_VTI_fromInterval']
xformsrc['WCSD']['transformlist'] = ['transform_WCSD_CDI']
xformsrc['WDWL']['transformlist'] = ['transform_WDWL_DWL']
xformsrc['WPUP']['transformlist'] = ['transform_WPUP_PUD']
xformsrc['WWM']['transformlist'] = ['transform_WWM']
xformsrc['ZI001_ACC']['transformlist'] = ['transform_ZI010_ACC']
xformsrc['ZI001_NSD']['transformlist'] = ['transform_ZI001_SRT']
xformsrc['ZI001_NSN']['transformlist'] = ['transform_ZI001_NSN']
xformsrc['ZI001_NSP']['transformlist'] = ['transform_ZI001_SRT']
#xformsrc['ZI001_SDP']['transformlist'] = ['transform_get_from_entity_collection_table']
#xformsrc['ZI001_SPS']['transformlist'] = ['transform_get_from_entity_collection_table','transform_ZI001_SPS']
#xformsrc['ZI001_SRT']['transformlist'] = ['transform_ZI001_SSY','transform_ZI001_NSD','transform_ZI001_NSN','transform_ZI001_NSP','transform_ZI001_SSD','transform_ZI001_SSN','transformZI001_SRTcodelist2ZI001_SRTenumvalue','transformZI001_SRTenumeration2ZI001_SRTcodelist','transformZI001_SRTfromcodelisttoenum']
xformsrc['ZI001_SSD']['transformlist'] = ['transform_ZI001_SRT','transform_ZI001_SDV']
xformsrc['ZI001_SSN']['transformlist'] = ['transform_ZI001_SDP']
xformsrc['ZI001_SSY']['transformlist'] = ['transform_ZI001_SRT']
xformsrc['ZI001_VSC']['transformlist'] = ['transformZI001_VSCcodelist2ZI001_VSCenumvalue','transformZI001_VSCenumvalue2ZI001_VSCcodelist','transformZI001_VSCfromcodelisttoenum','transformZI001_VSCfromenumtocodelist']
#xformsrc['ZI002_CCN']['transformlist'] = ['find_matchrestrictioninfoCCNCDR']
#xformsrc['ZI002_UFI']['transformlist'] = ['transform_SaveSomeRestrictionInfoToOTH']
#xformsrc['ZI004_RCG']['transformlist'] = ['transformRCGcodelist2RCGenumvalue','transformRCGenumeration2RCGcodelist','transformZI004_RCGenumeration2ZI004_RCGcodelist','transformZI004_RCGfromcodelisttoenum']
xformsrc['ZI013_FMM']['transformlist'] = ['transform_ZI013_PIG']
xformsrc['ZI013_PIG']['transformlist'] = ['transform_ZI013_FMM']
xformsrc['ZI016_WTC']['transformlist'] = ['transformZI016_WTC_CIW','transformZI016_WTC']
xformsrc['ZI020_GE4']['transformlist'] = ['transform_IC2_from_GE4']
xformsrc['ZI024_HYP']['transformlist'] = ['transform_HYP','transform_ZI024_HYP']
#xformsrc['ZI024_WTNO']['transformlist'] = ['transform_pull_wrdb_extension']
#xformsrc['ZI031S_URI']['transformlist'] = ['transform_saveDatasetURItoOther']
#xformsrc['ZI039S_UFI']['transformlist'] = ['transform_get_from_entity_collection_table','transform_SaveRelatedECInformation','transform_saveECUFIToOther']

# This function is going to load the field and schema information for the source and target geodatabases
# Then based on these, and based on the above specifications of transform functions for specific source attributes
# This function is going to prepare for each:
# Feature Class, Feature Code, Field - the set of potential test values for the field based on the schema, datatype, and codelist specifications
# Once we have this determined, then this function will prepare sample 'row' data - as if it were a row coming from a geodatabase,
# and for that row, we will then call all of the transform functions specified per field.
# At this time, we are primarily looking for errors that result in the exception print
#
# Future revisions need to also consider transforms (not defined here) specifically for TARGET fields,
# that also need to be called.
#
def preparefccompare(settings, resultlist):
    outputmax = 500
    outputii = 0

    source_db_version = settings.sourcedb_name_and_version.get()
    target_db_version = settings.targetdb_name_and_version.get()
    
    settings.sourcedb.field_information.clear()
    settings.targetdb.field_information.clear()

    # pull in the schema definitions for the geodatabases
    settings.sourcedb.load_schema_information()
    settings.targetdb.load_schema_information()
    fcodemapping = settings.sourcedb.get_fcode_subtype_mapping_for_all()

    # now we should have a schema defin in sourcedb and another in targetdb
    srcfc = set([fc for fc in settings.sourcedb.field_information[source_db_version] if fc.lower() \
                 not in ['defaultvalues', 'levels', "summarydomainvalues", 'interval_fields']])
    targetfc = set([fc for fc in settings.targetdb.field_information[target_db_version] if fc.lower() \
        not in ['defaultvalues', 'levels', "summarydomainvalues", 'interval_fields']])

    intersecting_fc = set(srcfc.intersection(targetfc))
    sourcediff = set(srcfc.difference(targetfc))
    targetdiff = set(targetfc.difference(srcfc))

    fcodemapping = settings.sourcedb.get_fcode_subtype_mapping_for_all()

    resultlist.append({'DB Source': source_db_version, 'DB Target': target_db_version, 
                       'Intersection': intersecting_fc, 
                       'In Source Only': sourcediff, 
                       'In Target Only': targetdiff})

    settings.my_logger.info("# Source: {0}  Target: {1}".format(
        source_db_version, target_db_version))
        
    for fc in list(srcfc):

        settings.my_logger.info("# Feature Class {0}".format(fc))

        settings.saved_mem.clear()           # We can start with a clean dictionary of MEM content for each feature class
        settings.saved_oth.clear()           # We can start with a clean dictionary of OTH content for each feature class
        clear_transformer_functions_report(settings)
        clear_transformer_issues_report(settings)
        outdict = dict()
        dfc = dict()
        rowsdata = dict()   # key: 'F_CODE'  values: (field, valuelist, transformlist)
        fieldliststarting = settings.sourcedb.get_field_list_from_fclass_schemadef(fc)
        fieldliststarting.extend(['FCSubtype'])

        for ffld in fieldliststarting:

            fieldata = list()

            sourcedatatype = settings.sourcedb.get_field_datatype(fc, ffld) if ffld != 'FCSubtype' else 'integer'
            sourcefcodes = settings.sourcedb.get_field_valid_fcode_list(fc, ffld) if ffld != 'FCSubtype' else list(settings.sourcedb.field_information[settings.sourcedb.db_version][fc]['F_CODE'][1])

            for fcode in sourcefcodes:
                if fcode not in outdict:
                    outdict[fcode] = dict()
                if ffld not in outdict[fcode]:
                    outdict[fcode][ffld] = list()

                enumvalues = [ 0 ]
                xformlist = ['transform_placeholder_return_source']
                if sourcedatatype == 'enumeration':
                    enums = settings.sourcedb.get_schema_defined_enumerated_value_possible_list(fc, fcode, ffld)
                    if isinstance(enums, tuple) or isinstance(enums, set):
                        enumvalues = list(enums)
                    elif isinstance(enums, list):
                        enumvalues = enums
                    else:
                        enumvalues = [ enums, -999999 ]
                    xformlist.extend( ['check_for_and_transform_missing_enum_index', 'transform_missing_enum_index_with_warnings'] )
                elif sourcedatatype == 'boolean':
                    enumvalues = [1000,1000,-999999]
                elif ffld == 'F_CODE':
                    enumvalues = [ fcode ]
                elif sourcedatatype == 'structuredtext' and ('UFI' in ffld or 'URI' in ffld):
                    enumvalues = [makerandomufi()]
                elif sourcedatatype == 'structuredtext':
                    enumvalues = [u'testvalue', makerandomufi(), 'noInformation']
                elif sourcedatatype == 'integer' and ffld == 'FCSubtype' :
                    if fcode in fcodemapping:
                        enumvalues = [ fcodemapping[fcode] ]
                    else:
                        enumvalues = [ 0 ]
                elif sourcedatatype == 'integer' or sourcedatatype == 'long' :
                    enumvalues = [-10,0,1,2,150,100003,-999999]
                    xformlist.extend( ['transform_decimetre_to_metre', 'transform_gramspercm_to_mgperlitre', 'transform_metre_to_decimetre', 'transform_millions_to_ones', 'transform_slope_degree_to_percent','transform_thousands_to_ones'])
                elif sourcedatatype == 'real' or sourcedatatype == 'double':
                    enumvalues = [-32.03,0,2.0, 0.001, 1.1,  151.0, 1000005.3, -999999.0]
                    xformlist.extend( ['transform_decimetre_to_metre', 'transform_gramspercm_to_mgperlitre', 'transform_metre_to_decimetre', 'transform_millions_to_ones', 'transform_slope_degree_to_percent','transform_thousands_to_ones'])
                elif sourcedatatype == 'string' or sourcedatatype == 'text':
                    enumvalues = [u'Ex Str',u'Test2',u'No Information',u'Côte D’Ivoire']
                    xformlist.extend( ['transform_default_value_string'])
                elif sourcedatatype == 'codelist':
                    enumvalues = get_potential_codelist_values_for_this_field(ffld)
                    xformlist.extend( ['transform_default_value_string'] )

                # Add more transforms for testing if specified for this field
                if ffld in xformsrc and len(xformsrc[ffld])>0:
                    xformlist.extend(xformsrc[ffld]['transformlist'])

                outdict[fcode][ffld] = (ffld, sourcedatatype, enumvalues, xformlist )
            # end for fcode in source fcodes
        # end for ffld

        # we should now have an outdict for this feature class
        for fcode in outdict:

            maxlistsize = 0
            maxxformlist = 0
            for ffld in outdict[fcode]:
                listlen = len(outdict[fcode][ffld][2])
                if listlen > maxlistsize:
                    maxlistsize = listlen
                listlen = len(outdict[fcode][ffld][3])
                if listlen > maxxformlist:
                    maxxformlist = listlen                
            
            # Generate a bunch of rows, so that we get each possible value
            rowcount = 0
            for ii in range(maxlistsize):
                rowcount += 1
                rowin = dict()
                for ffld in outdict[fcode]:
                    listitem = outdict[fcode][ffld][2]
                    listlen = len(listitem)
                    rowin[ffld] = listitem[getlistindexmodulooption(listlen, ii)]
                # end for each field
                
                # Now that we have a row of data, run the series of transform tests on each field in this row
                for jj in range(maxxformlist):
                    for ffld in outdict[fcode]:
                        listitem = outdict[fcode][ffld][3]
                        listlen = len(listitem)
                        transformer = listitem[getlistindexmodulooption(listlen, jj)]
                        datatype =  outdict[fcode][ffld][1]
                        transformok = True
                        if datatype == 'codelist' and 'codelist2' not in transformer:
                            transformok = False
                        if datatype != 'codelist' and 'codelist2' in transformer:
                            transformok = False
                        if transformok and transformer in call_transform_function:
                            try: 
                                xformval = call_transform_function[transformer](settings, rowin, ffld, ffld, fc, fc) 
                              #  if xformval != rowin[ffld] and \
                             #       ('millions' not in transformer and 'decimetre' not in transformer and 'degree' not in transformer and 'thousands' not in transformer) and \
                              #      ('transform_default_value' not in transformer):
                                 #   settings.my_logger.info("Row: {7} fc: {0} fcode: {4} field: {1} field_tpe: {6} value: {2} transform: {3} returnval: {5}".\
                                 #       format(fc, ffld, strout(rowin[ffld]), transformer, fcode, strout(xformval), datatype, rowcount))
                            except:
                                report_transfomer_issue_or_increment_count(
                                settings, "  Error processing fc: {0} fcode: {4} field: {1} field_tpe: {5} value: {2} transform: {3}. ".\
                                    format(fc, ffld, strout(rowin[ffld]), transformer, fcode, datatype),
                                "ERROR" ,"Row {0} Failure: {1} at: {2}".format(rowcount, sys.exc_info(), traceback.format_exc(5) ))


                #   #
            #
        #
        output_transformer_report_detail(settings.my_logger, fc, settings.report_values, "Information")
        output_transformer_report_detail(settings.my_logger, fc, settings.report_errors, "Errors")
    # end for fc


def getlistindexmodulooption(lenlist, ii):
    if ii >= lenlist:
        return int( ii % lenlist )
    else:
        return ii
        


def makerandomufi():
        return  "{" + str(uuid.uuid4()).upper() + "}"
 





def DoSelfTestOperations(settings):
    my_logger = settings.get_logger()

  #  versionvalssrc = ['TDS 6.1']  # 'TDS 4.0', 'TDS 6.1', 'GGDM 2.1', 'GGDM 2.2'
  #  versionvalstarget = [ 'GGDM 3.0']
    results = list()


    settings.sourcedb.gui_updated_info_update_internal_vars()
    settings.targetdb.gui_updated_info_update_internal_vars()

    preparefccompare(settings,  results) 



    my_logger.info ( "\n\nLog file available for review: " )
    my_logger.info ( "  {0}".format(settings.name_log_file.get()))


    my_logger.info ("All steps complete.\n")
    my_logger.info ("***********************")



