﻿
""" 
 ************************************************************************************************
 **                                                                                            **
 **  File: ExcelMappingFileAPI.py                                                              **
 **  Copyright (c) December 2017 and September, 2018 by Leidos                                 **
 **  Produced under U.S. Government contract W5J9CQ-12-D-0004  Task Order:  072 and 074        **
 **  As per DFARS, the U.S. Government is granted unlimited rights to use this work            **
 **  in any manner and for any purpose.                                                        **
 **                                                                                            **
 **  Summary:   API for the import of the mapping file information                             **
 **                                                                                            **
 **  Developed by Leidos, Inc., High Resolution ISR Systems Division, Geospatial Programs      **
 **                                                                                            **
 **  Development History:                                                                      **
 **  December 2017 / Annette Janett Filer                                                      **
 **  9/27/2018 - Updates made to support new capabilities                                      **
 **                                                                                            **
 **                                                                                            **
 ************************************************************************************************
"""

import os
import glob
import xlrd
import xlwt
import ast
from xlrd.sheet import ctype_text
import logging
import logging.handlers
from TranslateConfig import *



class APIExcelMappingFile():
    class feature_table_mapping_with_where(object):
        def __init__(self, properties):
            self.existing = "Still Here"
            self.properties = properties
        def __getattr__(self, name):
            if "properties" in self.__dict__ and name in self.properties:
                return self.properties[name] # Or call a function, etc
            return self.__dict__[name]
        def __setattr__(self, name, value):
            if "properties" in self.__dict__ and name in self.properties:
                self.properties[name] = value
            else:
                self.__dict__[name] = value

    class featuretranslation_rules_for_features_and_fields(object):
        def __init__(self, properties):
            self.existing = "Still Here"
            self.properties = properties

        def __getattr__(self, name):
            if "properties" in self.__dict__ and name in self.properties:
                return self.properties[name] # Or call a function, etc
            return self.__dict__[name]
        def addattrtoclass(self, name, value):
            setattr('featuretranslation_rules_for_features_and_fields', name, value)


    def __init__(self, mapping_file_name, in_logger):

        self.xls_sheet_content = list()
        self.my_logger = in_logger
        self.mapping_file_name = mapping_file_name
        self.xl_sheet = None
        self.workbook = None
        self.fc_names = list()
        self.table_names = list()
        self.default_geometric_fc = u'All Geometric Features Not Listed Here'
        self.headerSourceTarget = dict()
        self.file_contentSourceTarget = dict()
        self.file_content = dict()

        self.translation_rules_for_features_and_fields = None
        self.feature_mappings_object = None

        self.headerTranslateFeatures = dict()
        self.file_contentTranslateFeatures = dict()

        self.headerTranslateAttributeGroups = dict()
        self.file_contentTranslateAttributeGroups = dict()

        self.headerTranslateAttributes = dict()
        self.file_contentTranslateAttributes = dict()
        self.file_content_TargetValueMap = dict()
        self.file_content_TargetMappingSpec = dict()

        # Open the expected tabs and save data from each tab
        self.proc_open_excel_file_to_tab(u'SourceTarget')
        if self.xl_sheet <> None:
            self.headerSourceTarget = self.get_header_dictionary()
            self.file_contentSourceTarget = self.proc_mapping_file_getvalues(self.headerSourceTarget, [u'Index',])

        self.proc_open_excel_file_to_tab(u'TranslateFeatures')
        if self.xl_sheet <> None:
            self.headerTranslateFeatures = self.get_header_dictionary()
            self.file_contentTranslateFeatures = self.proc_mapping_file_getvalues(self.headerTranslateFeatures, [u'Index',])

        self.proc_open_excel_file_to_tab("TranslateAttributeGroups")
        if self.xl_sheet <> None:
            self.headerTranslateAttributeGroups = self.get_header_dictionary()
            self.file_contentTranslateAttributeGroups = self.proc_mapping_file_getvalues(self.headerTranslateAttributeGroups, [u'Index',])

        self.proc_open_excel_file_to_tab("TranslateAttributes")
        if self.xl_sheet <> None:
            self.headerTranslateAttributes = self.get_header_dictionary()
            self.file_contentTranslateAttributes = self.proc_mapping_file_getvalues(self.headerTranslateAttributes, [u'Index',])

    # Get the list of source and targets to process. Each source and target also lists the rules group and a where clause that may
    # limit the instances processed.
    def get_feature_table_translate_rules(self):
        fcs = list()
        for tfea in sorted(self.file_contentTranslateFeatures.iterkeys()):
            tdict = self.file_contentTranslateFeatures[tfea]
            if tdict[u'Type'].lower() == 'fcs':
              #  stringout = "      {0} : {1} : {2}".format(iikey, jjkey, str(contentin[iikey][jjkey])))
                
                fcs.append( (tdict[u'Source Table'], 
                             tdict[u'Target Table'], 
                             tdict[u'Translate Attributes Group'], 
                             tdict[u'Where Clause'] if tdict[u'Where Clause'] != '' else 'None') )
        return fcs


    # The target feature code is specified in the excel file
    def get_F_CODE_for_target(self, target_fc):
        for tfea in self.file_contentTranslateFeatures:
            tdict = self.file_contentTranslateFeatures[tfea]
            if tdict[u'Target Table'] == target_fc:
                return tdict[u'F_CODE']
        return None

    # Gets the translation features and fields for a particular attribute group that was
    # brought in from the excel file
    def get_translate_features_and_fields(self, feattrgroup, includestart, includeend):
        fandf = list()

        for attrgroup in sorted(self.file_contentTranslateAttributes.iterkeys()):
            tdict = self.file_contentTranslateAttributes[attrgroup]
            llgroup = tdict[u'Group'].lower()
            if llgroup == feattrgroup.lower():
                srcfield = (tdict[u'Source Field'] if tdict[u'Source Field'] != '' else 'None').strip('"')
                targetfield = (tdict[u'Target Field'] if tdict[u'Target Field'] != '' else 'None').strip('"')
                transform = (tdict[u'Transform'] if tdict[u'Transform'] != '' else 'None').strip('"')
                fandf.append( (srcfield, 
                                targetfield, 
                                transform) )

                vv = tdict[u'Target Value']
                mm = tdict[u'Mapping']
                if isinstance(vv, basestring) and len(vv) == 0:
                    vv = None
                if isinstance(mm, basestring) and len(mm) == 0:
                    mm = None
                if vv is not None:
                    if isinstance(vv, basestring):
                        vv = vv.strip('"').strip("'")
                        if llgroup not in self.file_content_TargetValueMap:
                            self.file_content_TargetValueMap[llgroup] = dict()
                        self.file_content_TargetValueMap[llgroup][tdict[u'Target Field'].lower()] = vv
                    else:
                        if llgroup not in self.file_content_TargetValueMap:
                            self.file_content_TargetValueMap[llgroup] = dict()
                        self.file_content_TargetValueMap[llgroup][tdict[u'Target Field'].lower()] = str(vv)
                        #self.my_logger.error("Non textual content {0} in Target Value column of mapping file, group {1} target field {2}. Just use ' around numbers.".format(vv, llgroup, tdict[u'Target Field']))
                       


                if mm is not None:
                    if isinstance(mm, basestring):
                        mm = mm.strip('"').strip("'")
                        if llgroup not in self.file_content_TargetMappingSpec:
                            self.file_content_TargetMappingSpec[llgroup] = dict()
                        self.file_content_TargetMappingSpec[llgroup][tdict[u'Target Field'].lower()] = ast.literal_eval(mm)
                    else:
                        self.my_logger.error("Non textual content {0} in Mapping column of mapping file, group {1} target field {2}. Just use ' around numbers.".format(mm, llgroup, tdict[u'Target Field']))


        return fandf

    def get_target_value_specific_default(self, feattrgroup, target_attribute):
        rtnval = None
        lwrgroup = feattrgroup.lower()
        lwrattr = target_attribute.lower()
        if lwrgroup in self.file_content_TargetValueMap:
            if lwrattr in self.file_content_TargetValueMap[lwrgroup]:
                rtnval =  self.file_content_TargetValueMap[lwrgroup][lwrattr]
        return rtnval


    def get_target_value_mapping(self, feattrgroup, target_attribute):
        rtnval = None
        lwrgroup = feattrgroup.lower()
        lwrattr = target_attribute.lower()
        if lwrgroup in self.file_content_TargetMappingSpec:
            if lwrattr in self.file_content_TargetMappingSpec[lwrgroup]:
                rtnval =  self.file_content_TargetMappingSpec[lwrgroup][lwrattr]
        return rtnval

    def get_translate_groups_information(self):
        groups = dict()
        for attrgroup in sorted(self.file_contentTranslateAttributeGroups.iterkeys()):
            tdict = self.file_contentTranslateAttributeGroups[attrgroup]
            groups[tdict[u'Group']] = (tdict[u'Group'], tdict[u'IncludeStart'], tdict[u'IncludeEnd'])
        return groups
 


    def prepare_feature_and_field_translation_rules(self, modulename):

        groups = self.get_translate_groups_information()

        for tdict in groups:
            valuesfortransrules = self.get_translate_features_and_fields( groups[tdict][0], groups[tdict][1] , groups[tdict][2])
          #  if groups[tdict][1] is not None:
          #      valuesfortransrules = copy.deepcopy(modulename.groups[tdict][1]) + valuesfortransrules
          #  if groups[tdict][2] is not None:
          #      valuesfortransrules =  valuesfortransrules + copy.deepcopy(modulename.groups[tdict][2])
            setattr(modulename, groups[tdict][0], valuesfortransrules)

        # print 'done with rules'


    def is_valid(self):
        if self.xl_sheet == None:
            return False
        else:
            if self.workbook == None:
                return False
            else:
                return True

    def get_header_dictionary(self):
        # Use header row (row 0) and save headings into dictionary with column numbers
        hdr_row = self.xl_sheet.row(0)
        header = dict()
        col_idx = 0
        for idx, cell_obj in enumerate(hdr_row):
            cell_type = ctype_text.get(cell_obj.ctype, 'unknown type')
            val = cell_obj.value
            if (val is not None and val <> ""):
                header[val] = col_idx
       #     header[col_idx] = val
            col_idx = col_idx + 1
        return header


    def get_max_index_header(self, header):
        start = len(header)/2
        done = False
        while not done:
            if start in header:
                start = start + 1
            else:
                return start
            if start > 200:
                return len(header)
        return 0

    def print_dictionary(self, contentin, my_logger):
        if isinstance(contentin, dict):
            for iikey in contentin:
                if isinstance(iikey, dict):
                    for jjkey in contentin[iikey]:
                        my_logger.info("      {0} : {1} : {2}".format(iikey, jjkey, str(contentin[iikey][jjkey])))
                else:
                    my_logger.info("  {0} : {1} ".format(iikey,  str(contentin[iikey])))
            my_logger.info ("  --")

    def proc_open_excel_file_to_tab(self, tabname=u'SourceTarget'):
        if os.path.isfile(self.mapping_file_name):
            self.my_logger.info( "Opening mapping file: {0}".format(self.mapping_file_name))
            self.workbook = xlrd.open_workbook(self.mapping_file_name, on_demand = True)


            self.xl_sheet = self.workbook.sheet_by_name(tabname)
            shname = self.xl_sheet.name
            self.my_logger.info("Working with sheet: {0}".format(shname))
        else:
            self.my_logger.error("Specified data excel file {0} not found".format(self.mapping_file_name))



    def proc_mapping_file_getvalues(self, inheader, keylist):
        # if the file is large, consider using the on_demand = True flag in this open call to page in the sheet as needed
        # , encoding = 'cp1252'

      #  for xlfile in xls_files:


        # Columns: Feature Class or Table Name	Type	Feature Class vs. Table	F_CODE	Field	Attribute Name	Set to value	Set only if current value is

        #   row = xl_sheet.row(0)  # 1st row
        #  print xl_sheet.cell(0, 0).value
        mappingrow = dict()
        num_cols = self.xl_sheet.ncols   # Number of columns

        sindex = self.get_max_index_header(inheader) + 1
        for row_idx in range(1, self.xl_sheet.nrows):
            rowD = dict()
            rowD['row'] = row_idx
            for hdrkey in inheader:
                if hdrkey <> "":
                    value = self.xl_sheet.cell(row_idx, inheader[hdrkey]).value
                    if value is None:
                        value = ''
                    if isinstance(value, basestring):          # If this is a string value, it may have spaces to strip off
                        rowD[hdrkey] = value.strip()
                    else:
                        rowD[hdrkey] = value
        
            # Get a unique key for this row: 
            # In this case, use header values: Feature Class or Table Name, Field
            ukey = "{0}".format(rowD[keylist[0]])
            if ukey <> "" and ukey not in mappingrow:
                mappingrow[ukey] = rowD
                # self.print_dictionary(rowD, self.my_logger)
        return mappingrow


    def getUniqueFeatureClassNames(self):
        fc = list()
        # Columns: Feature Class or Table Name	Type	Feature Class vs. Table	F_CODE	Field	Attribute Name	Set to value	Set only if current value is
        for ctrlrow in self.file_content:
            rowD = self.file_content[ctrlrow]
            fcname = rowD[u'Feature Class or Table Name']
            if fcname != '' and fcname not in fc and rowD[u'Feature Class vs. Table'].lower() == 'feature class':
                fc.append(fcname)
        return fc

                
    def getUniqueTableNames(self):
        fc = list()
        # Columns: Feature Class or Table Name	Type	Feature Class vs. Table	F_CODE	Field	Attribute Name	Set to value	Set only if current value is
        for ctrlrow in self.file_content:
            rowD = self.file_content[ctrlrow]
            fcname = rowD[u'Feature Class or Table Name']
            if fcname != '' and fcname not in fc and rowD[u'Feature Class vs. Table'].lower() == 'table':
                fc.append(fcname)
        return fc

    def getFieldsForFC(self, fc):
        fields = list()
        foundit = False
        # Columns: Feature Class or Table Name	Type	Feature Class vs. Table	F_CODE	Field	Attribute Name	Set to value	Set only if current value is
        for ctrlrow in self.file_content:
            rowD = self.file_content[ctrlrow]
            fcname = rowD[u'Feature Class or Table Name']
            if fcname == fc:
                foundit = True
                if rowD[u'Field'] not in fields and rowD[u'Set to value'] <> '':
                    fields.append(rowD[u'Field'])

        # if the feature class is geometric (last 3 chars are "Srf", "Pnt", "Crv") and we didnt find a match,
        # Look for the default 'All Geometric Features Not Listed Here' as the feature class in the spreadsheet. 
        if foundit == False and self.isfcgeometric(fc):
            fields = self.getFieldsForFC(self.default_geometric_fc)
        return fields

    def isfcgeometric(self, fc):
        if fc[-3:].lower() in ['srf', 'pnt', 'crv']:
            return True
        else:
            return False

    def getFieldValuesAndRulesForFC(self, fc):
        fields = dict()
        setrules = dict()
        attrnm = dict()
        foundit = False
        # Columns: Feature Class or Table Name	Type	Feature Class vs. Table	F_CODE	Field	Attribute Name	Set to value	Set only if current value is
        for ctrlrow in self.file_content:
            rowD = self.file_content[ctrlrow]
            fcname = rowD[u'Feature Class or Table Name']
            if fcname == fc:
                if rowD[u'Field'] not in fields and rowD[u'Set to value'] <> '':
                    foundit = True
                    fields[rowD[u'Field']] = rowD[u'Set to value']
                    setrules[rowD[u'Field']] = rowD[u'Set only if current value is']
                    attrnm[rowD[u'Field']] = rowD[u'Attribute Name']

        # If we did not find a matching feature class, perform one more tests for the 'All Geometric Features Not Listed Here'
        if foundit == False and self.isfcgeometric(fc):
            fields, setrules, attrnm = self.getFieldValuesAndRulesForFC(self.default_geometric_fc)

        return (fields, setrules, attrnm)

