﻿
""" 
 ************************************************************************************************
 **                                                                                            **
 **  File: ExcelResultsOut.py                                                                  **
 **  Copyright (c) February 21 by Leidos                                                       **
 **  Produced under U.S. Government contract W5J9CQ-12-D-0004  Task Order: 064 and 073         **
 **  As per DFARS, the U.S. Government is granted unlimited rights to use this work            **
 **  in any manner and for any purpose.                                                        **
 **                                                                                            **
 **  Summary:   API for the Excel Results Log
 **                                                                                            **
 **  Developed by Leidos, Inc., High Resolution ISR Systems Division, Geospatial Programs      **
 **                                                                                            **
 **  Development History:                                                                      **
 **  February 2017 / Annette Janett Filer                                                      ** 
 **  9/27/2018  Updates for translator and consistency
 **                                                                                            **
 **                                                                                            **
 ************************************************************************************************
"""


import os
import glob
import xlrd
import xlwt
import ast
from xlrd.sheet import ctype_text
from TranslateConfig import *

class APIExcelResultsOutput():

    def __init__(self, settings):

        self.xls_sheet_content = list()
        self.settings = settings
        self.my_logger = settings.my_logger
        self.results_file_name = settings.file_results_excel.get()
        self.xl = xlwt.Workbook()
        self.worksheet = None
        self.tab_names = dict()     # Names of tabs and current row
        self.dictsheets = dict()   # Names of tabs and sheet reference
        self.max_entries_hit = False
        self.columnentries = dict() # Column Types

        self.starting_report_row = 4
        self.tab_names['Content'] = 2
        self.tab_number = 3
        self.dictsheets['Content'] = self.xl.add_sheet('Content')

        self.report_saved_key = dict()
        self.report_saved_key_column = dict()
              
        self.color_red = 2
        self.color_blue = 7
        self.color_light_blue = 41
        self.color_yellow = 5
        self.color_light_yellow = 43
        self.color_magenta = 6
        self.color_light_pink = 45
        self.color_tan = 52
        self.color_light_tan = 47
        self.color_violet = 25
        self.color_light_violet = 31
        self.color_green = 3
        self.color_light_green = 42
        self.color_light_grey = 22

        self.style_light_yellow = xlwt.easyxf('pattern: pattern solid;')
        self.style_light_yellow.pattern.pattern_fore_colour = self.color_light_yellow
        self.style_light_green = xlwt.easyxf('pattern: pattern solid;')
        self.style_light_green.pattern.pattern_fore_colour = self.color_light_green
        self.style_light_tan = xlwt.easyxf('pattern: pattern solid;')
        self.style_light_tan.pattern.pattern_fore_colour = self.color_light_tan
        self.style_yellow = xlwt.easyxf('pattern: pattern solid;')
        self.style_yellow.pattern.pattern_fore_colour = self.color_yellow       
        self.style_light_grey = xlwt.easyxf('pattern: pattern solid;')
        self.style_light_grey.pattern.pattern_fore_colour = self.color_light_grey  
        self.style_light_blue = xlwt.easyxf('pattern: pattern solid;')
        self.style_light_blue.pattern.pattern_fore_colour = self.color_light_blue                   
        self.fr_row_num = 3

        rowout = self.dictsheets['Content'].row(2)
        rowout.write(1, "{0} Results and Reports".format(settings.app_title.get()))
        rowout.write(4, "{0}".format(settings.version_identifier.get()))
        rowout = self.dictsheets['Content'].row(4)
        rowout.write(1, self.results_file_name, self.style_light_yellow)
        rowout.write(2, "", self.style_light_yellow)
        rowout.write(3, "", self.style_light_yellow)
        rowout.write(4, "", self.style_light_yellow)
        rowout = self.dictsheets['Content'].row(5)
        rowout.write(2, "This file contains results and statistics regarding translation of:")
        rowout = self.dictsheets['Content'].row(6)
        rowout.write(3, "Source GeoDatabase")
        rowout.write(4, settings.dir_source_geodatabase.get())
        rowout.write(6, settings.sourcedb_name_and_version.get())
        rowout = self.dictsheets['Content'].row(7)
        rowout.write(3, "Target GeoDatabase")
        rowout.write(4, settings.dir_target_geodatabase.get())
        rowout.write(6, settings.targetdb_name_and_version.get())
        import datetime
        curdt = datetime.datetime.now().strftime("%Y-%m-%d  %H:%M")    # import datetime
        rowout = self.dictsheets['Content'].row(9)
        rowout.write(2, "Date and time of this translator execution: {0}".format(curdt))
        rowout = self.dictsheets['Content'].row(10)
        rowout.write(2, "Translation results and issues are identified in tabs of this sheet.")
        rowout = self.dictsheets['Content'].row(11)
        rowout.write(2, "There are three processing steps that may examine all features: Restriction Information, Entity Collection Metadata, and Table / Feature Class Translations.")
        rowout = self.dictsheets['Content'].row(12)
        rowout.write(2, "Each processing step may be represnted by a tab report within this document. Typical names for these tabs:")
        rowout = self.dictsheets['Content'].row(13)
        rowout.write(2, "Restriction# reports on restriction info processing that is performed across all feature instances. This sheet may be blank or it may not be present.")
        rowout = self.dictsheets['Content'].row(14)
        rowout.write(2, "EntityCol# reports on Entity Collection metadata processing that may be performed across all feature instances. This sheet may be blank or it may not be present.")
        rowout = self.dictsheets['Content'].row(15)
        rowout.write(2, "Features# reports on feature class and table general translations performed in Step 3 of the process.")
        rowout = self.dictsheets['Content'].row(17)
        rowout.write(2, "Optional tabs depend on processing settings and they may be present:")
        rowout = self.dictsheets['Content'].row(18)
        rowout.write(2, "FieldReport provides a summarized listing of the field codes identified in the mapping specification vs. the GeoDatabase table or feature class. This can be useful to quickly identify potential differences between the mapping and specified schema version.")
        rowout = self.dictsheets['Content'].row(19)
        rowout.write(2, "ufi is a report generated by the built-in checker utility and is output to this file if the checker was enabled.")
        self.starting_row_for_config_setting_report = 22
        self.done_save()

    # output the reports headings to column 1, starting in row 2

    def prepare_results_report(self, rowheadings):
        pass
        #self.tab_names['ColorTest'] = 6
        #self.dictsheets['ColorTest'] = self.xl.add_sheet('ColorTest')
        #styleTS = list()
        #for ii in range(1, 56):
        #    styleTS.append(xlwt.easyxf('pattern: pattern solid;'))
        #    styleTS[ii-1].pattern.pattern_fore_colour = ii

        #    rowout = self.dictsheets['ColorTest'].row(ii)
        #    rowout.write(0, "{0}".format(ii), styleTS[ii-1])




    # Output the report for a feature class
    def save_results_items_to_report(self, reporttabname, src_fc, targ_fc, wherecl, transformreport, row_num, issue_report = False):

        general_nonversioned_tabname = "{0}{1}".format(reporttabname, "")
        uniquekey = "{0} - {1} to {2} where {3}".format(reporttabname, src_fc, targ_fc, wherecl)
        columnforreportitem = 0

        if general_nonversioned_tabname not in self.columnentries:
            self.columnentries[general_nonversioned_tabname] = dict()
            self.columnentries[general_nonversioned_tabname]['NonVersionedTab'] = general_nonversioned_tabname
            self.columnentries[general_nonversioned_tabname]['CurrentColumn'] = 3
            self.columnentries[general_nonversioned_tabname]['CurrentTabIndex'] = 1
            self.columnentries[general_nonversioned_tabname]['RowHeader'] = 0
            self.columnentries[general_nonversioned_tabname]['RowIndex'] = 3
            self.columnentries[general_nonversioned_tabname]['IssuesDetected'] = 0


        tabdictionary = self.columnentries[general_nonversioned_tabname]
        # The first time we have seen this src_fc, targ_fc and type of item
        if uniquekey not in tabdictionary:
            tabdictionary[uniquekey] = dict()
            currdict = tabdictionary[uniquekey]
            # If we are getting close to the max 256 columns, trigger a reset, and
            # a tab number change - forcing the creation of a new tab
            if tabdictionary['CurrentColumn'] > 250:
                tabdictionary['CurrentTabIndex'] += 1
                tabdictionary['CurrentColumn'] = 3
                tabdictionary['RowIndex'] = 3
                tabdictionary['IssuesDetected'] = 0
                self.done_save()
            currdict['TabIndex'] = tabdictionary['CurrentTabIndex']
            currdict['TabName'] = "{0}{1}".format(general_nonversioned_tabname, tabdictionary['CurrentTabIndex'])
            currdict['ColumnIndex'] = tabdictionary['CurrentColumn']
            tabdictionary['CurrentColumn'] += 1


            # Check if we have this tab already, if not - set it up
            if currdict['TabName'] not in self.dictsheets:
                self.tab_names[currdict['TabName']] = self.tab_number
                self.tab_number += 1
                self.dictsheets[currdict['TabName']] = self.xl.add_sheet(currdict['TabName'])  # self.tab_number
                # headings output one time only
                rowout = self.dictsheets[currdict['TabName']].row( tabdictionary['RowHeader'] )
                rowout.write(2,  "Process Step - Source - Target:", self.style_light_blue)
                rowout = self.dictsheets[currdict['TabName']].row( tabdictionary['RowHeader']+1 )
                rowout.write(2,  "Source:", self.style_light_blue)
                rowout = self.dictsheets[currdict['TabName']].row( tabdictionary['RowHeader']+2 )
                #  rowout.write(1,  "Issue Label", self.style_yellow)  this one will be done below, if we see ANY issues
                rowout.write(2,  "Target:", self.style_light_blue)
                rowout = self.dictsheets[currdict['TabName']].row( tabdictionary['RowHeader']+2 )
                rowout.write(0,  "Counter Label", self.style_light_green)
            #


            # Headings output per feature class source target
            rowout = self.dictsheets[currdict['TabName']].row( tabdictionary['RowHeader'] )
            rowout.write(currdict['ColumnIndex'],  "{0}".format(uniquekey), self.style_light_blue)
            rowout = self.dictsheets[currdict['TabName']].row( tabdictionary['RowHeader'] + 1 )
            rowout.write(currdict['ColumnIndex'],  "{0} {1}".format(src_fc, wherecl), self.style_light_blue)
            rowout = self.dictsheets[currdict['TabName']].row( tabdictionary['RowHeader'] + 2 )
            rowout.write(currdict['ColumnIndex'],  "{0} {1}".format(targ_fc, wherecl), self.style_light_blue)
        else:
            currdict = tabdictionary[uniquekey]
        #
   
        # curdict['ColumnIndex'] is already set and is never > 250
        # curdict['TabName'] is already set
        # currdict['TabIndex'] is already set
        currdict['Source'] = src_fc
        currdict['Target'] = targ_fc
        currdict['Processing'] = transformreport

        
        currtab = currdict['TabName']
        # If we have a value, get the column number within which we will store the result
        # Otherwise, create one
        for keys, values in sorted(transformreport.items()):
            if values <> 0:
                # Prepare a new report key dictionary per tab
                if currtab not in self.report_saved_key:
                    self.report_saved_key[currtab] = dict()
                    self.report_saved_key_column[currtab] = self.starting_report_row
                    self.report_saved_key[currtab]['StatsOutput'] = 0

                # Check to see if we need the key name written (to the heading area)
                if keys not in self.report_saved_key[currtab]:
                    self.report_saved_key[currtab][keys] = self.report_saved_key_column[currtab]
                    self.report_saved_key_column[currtab] += 1
                    rowout2 = self.dictsheets[currtab].row( self.report_saved_key[currtab][keys] )
                    if issue_report:
                        rowout2.write(columnforreportitem+1, "{0}".format(keys), self.style_yellow)   # header
                        if tabdictionary['IssuesDetected'] == 0:   # If this is the 1st issue item, also add the header
                            tabdictionary['IssuesDetected'] = 1
                            rowout = self.dictsheets[currdict['TabName']].row( tabdictionary['RowHeader']+2 )
                            rowout.write(1,  "Issue Label", self.style_yellow)
                    else:
                        rowout2.write(columnforreportitem, "{0}".format(keys), self.style_light_green)   # header
                # End if keys not in report_saved_key

                self.report_saved_key[currtab]['StatsOutput'] += 1
                rowout = self.dictsheets[currtab].row( self.report_saved_key[currtab][keys] )
                
                if isinstance(values, str) or isinstance(values, unicode):
                    if issue_report:
                        rowout.write(currdict['ColumnIndex'], "{0}".format(values), self.style_yellow)
                    else:
                        rowout.write(currdict['ColumnIndex'], "{0}".format(values))
                else:
                    if issue_report:
                        rowout.write(currdict['ColumnIndex'], values, self.style_yellow)
                    else:
                        rowout.write(currdict['ColumnIndex'], values)
            # End if values not 0


                       
    def save_field_report(self, src_fc, reporttype,  expected_fields, intersected_fields, additional_fields):

        tabname = "FieldReport"
        if  tabname not in self.tab_names:
            self.tab_names[tabname] = self.tab_number
            self.tab_number += 1
            self.dictsheets[tabname] = self.xl.add_sheet(tabname)

            # Header and explanatory information
            rowout = self.dictsheets[tabname].row( 0 )
            rowout.write(0, "Processing Step", self.style_light_tan)
            rowout.write(1, "Source/Target Indicator", self.style_light_tan)
            rowout.write(2, "Feature Class or Table", self.style_light_tan)
            rowout.write(3, "This report provides a mapping field comparison against the database elements. It may be useful in helping to identify missing mappings and/or issues with transforms. However, lack of presence of a field is not necessarily an issue and metadata mappings typically involve a subset of the actual database content.")
            rowout = self.dictsheets[tabname].row( 1 )
            rowout.write(3, "Green shading: indicates the field is in the mapping definition and in the database", self.style_light_green)
            rowout.write(6, "Grey shading: indicates the field is in the mapping definition but is not in the database", self.style_light_grey)
            rowout.write(9, "Yellow shading: indicates the field is in the database but not in the mapping (the item may be present in a different 'case'.)", self.style_light_yellow)
        #


        rowout = self.dictsheets[tabname].row( self.fr_row_num )
        self.fr_row_num += 1
        rowout.write(0, "{0}".format(self.settings.current_step), self.style_light_tan)
        rowout.write(1, reporttype, self.style_light_tan)
        rowout.write(2, src_fc, self.style_light_tan)

        ii = 3
        for val in expected_fields:
            if ii > 250:
                rowout.write(ii, "TOO MANY FIELDS. RESULTS TRUNCATED", self.style_light_tan)
                ii += 1
                break
            if val in intersected_fields:
                rowout.write(ii, "{0}".format(val), self.style_light_green)
            else:
                rowout.write(ii, "{0}".format(val), self.style_light_grey)
            ii += 1
        #

        for val in additional_fields:
            if ii > 250:
                rowout.write(ii, "TOO MANY FIELDS. RESULTS TRUNCATED", self.style_light_tan)
                ii += 1
                break
            rowout.write(ii, "{0}".format(val), self.style_light_yellow)
            ii += 1
        #

        
    def done_save(self):
        # self.settings.my_logger.info("Saving results to {0}".format(self.results_file_name))
        self.xl.save(self.results_file_name)

    def save_settings_to_xl_report(self):
       # self.tab_names['Settings'] = 6
       # self.dictsheets['Settings'] = self.xl.add_sheet('Settings')

        tabname = "Content"

        # From self.settings report on 3 dictionaries: 
        # config_setting, maximum_records, debug_settings
        # and 2 lists:
        # debug_fc_list, debug_field_list


        cola = 2
        colaaa = 5
        colb = 10
        colbb = 8
        ii = self.starting_row_for_config_setting_report
        ### Config Settings


        rowout = self.dictsheets[tabname].row(ii )
        rowout.write(cola, "Configuration Settings (these are found in the config file and updated via the GUI)", self.style_light_green)
        ii += 1
        rowout = self.dictsheets[tabname].row(ii )
        rowout.write(cola, "Setting", self.style_light_green)
        rowout.write(colaaa, "Description", self.style_light_green)
        rowout.write(colbb, "Value Int", self.style_light_green)
        rowout.write(colb, "Value Text", self.style_light_green)
        
        ii += 1
        for keys, values in sorted(self.settings.config_setting_flag.items()):
            if keys in self.settings.procflagsgeneral:
                rowout = self.dictsheets[tabname].row(ii )
                rowout.write(cola, "{0}".format(keys))
                rowout.write(colaaa, "{0}".format(self.settings.procflagsgeneral[keys]['LabelName']))
                rowout.write(colbb, values)
                rowout.write(colb, "{0}".format(self.settings.procflagsgeneral[keys]['TextVariable'].get()))
                ii += 1
            #
        for keys, values in sorted(self.settings.config_setting_flag.items()):
            if keys in self.settings.procufiflags:
                rowout = self.dictsheets[tabname].row(ii )
                rowout.write(cola, "{0}".format(keys))
                rowout.write(colaaa, "{0}".format(self.settings.procufiflags[keys]['LabelName']))
                rowout.write(colbb, values)
                rowout.write(colb, "{0}".format(self.settings.procufiflags[keys]['TextVariable'].get()))
                ii += 1
            #
        #for keys, values in sorted(self.settings.config_setting_flag.items()):
        #    if keys in self.settings.procoperationmode:
        #        rowout = self.dictsheets[tabname].row(ii )
        #        rowout.write(cola, "{0}".format(keys))
        #        rowout.write(colaaa, "{0}".format(self.settings.procoperationmode[keys]['LabelName']))
        #        rowout.write(colbb, "{0}".format(values))
        #        rowout.write(colb, "{0}".format(self.settings.procoperationmode[keys]['TextVariable'].get()))
        #        ii += 1
            #
        for keys, values in sorted(self.settings.config_setting_flag.items()):
            if keys in self.settings.proctestflags:
                rowout = self.dictsheets[tabname].row(ii )
                rowout.write(cola, "{0}".format(keys))
                rowout.write(colaaa, "{0}".format(self.settings.proctestflags[keys]['LabelName']))
                rowout.write(colbb, values)
                rowout.write(colb, "{0}".format(self.settings.proctestflags[keys]['TextVariable'].get()))
                ii += 1
            #


        ii += 2
        ### Maximum Records

        rowout = self.dictsheets[tabname].row(ii )
        rowout.write(cola, "Maximums and Limits", self.style_light_tan)
        ii += 1
        rowout = self.dictsheets[tabname].row(ii )
        rowout.write(cola, "Setting", self.style_light_tan)
        rowout.write(colaaa, "Description", self.style_light_tan)
        rowout.write(colbb, "Value Int", self.style_light_tan)
        rowout.write(colb, "Value Text", self.style_light_tan)
        
        ii += 1
        for keys, values in sorted(self.settings.maximum_records.items()):
            if keys in self.settings.proclimitsconstraint:
                rowout = self.dictsheets[tabname].row(ii )
                rowout.write(cola, "{0}".format(keys))
                rowout.write(colaaa, "{0}".format(self.settings.proclimitsconstraint[keys]['LabelName']))
                rowout.write(colbb, values)
                rowout.write(colb, "{0}".format(self.settings.proclimitsconstraint[keys]['TextVariable'].get()))
                ii += 1

        ii += 2
        ### Debug Settings


        rowout = self.dictsheets[tabname].row(ii )
        rowout.write(cola, "Debug Settings", self.style_light_yellow)
        ii += 1
        rowout = self.dictsheets[tabname].row(ii )
        rowout.write(cola, "Setting", self.style_light_yellow)
        rowout.write(colaaa, "Description", self.style_light_yellow)
        rowout.write(colbb, "Value Int", self.style_light_yellow)
        rowout.write(colb, "Value Text", self.style_light_yellow)
        
        ii += 1
        for keys, values in sorted(self.settings.debug_settings.items()):
            if keys in self.settings.procdebugsettings:
                rowout = self.dictsheets[tabname].row(ii )
                rowout.write(cola, "{0}".format(keys))
                rowout.write(colaaa, "{0}".format(self.settings.procdebugsettings[keys]['LabelName']))
                rowout.write(colbb, values)
                rowout.write(colb, "{0}".format(self.settings.procdebugsettings[keys]['TextVariable'].get()))
                ii += 1
        ii += 1
        rowout = self.dictsheets[tabname].row(ii )
        rowout.write(cola, "Debug Feature Class List", self.style_light_grey)
        ii += 1
        for ff in self.settings.debug_fc_list:
            rowout = self.dictsheets[tabname].row(ii )
            rowout.write(colb, "{0}".format(ff))
            ii += 1
        ii +=1
        rowout = self.dictsheets[tabname].row(ii )
        rowout.write(cola, "Debug Fields", self.style_light_blue)
        ii +=1
        for ff in self.settings.debug_field_list:
            rowout = self.dictsheets[tabname].row(ii )
            rowout.write(colb, "{0}".format(ff))
            ii += 1
        self.done_save()



    def output_to_excel(self, result_type, partial, result):
        # First determine if we need to add this tab and add it and the header items
        if result_type not in self.tab_names:
            self.tab_names[result_type] = self.tab_number
            self.tab_number += 1
            self.dictsheets[result_type] = self.xl.add_sheet(result_type)
            rowout = self.dictsheets[result_type].row(0)
            ii = 0
            for k in sorted(result.keys()):
                if partial in k and " description" not in k:
                    rowout.write(ii, k, self.style_light_tan)
                    ii += 1
        
        # Next, determine if we have hit the maximum # rows in excel at which point report an error
        # via the logger
        if self.tab_names[result_type] <= 32000:
            # If we are within the max row count, output to a row in the sheet
            rowout = self.dictsheets[result_type].row( self.tab_names[result_type] )   # Get to the next row in this tab
            ii = 0

            for k in sorted(result.keys()):
                if partial in k and " description" not in k:
                    rowout.write(ii, result[k])
                    ii += 1
                # end if partial 
            # end for
            self.tab_names[result_type] += 1     # Use this to point to the next row

        elif self.max_entries_hit == False:
            self.max_entries_hit = True
            self.settings.my_logger.error("Too many error entries in tab {0}, maximum records of 32000 reached in excel file tab.", result_type)
            self.done_save()




