﻿
""" 
 ************************************************************************************************
 **                                                                                            **
 **  File: GGDM21_2_GGDM30_FeatureClassesToTranslate.py                                        **
 **  Copyright (c) May 2016 by Leidos                                                     **
 **  Produced under U.S. Government contract W5J9CQ-12-D-0004  Task Order: 053.                **
 **  As per DFARS, the U.S. Government is granted unlimited rights to use this work            **
 **  in any manner and for any purpose.                                                        **
 **                                                                                            **
 **  Summary:   This file provides the feature class list that will be translated             **
 **                 GGDM 2.1 Composite to GGDM 3.0 Composite                                    **
 **                                                                                            **
 **  Developed by Leidos, Inc., High Resolution ISR Systems Division, Geospatial Programs                                                  **
 **                                                                                            **
 **  Development History:                                                                      **
 **  May 2016 / Annette Janett Filer (Annette.J.Filer@leidos.com) Original version                                                     **               **
 **                                                                                            **
 **                                                                                            **
 ************************************************************************************************
"""


import sys
import os


from GGDM21_2_GGDM30_TranslateFeaturesandFields import *

# src, target, transformer   Do not include the Dataset or Entity Catalog feature classes as they will be done separately

#	
#	('InformationTbl','InformationTbl',InformationTblFields,None),
#	('CollectionSrf','MetadataSrf',CollectionMetadataSrfFields,'transformFC_CollectionMetadata'),
#	('MetadataTbl','MetadataTbl',MetadataTblFields,None),
# ('ConstraintTbl','ConstraintTbl',ConstraintTblFields,None),

# This is needed to get the restriction info content from Dataset
fcs_restriction_info_metadata = [
    ('DatasetSrf','RESTRICTION_INFO_T',RestrictionInfoMetaConvertSubsetFields,None),
    ]

# We need to move any existing dataset records to the target
fcs_process_dataset = [
    ('DatasetSrf', 'ResourceSrf', DatasetSrfResourceSrfFields, None)
    ]

fcs_entity_collection_metadata = [
    ('CollectionSrf', 'MetadataSrf', CollectionMetadataSrfFields, 'F_CODE IN (\'ZI040\')')
    ]

fcs_entity_collection_table = [
    ('CollectionSrf', 'ENTITY_COLLECTION_METADATA_T', CollectionMetadataSrfFields, 'F_CODE IN (\'ZI041\')')            # Non spatial MD Ent Collection goes to table
    ]

fcs = [	
	('AeronauticCrv','AeronauticCrv',AeronauticCrvFields,None),
	('AeronauticPnt','AeronauticPnt',AeronauticPntFields,None),
	('AeronauticPntExt','AeronauticPntExt',AeronauticPntExtFields,None),
	('AeronauticSrf','AeronauticSrf',AeronauticSrfFields,None),
	('AeronauticSrfExt','AeronauticSrfExt',AeronauticSrfExtFields,None),
	('AgriculturePnt','AgriculturePnt',AgriculturePntFields,None),
	('AgriculturePntExt','AgriculturePntExt',AgriculturePntExtFields,None),
	('AgricultureSrf','AgricultureSrf',AgricultureSrfFields,None),
	('BoundaryCrvExt','BoundaryCrvExt',BoundaryCrvExtFields,None),
	('BoundaryPnt','BoundaryPnt',BoundaryPntFields,None),
	('BoundarySrf','BoundarySrf',BoundarySrfFields,None),
	('BoundarySrfExt','BoundarySrfExt',BoundarySrfExtFields,None),
	('CultureCrv','CultureCrv',CultureCrvFields,None),
	('CulturePnt','CulturePnt',CulturePntFields,None),
	('CulturePntExt','CulturePntExt',CulturePntExtFields,None),
	('CultureSrf','CultureSrf',CultureSrfFields,'F_CODE NOT IN (\'AB507\')'),        # Not Waste Heap
    ('CultureSrf','IndustrySrf',CultureSrfIndustrySrfFields,'F_CODE IN (\'AB507\')'),   # Waste Heap
	('CultureSrfExt','CultureSrfExt',CultureSrfExtFields,None),
	('FacilityPnt','FacilityPnt',FacilityPntFields,None),
	('FacilitySrf','FacilitySrf',FacilitySrfFields,None),
	('HydroAidNavigationCrvExt','HydroAidNavigationCrvExt',HydroAidNavigationCrvExtFields,None),
	('HydroAidNavigationPnt','HydroAidNavigationPnt',HydroAidNavigationPntFields,None),
	('HydroAidNavigationPntExt','HydroAidNavigationPntExt',HydroAidNavigationPntExtFields,None),
	('HydroAidNavigationSrf','HydroAidNavigationSrf',HydroAidNavigationSrfFields,None),
	('HydrographyAONExt','HydrographyAONExt',HydrographyAONExtFields,None),
	('HydrographyCrv','HydrographyCrv',HydrographyCrvFields,None),
	('HydrographyCrvExt','HydrographyCrvExt',HydrographyCrvExtFields,None),
	('HydrographyPnt','HydrographyPnt',HydrographyPntFields,None),
	('HydrographyPntExt','HydrographyPntExt',HydrographyPntExtFields,None),
	('HydrographySrf','HydrographySrf',HydrographySrfFields,'F_CODE NOT IN (\'BH116\')'),           # Not Aquifer
	('HydrographySrf','SubterraneanSrf',HydrographySrfSubterraneanSrfFields,'F_CODE IN (\'BH116\')'),  # Aquifer
	('HydrographySrfExt','HydrographySrfExt',HydrographySrfExtFields,None),
	('HypsographyCrv','HypsographyCrv',HypsographyCrvFields,None),
	('HypsographyPnt','HypsographyPnt',HypsographyPntFields,None),
	('HypsographyPntExt','HypsographyPntExt',HypsographyPntExtFields,None),
	('IndustryCrv','IndustryCrv',IndustryCrvFields,None),
	('IndustryPnt','IndustryPnt',IndustryPntFields,None),
	('IndustryPntExt','IndustryPntExt',IndustryPntExtFields,None),
	('IndustrySrf','IndustrySrf',IndustrySrfFields,None),
	('InformationCrv','InformationCrv',InformationCrvFields,None),
	('InformationCrvExt','InformationCrvExt',InformationCrvExtFields,None),
	('InformationPnt','InformationPnt',InformationPntFields,None),
	('InformationSrf','InformationSrf',InformationSrfFields,None),
	('InformationSrfExt','InformationSrfExt',InformationSrfExtFields,None),
	('MilitaryCrv','MilitaryCrv',MilitaryCrvFields,None),
	('MilitaryCrvExt','MilitaryCrvExt',MilitaryCrvExtFields,None),
	('MilitaryPnt','MilitaryPnt',MilitaryPntFields,None),
	('MilitaryPntExt','MilitaryPntExt',MilitaryPntExtFields,None),
	('MilitarySrf','MilitarySrf',MilitarySrfFields,None),
	('MilitarySrfExt','MilitarySrfExt',MilitarySrfExtFields,None),
	('PhysiographyAONExt','PhysiographyAONExt',PhysiographyAONExtFields,None),
	('PhysiographyCrv','PhysiographyCrv',PhysiographyCrvFields,None),
	('PhysiographyCrvExt','PhysiographyCrvExt',PhysiographyCrvExtFields,None),
	('PhysiographyPnt','PhysiographyPnt',PhysiographyPntFields,None),
	('PhysiographyPntExt','PhysiographyPntExt',PhysiographyPntExtFields,None),
	('PhysiographySrf','PhysiographySrf',PhysiographySrfFields,'F_CODE NOT IN (\'DB028\')'),          # Not Cave Chamber
	('PhysiographySrf','SubterraneanSrf',PhysiographySrfSubterraneanSrfFields,'F_CODE IN (\'DB028\')'),  # Cave Chamber
	('PhysiographySrfExt','PhysiographySrfExt',PhysiographySrfExtFields,None),
	('PortHarbourCrv','PortHarbourCrv',PortHarbourCrvFields,None),
	('PortHarbourPnt','PortHarbourPnt',PortHarbourPntFields,None),
	('PortHarbourPntExt','PortHarbourPntExt',PortHarbourPntExtFields,None),
	('PortHarbourSrf','PortHarbourSrf',PortHarbourSrfFields,None),
	('PortHarbourSrfExt','PortHarbourSrfExt',PortHarbourSrfExtFields,None),
	('RecreationAONExt','RecreationAONExt',RecreationAONExtFields,None),
	('RecreationCrv','RecreationCrv',RecreationCrvFields,None),
	('RecreationPnt','RecreationPnt',RecreationPntFields,None),
	('RecreationSrf','RecreationSrf',RecreationSrfFields,None),
	('ReferenceTblExt','ReferenceTblExt',ReferenceTblExtFields,None),
	('ResourceTbl','ResourceTbl',ResourceTblFields,None),
	('SettlementPnt','SettlementPnt',SettlementPntFields,None),
	('SettlementSrf','SettlementSrf',SettlementSrfFields,None),
	('SettlementSrfExt','SettlementSrfExt',SettlementSrfExtFields,None),
	('StorageAONExt','StorageAONExt',StorageAONExtFields,None),
	('StoragePnt','StoragePnt',StoragePntFields,None),
	('StorageSrf','StorageSrf',StorageSrfFields,None),
	('StructureCrv','StructureCrv',StructureCrvFields,None),
	('StructurePnt','StructurePnt',StructurePntFields,None),
	('StructurePntExt','StructurePntExt',StructurePntExtFields,None),
	('StructureSrf','StructureSrf',StructureSrfFields,None),
	('TransportationGroundCrv','TransportationGroundCrv',TransportationGroundCrvFields,None),
	('TransportationGroundPnt','TransportationGroundPnt',TransportationGroundPntFields,None),
	('TransportationGroundPntExt','TransportationGroundPntExt',TransportationGroundPntExtFields,None),
	('TransportationGroundSrf','TransportationGroundSrf',TransportationGroundSrfFields,None),
	('TransportationWaterAONExt','TransportationWaterAONExt',TransportationWaterAONExtFields,None),
	('TransportationWaterCrv','TransportationWaterCrv',TransportationWaterCrvFields,None),
	('TransportationWaterPnt','TransportationWaterPnt',TransportationWaterPntFields,None),
	('TransportationWaterPntExt','TransportationWaterPntExt',TransportationWaterPntExtFields,None),
	('TransportationWaterSrf','TransportationWaterSrf',TransportationWaterSrfFields,None),
	('UtilityInfrastructureAONExt','UtilityInfrastructureAONExt',UtilityInfrastructureAONExtFields,None),
	('UtilityInfrastructureCrv','UtilityInfrastructureCrv',UtilityInfrastructureCrvFields,None),
	('UtilityInfrastructurePnt','UtilityInfrastructurePnt',UtilityInfrastructurePntFields,None),
	('UtilityInfrastructurePntExt','UtilityInfrastructurePntExt',UtilityInfrastructurePntExtFields,None),
	('UtilityInfrastructureSrf','UtilityInfrastructureSrf',UtilityInfrastructureSrfFields,None),
	('VegetationCrv','VegetationCrv',VegetationCrvFields,None),
	('VegetationPnt','VegetationPnt',VegetationPntFields,None),
	('VegetationPntExt','VegetationPntExt',VegetationPntExtFields,None),
	('VegetationSrf','VegetationSrf',VegetationSrfFields,None),
	('VegetationSrfExt','VegetationSrfExt',VegetationSrfExtFields,None)
        ]

