﻿
""" 
 ************************************************************************************************
 **                                                                                            **
 **  File: GGDM22_2_GGDM30_FeatureClassesToTranslate.py                                        **
 **  Copyright (c) June 2017 by Leidos                                                         **
 **  Produced under U.S. Government contract W5J9CQ-12-D-0004  Task Order: 062 and TO 74       **
 **  As per DFARS, the U.S. Government is granted unlimited rights to use this work            **
 **  in any manner and for any purpose.                                                        **
 **                                                                                            **
 **  Summary:   This file provides the feature class list that will be translated              **
 **                 GGDM 2.2 Composite to GGDM 3.0 Composite                                   **
 **                                                                                            **
 **  Developed by Leidos, Inc., High Resolution ISR Systems Division, Geospatial Programs      **
 **                                                                                            **
 **  Development History:                                                                      **
 **  June 2017 / Annette Janett Filer (Annette.J.Filer@leidos.com) Original version            **
 **                                                                                            **
 **                                                                                            **
 ************************************************************************************************
"""


import sys
import os


from GGDM22_2_GGDM30_TranslateFeaturesandFields import *

# src, target, transformer   Do not include the Dataset or Entity Catalog feature classes as they will be done separately

#	
#	('InformationTbl','InformationTbl',InformationTblFields,None),
#	('CollectionSrf','MetadataSrf',CollectionMetadataSrfFields,'transformFC_CollectionMetadata'),
#	('MetadataTbl','MetadataTbl',MetadataTblFields,None),
# ('ConstraintTbl','ConstraintTbl',ConstraintTblFields,None),

# This is needed to get the restriction info content from Dataset
fcs_restriction_info_metadata = [
    ('RESTRICTION_INFO_T','RESTRICTION_INFO_T',RestrictionInfoTblFields,None),
    ('DatasetSrf','RESTRICTION_INFO_T',RestrictionInfoMetaConvertSubsetFields,None),
    ]

# We need to move any existing dataset records to the target
fcs_process_dataset = [
    ('DatasetSrf', 'ResourceSrf', DatasetSrfResourceSrfFields, None)
    ]

fcs_entity_collection_metadata = [
##    ('MetadataSrf', 'MetadataSrf', EntityCollectionMetaConvertSubsetFields, None)
    ('AeronauticCrv','AeronauticCrv',EntityCollectionMetaConvertSubsetFields,None),
    ('AeronauticPnt','AeronauticPnt',EntityCollectionMetaConvertSubsetFields,None),
    ('AeronauticPntExt','AeronauticPntExt',EntityCollectionMetaConvertSubsetFields,None),
    ('AeronauticSrf','AeronauticSrf',EntityCollectionMetaConvertSubsetFields,None),
    ('AeronauticSrfExt','AeronauticSrfExt',EntityCollectionMetaConvertSubsetFields,None),
    ('AgriculturePnt','AgriculturePnt',EntityCollectionMetaConvertSubsetFields,None),
    ('AgriculturePntExt','AgriculturePntExt',EntityCollectionMetaConvertSubsetFields,None),
    ('AgricultureSrf','AgricultureSrf',EntityCollectionMetaConvertSubsetFields,None),
 #   ('AssociationTbl','None',EntityCollectionMetaConvertSubsetFields,None),
    ('BoundaryCrvExt','BoundaryCrvExt',EntityCollectionMetaConvertSubsetFields,None),
    ('BoundaryPnt','BoundaryPnt',EntityCollectionMetaConvertSubsetFields,None),
    ('BoundarySrf','BoundarySrf',EntityCollectionMetaConvertSubsetFields,None),
    ('BoundarySrfExt','BoundarySrfExt',EntityCollectionMetaConvertSubsetFields,None),
 #   ('ConstraintTbl','ConstraintTbl',EntityCollectionMetaConvertSubsetFields,None),
    ('CultureCrv','CultureCrv',EntityCollectionMetaConvertSubsetFields,None),
    ('CulturePnt','CulturePnt',EntityCollectionMetaConvertSubsetFields,None),
    ('CulturePntExt','CulturePntExt',EntityCollectionMetaConvertSubsetFields,None),
    ('CultureSrf','CultureSrf',EntityCollectionMetaConvertSubsetFields,None),
    ('CultureSrfExt','CultureSrfExt',EntityCollectionMetaConvertSubsetFields,None),
    ('FacilityPnt','FacilityPnt',EntityCollectionMetaConvertSubsetFields,None),
    ('FacilitySrf','FacilitySrf',EntityCollectionMetaConvertSubsetFields,None),
    ('HydroAidNavigationCrvExt','HydroAidNavigationCrvExt',EntityCollectionMetaConvertSubsetFields,None),
    ('HydroAidNavigationPnt','HydroAidNavigationPnt',EntityCollectionMetaConvertSubsetFields,None),
    ('HydroAidNavigationPntExt','HydroAidNavigationPntExt',EntityCollectionMetaConvertSubsetFields,None),
    ('HydroAidNavigationSrf','HydroAidNavigationSrf',EntityCollectionMetaConvertSubsetFields,None),
    ('HydrographyAONExt','HydrographyAONExt',EntityCollectionMetaConvertSubsetFields,None),
    ('HydrographyCrv','HydrographyCrv',EntityCollectionMetaConvertSubsetFields,None),
    ('HydrographyCrvExt','HydrographyCrvExt',EntityCollectionMetaConvertSubsetFields,None),
    ('HydrographyPnt','HydrographyPnt',EntityCollectionMetaConvertSubsetFields,None),
    ('HydrographyPntExt','HydrographyPntExt',EntityCollectionMetaConvertSubsetFields,None),
    ('HydrographySrf','HydrographySrf',EntityCollectionMetaConvertSubsetFields,None),
    ('HydrographySrfExt','HydrographySrfExt',EntityCollectionMetaConvertSubsetFields,None),
    ('HypsographyCrv','HypsographyCrv',EntityCollectionMetaConvertSubsetFields,None),
    ('HypsographyPnt','HypsographyPnt',EntityCollectionMetaConvertSubsetFields,None),
    ('HypsographyPntExt','HypsographyPntExt',EntityCollectionMetaConvertSubsetFields,None),
    ('IndustryCrv','IndustryCrv',EntityCollectionMetaConvertSubsetFields,None),
    ('IndustryPnt','IndustryPnt',EntityCollectionMetaConvertSubsetFields,None),
    ('IndustryPntExt','IndustryPntExt',EntityCollectionMetaConvertSubsetFields,None),
    ('IndustrySrf','IndustrySrf',EntityCollectionMetaConvertSubsetFields,None),
    ('InformationCrv','InformationCrv',EntityCollectionMetaConvertSubsetFields,None),
    ('InformationCrvExt','InformationCrvExt',EntityCollectionMetaConvertSubsetFields,None),
    ('InformationPnt','InformationPnt',EntityCollectionMetaConvertSubsetFields,None),
    ('InformationSrf','InformationSrf',EntityCollectionMetaConvertSubsetFields,None),
    ('InformationSrfExt','InformationSrfExt',EntityCollectionMetaConvertSubsetFields,None),
 #   ('MetadataSrf','MetadataSrf',EntityCollectionMetaConvertSubsetFields,None),
 #   ('MetadataTbl','MetadataTbl',EntityCollectionMetaConvertSubsetFields,None),
    ('MilitaryCrv','MilitaryCrv',EntityCollectionMetaConvertSubsetFields,None),
    ('MilitaryCrvExt','MilitaryCrvExt',EntityCollectionMetaConvertSubsetFields,None),
    ('MilitaryPnt','MilitaryPnt',EntityCollectionMetaConvertSubsetFields,None),
    ('MilitaryPntExt','MilitaryPntExt',EntityCollectionMetaConvertSubsetFields,None),
    ('MilitarySrf','MilitarySrf',EntityCollectionMetaConvertSubsetFields,None),
    ('MilitarySrfExt','MilitarySrfExt',EntityCollectionMetaConvertSubsetFields,None),
    ('PhysiographyAONExt','PhysiographyAONExt',EntityCollectionMetaConvertSubsetFields,None),
    ('PhysiographyCrv','PhysiographyCrv',EntityCollectionMetaConvertSubsetFields,None),
    ('PhysiographyCrvExt','PhysiographyCrvExt',EntityCollectionMetaConvertSubsetFields,None),
    ('PhysiographyPnt','PhysiographyPnt',EntityCollectionMetaConvertSubsetFields,None),
    ('PhysiographyPntExt','PhysiographyPntExt',EntityCollectionMetaConvertSubsetFields,None),
    ('PhysiographySrf','PhysiographySrf',EntityCollectionMetaConvertSubsetFields,None),
    ('PhysiographySrfExt','PhysiographySrfExt',EntityCollectionMetaConvertSubsetFields,None),
    ('PortHarbourCrv','PortHarbourCrv',EntityCollectionMetaConvertSubsetFields,None),
    ('PortHarbourPnt','PortHarbourPnt',EntityCollectionMetaConvertSubsetFields,None),
    ('PortHarbourPntExt','PortHarbourPntExt',EntityCollectionMetaConvertSubsetFields,None),
    ('PortHarbourSrf','PortHarbourSrf',EntityCollectionMetaConvertSubsetFields,None),
    ('PortHarbourSrfExt','PortHarbourSrfExt',EntityCollectionMetaConvertSubsetFields,None),
    ('RecreationAONExt','RecreationAONExt',EntityCollectionMetaConvertSubsetFields,None),
    ('RecreationCrv','RecreationCrv',EntityCollectionMetaConvertSubsetFields,None),
    ('RecreationPnt','RecreationPnt',EntityCollectionMetaConvertSubsetFields,None),
    ('RecreationSrf','RecreationSrf',EntityCollectionMetaConvertSubsetFields,None),
  #  ('ReferenceTblExt','ReferenceTblExt',EntityCollectionMetaConvertSubsetFields,None),
 #   ('ResourceSrf','ResourceSrf',EntityCollectionMetaConvertSubsetFields,None),
 #   ('ResourceTbl','ResourceTbl',EntityCollectionMetaConvertSubsetFields,None),
    ('SettlementPnt','SettlementPnt',EntityCollectionMetaConvertSubsetFields,None),
    ('SettlementSrf','SettlementSrf',EntityCollectionMetaConvertSubsetFields,None),
    ('SettlementSrfExt','SettlementSrfExt',EntityCollectionMetaConvertSubsetFields,None),
    ('StorageAONExt','StorageAONExt',EntityCollectionMetaConvertSubsetFields,None),
    ('StoragePnt','StoragePnt',EntityCollectionMetaConvertSubsetFields,None),
    ('StorageSrf','StorageSrf',EntityCollectionMetaConvertSubsetFields,None),
    ('StructureCrv','StructureCrv',EntityCollectionMetaConvertSubsetFields,None),
    ('StructurePnt','StructurePnt',EntityCollectionMetaConvertSubsetFields,None),
    ('StructurePntExt','StructurePntExt',EntityCollectionMetaConvertSubsetFields,None),
    ('StructureSrf','StructureSrf',EntityCollectionMetaConvertSubsetFields,None),
    ('SubterraneanSrf','SubterraneanSrf',EntityCollectionMetaConvertSubsetFields,None),
    ('TransportationGroundCrv','TransportationGroundCrv',EntityCollectionMetaConvertSubsetFields,None),
    ('TransportationGroundPnt','TransportationGroundPnt',EntityCollectionMetaConvertSubsetFields,None),
    ('TransportationGroundPntExt','TransportationGroundPntExt',EntityCollectionMetaConvertSubsetFields,None),
    ('TransportationGroundSrf','TransportationGroundSrf',EntityCollectionMetaConvertSubsetFields,None),
    ('TransportationWaterAONExt','TransportationWaterAONExt',EntityCollectionMetaConvertSubsetFields,None),
    ('TransportationWaterCrv','TransportationWaterCrv',EntityCollectionMetaConvertSubsetFields,None),
    ('TransportationWaterPnt','TransportationWaterPnt',EntityCollectionMetaConvertSubsetFields,None),
    ('TransportationWaterPntExt','TransportationWaterPntExt',EntityCollectionMetaConvertSubsetFields,None),
    ('TransportationWaterSrf','TransportationWaterSrf',EntityCollectionMetaConvertSubsetFields,None),
    ('UtilityInfrastructureAONExt','UtilityInfrastructureAONExt',EntityCollectionMetaConvertSubsetFields,None),
    ('UtilityInfrastructureCrv','UtilityInfrastructureCrv',EntityCollectionMetaConvertSubsetFields,None),
    ('UtilityInfrastructurePnt','UtilityInfrastructurePnt',EntityCollectionMetaConvertSubsetFields,None),
    ('UtilityInfrastructurePntExt','UtilityInfrastructurePntExt',EntityCollectionMetaConvertSubsetFields,None),
    ('UtilityInfrastructureSrf','UtilityInfrastructureSrf',EntityCollectionMetaConvertSubsetFields,None),
    ('VegetationCrv','VegetationCrv',EntityCollectionMetaConvertSubsetFields,None),
    ('VegetationPnt','VegetationPnt',EntityCollectionMetaConvertSubsetFields,None),
    ('VegetationPntExt','VegetationPntExt',EntityCollectionMetaConvertSubsetFields,None),
    ('VegetationSrf','VegetationSrf',EntityCollectionMetaConvertSubsetFields,None),
    ('VegetationSrfExt','VegetationSrfExt',EntityCollectionMetaConvertSubsetFields,None)
    ]

fcs_entity_collection_table = [
    ('MetadataSrf', 'ENTITY_COLLECTION_METADATA_T', CollectionMetadataSrfFields, None)            
    ]

# We need to move any existing entity collection records and dataset records to the target
fcs_process_entity_collection_and_dataset = [
    ('MetadataSrf', 'MetadataSrf', MetadataSrfFields, None),
    ('ResourceSrf', 'ResourceSrf', DatasetSrfResourceSrfFields, None)
    ]


fcs = [	
    ('AeronauticCrv','AeronauticCrv',AeronauticCrvFields,None),
    ('AeronauticPnt','AeronauticPnt',AeronauticPntFields,None),
    ('AeronauticPntExt','AeronauticPntExt',AeronauticPntExtFields,None),
    ('AeronauticSrf','AeronauticSrf',AeronauticSrfFields,None),
    ('AeronauticSrfExt','AeronauticSrfExt',AeronauticSrfExtFields,None),
    ('AgriculturePnt','AgriculturePnt',AgriculturePntFields,None),
    ('AgriculturePntExt','AgriculturePntExt',AgriculturePntExtFields,None),
    ('AgricultureSrf','AgricultureSrf',AgricultureSrfFields,None),
 #   ('AssociationTbl','None',AssociationTblFields,None),
    ('BoundaryCrvExt','BoundaryCrvExt',BoundaryCrvExtFields,None),
    ('BoundaryPnt','BoundaryPnt',BoundaryPntFields,None),
    ('BoundarySrf','BoundarySrf',BoundarySrfFields,None),
    ('BoundarySrfExt','BoundarySrfExt',BoundarySrfExtFields,None),
 #   ('ConstraintTbl','ConstraintTbl',ConstraintTblFields,None),
    ('CultureCrv','CultureCrv',CultureCrvFields,None),
    ('CulturePnt','CulturePnt',CulturePntFields,None),
    ('CulturePntExt','CulturePntExt',CulturePntExtFields,None),
    ('CultureSrf','CultureSrf',CultureSrfFields,None),
    ('CultureSrfExt','CultureSrfExt',CultureSrfExtFields,None),
    ('FacilityPnt','FacilityPnt',FacilityPntFields,None),
    ('FacilitySrf','FacilitySrf',FacilitySrfFields,None),
    ('HydroAidNavigationCrvExt','HydroAidNavigationCrvExt',HydroAidNavigationCrvExtFields,None),
    ('HydroAidNavigationPnt','HydroAidNavigationPnt',HydroAidNavigationPntFields,None),
    ('HydroAidNavigationPntExt','HydroAidNavigationPntExt',HydroAidNavigationPntExtFields,None),
    ('HydroAidNavigationSrf','HydroAidNavigationSrf',HydroAidNavigationSrfFields,None),
    ('HydrographyAONExt','HydrographyAONExt',HydrographyAONExtFields,None),
    ('HydrographyCrv','HydrographyCrv',HydrographyCrvFields,None),
    ('HydrographyCrvExt','HydrographyCrvExt',HydrographyCrvExtFields,None),
    ('HydrographyPnt','HydrographyPnt',HydrographyPntFields,None),
    ('HydrographyPntExt','HydrographyPntExt',HydrographyPntExtFields,None),
    ('HydrographySrf','HydrographySrf',HydrographySrfFields,None),
 #   ('HydrographySrf','HydrographyAONExt',HydrographyAONExtFields,None),   # For the special case WRDB 2.2 versions
    ('HydrographySrfExt','HydrographySrfExt',HydrographySrfExtFields,None),
    ('HypsographyCrv','HypsographyCrv',HypsographyCrvFields,None),
    ('HypsographyPnt','HypsographyPnt',HypsographyPntFields,None),
    ('HypsographyPntExt','HypsographyPntExt',HypsographyPntExtFields,None),
    ('IndustryCrv','IndustryCrv',IndustryCrvFields,None),
    ('IndustryPnt','IndustryPnt',IndustryPntFields,None),
    ('IndustryPntExt','IndustryPntExt',IndustryPntExtFields,None),
    ('IndustrySrf','IndustrySrf',IndustrySrfFields,None),
    ('InformationCrv','InformationCrv',InformationCrvFields,None),
    ('InformationCrvExt','InformationCrvExt',InformationCrvExtFields,None),
    ('InformationPnt','InformationPnt',InformationPntFields,None),
    ('InformationSrf','InformationSrf',InformationSrfFields,None),
    ('InformationSrfExt','InformationSrfExt',InformationSrfExtFields,None),
 #   ('MetadataSrf','MetadataSrf',MetadataSrfFields,None),
 #   ('MetadataTbl','MetadataTbl',MetadataTblFields,None),
    ('MilitaryCrv','MilitaryCrv',MilitaryCrvFields,None),
    ('MilitaryCrvExt','MilitaryCrvExt',MilitaryCrvExtFields,None),
    ('MilitaryPnt','MilitaryPnt',MilitaryPntFields,None),
    ('MilitaryPntExt','MilitaryPntExt',MilitaryPntExtFields,None),
    ('MilitarySrf','MilitarySrf',MilitarySrfFields,None),
    ('MilitarySrfExt','MilitarySrfExt',MilitarySrfExtFields,None),
    ('PhysiographyAONExt','PhysiographyAONExt',PhysiographyAONExtFields,None),
    ('PhysiographyCrv','PhysiographyCrv',PhysiographyCrvFields,None),
    ('PhysiographyCrvExt','PhysiographyCrvExt',PhysiographyCrvExtFields,None),
    ('PhysiographyPnt','PhysiographyPnt',PhysiographyPntFields,None),
    ('PhysiographyPntExt','PhysiographyPntExt',PhysiographyPntExtFields,None),
    ('PhysiographySrf','PhysiographySrf',PhysiographySrfFields,None),
#    ('PhysiographySrf','PhysiographyAONExt',PhysiographyAONExtFields,None),          # for the special WRDB 2.2
    ('PhysiographySrfExt','PhysiographySrfExt',PhysiographySrfExtFields,None),
    ('PortHarbourCrv','PortHarbourCrv',PortHarbourCrvFields,None),
    ('PortHarbourPnt','PortHarbourPnt',PortHarbourPntFields,None),
    ('PortHarbourPntExt','PortHarbourPntExt',PortHarbourPntExtFields,None),
    ('PortHarbourSrf','PortHarbourSrf',PortHarbourSrfFields,None),
    ('PortHarbourSrfExt','PortHarbourSrfExt',PortHarbourSrfExtFields,None),
    ('RecreationAONExt','RecreationAONExt',RecreationAONExtFields,None),
    ('RecreationCrv','RecreationCrv',RecreationCrvFields,None),
    ('RecreationPnt','RecreationPnt',RecreationPntFields,None),
    ('RecreationSrf','RecreationSrf',RecreationSrfFields,None),
 #   ('RecreationSrf','RecreationAONExt',RecreationAONExtFields,None),      # for the special WRDB 2.2
  #  ('ReferenceTblExt','ReferenceTblExt',ReferenceTblExtFields,None),
 #   ('ResourceSrf','ResourceSrf',ResourceSrfFields,None),
 #   ('ResourceTbl','ResourceTbl',ResourceTblFields,None),
    ('SettlementPnt','SettlementPnt',SettlementPntFields,None),
    ('SettlementSrf','SettlementSrf',SettlementSrfFields,None),
    ('SettlementSrfExt','SettlementSrfExt',SettlementSrfExtFields,None),
    ('StorageAONExt','StorageAONExt',StorageAONExtFields,None),
    ('StoragePnt','StoragePnt',StoragePntFields,None),
    ('StorageSrf','StorageSrf',StorageSrfFields,None),
 #   ('StorageSrf','StorageAONExt',StorageAONExtFields,None),          # for the special WRDB 2.2
    ('StructureCrv','StructureCrv',StructureCrvFields,None),
    ('StructurePnt','StructurePnt',StructurePntFields,None),
    ('StructurePntExt','StructurePntExt',StructurePntExtFields,None),
    ('StructureSrf','StructureSrf',StructureSrfFields,None),
    ('SubterraneanSrf','SubterraneanSrf',SubterraneanSrfFields,None),
    ('TransportationGroundCrv','TransportationGroundCrv',TransportationGroundCrvFields,None),
    ('TransportationGroundPnt','TransportationGroundPnt',TransportationGroundPntFields,None),
    ('TransportationGroundPntExt','TransportationGroundPntExt',TransportationGroundPntExtFields,None),
    ('TransportationGroundSrf','TransportationGroundSrf',TransportationGroundSrfFields,None),
    ('TransportationWaterAONExt','TransportationWaterAONExt',TransportationWaterAONExtFields,None),
    ('TransportationWaterCrv','TransportationWaterCrv',TransportationWaterCrvFields,None),
    ('TransportationWaterPnt','TransportationWaterPnt',TransportationWaterPntFields,None),
    ('TransportationWaterPntExt','TransportationWaterPntExt',TransportationWaterPntExtFields,None),
    ('TransportationWaterSrf','TransportationWaterSrf',TransportationWaterSrfFields,None),
 #   ('TransportationWaterSrf','TransportationWaterAONExt',TransportationWaterAONExtFields,None),       # for the special WRDB 2.2
    ('UtilityInfrastructureAONExt','UtilityInfrastructureAONExt',UtilityInfrastructureAONExtFields,None),
    ('UtilityInfrastructureCrv','UtilityInfrastructureCrv',UtilityInfrastructureCrvFields,None),
    ('UtilityInfrastructurePnt','UtilityInfrastructurePnt',UtilityInfrastructurePntFields,None),
    ('UtilityInfrastructurePntExt','UtilityInfrastructurePntExt',UtilityInfrastructurePntExtFields,None),
    ('UtilityInfrastructureSrf','UtilityInfrastructureSrf',UtilityInfrastructureSrfFields,None),
  #  ('UtilityInfrastructureSrf','UtilityInfrastructureAONExt',UtilityInfrastructureAONExtFields,None),        # for the special WRDB 2.2
    ('VegetationCrv','VegetationCrv',VegetationCrvFields,None),
    ('VegetationPnt','VegetationPnt',VegetationPntFields,None),
    ('VegetationPntExt','VegetationPntExt',VegetationPntExtFields,None),
    ('VegetationSrf','VegetationSrf',VegetationSrfFields,None),
    ('VegetationSrfExt','VegetationSrfExt',VegetationSrfExtFields,None)
        ]

