﻿
""" 
 ************************************************************************************************
 **                                                                                            **
 **  File: GGDM30_2_GGDM22_FeatureClassesToTranslate.py                                        **
 **  Copyright (c) June 2017 by Leidos                                                         **
 **  Produced under U.S. Government contract W5J9CQ-12-D-0004  Task Order: 062 and TO 074      **
 **  As per DFARS, the U.S. Government is granted unlimited rights to use this work            **
 **  in any manner and for any purpose.                                                        **
 **                                                                                            **
 **  Summary:   This file provides the feature class list that will be translated              **
 **                 GGDM 3.0 Composite to GGDM 2.2 Composite                                   **
 **                                                                                            **
 **  Developed by Leidos, Inc., High Resolution ISR Systems Division, Geospatial Programs       **
 **                                                                                            **
 **  Development History:                                                                      **
 **  June 2017 / Annette Janett Filer (Annette.J.Filer@leidos.com) Original version            **
 **                                                                                            **
 **                                                                                            **
 ************************************************************************************************
"""


import sys
import os


from GGDM30_2_GGDM22_TranslateFeaturesandFields import *

# GGDM 3.0 has tables: DATASET_T, ENTITY_COLLECTION_METADATA_T, RESTRICTION_INFO_T

#	('ConstraintTbl','None',NoneFields,None),
#	('ReferenceTblExt','None',NoneFields,None),
#	('ResourceSrf','DatasetSrf',DatasetSrfFields,None),
#	('ResourceTbl','None',NoneFields,None),
#	('MetadataSrf','CollectionSrf',CollectionSrfFields,None),
#	('MetadataTbl','None',NoneFields,None),

# GGDM 2.1 has only InformationTbl. And none of InformationTbl is in GGDM 3.0
# So we need to put ENTITY_COLLECTION_METADATA_T into CollectionSrf ZI040 and ZI041
# DATASET_T into DatasetSrf / DATASET_S
fcs_restriction_info_metadata = [
    ('ResourceSrf','ResourceSrf',RestrictionInfoMetaConvertSubsetFields,None),
    ]

fcs_restriction_info_metadata_table = [
    ('RESTRICTION_INFO_T','ResourceSrf',RestrictionInfoMetaConvertSubsetFields,None),
    ]

# We need to move any existing entity collection records and dataset records to the target
fcs_process_dataset_FC = [
    ('ResourceSrf', 'ResourceSrf', ResourceSrfDatasetSrfFields, None)
    ]

fcs_process_dataset_Table = [
    ('DATASET_T', 'ResourceSrf', ResourceTblDatasetSrfFields, None)
    ]

fcs_entity_collection_metadata = [
    ('MetadataSrf', 'MetadataSrf', MetadataSrfCollectionSrfFields, None)
    ]

fcs_entity_collection_metadataFC = [
    ('MetadataSrf', 'MetadataSrf', MetadataSrfCollectionSrfFields, None)
    ]
fcs_entity_collection_metadataTable = [
    ('ENTITY_COLLECTION_METADATA_T', 'MetadataSrf', MetadataTblCollectionSrfFields, None)
    ]

# this next set is not used now, we can't do anything about these dataset fields on each feature
fcs_process_for_dataset = [
    ]
	

fcs_process_for_EC = [
    ]

# src, target, transformer   Do not include the Dataset or Entity Catalog feature classes as they will be done separately
fcs = [	
    ('AeronauticCrv','AeronauticCrv',AeronauticCrvFields,None),
    ('AeronauticPnt','AeronauticPnt',AeronauticPntFields,None),
    ('AeronauticPntExt','AeronauticPntExt',AeronauticPntExtFields,None),
    ('AeronauticSrf','AeronauticSrf',AeronauticSrfFields,None),
    ('AeronauticSrfExt','AeronauticSrfExt',AeronauticSrfExtFields,None),
    ('AgriculturePnt','AgriculturePnt',AgriculturePntFields,None),
    ('AgriculturePntExt','AgriculturePntExt',AgriculturePntExtFields,None),
    ('AgricultureSrf','AgricultureSrf',AgricultureSrfFields,None),
  #  ('AssociationTbl','AssociationTbl',AssociationTblFields,None),
    ('BoundaryCrvExt','BoundaryCrvExt',BoundaryCrvExtFields,None),
    ('BoundaryPnt','BoundaryPnt',BoundaryPntFields,None),
    ('BoundarySrf','BoundarySrf',BoundarySrfFields,None),
    ('BoundarySrfExt','BoundarySrfExt',BoundarySrfExtFields,None),
  #  ('ConstraintTbl','ConstraintTbl',ConstraintTblFields,None),
    ('CultureCrv','CultureCrv',CultureCrvFields,None),
    ('CulturePnt','CulturePnt',CulturePntFields,None),
    ('CulturePntExt','CulturePntExt',CulturePntExtFields,None),
    ('CultureSrf','CultureSrf',CultureSrfFields,None),
    ('CultureSrfExt','CultureSrfExt',CultureSrfExtFields,None),
    ('FacilityPnt','FacilityPnt',FacilityPntFields,None),
    ('FacilitySrf','FacilitySrf',FacilitySrfFields,None),
    ('HydroAidNavigationCrvExt','HydroAidNavigationCrvExt',HydroAidNavigationCrvExtFields,None),
    ('HydroAidNavigationPnt','HydroAidNavigationPnt',HydroAidNavigationPntFields,None),
    ('HydroAidNavigationPntExt','HydroAidNavigationPntExt',HydroAidNavigationPntExtFields,None),
    ('HydroAidNavigationSrf','HydroAidNavigationSrf',HydroAidNavigationSrfFields,None),
    ('HydrographyAONExt','HydrographyAONExt',HydrographyAONExtFields,None),
    ('HydrographyCrv','HydrographyCrv',HydrographyCrvFields,None),
    ('HydrographyCrvExt','HydrographyCrvExt',HydrographyCrvExtFields,None),
    ('HydrographyPnt','HydrographyPnt',HydrographyPntFields,None),
    ('HydrographyPntExt','HydrographyPntExt',HydrographyPntExtFields,None),
    ('HydrographySrf','HydrographySrf',HydrographySrfFields,None),
    ('HydrographySrfExt','HydrographySrfExt',HydrographySrfExtFields,None),
    ('HypsographyCrv','HypsographyCrv',HypsographyCrvFields,None),
    ('HypsographyPnt','HypsographyPnt',HypsographyPntFields,None),
    ('HypsographyPntExt','HypsographyPntExt',HypsographyPntExtFields,None),
    ('IndustryCrv','IndustryCrv',IndustryCrvFields,None),
    ('IndustryPnt','IndustryPnt',IndustryPntFields,None),
    ('IndustryPntExt','IndustryPntExt',IndustryPntExtFields,None),
    ('IndustrySrf','IndustrySrf',IndustrySrfFields,None),
    ('InformationCrv','InformationCrv',InformationCrvFields,None),
    ('InformationCrvExt','InformationCrvExt',InformationCrvExtFields,None),
    ('InformationPnt','InformationPnt',InformationPntFields,None),
    ('InformationSrf','InformationSrf',InformationSrfFields,None),
    ('InformationSrfExt','InformationSrfExt',InformationSrfExtFields,None),
   # ('MetadataSrf','MetadataSrf',MetadataSrfFields,None),
  #  ('MetadataTbl','MetadataTbl',MetadataTblFields,None),
    ('MilitaryCrv','MilitaryCrv',MilitaryCrvFields,None),
    ('MilitaryCrvExt','MilitaryCrvExt',MilitaryCrvExtFields,None),
    ('MilitaryPnt','MilitaryPnt',MilitaryPntFields,None),
    ('MilitaryPntExt','MilitaryPntExt',MilitaryPntExtFields,None),
    ('MilitarySrf','MilitarySrf',MilitarySrfFields,None),
    ('MilitarySrfExt','MilitarySrfExt',MilitarySrfExtFields,None),
    ('PhysiographyAONExt','PhysiographyAONExt',PhysiographyAONExtFields,None),
    ('PhysiographyCrv','PhysiographyCrv',PhysiographyCrvFields,None),
    ('PhysiographyCrvExt','PhysiographyCrvExt',PhysiographyCrvExtFields,None),
    ('PhysiographyPnt','PhysiographyPnt',PhysiographyPntFields,None),
    ('PhysiographyPntExt','PhysiographyPntExt',PhysiographyPntExtFields,None),
    ('PhysiographySrf','PhysiographySrf',PhysiographySrfFields,None),
    ('PhysiographySrfExt','PhysiographySrfExt',PhysiographySrfExtFields,None),
    ('PortHarbourCrv','PortHarbourCrv',PortHarbourCrvFields,None),
    ('PortHarbourPnt','PortHarbourPnt',PortHarbourPntFields,None),
    ('PortHarbourPntExt','PortHarbourPntExt',PortHarbourPntExtFields,None),
    ('PortHarbourSrf','PortHarbourSrf',PortHarbourSrfFields,None),
    ('PortHarbourSrfExt','PortHarbourSrfExt',PortHarbourSrfExtFields,None),
    ('RecreationAONExt','RecreationAONExt',RecreationAONExtFields,None),
    ('RecreationCrv','RecreationCrv',RecreationCrvFields,None),
    ('RecreationPnt','RecreationPnt',RecreationPntFields,None),
    ('RecreationSrf','RecreationSrf',RecreationSrfFields,None),
 #   ('ReferenceTblExt','ReferenceTblExt',ReferenceTblExtFields,None),
 #   ('ResourceSrf','ResourceSrf',ResourceSrfFields,None),
 #   ('ResourceTbl','ResourceTbl',ResourceTblFields,None),
    ('SettlementPnt','SettlementPnt',SettlementPntFields,None),
    ('SettlementSrf','SettlementSrf',SettlementSrfFields,None),
    ('SettlementSrfExt','SettlementSrfExt',SettlementSrfExtFields,None),
    ('StorageAONExt','StorageAONExt',StorageAONExtFields,None),
    ('StoragePnt','StoragePnt',StoragePntFields,None),
    ('StorageSrf','StorageSrf',StorageSrfFields,None),
    ('StructureCrv','StructureCrv',StructureCrvFields,None),
    ('StructurePnt','StructurePnt',StructurePntFields,None),
    ('StructurePntExt','StructurePntExt',StructurePntExtFields,None),
    ('StructureSrf','StructureSrf',StructureSrfFields,None),
    ('SubterraneanSrf','SubterraneanSrf',SubterraneanSrfFields,None),
    ('TransportationGroundCrv','TransportationGroundCrv',TransportationGroundCrvFields,None),
    ('TransportationGroundPnt','TransportationGroundPnt',TransportationGroundPntFields,None),
    ('TransportationGroundPntExt','TransportationGroundPntExt',TransportationGroundPntExtFields,None),
    ('TransportationGroundSrf','TransportationGroundSrf',TransportationGroundSrfFields,None),
    ('TransportationWaterAONExt','TransportationWaterAONExt',TransportationWaterAONExtFields,None),
    ('TransportationWaterCrv','TransportationWaterCrv',TransportationWaterCrvFields,None),
    ('TransportationWaterPnt','TransportationWaterPnt',TransportationWaterPntFields,None),
    ('TransportationWaterPntExt','TransportationWaterPntExt',TransportationWaterPntExtFields,None),
    ('TransportationWaterSrf','TransportationWaterSrf',TransportationWaterSrfFields,None),
    ('UtilityInfrastructureAONExt','UtilityInfrastructureAONExt',UtilityInfrastructureAONExtFields,None),
    ('UtilityInfrastructureCrv','UtilityInfrastructureCrv',UtilityInfrastructureCrvFields,None),
    ('UtilityInfrastructurePnt','UtilityInfrastructurePnt',UtilityInfrastructurePntFields,None),
    ('UtilityInfrastructurePntExt','UtilityInfrastructurePntExt',UtilityInfrastructurePntExtFields,None),
    ('UtilityInfrastructureSrf','UtilityInfrastructureSrf',UtilityInfrastructureSrfFields,None),
    ('VegetationCrv','VegetationCrv',VegetationCrvFields,None),
    ('VegetationPnt','VegetationPnt',VegetationPntFields,None),
    ('VegetationPntExt','VegetationPntExt',VegetationPntExtFields,None),
    ('VegetationSrf','VegetationSrf',VegetationSrfFields,None),
    ('VegetationSrfExt','VegetationSrfExt',VegetationSrfExtFields,None)
        ]

