﻿
""" 
 ************************************************************************************************
 **                                                                                            **
 **  File: GGDM30_2_TDS4_FeatureClassesToTranslate.py                                        **
 **  Copyright (c) May 2016 by Leidos                                                     **
 **  Produced under U.S. Government contract W5J9CQ-12-D-0004  Task Order: 053.                **
 **  As per DFARS, the U.S. Government is granted unlimited rights to use this work            **
 **  in any manner and for any purpose.                                                        **
 **                                                                                            **
 **  Summary:   This file provides the feature class list that will be translated             **
 **                 GGDM 3.0 Composite to TDS 4.0 Composite                                    **
 **                                                                                            **
 **  Developed by Leidos, Inc., High Resolution ISR Systems Division, Geospatial Programs                                                  **
 **                                                                                            **
 **  Development History:                                                                      **
 **  May 2016 / Annette Janett Filer (Annette.J.Filer@leidos.com) Original version                                                     **               **
 **                                                                                            **
 **                                                                                            **
 ************************************************************************************************
"""


import sys
import os


from GGDM30_2_TDS4_TranslateFeaturesandFields import *

fcs_restriction_info_metadata = [
    ('ResourceSrf','DatasetSrf',RestrictionInfoMetaConvertSubsetFields,None),
    ]

fcs_restriction_info_metadata_table = [
    ('RESTRICTION_INFO_T','DatasetSrf',RestrictionInfoMetaConvertSubsetFields,None),
    ]

# We need to move any existing entity collection records and dataset records to the target
fcs_process_dataset_FC = [
    ('ResourceSrf', 'DatasetSrf', ResourceSrfDatasetSrfFields, None)
    ]

fcs_process_dataset_Table = [
    ('DATASET_T', 'DatasetSrf', ResourceTblDatasetSrfFields, None)
    ]

fcs_entity_collection_metadata = [
    ('MetadataSrf', 'CollectionSrf', MetadataSrfCollectionSrfFields, None)
    ]

fcs_entity_collection_metadataFC = [
    ('MetadataSrf', 'CollectionSrf', MetadataSrfCollectionSrfFields, None)
    ]
fcs_entity_collection_metadataTable = [
    ('ENTITY_COLLECTION_METADATA_T', 'CollectionSrf', MetadataTblCollectionSrfFields, None)
    ]

# this next set is not used now, we can't do anything about these dataset fields on each feature
fcs_process_for_dataset = [
    ('AeronauticCrv','AeronauticCrv',GetDatasetFields,None),
    ('AeronauticPnt','AeronauticPnt',GetDatasetFields,None),
    ('AeronauticPntExt','AeronauticPntExt',GetDatasetFields,None),
    ('AeronauticSrf','AeronauticSrf',GetDatasetFields,None),
    ('AeronauticSrfExt','AeronauticSrfExt',GetDatasetFields,None),
    ('AgriculturePnt','AgriculturePnt',GetDatasetFields,None),
    ('AgriculturePntExt','AgriculturePntExt',GetDatasetFields,None),
    ('AgricultureSrf','AgricultureSrf',GetDatasetFields,None),
    ('BoundaryCrvExt','BoundaryCrvExt',GetDatasetFields,None),
    ('BoundaryPnt','BoundaryPnt',GetDatasetFields,None),
    ('BoundarySrf','BoundarySrf',GetDatasetFields,None),
    ('BoundarySrfExt','BoundarySrfExt',GetDatasetFields,None),
    ('CultureCrv','CultureCrv',GetDatasetFields,None),
    ('CulturePnt','CulturePnt',GetDatasetFields,None),
    ('CulturePntExt','CulturePntExt',GetDatasetFields,None),
    ('CultureSrf','CultureSrf',GetDatasetFields,None),
    ('CultureSrfExt','CultureSrfExt',GetDatasetFields,None),
    ('FacilityPnt','FacilityPnt',GetDatasetFields,None),
    ('FacilitySrf','FacilitySrf',GetDatasetFields,None),
    ('HydroAidNavigationCrvExt','HydroAidNavigationCrvExt',GetDatasetFields,None),
    ('HydroAidNavigationPnt','HydroAidNavigationPnt',GetDatasetFields,None),
    ('HydroAidNavigationPntExt','HydroAidNavigationPntExt',GetDatasetFields,None),
    ('HydroAidNavigationSrf','HydroAidNavigationSrf',GetDatasetFields,None),
    ('HydrographyCrv','HydrographyCrv',GetDatasetFields,None),
    ('HydrographyCrvExt','HydrographyCrvExt',GetDatasetFields,None),
    ('HydrographyPnt','HydrographyPnt',GetDatasetFields,None),
    ('HydrographyPntExt','HydrographyPntExt',GetDatasetFields,None),
    ('HydrographySrf','HydrographySrf',GetDatasetFields,None),
    ('HydrographySrfExt','HydrographySrfExt',GetDatasetFields,None),
    ('HypsographyCrv','HypsographyCrv',GetDatasetFields,None),
    ('HypsographyPnt','HypsographyPnt',GetDatasetFields,None),
    ('HypsographyPntExt','HypsographyPntExt',GetDatasetFields,None),
    ('IndustryCrv','IndustryCrv',GetDatasetFields,None),
    ('IndustryPnt','IndustryPnt',GetDatasetFields,None),
    ('IndustryPntExt','IndustryPntExt',GetDatasetFields,None),
    ('IndustrySrf','IndustrySrf',GetDatasetFields,None),
    ('InformationCrv','InformationCrv',GetDatasetFields,None),
    ('InformationCrvExt','InformationCrv',GetDatasetFields,None),   # Need to move Ext to Crv
    ('InformationPnt','InformationPnt',GetDatasetFields,None),
    ('InformationSrf','InformationSrf',GetDatasetFields,None),
    ('InformationSrfExt','InformationSrf',GetDatasetFields,None),    # Need to move Ext to Srf
    ('MilitaryCrv','MilitaryCrv',GetDatasetFields,None),
    ('MilitaryCrvExt','MilitaryCrvExt',GetDatasetFields,None),
    ('MilitaryPnt','MilitaryPnt',GetDatasetFields,None),
    ('MilitaryPntExt','MilitaryPntExt',GetDatasetFields,None),
    ('MilitarySrf','MilitarySrf',GetDatasetFields,None),
    ('MilitarySrfExt','MilitarySrfExt',GetDatasetFields,None),
    ('PhysiographyCrv','PhysiographyCrv',GetDatasetFields,None),
    ('PhysiographyCrvExt','PhysiographyCrvExt',GetDatasetFields,None),
    ('PhysiographyPnt','PhysiographyPnt',GetDatasetFields,None),
    ('PhysiographyPntExt','PhysiographyPntExt',GetDatasetFields,None),
    ('PhysiographySrf','PhysiographySrf',GetDatasetFields,None),
    ('PhysiographySrfExt','PhysiographySrfExt',GetDatasetFields,None),
    ('PortHarbourCrv','PortHarbourCrv',GetDatasetFields,None),
    ('PortHarbourPnt','PortHarbourPnt',GetDatasetFields,None),
    ('PortHarbourPntExt','PortHarbourPntExt',GetDatasetFields,None),
    ('PortHarbourSrf','PortHarbourSrf',GetDatasetFields,None),
    ('PortHarbourSrfExt','PortHarbourSrfExt',GetDatasetFields,None),
    ('RecreationCrv','RecreationCrv',GetDatasetFields,None),
    ('RecreationPnt','RecreationPnt',GetDatasetFields,None),
    ('RecreationSrf','RecreationSrf',GetDatasetFields,None),
    ('SettlementPnt','SettlementPnt',GetDatasetFields,None),
    ('SettlementSrf','SettlementSrf',GetDatasetFields,None),
    ('StoragePnt','StoragePnt',GetDatasetFields,None),
    ('StorageSrf','StorageSrf',GetDatasetFields,None),
    ('StructureCrv','StructureCrv',GetDatasetFields,None),
    ('StructurePnt','StructurePnt',GetDatasetFields,None),
    ('StructurePntExt','StructurePntExt',GetDatasetFields,None),
    ('StructureSrf','StructureSrf',GetDatasetFields,None),
    ('SubterraneanSrf','PhysiographySrf',GetDatasetFields,None),
    ('TransportationGroundCrv','TransportationGroundCrv',GetDatasetFields,None),
    ('TransportationGroundPnt','TransportationGroundPnt',GetDatasetFields,None),
    ('TransportationGroundPntExt','TransportationGroundPntExt',GetDatasetFields,None),
    ('TransportationGroundSrf','TransportationGroundSrf',GetDatasetFields,None),
    ('TransportationWaterCrv','TransportationWaterCrv',GetDatasetFields,None),
    ('TransportationWaterPnt','TransportationWaterPnt',GetDatasetFields,None),
    ('TransportationWaterPntExt','TransportationWaterPntExt',GetDatasetFields,None),
    ('TransportationWaterSrf','TransportationWaterSrf',GetDatasetFields,None),
    ('UtilityInfrastructureCrv','UtilityInfrastructureCrv',GetDatasetFields,None),
    ('UtilityInfrastructurePnt','UtilityInfrastructurePnt',GetDatasetFields,None),
    ('UtilityInfrastructureSrf','UtilityInfrastructureSrf',GetDatasetFields,None),
    ('VegetationCrv','VegetationCrv',GetDatasetFields,None),
    ('VegetationPnt','VegetationPnt',GetDatasetFields,None),
    ('VegetationPntExt','VegetationPntExt',GetDatasetFields,None),
    ('VegetationSrf','VegetationSrf',GetDatasetFields,None),
    ('VegetationSrfExt','VegetationSrfExt',GetDatasetFields,None)
    ]
	

fcs_process_for_EC = [
    ('AeronauticCrv','AeronauticCrv',GetECFields,None),
    ('AeronauticPnt','AeronauticPnt',GetECFields,None),
    ('AeronauticPntExt','AeronauticPntExt',GetECFields,None),
    ('AeronauticSrf','AeronauticSrf',GetECFields,None),
    ('AeronauticSrfExt','AeronauticSrfExt',GetECFields,None),
    ('AgriculturePnt','AgriculturePnt',GetECFields,None),
    ('AgriculturePntExt','AgriculturePntExt',GetECFields,None),
    ('AgricultureSrf','AgricultureSrf',GetECFields,None),
    ('BoundaryCrvExt','BoundaryCrvExt',GetECFields,None),
    ('BoundaryPnt','BoundaryPnt',GetECFields,None),
    ('BoundarySrf','BoundarySrf',GetECFields,None),
    ('BoundarySrfExt','BoundarySrfExt',GetECFields,None),
    ('CultureCrv','CultureCrv',GetECFields,None),
    ('CulturePnt','CulturePnt',GetECFields,None),
    ('CulturePntExt','CulturePntExt',GetECFields,None),
    ('CultureSrf','CultureSrf',GetECFields,None),
    ('CultureSrfExt','CultureSrfExt',GetECFields,None),
    ('FacilityPnt','FacilityPnt',GetECFields,None),
    ('FacilitySrf','FacilitySrf',GetECFields,None),
    ('HydroAidNavigationCrvExt','HydroAidNavigationCrvExt',GetECFields,None),
    ('HydroAidNavigationPnt','HydroAidNavigationPnt',GetECFields,None),
    ('HydroAidNavigationPntExt','HydroAidNavigationPntExt',GetECFields,None),
    ('HydroAidNavigationSrf','HydroAidNavigationSrf',GetECFields,None),
    ('HydrographyCrv','HydrographyCrv',GetECFields,None),
    ('HydrographyCrvExt','HydrographyCrvExt',GetECFields,None),
    ('HydrographyPnt','HydrographyPnt',GetECFields,None),
    ('HydrographyPntExt','HydrographyPntExt',GetECFields,None),
    ('HydrographySrf','HydrographySrf',GetECFields,None),
    ('HydrographySrfExt','HydrographySrfExt',GetECFields,None),
    ('HypsographyCrv','HypsographyCrv',GetECFields,None),
    ('HypsographyPnt','HypsographyPnt',GetECFields,None),
    ('HypsographyPntExt','HypsographyPntExt',GetECFields,None),
    ('IndustryCrv','IndustryCrv',GetECFields,None),
    ('IndustryPnt','IndustryPnt',GetECFields,None),
    ('IndustryPntExt','IndustryPntExt',GetECFields,None),
    ('IndustrySrf','IndustrySrf',GetECFields,None),
    ('InformationCrv','InformationCrv',GetECFields,None),
    ('InformationCrvExt','InformationCrv',GetECFields,None),      # Need to move Ext to Crv
    ('InformationPnt','InformationPnt',GetECFields,None),
    ('InformationSrf','InformationSrf',GetECFields,None),
    ('InformationSrfExt','InformationSrf',GetECFields,None),    # Need to move Ext to Srf
    ('MilitaryCrv','MilitaryCrv',GetECFields,None),
    ('MilitaryCrvExt','MilitaryCrvExt',GetECFields,None),
    ('MilitaryPnt','MilitaryPnt',GetECFields,None),
    ('MilitaryPntExt','MilitaryPntExt',GetECFields,None),
    ('MilitarySrf','MilitarySrf',GetECFields,None),
    ('MilitarySrfExt','MilitarySrfExt',GetECFields,None),
    ('None','InformationTbl',GetECFields,None),
    ('PhysiographyCrv','PhysiographyCrv',GetECFields,None),
    ('PhysiographyCrvExt','PhysiographyCrvExt',GetECFields,None),
    ('PhysiographyPnt','PhysiographyPnt',GetECFields,None),
    ('PhysiographyPntExt','PhysiographyPntExt',GetECFields,None),
    ('PhysiographySrf','PhysiographySrf',GetECFields,None),
    ('PhysiographySrfExt','PhysiographySrfExt',GetECFields,None),
    ('PortHarbourCrv','PortHarbourCrv',GetECFields,None),
    ('PortHarbourPnt','PortHarbourPnt',GetECFields,None),
    ('PortHarbourPntExt','PortHarbourPntExt',GetECFields,None),
    ('PortHarbourSrf','PortHarbourSrf',GetECFields,None),
    ('PortHarbourSrfExt','PortHarbourSrfExt',GetECFields,None),
    ('RecreationCrv','RecreationCrv',GetECFields,None),
    ('RecreationPnt','RecreationPnt',GetECFields,None),
    ('RecreationSrf','RecreationSrf',GetECFields,None),
    ('SettlementPnt','SettlementPnt',GetECFields,None),
    ('SettlementSrf','SettlementSrf',GetECFields,None),
    ('StoragePnt','StoragePnt',GetECFields,None),
    ('StorageSrf','StorageSrf',GetECFields,None),
    ('StructureCrv','StructureCrv',GetECFields,None),
    ('StructurePnt','StructurePnt',GetECFields,None),
    ('StructurePntExt','StructurePntExt',GetECFields,None),
    ('StructureSrf','StructureSrf',GetECFields,None),
    ('SubterraneanSrf','PhysiographySrf',GetECFields,None),
    ('TransportationGroundCrv','TransportationGroundCrv',GetECFields,None),
    ('TransportationGroundPnt','TransportationGroundPnt',GetECFields,None),
    ('TransportationGroundPntExt','TransportationGroundPntExt',GetECFields,None),
    ('TransportationGroundSrf','TransportationGroundSrf',GetECFields,None),
    ('TransportationWaterCrv','TransportationWaterCrv',GetECFields,None),
    ('TransportationWaterPnt','TransportationWaterPnt',GetECFields,None),
    ('TransportationWaterPntExt','TransportationWaterPntExt',GetECFields,None),
    ('TransportationWaterSrf','TransportationWaterSrf',GetECFields,None),
    ('UtilityInfrastructureCrv','UtilityInfrastructureCrv',GetECFields,None),
    ('UtilityInfrastructurePnt','UtilityInfrastructurePnt',GetECFields,None),
    ('UtilityInfrastructureSrf','UtilityInfrastructureSrf',GetECFields,None),
    ('VegetationCrv','VegetationCrv',GetECFields,None),
    ('VegetationPnt','VegetationPnt',GetECFields,None),
    ('VegetationPntExt','VegetationPntExt',GetECFields,None),
    ('VegetationSrf','VegetationSrf',GetECFields,None),
    ('VegetationSrfExt','VegetationSrfExt',GetECFields,None)
    ]


# src, target, transformer   Do not include the Dataset or Entity Catalog feature classes as they will be done separately
fcs = [	
	('AeronauticCrv','AeronauticCrv',AeronauticCrvFields,None),
	('AeronauticPnt','AeronauticPnt',AeronauticPntFields,None),
	('AeronauticSrf','AeronauticSrf',AeronauticSrfFields,None),
	('AgriculturePnt','AgriculturePnt',AgriculturePntFields,None),
	('AgricultureSrf','AgricultureSrf',AgricultureSrfFields,None),
	('BoundaryCrvExt','BoundaryCrvExt',BoundaryCrvExtFields,None),
	('BoundaryPnt','BoundaryPnt',BoundaryPntFields,None),
	('CultureCrv','CultureCrv',CultureCrvFields,None),
	('CulturePnt','CulturePnt',CulturePntFields,None),
	('CulturePntExt','CulturePntExt',CulturePntExtFields,None),
	('CultureSrf','CultureSrf',CultureSrfFields,None),
	('CultureSrfExt','CultureSrfExt',CultureSrfExtFields,None),
	('FacilityPnt','FacilityPnt',FacilityPntFields,None),
	('FacilitySrf','FacilitySrf',FacilitySrfFields,None),
	('HydroAidNavigationPnt','HydroAidNavigationPnt',HydroAidNavigationPntFields,None),
	('HydroAidNavigationSrf','HydroAidNavigationSrf',HydroAidNavigationSrfFields,None),
	('HydrographyCrv','HydrographyCrv',HydrographyCrvFields,None),
	('HydrographyPnt','HydrographyPnt',HydrographyPntFields,None),
	('HydrographySrf','HydrographySrf',HydrographySrfFields,None),
	('HypsographyCrv','HypsographyCrv',HypsographyCrvFields,None),
	('HypsographyPnt','HypsographyPnt',HypsographyPntFields,None),
	('IndustryCrv','IndustryCrv',IndustryCrvFields,None),
	('IndustryPnt','IndustryPnt',IndustryPntFields,None),
	('IndustrySrf','IndustrySrf',IndustrySrfFields,'F_CODE NOT IN (\'AB507\')'),
	('IndustrySrf','CultureSrf',IndustrySrfCultureSrfFields,'F_CODE IN (\'AB507\')'),
	('InformationCrv','InformationCrv',InformationCrvFields,None),
	('InformationCrvExt','InformationCrv',InformationCrvFields,None),  # Move Ext to Crv
	('InformationPnt','InformationPnt',InformationPntFields,None),
	('InformationSrf','InformationSrf',InformationSrfFields,None),
	('InformationSrfExt','InformationSrf',InformationSrfFields,None),  # Move Ext to Srf
	('MetadataSrf','CollectionSrf',MetadataSrfCollectionSrfFields,None),
	('MilitaryCrv','MilitaryCrv',MilitaryCrvFields,None),
	('MilitaryPnt','MilitaryPnt',MilitaryPntFields,None),
	('MilitarySrf','MilitarySrf',MilitarySrfFields,None),
	('PhysiographyCrv','PhysiographyCrv',PhysiographyCrvFields,None),
	('PhysiographyPnt','PhysiographyPnt',PhysiographyPntFields,None),
	('PhysiographySrf','PhysiographySrf',PhysiographySrfFields,None),
	('PortHarbourCrv','PortHarbourCrv',PortHarbourCrvFields,None),
	('PortHarbourPnt','PortHarbourPnt',PortHarbourPntFields,None),
	('PortHarbourSrf','PortHarbourSrf',PortHarbourSrfFields,None),
	('RecreationCrv','RecreationCrv',RecreationCrvFields,None),
	('RecreationPnt','RecreationPnt',RecreationPntFields,None),
	('RecreationSrf','RecreationSrf',RecreationSrfFields,None),
	('ResourceSrf','DatasetSrf',ResourceSrfDatasetSrfFields,None),
	('SettlementPnt','SettlementPnt',SettlementPntFields,None),
	('SettlementSrf','SettlementSrf',SettlementSrfFields,None),
	('StoragePnt','StoragePnt',StoragePntFields,None),
	('StorageSrf','StorageSrf',StorageSrfFields,None),
	('StructureCrv','StructureCrv',StructureCrvFields,None),
	('StructurePnt','StructurePnt',StructurePntFields,None),
	('StructureSrf','StructureSrf',StructureSrfFields,None),
	('SubterraneanSrf','HydrographySrf',SubterraneanSrfHydrographySrfFields,'F_CODE IN (\'BH116\')'),
	('SubterraneanSrf','PhysiographySrf',SubterraneanSrfPhysiographySrfFields,'F_CODE IN (\'DB028\')'),
	('TransportationGroundCrv','TransportationGroundCrv',TransportationGroundCrvFields,None),
	('TransportationGroundPnt','TransportationGroundPnt',TransportationGroundPntFields,None),
	('TransportationGroundSrf','TransportationGroundSrf',TransportationGroundSrfFields,None),
	('TransportationWaterCrv','TransportationWaterCrv',TransportationWaterCrvFields,None),
	('TransportationWaterPnt','TransportationWaterPnt',TransportationWaterPntFields,None),
	('TransportationWaterSrf','TransportationWaterSrf',TransportationWaterSrfFields,None),
	('UtilityInfrastructureCrv','UtilityInfrastructureCrv',UtilityInfrastructureCrvFields,None),
	('UtilityInfrastructurePnt','UtilityInfrastructurePnt',UtilityInfrastructurePntFields,None),
	('UtilityInfrastructureSrf','UtilityInfrastructureSrf',UtilityInfrastructureSrfFields,None),
	('VegetationCrv','VegetationCrv',VegetationCrvFields,None),
	('VegetationPnt','VegetationPnt',VegetationPntFields,None),
	('VegetationSrf','VegetationSrf',VegetationSrfFields,None)
        ]
	
	
