﻿
""" 
 ************************************************************************************************
 **                                                                                            **
 **  File: GGDM30_2_TDS70_FeatureClassesToTranslate.py
 **  Copyright (c) March 2020 by Leidos                                                     **
 **  Produced under U.S. Government contract W5J9CQ-12-D-0004  Task Order: 053.                **
 **  As per DFARS, the U.S. Government is granted unlimited rights to use this work            **
 **  in any manner and for any purpose.                                                        **
 **                                                                                            **
 **  Summary:   This file provides the feature class list that will be translated             **
 **                 GGDM 3.0 to TDS 7.0                                     **
 **                                                                                            **
 **  Developed by Leidos, Inc., High Resolution ISR Systems Division, Geospatial Programs                                                  **
 **                                                                                            **
 **  Development History:                                                                      **
 **  March 2020 / Annette Janett Filer (Annette.J.Filer@leidos.com) Original version                                                     **               **
 **                                                                                            **
 **                                                                                            **
 ************************************************************************************************
"""


import sys
import os


from GGDM30_2_TDS70_TranslateFeaturesandFields import *

# src, target, transformer   Do not include the Dataset or Entity Catalog feature classes as they will be done separately
fcs = [
    ('AeronauticCrv','AeronauticCrv',AeronauticCrvFields,None),
    ('AeronauticPnt','AeronauticPnt',AeronauticPntFields,None),
    ('AeronauticSrf','AeronauticSrf',AeronauticSrfFields,None),
    ('AgriculturePnt','AgriculturePnt',AgriculturePntFields,None),
    ('AgricultureSrf','AgricultureSrf',AgricultureSrfFields,None),
    ('BoundaryPnt','BoundaryPnt',BoundaryPntFields,None),
    ('BoundarySrf','BoundarySrf',BoundarySrfFields,None),
    ('CultureCrv','CultureCrv',CultureCrvFields,None),
    ('CulturePnt','CulturePnt',CulturePntFields,None),
    ('CultureSrf','CultureSrf',CultureSrfFields,None),
    ('FacilityPnt','FacilityPnt',FacilityPntFields,None),
    ('FacilitySrf','FacilitySrf',FacilitySrfFields,None),
    ('HydroAidNavigationPnt','HydroAidNavigationPnt',HydroAidNavigationPntFields,None),
    ('HydroAidNavigationSrf','HydroAidNavigationSrf',HydroAidNavigationSrfFields,None),
    ('HydrographyCrv','HydrographyCrv',HydrographyCrvFields,None),
    ('HydrographyPnt','HydrographyPnt',HydrographyPntFields,None),
    ('HydrographySrf','HydrographySrf',HydrographySrfFields,None),
    ('HypsographyCrv','HypsographyCrv',HypsographyCrvFields,None),
    ('HypsographyPnt','HypsographyPnt',HypsographyPntFields,None),
    ('IndustryCrv','IndustryCrv',IndustryCrvFields,None),
    ('IndustryPnt','IndustryPnt',IndustryPntFields,None),
    ('IndustrySrf','IndustrySrf',IndustrySrfFields,None),
    ('InformationCrv','InformationCrv',InformationCrvFields,None),
    ('InformationPnt','InformationPnt',InformationPntFields,None),
    ('InformationSrf','InformationSrf',InformationSrfFields,None),
    ('MilitaryCrv','MilitaryCrv',MilitaryCrvFields,None),
    ('MilitaryPnt','MilitaryPnt',MilitaryPntFields,None),
    ('MilitarySrf','MilitarySrf',MilitarySrfFields,None),
    ('PhysiographyCrv','PhysiographyCrv',PhysiographyCrvFields,None),
    ('PhysiographyPnt','PhysiographyPnt',PhysiographyPntFields,None),
    ('PhysiographySrf','PhysiographySrf',PhysiographySrfFields,None),
    ('PortHarbourCrv','PortHarbourCrv',PortHarbourCrvFields,None),
    ('PortHarbourPnt','PortHarbourPnt',PortHarbourPntFields,None),
    ('PortHarbourSrf','PortHarbourSrf',PortHarbourSrfFields,None),
    ('RecreationCrv','RecreationCrv',RecreationCrvFields,None),
    ('RecreationPnt','RecreationPnt',RecreationPntFields,None),
    ('RecreationSrf','RecreationSrf',RecreationSrfFields,None),
    ('SettlementPnt','SettlementPnt',SettlementPntFields,None),
    ('SettlementSrf','SettlementSrf',SettlementSrfFields,None),
    ('StoragePnt','StoragePnt',StoragePntFields,None),
    ('StorageSrf','StorageSrf',StorageSrfFields,None),
    ('StructureCrv','StructureCrv',StructureCrvFields,None),
    ('StructurePnt','StructurePnt',StructurePntFields,None),
    ('StructureSrf','StructureSrf',StructureSrfFields,None),
    ('SubterraneanSrf','SubterraneanSrf',SubterraneanSrfFields,None),
    ('TransportationGroundCrv','TransportationGroundCrv',TransportationGroundCrvFields,None),
    ('TransportationGroundPnt','TransportationGroundPnt',TransportationGroundPntFields,None),
    ('TransportationGroundSrf','TransportationGroundSrf',TransportationGroundSrfFields,None),
    ('TransportationWaterCrv','TransportationWaterCrv',TransportationWaterCrvFields,None),
    ('TransportationWaterPnt','TransportationWaterPnt',TransportationWaterPntFields,None),
    ('TransportationWaterSrf','TransportationWaterSrf',TransportationWaterSrfFields,None),
    ('UtilityInfrastructureCrv','UtilityInfrastructureCrv',UtilityInfrastructureCrvFields,None),
    ('UtilityInfrastructurePnt','UtilityInfrastructurePnt',UtilityInfrastructurePntFields,None),
    ('UtilityInfrastructureSrf','UtilityInfrastructureSrf',UtilityInfrastructureSrfFields,None),
    ('VegetationCrv','VegetationCrv',VegetationCrvFields,None),
    ('VegetationPnt','VegetationPnt',VegetationPntFields,None),
    ('VegetationSrf','VegetationSrf',VegetationSrfFields,None),
    ('MetadataSrf', 'MetadataSrf', MetadataSrfFields, None),
    ('ResourceSrf', 'ResourceSrf', ResourceSrfFields, None)
]
