﻿
""" 
 ************************************************************************************************
 **                                                                                            **
 **  File: TDS4_2_GGDM30_FeatureClassesToTranslate.py                                        **
 **  Copyright (c) May 2016 by Leidos                                                     **
 **  Produced under U.S. Government contract W5J9CQ-12-D-0004  Task Order: 053.                **
 **  As per DFARS, the U.S. Government is granted unlimited rights to use this work            **
 **  in any manner and for any purpose.                                                        **
 **                                                                                            **
 **  Summary:   This file provides the feature class list that will be translated             **
 **                 TDS 4.0 Composite to GGDM 3.0 Composite                                    **
 **                                                                                            **
 **  Developed by Leidos, Inc., High Resolution ISR Systems Division, Geospatial Programs                                                  **
 **                                                                                            **
 **  Development History:                                                                      **
 **  May 2016 / Annette Janett Filer (Annette.J.Filer@leidos.com) Original version                                                     **               **
 **                                                                                            **
 **                                                                                            **
 ************************************************************************************************
"""


import sys
import os


from TDS4_2_GGDM30_TranslateFeaturesandFields import *


# This is needed to get the restriction info content from Dataset
fcs_restriction_info_metadata = [
    ('DatasetSrf','RESTRICTION_INFO_T',RestrictionInfoMetaConvertSubsetFields,None),
    ]

# We need to move any existing dataset records to the target
fcs_process_dataset = [
    ('DatasetSrf', 'ResourceSrf', DatasetSrfResourceSrfFields, None)
    ]

fcs_entity_collection_metadata = [
    ('CollectionSrf', 'MetadataSrf', CollectionMetadataSrfFields, None)
    ]

# src, target, transformer   Do not include the Dataset or Entity Catalog feature classes as they will be done separately
fcs = [	
	('AeronauticCrv','AeronauticCrv',AeronauticCrvFields,None),
	('AeronauticPnt','AeronauticPnt',AeronauticPntFields,None),
	('AeronauticSrf','AeronauticSrf',AeronauticSrfFields,None),
	('AgriculturePnt','AgriculturePnt',AgriculturePntFields,None),
	('AgricultureSrf','AgricultureSrf',AgricultureSrfFields,None),
	('BoundaryPnt','BoundaryPnt',BoundaryPntFields,None),
	('CultureCrv','CultureCrv',CultureCrvFields,None),
	('CulturePnt','CulturePnt',CulturePntFields,None),
	('CultureSrf','CultureSrf',CultureSrfFields,'F_CODE NOT IN (\'AB507\')'),        # Not Waste Heap
        ('CultureSrf','IndustrySrf',CultureSrfIndustrySrfFields,'F_CODE IN (\'AB507\')'),   # Waste Heap
	('FacilityPnt','FacilityPnt',FacilityPntFields,None),
	('FacilitySrf','FacilitySrf',FacilitySrfFields,None),
	('HydroAidNavigationPnt','HydroAidNavigationPnt',HydroAidNavigationPntFields,None),
	('HydroAidNavigationSrf','HydroAidNavigationSrf',HydroAidNavigationSrfFields,None),
	('HydrographyCrv','HydrographyCrv',HydrographyCrvFields,None),
	('HydrographyPnt','HydrographyPnt',HydrographyPntFields,None),
	('HydrographySrf','HydrographySrf',HydrographySrfFields,'F_CODE NOT IN (\'BH116\')'),           # Not Aquifer
	('HydrographySrf','SubterraneanSrf',HydrographySrfSubterraneanSrfFields,'F_CODE IN (\'BH116\')'),  # Aquifer
	('HydrographySrf','SubterraneanSrf',SubterraneanSrfFields,None),
	('HypsographyCrv','HypsographyCrv',HypsographyCrvFields,None),
	('HypsographyPnt','HypsographyPnt',HypsographyPntFields,None),
	('IndustryCrv','IndustryCrv',IndustryCrvFields,None),
	('IndustryPnt','IndustryPnt',IndustryPntFields,None),
	('IndustrySrf','IndustrySrf',IndustrySrfFields,None),
        ('InformationCrv','InformationCrv',InformationCrvFields, 'F_CODE NOT IN (\'ZD040\')'),        # Not Named Location
        ('InformationCrv','InformationCrvExt',InformationCrvExtFields, 'F_CODE IN (\'ZD040\')'),   # Named Location
	('InformationPnt','InformationPnt',InformationPntFields,None),
	('InformationSrf','InformationSrf',InformationSrfFields, 'F_CODE NOT IN (\'ZD040\')'),        # Not Named Location
        ('InformationSrf','InformationSrfExt',InformationSrfExtFields, 'F_CODE IN (\'ZD040\')'),   # Named Location
	('MilitaryCrv','MilitaryCrv',MilitaryCrvFields,None),
	('MilitaryPnt','MilitaryPnt',MilitaryPntFields,None),
	('MilitarySrf','MilitarySrf',MilitarySrfFields,None),
	('PhysiographyCrv','PhysiographyCrv',PhysiographyCrvFields,None),
	('PhysiographyPnt','PhysiographyPnt',PhysiographyPntFields,None),
	# ('PhysiographySrf','PhysiographySrf',PhysiographySrfFields,None),                   # Replaced by specific mappings for cave chamber vs not
	  ('PhysiographySrf','PhysiographySrf',PhysiographySrfFields,'F_CODE NOT IN (\'DB028\')'),          # Not Cave Chamber
	  ('PhysiographySrf','SubterraneanSrf',PhysiographySrfSubterraneanSrfFields,'F_CODE IN (\'DB028\')'),  # Cave Chamber
	('PortHarbourCrv','PortHarbourCrv',PortHarbourCrvFields,None),
	('PortHarbourPnt','PortHarbourPnt',PortHarbourPntFields,None),
	('PortHarbourSrf','PortHarbourSrf',PortHarbourSrfFields,None),
	('RecreationCrv','RecreationCrv',RecreationCrvFields,None),
	('RecreationPnt','RecreationPnt',RecreationPntFields,None),
	('RecreationSrf','RecreationSrf',RecreationSrfFields,None),
	('SettlementPnt','SettlementPnt',SettlementPntFields,None),
	('SettlementSrf','SettlementSrf',SettlementSrfFields,None),
	('StoragePnt','StoragePnt',StoragePntFields,None),
	('StorageSrf','StorageSrf',StorageSrfFields,None),
	('StructureCrv','StructureCrv',StructureCrvFields,None),
	('StructurePnt','StructurePnt',StructurePntFields,None),
	('StructureSrf','StructureSrf',StructureSrfFields,None),
	('TransportationGroundCrv','TransportationGroundCrv',TransportationGroundCrvFields,None),
	('TransportationGroundPnt','TransportationGroundPnt',TransportationGroundPntFields,None),
	('TransportationGroundSrf','TransportationGroundSrf',TransportationGroundSrfFields,None),
	('TransportationWaterCrv','TransportationWaterCrv',TransportationWaterCrvFields,None),
	('TransportationWaterPnt','TransportationWaterPnt',TransportationWaterPntFields,None),
	('TransportationWaterSrf','TransportationWaterSrf',TransportationWaterSrfFields,None),
	('UtilityInfrastructureCrv','UtilityInfrastructureCrv',UtilityInfrastructureCrvFields,None),
	('UtilityInfrastructurePnt','UtilityInfrastructurePnt',UtilityInfrastructurePntFields,None),
	('UtilityInfrastructureSrf','UtilityInfrastructureSrf',UtilityInfrastructureSrfFields,None),
	('VegetationCrv','VegetationCrv',VegetationCrvFields,None),
	('VegetationPnt','VegetationPnt',VegetationPntFields,None),
	('VegetationSrf','VegetationSrf',VegetationSrfFields,None)
        ]
	
