﻿
""" 
 ************************************************************************************************
 **                                                                                            **
 **  File: TDS71_2_GGDM30_FeatureClassesToTranslate.py
 **  Copyright (c) March 2020 by Leidos                                                     **
 **  Produced under U.S. Government contract W5J9CQ-12-D-0004  Task Order: 053.                **
 **  As per DFARS, the U.S. Government is granted unlimited rights to use this work            **
 **  in any manner and for any purpose.                                                        **
 **                                                                                            **
 **  Summary:   This file provides the feature class list for translation           **
 **                 TDS 7.1 Composite to GGDM 3.0 Composite                                    **
 **                                                                                            **
 **  Developed by Leidos, Inc., GSTI Division                                                  **
 **                                                                                            **
 **  Development History:                                                                      **
 **  March 2020 / Annette Janett Filer  Initial file based on TDS 6.1    **
 **                                                                                            **
 **                                                                                            **
 ************************************************************************************************
"""


import sys
import os

from TDS71_2_GGDM30_TranslateFeaturesandFields import *

# src, target, transformer   Do not include the Dataset or Entity Catalog feature classes as they will be done separately
fcs = [
('AeronauticCrv','AeronauticCrv',AeronauticCrvFields,None),
('AeronauticPnt','AeronauticPnt',AeronauticPntFields,None),
('AeronauticSrf','AeronauticSrf',AeronauticSrfFields,None),
('AgriculturePnt','AgriculturePnt',AgriculturePntFields,None),
('AgricultureSrf','AgricultureSrf',AgricultureSrfFields,None),
('BoundaryPnt','BoundaryPnt',BoundaryPntFields,None),
('BoundarySrf','BoundarySrf',BoundarySrfFields,None),
('CultureCrv','CultureCrv',CultureCrvFields,None),
('CulturePnt','CulturePnt',CulturePntFields,None),
('CultureSrf','CultureSrf',CultureSrfFields,None),
('FacilityPnt','FacilityPnt',FacilityPntFields,None),
('FacilitySrf','FacilitySrf',FacilitySrfFields,None),
('HydroAidNavigationPnt','HydroAidNavigationPnt',HydroAidNavigationPntFields,None),
('HydroAidNavigationSrf','HydroAidNavigationSrf',HydroAidNavigationSrfFields,None),
('HydrographyCrv','HydrographyCrv',HydrographyCrvFields,None),
('HydrographyPnt','HydrographyPnt',HydrographyPntFields,None),
('HydrographySrf','HydrographySrf',HydrographySrfFields,None),
('HypsographyCrv','HypsographyCrv',HypsographyCrvFields,None),
('HypsographyPnt','HypsographyPnt',HypsographyPntFields,None),
('IndustryCrv','IndustryCrv',IndustryCrvFields,None),
('IndustryPnt','IndustryPnt',IndustryPntFields,None),
('IndustrySrf','IndustrySrf',IndustrySrfFields,None),
('InformationCrv','InformationCrv',InformationCrvFields,None),
('InformationPnt','InformationPnt',InformationPntFields,None),
('InformationSrf','InformationSrf',InformationSrfFields,None),
('MilitaryCrv','MilitaryCrv',MilitaryCrvFields,None),
('MilitaryPnt','MilitaryPnt',MilitaryPntFields,None),
('MilitarySrf','MilitarySrf',MilitarySrfFields,None),
('PhysiographyCrv','PhysiographyCrv',PhysiographyCrvFields,None),
('PhysiographyPnt','PhysiographyPnt',PhysiographyPntFields,None),
('PhysiographySrf','PhysiographySrf',PhysiographySrfFields,None),
('PortHarbourCrv','PortHarbourCrv',PortHarbourCrvFields,None),
('PortHarbourPnt','PortHarbourPnt',PortHarbourPntFields,None),
('PortHarbourSrf','PortHarbourSrf',PortHarbourSrfFields,None),
('RecreationCrv','RecreationCrv',RecreationCrvFields,None),
('RecreationPnt','RecreationPnt',RecreationPntFields,None),
('RecreationSrf','RecreationSrf',RecreationSrfFields,None),
('SettlementPnt','SettlementPnt',SettlementPntFields,None),
('SettlementSrf','SettlementSrf',SettlementSrfFields,None),
('StoragePnt','StoragePnt',StoragePntFields,None),
('StorageSrf','StorageSrf',StorageSrfFields,None),
('StructureCrv','StructureCrv',StructureCrvFields,None),
('StructurePnt','StructurePnt',StructurePntFields,None),
('StructureSrf','StructureSrf',StructureSrfFields,None),
('SubterraneanSrf','SubterraneanSrf',SubterraneanSrfFields,None),
('TransportationGroundCrv','TransportationGroundCrv',TransportationGroundCrvFields,None),
('TransportationGroundPnt','TransportationGroundPnt',TransportationGroundPntFields,None),
('TransportationGroundSrf','TransportationGroundSrf',TransportationGroundSrfFields,None),
('TransportationWaterCrv','TransportationWaterCrv',TransportationWaterCrvFields,None),
('TransportationWaterPnt','TransportationWaterPnt',TransportationWaterPntFields,None),
('TransportationWaterSrf','TransportationWaterSrf',TransportationWaterSrfFields,None),
('UtilityInfrastructureCrv','UtilityInfrastructureCrv',UtilityInfrastructureCrvFields,None),
('UtilityInfrastructurePnt','UtilityInfrastructurePnt',UtilityInfrastructurePntFields,None),
('UtilityInfrastructureSrf','UtilityInfrastructureSrf',UtilityInfrastructureSrfFields,None),
('VegetationCrv','VegetationCrv',VegetationCrvFields,None),
('VegetationPnt','VegetationPnt',VegetationPntFields,None),
('VegetationSrf','VegetationSrf',VegetationSrfFields,None)
]

# contains set of: src_fc, target_fc, mapping, whereclause, We do not include Entity Catalog as it does not have restriction info
fcs_restriction_info_metadata = [
('ResourceSrf', 'ResourceSrf',RestrictionInfoMetaConvertSubsetFields, None),     # Be sure ResourceSrf gets processed first. This is Dataset
('AeronauticCrv','AeronauticCrv',RestrictionInfoMetaConvertSubsetFields,None),
('AeronauticPnt','AeronauticPnt',RestrictionInfoMetaConvertSubsetFields,None),
('AeronauticSrf','AeronauticSrf',RestrictionInfoMetaConvertSubsetFields,None),
('AgriculturePnt','AgriculturePnt',RestrictionInfoMetaConvertSubsetFields,None),
('AgricultureSrf','AgricultureSrf',RestrictionInfoMetaConvertSubsetFields,None),
('BoundaryPnt','BoundaryPnt',RestrictionInfoMetaConvertSubsetFields,None),
('BoundarySrf','BoundarySrf',RestrictionInfoMetaConvertSubsetFields,None),
('CultureCrv','CultureCrv',RestrictionInfoMetaConvertSubsetFields,None),
('CulturePnt','CulturePnt',RestrictionInfoMetaConvertSubsetFields,None),
('CultureSrf','CultureSrf',RestrictionInfoMetaConvertSubsetFields,None),
('FacilityPnt','FacilityPnt',RestrictionInfoMetaConvertSubsetFields,None),
('FacilitySrf','FacilitySrf',RestrictionInfoMetaConvertSubsetFields,None),
('HydroAidNavigationPnt','HydroAidNavigationPnt',RestrictionInfoMetaConvertSubsetFields,None),
('HydroAidNavigationSrf','HydroAidNavigationSrf',RestrictionInfoMetaConvertSubsetFields,None),
('HydrographyCrv','HydrographyCrv',RestrictionInfoMetaConvertSubsetFields,None),
('HydrographyPnt','HydrographyPnt',RestrictionInfoMetaConvertSubsetFields,None),
('HydrographySrf','HydrographySrf',RestrictionInfoMetaConvertSubsetFields,None),
('HypsographyCrv','HypsographyCrv',RestrictionInfoMetaConvertSubsetFields,None),
('HypsographyPnt','HypsographyPnt',RestrictionInfoMetaConvertSubsetFields,None),
('IndustryCrv','IndustryCrv',RestrictionInfoMetaConvertSubsetFields,None),
('IndustryPnt','IndustryPnt',RestrictionInfoMetaConvertSubsetFields,None),
('IndustrySrf','IndustrySrf',RestrictionInfoMetaConvertSubsetFields,None),
('InformationCrv','InformationCrv',RestrictionInfoMetaConvertSubsetFields,None),
('InformationPnt','InformationPnt',RestrictionInfoMetaConvertSubsetFields,None),
('InformationSrf','InformationSrf',RestrictionInfoMetaConvertSubsetFields,None),
('MilitaryCrv','MilitaryCrv',RestrictionInfoMetaConvertSubsetFields,None),
('MilitaryPnt','MilitaryPnt',RestrictionInfoMetaConvertSubsetFields,None),
('MilitarySrf','MilitarySrf',RestrictionInfoMetaConvertSubsetFields,None),
('PhysiographyCrv','PhysiographyCrv',RestrictionInfoMetaConvertSubsetFields,None),
('PhysiographyPnt','PhysiographyPnt',RestrictionInfoMetaConvertSubsetFields,None),
('PhysiographySrf','PhysiographySrf',RestrictionInfoMetaConvertSubsetFields,None),
('PortHarbourCrv','PortHarbourCrv',RestrictionInfoMetaConvertSubsetFields,None),
('PortHarbourPnt','PortHarbourPnt',RestrictionInfoMetaConvertSubsetFields,None),
('PortHarbourSrf','PortHarbourSrf',RestrictionInfoMetaConvertSubsetFields,None),
('RecreationCrv','RecreationCrv',RestrictionInfoMetaConvertSubsetFields,None),
('RecreationPnt','RecreationPnt',RestrictionInfoMetaConvertSubsetFields,None),
('RecreationSrf','RecreationSrf',RestrictionInfoMetaConvertSubsetFields,None),
('SettlementPnt','SettlementPnt',RestrictionInfoMetaConvertSubsetFields,None),
('SettlementSrf','SettlementSrf',RestrictionInfoMetaConvertSubsetFields,None),
('StoragePnt','StoragePnt',RestrictionInfoMetaConvertSubsetFields,None),
('StorageSrf','StorageSrf',RestrictionInfoMetaConvertSubsetFields,None),
('StructureCrv','StructureCrv',RestrictionInfoMetaConvertSubsetFields,None),
('StructurePnt','StructurePnt',RestrictionInfoMetaConvertSubsetFields,None),
('StructureSrf','StructureSrf',RestrictionInfoMetaConvertSubsetFields,None),
('SubterraneanSrf','SubterraneanSrf',RestrictionInfoMetaConvertSubsetFields,None),
('TransportationGroundCrv','TransportationGroundCrv',RestrictionInfoMetaConvertSubsetFields,None),
('TransportationGroundPnt','TransportationGroundPnt',RestrictionInfoMetaConvertSubsetFields,None),
('TransportationGroundSrf','TransportationGroundSrf',RestrictionInfoMetaConvertSubsetFields,None),
('TransportationWaterCrv','TransportationWaterCrv',RestrictionInfoMetaConvertSubsetFields,None),
('TransportationWaterPnt','TransportationWaterPnt',RestrictionInfoMetaConvertSubsetFields,None),
('TransportationWaterSrf','TransportationWaterSrf',RestrictionInfoMetaConvertSubsetFields,None),
('UtilityInfrastructureCrv','UtilityInfrastructureCrv',RestrictionInfoMetaConvertSubsetFields,None),
('UtilityInfrastructurePnt','UtilityInfrastructurePnt',RestrictionInfoMetaConvertSubsetFields,None),
('UtilityInfrastructureSrf','UtilityInfrastructureSrf',RestrictionInfoMetaConvertSubsetFields,None),
('VegetationCrv','VegetationCrv',RestrictionInfoMetaConvertSubsetFields,None),
('VegetationPnt','VegetationPnt',RestrictionInfoMetaConvertSubsetFields,None),
('VegetationSrf','VegetationSrf',RestrictionInfoMetaConvertSubsetFields,None)
]


# We need to move any existing entity collection records and dataset records to the target
fcs_process_entity_collection_and_dataset = [
    ('MetadataSrf', 'MetadataSrf', MetadataSrfFields, None),
    ('ResourceSrf', 'ResourceSrf', DatasetSrfFields, None)
    ]

# This set will examine only the entity collection metadata subset fields in each feature class. Don't include the entity catalog or dataset feature classes
fcs_entity_collection_metadata = [
('AeronauticCrv','AeronauticCrv',EntityCollectionMetaConvertSubsetFields,None),
('AeronauticPnt','AeronauticPnt',EntityCollectionMetaConvertSubsetFields,None),
('AeronauticSrf','AeronauticSrf',EntityCollectionMetaConvertSubsetFields,None),
('AgriculturePnt','AgriculturePnt',EntityCollectionMetaConvertSubsetFields,None),
('AgricultureSrf','AgricultureSrf',EntityCollectionMetaConvertSubsetFields,None),
('BoundaryPnt','BoundaryPnt',EntityCollectionMetaConvertSubsetFields,None),
('BoundarySrf','BoundarySrf',EntityCollectionMetaConvertSubsetFields,None),
('CultureCrv','CultureCrv',EntityCollectionMetaConvertSubsetFields,None),
('CulturePnt','CulturePnt',EntityCollectionMetaConvertSubsetFields,None),
('CultureSrf','CultureSrf',EntityCollectionMetaConvertSubsetFields,None),
('FacilityPnt','FacilityPnt',EntityCollectionMetaConvertSubsetFields,None),
('FacilitySrf','FacilitySrf',EntityCollectionMetaConvertSubsetFields,None),
('HydroAidNavigationPnt','HydroAidNavigationPnt',EntityCollectionMetaConvertSubsetFields,None),
('HydroAidNavigationSrf','HydroAidNavigationSrf',EntityCollectionMetaConvertSubsetFields,None),
('HydrographyCrv','HydrographyCrv',EntityCollectionMetaConvertSubsetFields,None),
('HydrographyPnt','HydrographyPnt',EntityCollectionMetaConvertSubsetFields,None),
('HydrographySrf','HydrographySrf',EntityCollectionMetaConvertSubsetFields,None),
('HypsographyCrv','HypsographyCrv',EntityCollectionMetaConvertSubsetFields,None),
('HypsographyPnt','HypsographyPnt',EntityCollectionMetaConvertSubsetFields,None),
('IndustryCrv','IndustryCrv',EntityCollectionMetaConvertSubsetFields,None),
('IndustryPnt','IndustryPnt',EntityCollectionMetaConvertSubsetFields,None),
('IndustrySrf','IndustrySrf',EntityCollectionMetaConvertSubsetFields,None),
('InformationCrv','InformationCrv',EntityCollectionMetaConvertSubsetFields,None),
('InformationPnt','InformationPnt',EntityCollectionMetaConvertSubsetFields,None),
('InformationSrf','InformationSrf',EntityCollectionMetaConvertSubsetFields,None),
('MilitaryCrv','MilitaryCrv',EntityCollectionMetaConvertSubsetFields,None),
('MilitaryPnt','MilitaryPnt',EntityCollectionMetaConvertSubsetFields,None),
('MilitarySrf','MilitarySrf',EntityCollectionMetaConvertSubsetFields,None),
('PhysiographyCrv','PhysiographyCrv',EntityCollectionMetaConvertSubsetFields,None),
('PhysiographyPnt','PhysiographyPnt',EntityCollectionMetaConvertSubsetFields,None),
('PhysiographySrf','PhysiographySrf',EntityCollectionMetaConvertSubsetFields,None),
('PortHarbourCrv','PortHarbourCrv',EntityCollectionMetaConvertSubsetFields,None),
('PortHarbourPnt','PortHarbourPnt',EntityCollectionMetaConvertSubsetFields,None),
('PortHarbourSrf','PortHarbourSrf',EntityCollectionMetaConvertSubsetFields,None),
('RecreationCrv','RecreationCrv',EntityCollectionMetaConvertSubsetFields,None),
('RecreationPnt','RecreationPnt',EntityCollectionMetaConvertSubsetFields,None),
('RecreationSrf','RecreationSrf',EntityCollectionMetaConvertSubsetFields,None),
('SettlementPnt','SettlementPnt',EntityCollectionMetaConvertSubsetFields,None),
('SettlementSrf','SettlementSrf',EntityCollectionMetaConvertSubsetFields,None),
('StoragePnt','StoragePnt',EntityCollectionMetaConvertSubsetFields,None),
('StorageSrf','StorageSrf',EntityCollectionMetaConvertSubsetFields,None),
('StructureCrv','StructureCrv',EntityCollectionMetaConvertSubsetFields,None),
('StructurePnt','StructurePnt',EntityCollectionMetaConvertSubsetFields,None),
('StructureSrf','StructureSrf',EntityCollectionMetaConvertSubsetFields,None),
('SubterraneanSrf','SubterraneanSrf',EntityCollectionMetaConvertSubsetFields,None),
('TransportationGroundCrv','TransportationGroundCrv',EntityCollectionMetaConvertSubsetFields,None),
('TransportationGroundPnt','TransportationGroundPnt',EntityCollectionMetaConvertSubsetFields,None),
('TransportationGroundSrf','TransportationGroundSrf',EntityCollectionMetaConvertSubsetFields,None),
('TransportationWaterCrv','TransportationWaterCrv',EntityCollectionMetaConvertSubsetFields,None),
('TransportationWaterPnt','TransportationWaterPnt',EntityCollectionMetaConvertSubsetFields,None),
('TransportationWaterSrf','TransportationWaterSrf',EntityCollectionMetaConvertSubsetFields,None),
('UtilityInfrastructureCrv','UtilityInfrastructureCrv',EntityCollectionMetaConvertSubsetFields,None),
('UtilityInfrastructurePnt','UtilityInfrastructurePnt',EntityCollectionMetaConvertSubsetFields,None),
('UtilityInfrastructureSrf','UtilityInfrastructureSrf',EntityCollectionMetaConvertSubsetFields,None),
('VegetationCrv','VegetationCrv',EntityCollectionMetaConvertSubsetFields,None),
('VegetationPnt','VegetationPnt',EntityCollectionMetaConvertSubsetFields,None),
('VegetationSrf','VegetationSrf',EntityCollectionMetaConvertSubsetFields,None)
]
