﻿""" 
 ************************************************************************************************
 **                                                                                            **
 **  File: __Go_PerformTransformTests.py                                                       **
 **  Copyright (c) September 2018 by Leidos                                                    **
 **  Produced under U.S. Government contract W5J9CQ-12-D-0004  Task Order: 073                 **
 **  As per DFARS, the U.S. Government is granted unlimited rights to use this work            **
 **  in any manner and for any purpose.                                                        **
 **                                                                                            **
 **  Summary:   This file provides the starting point, for a test application                  **
 **                                                                                            **
 **  Developed by Leidos, Inc., High Resolution ISR Systems Division, Geospatial Programs      **
 **                                                                                            **
 **  Development History:                                                                      **
 **  9/27/2018 / Annette Janett Filer                                                          **
 **                                                                                            **
 **                                                                                            **
 ************************************************************************************************
"""
import Queue
from Tkinter import *
from ScrolledText import *
import tkFileDialog
import ttk
# from ttk import *
import ConfigParser
import sys
import os
import copy

import arcpy
import uuid
import glob
from GUISet_Special_Flags import Application_Set_Special_Settings
from GUISet_Special_Flags import Tooltip

from TranslateConfig import *
from DoTestsOfTransforms import *



class QueueLogger(logging.Handler):
    def __init__(self, queue):
        logging.Handler.__init__(self)
        self.queue = queue
 
    # write in the queue
    def emit(self, record):
        self.queue.put(self.format(record).rstrip('\n') + '\n')



class Application(Frame):
    """Main GUI"""

    def __init__(self, master=None):
        Frame.__init__(self, master)

        self.master = master
        self.settings = MyConfigSettings()
        self.settings.config_start_of_result_file = 'Test'
        #self.settings.flag_execution_of_app_is_in_compare_mode.set(0)

        # self.my_logger = self.settings.get_logger()

        # Queue where the logging handler will write
        self.logconsole = Queue.Queue()           


        self.threadcount = 0
        self.threaditem = None


        ##### CREATE WIDGETS ######################
        self.gobuttonstyle = ttk.Style()
        self.gobuttonstyle.configure('GoButton.TButton', background = 'maroon', foreground = 'black')

        self.pack()
        self.createWidgets()


        self.file_opt = options = {}
        options['defaultextension'] = '.gdb'
        options['filetypes'] = [('all files', '.*'), ('geodatabase files', '.gdb')]
        # options['filetypes'] = [('geodatabase files', '.gdb')]
        options['initialdir'] = 'C:\\'
        options['parent'] = root
        options['title'] = 'This is a title'

        self.dir_opt = options = {}
        options['initialdir'] = 'C:\\'
        options['mustexist'] = True
        options['parent'] = root
        options['title'] = 'This is a title'



 
               
    def perform_schema_compare(self):
        self.status_detail_replace("Save configuration")
        self.settings.save_config_settings()
        self.settings.start_logger()
        self.settings.prepgeodatabasesource()
        self.settings.prepgeodatabasetarget()

        # self.update_widget(self.log_widget, self.logconsole)
        self.status_detail_replace("Begin compare, see console screen for log")

        DoSelfTestOperations(self.settings)
        self.status_detail_insert("Compare complete, see console or log file for details")


    def save_updated_settings(self):
        # self.master.status_detail_replace("Save configuration")
        self.save_grouped_item( self.settings.debug_settings, self.settings.procdebugsettings)
        self.save_grouped_item( self.settings.maximum_records, self.settings.proclimitsconstraint)
        self.save_grouped_item( self.settings.config_setting_flag, self.settings.procflagsgeneral)
        self.save_grouped_item( self.settings.config_setting_flag, self.settings.procufiflags)
        #self.save_grouped_item( self.settings.config_setting_flag, self.settings.procoperationmode)
        self.save_grouped_item( self.settings.config_setting_flag, self.settings.proctestflags)


    def createsetsubwidg(self, startrow, gensettingsdict, procsettingsdict, guisettingdict, hostingframe):
        indii = 0
        for keyx in gensettingsdict:
            if keyx in procsettingsdict:
                #if procsettingsdict[keyx]['DefaultValue'] != procsettingsdict['TextValue']:
                guisettingdict[keyx] = dict()
                guisettingdict[keyx]['GUILabel'] = Label(hostingframe, text=procsettingsdict[keyx]['LabelName'], width=80)
                guisettingdict[keyx]['GUILabel'].grid(row=startrow + indii, column=2, columnspan=2, sticky = 'E')
                guisettingdict[keyx]['ComboBox'] = ttk.Combobox(hostingframe, textvariable = procsettingsdict[keyx]['TextVariable'], width = 30)
                guisettingdict[keyx]['ComboBox'].grid(row=startrow + indii, column = 10, sticky = 'E', padx = 2, pady = 2)
                guisettingdict[keyx]['ComboBox']['values'] = procsettingsdict[keyx]['ValuesList']
                if len(procsettingsdict[keyx]['ToolTip']) > 0:
                    guisettingdict[keyx]['Tooltip'] = Tooltip(guisettingdict[keyx]['ComboBox'], text=procsettingsdict[keyx]['ToolTip'], wraplength = 250)
                indii += 1
        return startrow + indii

    def createWidgets(self):

        self.master.title("{0}".format(self.settings.name_application_title.get()))
        self.QUIT = Button(self)
        self.QUIT["text"] = "Quit"
        # self.QUIT["fg"]   = "red"

        self.QUIT["command"] =  self.quit
        self.QUIT.grid(row=1,column=10)

        # TITLE TITLE TITLE
        self.TTITLE = Label(self, text=self.settings.app_title.get())
        self.TTITLE.grid(row=1, column = 0, sticky='NW', padx = 2, pady = 2)

        self.dblabel_blankaa = Label(self, text="  ")
        self.dblabel_blankaa.grid(row=2,column=1)

        # REPORTS REPORTS REPORTS
        # Frame for Log file specification
        self.logframe = LabelFrame(self, text="Reporting: Log file and statistics output files")
        self.logframe.grid(row=3, column=0, columnspan=10, sticky='NEW')

        self.SPEC_LOGABEL_A = Label(self.logframe, text="Specify Log File Location     ")
        self.SPEC_LOGABEL_A.grid(row=2,column=1, columnspan=5 )   
        self.SPEC_LOG_FILE = Button(self.logframe, text="Browse to Log File Location", command=self.getLogFileName)
        self.SPEC_LOG_FILE.grid(row=3, column=0, sticky='NW', padx=2, pady = 2)
        self.SPEC_LOG_FILE_RESULT = Entry(self.logframe, textvariable=self.settings.name_log_file, width = 80  )
        self.SPEC_LOG_FILE_RESULT.grid(row=3, column=1, columnspan=7, sticky="W", padx = 2, pady = 2)

        #self.CJLABEL_A = Label(self.logframe, text="Specifiy Excel Statistics File Location     ")
        #self.CJLABEL_A.grid(row=4,column=1, columnspan=5 ) 
        #self.CJBUTTON_SELECTFILE = Button(self.logframe, text="Browse to Excel File Directory", command=self.getExcelResultsDir)
        #self.CJBUTTON_SELECTFILE.grid(row=5, column=0, sticky='NW', padx=2, pady = 2)
        #self.CJENTRY_SELECTRESULT = Entry(self.logframe, textvariable=self.settings.file_results_excel, width = 80  )
        #self.CJENTRY_SELECTRESULT.grid(row=5, column=1, columnspan=7,  sticky="W", padx = 2, pady = 2)


        self.dblabel_blanka = Label(self, text="  ")
        self.dblabel_blanka.grid(row=4,column=1)
        
        # SOURCE AND TARGET, SOURCE AND TARGET, SOURCE AND TARGET
        # Frame for database selection area
        self.source_dbframe = LabelFrame(self, text="Source and Target Specification")
        self.source_dbframe.grid(row=5,column=0, columnspan=5, sticky='NEW')

        self.dblabel_a = Label(self.source_dbframe, text="                 Database path and name                        ")
        self.dblabel_a.grid(row=1,column=2, columnspan=5 )

        self.dblabel_b = Label(self.source_dbframe, text="Schema Version")
        self.dblabel_b.grid(row=1,column=9)

        #self.dblabel_c = Label(self.source_dbframe, text="Dataset")
        #self.dblabel_c.grid(row=1,column=10)
        
        rownum = 2

        self.source_dbbrowse = Button(self.source_dbframe, text="Browse to Source GeoDB:",command=self.getsourcedb)
        self.source_dbbrowse.grid(row=rownum, column=1, sticky='NW', padx=2, pady = 2)

        self.source_dbframeentry = Entry(self.source_dbframe, textvariable=self.settings.dir_source_geodatabase, width = 80 )
        self.source_dbframeentry.grid(row=rownum, column=2,  columnspan=7, sticky="NSEW", pady = 2)

        self.source_db_schema_name_and_versioncombo = ttk.Combobox(self.source_dbframe, textvariable = self.settings.sourcedb_name_and_version, width = 20)
        self.source_db_schema_name_and_versioncombo.grid(row=rownum, column = 9, sticky = 'E', padx = 2, pady = 2)
        self.source_db_schema_name_and_versioncombo['values'] = [
            'TDS 4.0', 'TDS 6.1', 'TDS 7.0', 'TDS 7.1', 'GGDM 2.1', 'GGDM 2.2', 'GGDM 3.0']
      
        #self.source_dbdatasetcombo = ttk.Combobox(self.source_dbframe, textvariable = self.settings.sourcedb_cgrls, width = 20)
        #self.source_dbdatasetcombo.grid(row=rownum, column = 10, sticky = 'E', padx = 2, pady = 2)
        #self.source_dbdatasetcombo['values'] = ['Unspecified', 'Composite', 'Global', 'Regional', 'Local', 'Specialized']


        rownum+=1

        self.target_dbbrowse = Button(self.source_dbframe, text="Browse to Target GeoDB:",command=self.gettargetdb)
        self.target_dbbrowse.grid(row=rownum, column=1, sticky='NW', padx=2, pady = 2)

        self.target_dbframeentry = Entry(self.source_dbframe, textvariable=self.settings.dir_target_geodatabase, width = 80  )
        self.target_dbframeentry.grid(row=rownum, column=2, columnspan=7, sticky="NSEW",padx=2, pady = 2)

        self.target_db_schema_name_and_versioncombo = ttk.Combobox(self.source_dbframe, textvariable = self.settings.targetdb_name_and_version, width = 20)
        self.target_db_schema_name_and_versioncombo.grid(row=rownum, column = 9, sticky = 'E', padx = 2, pady = 2)
        self.target_db_schema_name_and_versioncombo['values'] = \
            ['TDS 4.0',  'TDS 6.1', 'TDS 7.0', 'TDS 7.1', 'GGDM 2.1', 'GGDM 2.2', 'GGDM 3.0']

        #self.target_dbdatasetcombo = ttk.Combobox(self.source_dbframe, textvariable = self.settings.targetdb_cgrls, width = 20)
        #self.target_dbdatasetcombo.grid(row=rownum, column = 10, sticky = 'E', padx = 2, pady = 2)
        #self.target_dbdatasetcombo['values'] = ['Unspecified', 'Composite', 'Global', 'Regional', 'Local', 'Specialized']

        rownum +=1
        self.dblabel_blankr1 = Label(self.source_dbframe, text="  ")
        self.dblabel_blankr1.grid(row=rownum,column=1)

        #rownum+=1
        #self.dblabel_mv = Label(self.source_dbframe, text="For source schema 'unknown' provide excel mapping file")
        #self.dblabel_mv.grid(row=rownum,column=1, columnspan=8)
        #rownum+=1
        #self.mappingfile_dbbrowse = Button(self.source_dbframe, text="Browse to Mapping Spec (XLS):",command=self.getmappingfile)
        #self.mappingfile_dbbrowse.grid(row=rownum, column=1, sticky='NW', padx=2, pady = 2)

        #self.mappingfile_frameentry = Entry(self.source_dbframe, textvariable=self.settings.file_mapping_specification, width = 60  )
        #self.mappingfile_frameentry.grid(row=rownum, column=2, columnspan=5, sticky="NSEW", padx=2, pady = 2)

        self.dblabel_blankb = Label(self, text="  ")
        self.dblabel_blankb.grid(row=7,column=1)

        ### START BUTTONS, START BUTTONS, START BUTTONS

        self.xlatenow = Button(self)
        self.xlatenow["text"] = "Perform Transform Tests"
        self.xlatenow["command"] = self.perform_schema_compare
        self.xlatenow.grid(row=10,column=1)


        self.dblabel_blankc = Label(self, text="  ")
        self.dblabel_blankc.grid(row=11,column=1)


        # Frame for flags selection
        self.logframe = LabelFrame(self, text=" Status ")
        self.logframe.grid(row=20,column=0, columnspan=5, sticky='NEW')
        

        self.BUTENTRY_A3E_1 = ScrolledText(self.logframe, width = 80, height=15, takefocus=False, wrap="word"    )
        self.BUTENTRY_A3E_1.grid(row=1, column=2,  padx=2, pady = 6,  columnspan=6, ipady=2)

    def save_grouped_item(self, generalsettingsdict, procsettingsdict):
        for keyx in generalsettingsdict:
            if keyx in procsettingsdict:
                txtkey = procsettingsdict[keyx]['TextVariable'].get()
                # Set the IntVariable based on the TextVariable, and also set the main dictionary integer
                procsettingsdict[keyx]['IntVariable'].set( procsettingsdict[keyx]['OptionCombo'][txtkey] )
                generalsettingsdict[keyx] = procsettingsdict[keyx]['OptionCombo'][txtkey]  

    def save_updated_settings(self):
        # self.master.status_detail_replace("Save configuration")
        self.save_grouped_item( self.settings.debug_settings, self.settings.procdebugsettings)
        self.save_grouped_item( self.settings.maximum_records, self.settings.proclimitsconstraint)
        self.save_grouped_item( self.settings.config_setting_flag, self.settings.procflagsgeneral)
        self.save_grouped_item( self.settings.config_setting_flag, self.settings.procufiflags)
        #self.save_grouped_item( self.settings.config_setting_flag, self.settings.procoperationmode)
   #     self.save_grouped_item( self.settings.config_setting_flag, self.settings.proctestflags)
        self.settings.save_config_settings()

    def status_detail_replace(self, detailtext):
        vvar = detailtext
        self.BUTENTRY_A3E_1.delete('1.0', END)    # Note an element is entry.delete(0, END)
        if vvar <> "":
            self.BUTENTRY_A3E_1.insert('1.0', vvar)
        else:
            self.BUTENTRY_A3E_1.insert('1.0', 'This is the detailed status area. Use the button above to start the process')
        self.master.update_idletasks()
        self.master.after(1)
        self.master.update_idletasks()


    def status_detail_insert(self, detailtext):
        vvar = detailtext
        if vvar <> "":
            vvar = "\n{0}".format(detailtext)
            self.BUTENTRY_A3E_1.insert(END, vvar)
            self.BUTENTRY_A3E_1.see(END)
        self.master.update_idletasks()
        self.master.after(1)
        self.master.update_idletasks()


    def update_widget(self, widget, queue):
        widget.config(state='normal')
        # Read from the Queue and add to the log widger
        while not queue.empty():
            line = queue.get()
            widget.insert('END', line)
            widget.see('END')  # Scroll to the bottom
            widget.update_idletasks()
        widget.config(state='disabled')
        self.logger_alarm = widget.after(10, self.update_widget, widget, queue)
        self.master.after(1)
        self.master.update_idletasks()



    def selectAFile(self, instring, defaultext, filetypes):
        file_opt = options = {}
        options['defaultextension'] = defaultext
        options['filetypes'] = filetypes
        options['initialdir'] = os.path.expanduser(r'~\Documents')
        options['parent'] = self.master
        options['title'] = instring
        # filesin = tkFileDialog.askopenfilenames(parent=mdir, title=instring)
        filez = tkFileDialog.askopenfilename(**file_opt)
        return os.path.normpath(filez)
 
    
    def selectADir(self, instring):
        dir_opt = options = {}
        options['mustexist'] = True
        options['initialdir'] = os.path.expanduser(r'~\Documents')
        options['parent'] = self.master
        options['title'] = instring
        filez = tkFileDialog.askdirectory(**dir_opt)
        return os.path.normpath(filez)
    
              
    def getsourcedb(self):
        tempdir = self.selectADir("Source Geodatabase")
        if tempdir is not None:
            self.settings.dir_source_geodatabase.set(tempdir)
        # self.source_dblbl.text = self.sourcefilename
        

    def gettargetdb(self):
        tempdir = self.selectADir("Target Geodatabase")
        if tempdir is not None:
            self.settings.dir_target_geodatabase.set(tempdir)
        
    def getmappingfile(self):
        tempdir = self.selectAFile("Excel Mapping Specification", ".xls", "Excel")
        if tempdir is not None:
            self.settings.file_mapping_specification.set(tempdir)
             

    def getLogFileName(self):
        bdir = self.selectADir("Directory for Log File")
        self.settings.prepare_log_file_name(bdir)

    def getExcelResultsDir(self):
        tfile = self.selectADir("Directory for Excel Results File")
        self.settings.prepare_file_results_excel(tfile)
        # This call will set self.settings.file_results.excel
                

        

root = Tk()
app = Application(master=root) 
app.mainloop()
root.destroy()
