# -*- coding: utf-8 -*-

""" 
 ************************************************************************************************
 **                                                                                            **
 **  File: parseOTH.py                                                                         **
 **  Copyright (c) March 2016 by Leidos                                                        **
 **  Produced under U.S. Government contract W5J9CQ-12-D-0004  Task Order: 053.                **
 **  As per DFARS, the U.S. Government is granted unlimited rights to use this work            **
 **  in any manner and for any purpose.                                                        **
 **                                                                                            **
 **  Summary:   This file makes use of the python parsing capability to parse the              **
 **             OTH Other Enumerants attribute                                                 **
 **             Note that you can add test cases within this file.
 **             Uncomment the test cases and test code below and then you can test the
 **             OTH parser by simply running this script.
 **                                                                                            **
 **  Developed by Leidos, Inc., High Resolution ISR Systems Division, Geospatial Programs      **
 **                                                                                            **
 **  Development History:                                                                      **
 **  March 2016 / Annette Janett Filer (Annette.J.Filer@leidos.com) Original version           **
 **                                                                                            **
 **                                                                                            **
 ************************************************************************************************
"""

from pyparsing import *

def is_number(s):
    try:
        float(s)
        return True
    except ValueError:
        pass
 
    try:
        import unicodedata
        unicodedata.numeric(s)
        return True
    except (TypeError, ValueError):
        pass
    return False



# returns a list of OTH entries, for example say we had OTH = (FFN:3=name of 3)(TRS2:Bus)  (TRS:2)
# we want to get out of this:
# ( ('FFN', 3, 'name of 3'), ('TRS2', None, 'Bus'), ('TRS', 2, None) )
def parseOTHentry(inOTHstr):
    # if there are no parens in the OTH string, we cannot parse it
    if '(' not in inOTHstr:
        return [{'inputvalue':inOTHstr, 'result':None}]
    # if there is no colon in the string, we cannot parse it
    if ':' not in inOTHstr:
        return [{'inputvalue':inOTHstr, 'result':None}]

    LParen = Suppress(Literal('('))
    RParen = Suppress(Literal(')'))
    Equal = Suppress(Literal('='))
    Colon = Suppress(Literal(':'))
    WSpace = Suppress(Optional(White()))
    Between = Suppress(Optional(Literal(',')))
    
    
    OTHAttribute =  Word(alphanums + '_') 
    #  OTHContent =  Word(alphanums + '_' + " " + "/" + "|")
    OTHContent = CharsNotIn('(' + ')' + '=' + ':')
    OTHValue =  Word(nums + '.') 
    pattern1 = Group(LParen + WSpace + OTHAttribute + WSpace + Colon + WSpace + OTHValue + WSpace + RParen + WSpace + Between + WSpace)
    pattern2 = Group(LParen + WSpace + OTHAttribute + WSpace + Colon + WSpace + OTHContent + WSpace + RParen + WSpace + Between + WSpace)
    pattern3 = Group(LParen + WSpace + OTHAttribute + WSpace + Colon + WSpace + OTHValue + Equal + WSpace + OTHContent + WSpace + RParen + WSpace + Between + WSpace)
    pattern4 = Group(LParen + WSpace + OTHAttribute + WSpace + Equal + WSpace + OTHContent + WSpace + RParen + WSpace + Between + WSpace)

    #set up for parsing OTH
    multpatern = ZeroOrMore(pattern4 ^ pattern1 ^ pattern3 ^ pattern2)
    try:
        tempresult = multpatern.parseString(inOTHstr)
    except ParseException, err:
        print err.line
        print " "*(err.column-1) + "^"
        print err   
        tempresult = []
        tempresult.append(inOTHstr)

    resultout = []
    

    if len(tempresult) == 0 :
        resultout = [{'inputvalue':inOTHstr, 'result':None}]
    else:
        ii = 0
        for resultval in tempresult:
            llltempresult = len(resultval)
            #print "Length: {0}".format(llltempresult)
            #print resultval
            tempdict  = {}
            tempdict['inputvalue'] = inOTHstr
            tempdict['fieldname'] = resultval[0]
            tempdict['result'] = 'parsed'
            if is_number(resultval[1]):
                tempdict['indexvalue'] = int(resultval[1])
                tempdict['result'] = 'parsed with index'
            else:
                tempdict['stringvalue'] = resultval[1]
                tempdict['result'] = 'parsed with string'
            if llltempresult == 3:
                if 'stringvalue' not in tempdict:
                    tempdict['stringvalue'] = resultval[2]
                    tempdict['result'] = 'parsed with index and string'
                else:
                    tempdict['stringvalue2'] = resultval[2]
            if llltempresult > 3:
                tempdict['extra' + ii] = resultval[ii]
            ii = ii + 1
            resultout.append(tempdict)
            
    return (resultout)


def get_len_OTH_rtn_items(inlist):
    if len(inlist) < 1:
        return 0
    counter = 0
    for listitem in inlist:
        if 'result' in listitem:
            if listitem['result'] is not None:
                counter = counter + 1
    return counter

def get_OTH_rtn_inputvalue(inlist, indexii):
    if len(inlist) < indexii:
        return None
    counter = 0
    for listitem in inlist:
        if counter == indexii:
            if 'inputvalue' in listitem:
                return listitem['inputvalue']
        else:
            counter = counter + 1
    return None

def get_OTH_rtn_field(inlist, indexii):
    if len(inlist) < indexii:
        return None
    counter = 0
    for listitem in inlist:
        if 'result' in listitem:
            if listitem['result'] is not None and counter == indexii:
                if 'fieldname' in listitem:
                    return listitem['fieldname']
            else:
                counter = counter + 1
    return None

def get_OTH_rtn_index_value(inlist, indexii):
    if len(inlist) < indexii:
        return None
    counter = 0
    for listitem in inlist:
        if 'result' in listitem:
            if listitem['result'] is not None and counter == indexii:
                if 'indexvalue' in listitem:
                    return listitem['indexvalue']
            else:
                counter = counter + 1
    return None

def get_OTH_rtn_string_value(inlist, indexii):
    if len(inlist) < indexii:
        return None
    counter = 0
    for listitem in inlist:
        if 'result' in listitem:
            if listitem['result'] is not None and counter == indexii:
                if 'stringvalue' in listitem:
                    return listitem['stringvalue']
            else:
                counter = counter + 1
    return None


####### Test values from real data sets
##OTHList = []
##OTHList.append('(FFN:932=Islamic Prayer Hall)(ZI037_REL:2=Islam)')
##OTHList.append('(FFN2:513=Harbour Control) (FFN3=Canal Transport)')
##OTHList.append('(FFN:Important Tourist Attraction | Building)')
##OTHList.append('(FFN2:Embassy/Consulate)')
##OTHList.append('(TRS:1=Aeronautical) ')
##OTHList.append('(ZI019_ASP:Hard/Paved)  (ZI019_ASU:PEM) ')
##OTHList.append('(FFN2:Construction/Property) ')
##OTHList.append('(ZI019_ASP:Hard/Paved) ')
##OTHList.append('(ADI:Regional Park) ')
##OTHList.append('(TRS:4=Bus) ')
##OTHList.append('(APY:Alert Apron/Hardstand), (ZI019_ASP:Hard/Paved) ')
##OTHList.append('(FFN:Important Tourist Attraction | Building) ')
##OTHList.append('(FFN:932=Islamic Prayer Hall) ')
##OTHList.append('(TRS:3=Automotive) ')
##OTHList.append('(ZI005_FNA:NWEREME)(TEST:TEST) ')
##OTHList.append('(ZI005_FNA:NWEREME) Fétéko ')
##OTHList.append('Ba ou Babilé ')
##OTHList.append('(TRS:Cart Track) ')
##OTHList.append('(TRS:1=Aeronautical) ')
####
####
####
#####print OTH
##print "Results: "
##for  OTH in OTHList:
##    print OTH
##    rezz = []
##    rezz = parseOTHentry(OTH)
##    print "Count OTH items parsed: {0}".format(get_len_OTH_rtn_items(rezz))
##    for ii in range(get_len_OTH_rtn_items(rezz)):
##        fieldname = get_OTH_rtn_field(rezz, ii)
##        indexvalue = get_OTH_rtn_index_value(rezz, ii)
##        stringvalue = get_OTH_rtn_string_value(rezz, ii)
##        print "Field: {0} Index: {1}  String: {2}".format(fieldname, indexvalue, stringvalue)
##
