﻿

""" 
 ************************************************************************************************
 **                                                                                            **
 **  File: FieldValueMappings.py                                                               **
 **  Copyright (c) December 2015 by Leidos                                                     **
 **  Produced under U.S. Government contract W5J9CQ-12-D-0004  Task Order: 053 and 064 and 073.  **
 **  As per DFARS, the U.S. Government is granted unlimited rights to use this work            **
 **  in any manner and for any purpose.                                                        **
 **                                                                                            **
 **  Summary:   This file allows for mappings of common attribute fields where the source      **
 **             and destination values are well defined. For instance, this will provide       **
 **             for the mapping of 3-char ISO country code (IC2) to GENC (GE4) attribute       **
 **             as well as the reverse.                                                        **
 **             This also provides for the mapping of enumerated domain value metadata to      **
 **             or from the codelist (textual) values.                                         **
 **             All operations allow for terms input with expected camel-case OR lowercase.    **
 **             Output values are delivered in the expected camel-case form.                   **
 **                                                                                            **
 **  Developed by Leidos, Inc., High Resolution ISR Systems Division, Geospatial Programs      **
 **                                                                                            **
 **  Development History:                                                                      **
 **  December 2015 / Annette Janett Filer                                                      **
 **  May 2016 / AF - Added transforms for SSY and NSP to Source Type SRT
 **  9/27/2018 Consistency review
 **  3/5/2020  Updated RCG values to include the additional values specified by NSG
 **  
 **                                                                                            **
 **                                                                                            **
 ************************************************************************************************
"""

# Import required system modules
import os, sys
import arcpy

CountryNameToGE4 = {}
CountryNameToGE4["Afghanistan"] = "ge:GENC:3:1-2:AFG"
CountryNameToGE4["Albania"] = "ge:GENC:3:1-2:ALB"
CountryNameToGE4["Algeria"] = "ge:GENC:3:1-2:DZA"
CountryNameToGE4["Angola"] = "ge:GENC:3:1-2:AGO"
CountryNameToGE4["Antigua and Barbuda"] = "ge:GENC:3:1-2:ATG"
CountryNameToGE4["Argentina"] = "ge:GENC:3:1-2:ARG"
CountryNameToGE4["Armenia"] = "ge:GENC:3:1-2:ARM"
CountryNameToGE4["Australia"] = "ge:GENC:3:1-2:AUS"
CountryNameToGE4["Austria"] = "ge:GENC:3:1-2:AUT"
CountryNameToGE4["Azerbaijan"] = "ge:GENC:3:1-2:AZE"
CountryNameToGE4["Bangladesh"] = "ge:GENC:3:1-2:BGD"
CountryNameToGE4["Belarus"] = "ge:GENC:3:1-2:BLR"
CountryNameToGE4["Belgium"] = "ge:GENC:3:1-2:BEL"
CountryNameToGE4["Belize"] = "ge:ISO1:3:VI-15:BLZ"
CountryNameToGE4["Benin"] = "ge:GENC:3:1-2:BEN"
CountryNameToGE4["Bhutan"] = "ge:GENC:3:1-2:BTN"
CountryNameToGE4["Bolivia"] = "ge:GENC:3:1-2:BOL"
CountryNameToGE4["Bosnia and Herzegovina"] = "ge:ISO1:3:VI-15:BIH"
CountryNameToGE4["Botswana"] = "ge:GENC:3:1-2:BWA"
CountryNameToGE4["Brazil"] = "ge:GENC:3:1-2:BRA"
CountryNameToGE4["Brunei"] = "ge:GENC:3:1-2:BRN"
CountryNameToGE4["Bulgaria"] = "ge:GENC:3:1-2:BGR"
CountryNameToGE4["Burkina Faso"] = "ge:GENC:3:1-2:BFA"
CountryNameToGE4["Burundi"] = "ge:GENC:3:1-2:BDI"
CountryNameToGE4["Cambodia"] = "ge:GENC:3:1-2:KHM"
CountryNameToGE4["Cameroon"] = "ge:GENC:3:1-2:CMR"
CountryNameToGE4["Canada"] = "ge:GENC:3:1-2:CAN"
CountryNameToGE4["Central African Republic"] = "ge:GENC:3:1-2:CAF"
CountryNameToGE4["Chad"] = "ge:GENC:3:1-2:TCD"
CountryNameToGE4["Chile"] = "ge:GENC:3:1-2:CHL"
CountryNameToGE4["China"] = "ge:GENC:3:1-2:CHN"
CountryNameToGE4["Colombia"] = "ge:GENC:3:1-2:COL"
CountryNameToGE4["Costa Rica"] = "ge:GENC:3:1-2:CRI"
CountryNameToGE4["Croatia"] = "ge:GENC:3:1-2:HRV"
CountryNameToGE4["Cuba"] = "ge:GENC:3:1-2:CUB"
CountryNameToGE4["Cyprus"] = "ge:GENC:3:1-2:CYP"
CountryNameToGE4["Czech Republic"] = "ge:GENC:3:1-2:CZE"

CountryNameToGE4["Denmark"] = "ge:GENC:3:1-2:DNK"
CountryNameToGE4["Djibouti"] = "ge:GENC:3:1-2:DJI"
CountryNameToGE4["Dominican Republic"] = "ge:GENC:3:1-2:DOM"
CountryNameToGE4["Ecuador"] = "ge:GENC:3:1-2:ECU"
CountryNameToGE4["Egypt"] = "ge:GENC:3:1-2:EGY"
CountryNameToGE4["El Salvador"] = "ge:GENC:3:1-2:SLV"
CountryNameToGE4["Eritrea"] = "ge:GENC:3:1-2:ERI"
CountryNameToGE4["Estonia"] = "ge:GENC:3:1-2:EST"
CountryNameToGE4["Ethiopia"] = "ge:GENC:3:1-2:ETH"
CountryNameToGE4["Fiji"] = "ge:GENC:3:1-2:FJI"
CountryNameToGE4["Finland"] = "ge:GENC:3:1-2:FIN"
CountryNameToGE4["France"] = "ge:GENC:3:1-2:FRA"
CountryNameToGE4["Gabon"] = "ge:GENC:3:1-2:GAB"
CountryNameToGE4["Gambia"] = "ge:GENC:3:1-2:GMB"
CountryNameToGE4["Georgia"] = "ge:GENC:3:1-2:GEO"
CountryNameToGE4["Germany"] = "ge:GENC:3:1-2:DEU"
CountryNameToGE4["Ghana"] = "ge:GENC:3:1-2:GHA"
CountryNameToGE4["Greece"] = "ge:GENC:3:1-2:GRC"
CountryNameToGE4["Guatemala"] = "ge:GENC:3:1-2:GTM"
CountryNameToGE4["Guinea"] = "ge:GENC:3:1-2:GIN"
CountryNameToGE4["Guinea Bissau"] = "ge:GENC:3:1-2:GNB"
CountryNameToGE4["Guyana"] = "ge:GENC:3:1-2:GUY"
CountryNameToGE4["Haiti"] = "ge:GENC:3:1-2:HTI"
CountryNameToGE4["Honduras"] = "ge:GENC:3:1-2:HND"
CountryNameToGE4["Hungary"] = "ge:ISO1:3:VI-15:HUN"
CountryNameToGE4["Iceland"] = "ge:GENC:3:1-2:ISL"
CountryNameToGE4["India"] = "ge:GENC:3:1-2:IND"
CountryNameToGE4["Indonesia"] = "ge:GENC:3:1-2:IDN"
CountryNameToGE4["Iran"] = "ge:GENC:3:1-2:IRN"
CountryNameToGE4["Iraq"] = "ge:GENC:3:1-2:IRQ"
CountryNameToGE4["Ireland"] = "ge:ISO1:3:VI-15:IRL"
CountryNameToGE4["Israel"] = "ge:GENC:3:1-2:ISR"
CountryNameToGE4["Italy"] = "ge:GENC:3:1-2:ITA"

CountryNameToGE4["Jamaica"] = "ge:ISO1:3:VI-15:JAM"
CountryNameToGE4["Japan"] = "ge:ISO1:3:VI-15:JPN"
CountryNameToGE4["Jordan"] = "ge:GENC:3:1-2:JOR"
CountryNameToGE4["Kazakhstan"] = "ge:GENC:3:1-2:KAZ"
CountryNameToGE4["Kenya"] = "ge:GENC:3:1-2:KEN"
CountryNameToGE4["Kiribati"] = "ge:GENC:3:1-2:KIR"
CountryNameToGE4["Kosovo"] = "ge:GENC:3:1-2:XKS"
CountryNameToGE4["Kuwait"] = "ge:GENC:3:1-2:KWT"
CountryNameToGE4["Kyrgyzstan"] = "ge:GENC:3:1-2:KGZ"
CountryNameToGE4["Laos"] = "ge:GENC:3:1-2:LAO"
CountryNameToGE4["Latvia"] = "ge:GENC:3:1-2:LVA"
CountryNameToGE4["Lebanon"] = "ge:GENC:3:1-2:LBN"
CountryNameToGE4["Lesotho"] = "ge:GENC:3:1-2:LSO"
CountryNameToGE4["Liberia"] = "ge:GENC:3:1-2:LBR"
CountryNameToGE4["Libya"] = "ge:ISO1:3:VI-15:LBY"
CountryNameToGE4["Lithuania"] = "ge:GENC:3:1-2:LTU"
CountryNameToGE4["Luxembourg"] = "ge:GENC:3:1-2:LUX"
CountryNameToGE4["Macedonia"] = "ge:GENC:3:1-2:MKD"
CountryNameToGE4["Madagascar"] = "ge:GENC:3:1-2:MDG"
CountryNameToGE4["Malawi"] = "ge:GENC:3:1-2:MWI"
CountryNameToGE4["Malaysia"] = "ge:GENC:3:1-2:MYS"
CountryNameToGE4["Mali"] = "ge:GENC:3:1-2:MLI"
CountryNameToGE4["Mauritania"] = "ge:GENC:3:1-2:MRT"
CountryNameToGE4["Mauritius"] = "ge:GENC:3:1-2:MUS"
CountryNameToGE4["Mexico"] = "ge:GENC:3:1-2:MEX"
CountryNameToGE4["Moldova"] = "ge:GENC:3:1-2:MDA"
CountryNameToGE4["Mongolia"] = "ge:GENC:3:1-2:MNG"
CountryNameToGE4["Montenegro"] = "ge:ISO1:3:VI-15:MNE"
CountryNameToGE4["Morocco"] = "ge:GENC:3:1-2:MAR"
CountryNameToGE4["Mozambique"] = "ge:GENC:3:1-2:MOZ"

CountryNameToGE4["Namibia"] = "ge:GENC:3:1-2:NAM"
CountryNameToGE4["Nepal"] = "ge:GENC:3:1-2:NPL"
CountryNameToGE4["Netherlands"] = "ge:GENC:3:1-2:NLD"
CountryNameToGE4["New Zealand"] = "ge:GENC:3:1-2:NZL"
CountryNameToGE4["Nicaragua"] = "ge:GENC:3:1-2:NIC"
CountryNameToGE4["Niger"] = "ge:GENC:3:1-2:NER"
CountryNameToGE4["Nigeria"] = "ge:GENC:3:1-2:NGA"
CountryNameToGE4["North Korea"] = "ge:GENC:3:1-2:PRK"
CountryNameToGE4["Norway"] = "ge:GENC:3:1-2:NOR"
CountryNameToGE4["Oman"] = "ge:GENC:3:1-2:OMN"
CountryNameToGE4["Pakistan"] = "ge:GENC:3:1-2:PAK"
CountryNameToGE4["Panama"] = "ge:GENC:3:1-2:PAN"
CountryNameToGE4["Papua New Guinea"] = "ge:ISO1:3:VI-15:PNG"
CountryNameToGE4["Paraguay"] = "ge:GENC:3:1-2:PRY"
CountryNameToGE4["Peru"] = "ge:GENC:3:1-2:PER"
CountryNameToGE4["Philippines"] = "ge:GENC:3:1-2:PHL"
CountryNameToGE4["Poland"] = "ge:GENC:3:1-2:POL"
CountryNameToGE4["Portugal"] = "ge:GENC:3:1-2:PRT"

CountryNameToGE4["Republic of Serbia"] = "ge:GENC:3:1-2:SRB"
CountryNameToGE4["Romania"] = "ge:ISO1:3:VI-15:ROU"
CountryNameToGE4["Russia"] = "ge:GENC:3:1-2:RUS"
CountryNameToGE4["Rwanda"] = "ge:GENC:3:1-2:RWA"
CountryNameToGE4["Saint Kitts and Nevis"] = "ge:GENC:3:1-2:KNA"
CountryNameToGE4["Samoa"] = "ge:GENC:3:1-2:WSM"
CountryNameToGE4["Saudi Arabia"] = "ge:GENC:3:1-2:SAU"
CountryNameToGE4["Senegal"] = "ge:GENC:3:1-2:SEN"
CountryNameToGE4["Sierra Leone"] = "ge:GENC:3:1-2:SLE"
CountryNameToGE4["Singapore"] = "ge:GENC:3:1-2:SGP"
CountryNameToGE4["Slovakia"] = "ge:GENC:3:1-2:SVK"
CountryNameToGE4["Slovenia"] = "ge:GENC:3:1-2:SVN"
CountryNameToGE4["Solomon Islands"] = "ge:GENC:3:1-2:SLB"
CountryNameToGE4["Somalia"] = "ge:GENC:3:1-2:SOM"
CountryNameToGE4["South Africa"] = "ge:GENC:3:1-2:ZAF"
CountryNameToGE4["South Korea"] = "ge:GENC:3:1-2:KOR"
CountryNameToGE4["South Sudan"] = "ge:GENC:3:1-2:SSD"
CountryNameToGE4["Spain"] = "ge:GENC:3:1-2:ESP"
CountryNameToGE4["Sri Lanka"] = "ge:GENC:3:1-2:LKA"
CountryNameToGE4["Sudan"] = "ge:GENC:3:1-2:SDN"
CountryNameToGE4["Suriname"] = "ge:GENC:3:1-2:SUR"
CountryNameToGE4["Swaziland"] = "ge:GENC:3:1-2:SWZ"
CountryNameToGE4["Sweden"] = "ge:GENC:3:1-2:SWE"
CountryNameToGE4["Switzerland"] = "ge:GENC:3:1-2:CHE"
CountryNameToGE4["Syria"] = "ge:GENC:3:1-2:SYR"
CountryNameToGE4["Taiwan"] = "ge:GENC:3:1-2:TWN"
CountryNameToGE4["Tajikistan"] = "ge:GENC:3:1-2:TJK"
CountryNameToGE4["Thailand"] = "ge:GENC:3:1-2:THA"
CountryNameToGE4["The Bahamas"] = "ge:GENC:3:1-2:BHS"
CountryNameToGE4["Togo"] = "ge:GENC:3:1-2:TGO"
CountryNameToGE4["Tonga"] = "ge:GENC:3:1-2:TON"
CountryNameToGE4["Trinidad and Tobago"] = "ge:GENC:3:1-2:TTO"
CountryNameToGE4["Tunisia"] = "ge:GENC:3:1-2:TUN"
CountryNameToGE4["Turkey"] = "ge:GENC:3:1-2:TUR"
CountryNameToGE4["Turkmenistan"] = "ge:ISO1:3:VI-15:TKM"
CountryNameToGE4["Uganda"] = "ge:GENC:3:1-2:UGA"
CountryNameToGE4["Ukraine"] = "ge:GENC:3:1-2:UKR"
CountryNameToGE4["United Arab Emirates"] = "ge:GENC:3:1-2:ARE"
CountryNameToGE4["United Kingdom"] = "ge:GENC:3:1-2:GBR"
CountryNameToGE4["United Republic of Tanzania"] = "ge:GENC:3:1-2:TZA"
CountryNameToGE4["United States of America"] = "ge:GENC:3:1-2:USA"
CountryNameToGE4["Uruguay"] = "ge:GENC:3:1-2:URY"
CountryNameToGE4["Uzbekistan"] = "ge:GENC:3:1-2:UZB"
CountryNameToGE4["Vanuatu"] = "ge:GENC:3:1-2:VUT"
CountryNameToGE4["Venezuela"] = "ge:GENC:3:1-2:VEN"
CountryNameToGE4["Vietnam"] = "ge:GENC:3:1-2:VNM"
CountryNameToGE4["Yemen"] = "ge:GENC:3:1-2:YEM"
CountryNameToGE4["Zambia"] = "ge:GENC:3:1-2:ZMB"
CountryNameToGE4["Zimbabwe"] = "ge:GENC:3:1-2:ZWE"
CountryNameToGE4["Ivory Coast"] = "other"
CountryNameToGE4["Myanmar"] = "other"
CountryNameToGE4["Republic of Congo"] = "other"
CountryNameToGE4["Democratic Republic of the Congo"] = "other"
CountryNameToGE4["other"] = "other"


codelist2enumvalue_mappings = {}
codelist2enumvalue_mappings["CPS2CPS"] = "CPScodelist2CPSenumvalue"
codelist2enumvalue_mappings["ETS2ETS"] = "ETScodelist2ETSenumvalue"
codelist2enumvalue_mappings["HZD2HZD"] = "HZDcodelist2HZDenumvalue"
codelist2enumvalue_mappings["VDT2VDT"] = "VDTcodelist2VDTenumvalue"
codelist2enumvalue_mappings["RCG2RCG"] = "RCGcodelist2RCGenumvalue"
codelist2enumvalue_mappings["ZI001_SRT2ZI001_SRT"] = "ZI001_SRTcodelist2ZI001_SRTenumvalue"
codelist2enumvalue_mappings["ZI001_VSC2ZI001_VSC"] = "ZI001_VSCcodelist2ZI001_VSCenumvalue"
codelist2enumvalue_mappings["ZI004_RCG2ZI004_RCG"] = "ZI004_RCGcodelist2ZI004_RCGenumvalue"

enumvalue2codelist_mappings = {"CPS2CPS": "CPSenumvalue2CPScodelist", "ETS2ETS": "ETSenumvalue2ETScodelist",
                               "HZD2HZD": "HZDenumvalue2HZDcodelist", "VDT2VDT": "VDTenumvalue2VDTcodelist",
                               "RCG2RCG": "RCGenumvalue2RCGcodelist",
                               "ZI001_SRT2ZI001_SRT": "ZI001_SRTenumvalue2ZI001_SRTcodelist",
                               "ZI001_VSC2ZI001_VSC": "ZI001_VSCenumvalue2ZI001_VSCcodelist",
                               "ZI004_RCG2ZI004_RCG": "ZI004_RCGenumvalue2ZI004_RCGcodelist",
                               "ZI001_SRT2ZI001_SSY": "ZI001_SRTenumvalue2ZI001_SSYcodelist",
                               "ZI001_SRT2ZI001_NSP": "ZI001_SRTenumvalue2ZI001_NSPcodelist"}

codelist2codelist_mappings = {"GE42IC2": "GE4codelist2IC2codelist", "IC22GE4": "IC2codelist2GE4codelist"}

EQCcodelist2numericEQS = {}
EQCcodelist2numericEQS['scale100k'] = 100000
EQCcodelist2numericEQS['scale12r5k'] = 12500
EQCcodelist2numericEQS['scale1m'] = 1000000
EQCcodelist2numericEQS['scale250k'] = 250000
EQCcodelist2numericEQS['scale25k'] = 25000
EQCcodelist2numericEQS['scale2m'] = 2000000
EQCcodelist2numericEQS['scale500k'] = 500000
EQCcodelist2numericEQS['scale50k'] = 50000
EQCcodelist2numericEQS['scale5k'] = 5000
EQCcodelist2numericEQS['scale5m'] = 5000000
EQCcodelist2numericEQS['other'] = 999
EQCcodelist2numericEQS['Other'] = 999
EQCcodelist2numericEQS['noInformation'] = -999999
EQCcodelist2numericEQS['noinformation'] = -999999

EQSnumeric2codelistEQC = {}
EQSnumeric2codelistEQC[100000] = 'scale100k'
EQSnumeric2codelistEQC[12500] = 'scale12r5k'
EQSnumeric2codelistEQC[1000000] = 'scale1m'
EQSnumeric2codelistEQC[250000] = 'scale250k'
EQSnumeric2codelistEQC[25000] = 'scale25k'
EQSnumeric2codelistEQC[2000000] = 'scale2m'
EQSnumeric2codelistEQC[500000] = 'scale500k'
EQSnumeric2codelistEQC[50000] = 'scale50k'
EQSnumeric2codelistEQC[5000] = 'scale5k'
EQSnumeric2codelistEQC[5000000]  = 'scale5m'
EQSnumeric2codelistEQC[999] = 'other'
EQSnumeric2codelistEQC[-999999] = 'noInformation'

GE4codelist2IC2codelist = {}
GE4codelist2IC2codelist["ge:GENC:3:1-2:ABW"] = "ABW"
GE4codelist2IC2codelist["ge:GENC:3:1-2:AFG"] = "AFG"
GE4codelist2IC2codelist["ge:GENC:3:1-2:AGO"] = "AGO"
GE4codelist2IC2codelist["ge:GENC:3:1-2:ALB"] = "ALB"
GE4codelist2IC2codelist["ge:GENC:3:1-2:AND"] = "AND"
GE4codelist2IC2codelist["ge:GENC:3:1-2:ARE"] = "ARE"
GE4codelist2IC2codelist["ge:GENC:3:1-2:ARG"] = "ARG"
GE4codelist2IC2codelist["ge:GENC:3:1-2:ARM"] = "ARM"
GE4codelist2IC2codelist["ge:GENC:3:1-2:ASM"] = "ASM"
GE4codelist2IC2codelist["ge:GENC:3:1-2:ATF"] = "ATF"
GE4codelist2IC2codelist["ge:GENC:3:1-2:ATG"] = "ATG"
GE4codelist2IC2codelist["ge:GENC:3:1-2:AUS"] = "AUS"
GE4codelist2IC2codelist["ge:GENC:3:1-2:AUT"] = "AUT"
GE4codelist2IC2codelist["ge:GENC:3:1-2:AX1"] = "AX1"
GE4codelist2IC2codelist["ge:GENC:3:1-2:AX2"] = "AX2"
GE4codelist2IC2codelist["ge:GENC:3:1-2:AZE"] = "AZE"
GE4codelist2IC2codelist["ge:GENC:3:1-2:BDI"] = "BDI"
GE4codelist2IC2codelist["ge:GENC:3:1-2:BEL"] = "BEL"
GE4codelist2IC2codelist["ge:GENC:3:1-2:BEN"] = "BEN"
GE4codelist2IC2codelist["ge:GENC:3:1-2:BES"] = "BES"
GE4codelist2IC2codelist["ge:GENC:3:1-2:BFA"] = "BFA"
GE4codelist2IC2codelist["ge:GENC:3:1-2:BGD"] = "BGD"
GE4codelist2IC2codelist["ge:GENC:3:1-2:BGR"] = "BGR"
GE4codelist2IC2codelist["ge:GENC:3:1-2:BHR"] = "BHR"
GE4codelist2IC2codelist["ge:GENC:3:1-2:BHS"] = "BHS"
GE4codelist2IC2codelist["ge:GENC:3:1-2:BLM"] = "BLM"
GE4codelist2IC2codelist["ge:GENC:3:1-2:BLR"] = "BLR"
GE4codelist2IC2codelist["ge:GENC:3:1-2:BOL"] = "BOL"
GE4codelist2IC2codelist["ge:GENC:3:1-2:BRA"] = "BRA"
GE4codelist2IC2codelist["ge:GENC:3:1-2:BRN"] = "BRN"
GE4codelist2IC2codelist["ge:GENC:3:1-2:BTN"] = "BTN"
GE4codelist2IC2codelist["ge:GENC:3:1-2:BWA"] = "BWA"
GE4codelist2IC2codelist["ge:GENC:3:1-2:CAF"] = "CAF"
GE4codelist2IC2codelist["ge:GENC:3:1-2:CAN"] = "CAN"
GE4codelist2IC2codelist["ge:GENC:3:1-2:CCK"] = "CCK"
GE4codelist2IC2codelist["ge:GENC:3:1-2:CHE"] = "CHE"
GE4codelist2IC2codelist["ge:GENC:3:1-2:CHL"] = "CHL"
GE4codelist2IC2codelist["ge:GENC:3:1-2:CHN"] = "CHN"
GE4codelist2IC2codelist["ge:GENC:3:1-2:CIV"] = "CIV"
GE4codelist2IC2codelist["ge:GENC:3:1-2:CMR"] = "CMR"
GE4codelist2IC2codelist["ge:GENC:3:1-2:COD"] = "COD"
GE4codelist2IC2codelist["ge:GENC:3:1-2:COG"] = "COG"
GE4codelist2IC2codelist["ge:GENC:3:1-2:COK"] = "COK"
GE4codelist2IC2codelist["ge:GENC:3:1-2:COL"] = "COL"
GE4codelist2IC2codelist["ge:GENC:3:1-2:COM"] = "COM"
GE4codelist2IC2codelist["ge:GENC:3:1-2:CPT"] = "CPT"
GE4codelist2IC2codelist["ge:GENC:3:1-2:CPV"] = "CPV"
GE4codelist2IC2codelist["ge:GENC:3:1-2:CRI"] = "CRI"
GE4codelist2IC2codelist["ge:GENC:3:1-2:CUB"] = "CUB"
GE4codelist2IC2codelist["ge:GENC:3:1-2:CUW"] = "CUW"
GE4codelist2IC2codelist["ge:GENC:3:1-2:CXR"] = "CXR"
GE4codelist2IC2codelist["ge:GENC:3:1-2:CYM"] = "CYM"
GE4codelist2IC2codelist["ge:GENC:3:1-2:CYP"] = "CYP"
GE4codelist2IC2codelist["ge:GENC:3:1-2:CZE"] = "CZE"
GE4codelist2IC2codelist["ge:GENC:3:1-2:DEU"] = "DEU"
GE4codelist2IC2codelist["ge:GENC:3:1-2:DGA"] = "DGA"
GE4codelist2IC2codelist["ge:GENC:3:1-2:DJI"] = "DJI"
GE4codelist2IC2codelist["ge:GENC:3:1-2:DMA"] = "DMA"
GE4codelist2IC2codelist["ge:GENC:3:1-2:DNK"] = "DNK"
GE4codelist2IC2codelist["ge:GENC:3:1-2:DOM"] = "DOM"
GE4codelist2IC2codelist["ge:GENC:3:1-2:DZA"] = "DZA"
GE4codelist2IC2codelist["ge:GENC:3:1-2:ECU"] = "ECU"
GE4codelist2IC2codelist["ge:GENC:3:1-2:EGY"] = "EGY"
GE4codelist2IC2codelist["ge:GENC:3:1-2:ERI"] = "ERI"
GE4codelist2IC2codelist["ge:GENC:3:1-2:ESH"] = "ESH"
GE4codelist2IC2codelist["ge:GENC:3:1-2:ESP"] = "ESP"
GE4codelist2IC2codelist["ge:GENC:3:1-2:EST"] = "EST"
GE4codelist2IC2codelist["ge:GENC:3:1-2:ETH"] = "ETH"
GE4codelist2IC2codelist["ge:GENC:3:1-2:FIN"] = "FIN"
GE4codelist2IC2codelist["ge:GENC:3:1-2:FJI"] = "FJI"
GE4codelist2IC2codelist["ge:GENC:3:1-2:FLK"] = "FLK"
GE4codelist2IC2codelist["ge:GENC:3:1-2:FRA"] = "FRA"
GE4codelist2IC2codelist["ge:GENC:3:1-2:FRO"] = "FRO"
GE4codelist2IC2codelist["ge:GENC:3:1-2:FSM"] = "FSM"
GE4codelist2IC2codelist["ge:GENC:3:1-2:GAB"] = "GAB"
GE4codelist2IC2codelist["ge:GENC:3:1-2:GBR"] = "GBR"
GE4codelist2IC2codelist["ge:GENC:3:1-2:GEO"] = "GEO"
GE4codelist2IC2codelist["ge:GENC:3:1-2:GGY"] = "GGY"
GE4codelist2IC2codelist["ge:GENC:3:1-2:GHA"] = "GHA"
GE4codelist2IC2codelist["ge:GENC:3:1-2:GIN"] = "GIN"
GE4codelist2IC2codelist["ge:GENC:3:1-2:GLP"] = "GLP"
GE4codelist2IC2codelist["ge:GENC:3:1-2:GMB"] = "GMB"
GE4codelist2IC2codelist["ge:GENC:3:1-2:GNB"] = "GNB"
GE4codelist2IC2codelist["ge:GENC:3:1-2:GNQ"] = "GNQ"
GE4codelist2IC2codelist["ge:GENC:3:1-2:GRC"] = "GRC"
GE4codelist2IC2codelist["ge:GENC:3:1-2:GTM"] = "GTM"
GE4codelist2IC2codelist["ge:GENC:3:1-2:GUF"] = "GUF"
GE4codelist2IC2codelist["ge:GENC:3:1-2:GUM"] = "GUM"
GE4codelist2IC2codelist["ge:GENC:3:1-2:GUY"] = "GUY"
GE4codelist2IC2codelist["ge:GENC:3:1-2:HKG"] = "HKG"
GE4codelist2IC2codelist["ge:GENC:3:1-2:HMD"] = "HMD"
GE4codelist2IC2codelist["ge:GENC:3:1-2:HND"] = "HND"
GE4codelist2IC2codelist["ge:GENC:3:1-2:HRV"] = "HRV"
GE4codelist2IC2codelist["ge:GENC:3:1-2:HTI"] = "HTI"
GE4codelist2IC2codelist["ge:GENC:3:1-2:IDN"] = "IDN"
GE4codelist2IC2codelist["ge:GENC:3:1-2:IND"] = "IND"
GE4codelist2IC2codelist["ge:GENC:3:1-2:IOT"] = "IOT"
GE4codelist2IC2codelist["ge:GENC:3:1-2:IRN"] = "IRN"
GE4codelist2IC2codelist["ge:GENC:3:1-2:IRQ"] = "IRQ"
GE4codelist2IC2codelist["ge:GENC:3:1-2:ISL"] = "ISL"
GE4codelist2IC2codelist["ge:GENC:3:1-2:ISR"] = "ISR"
GE4codelist2IC2codelist["ge:GENC:3:1-2:ITA"] = "ITA"
GE4codelist2IC2codelist["ge:GENC:3:1-2:JEY"] = "JEY"
GE4codelist2IC2codelist["ge:GENC:3:1-2:JOR"] = "JOR"
GE4codelist2IC2codelist["ge:GENC:3:1-2:KAZ"] = "KAZ"
GE4codelist2IC2codelist["ge:GENC:3:1-2:KEN"] = "KEN"
GE4codelist2IC2codelist["ge:GENC:3:1-2:KGZ"] = "KGZ"
GE4codelist2IC2codelist["ge:GENC:3:1-2:KHM"] = "KHM"
GE4codelist2IC2codelist["ge:GENC:3:1-2:KIR"] = "KIR"
GE4codelist2IC2codelist["ge:GENC:3:1-2:KNA"] = "KNA"
GE4codelist2IC2codelist["ge:GENC:3:1-2:KOR"] = "KOR"
GE4codelist2IC2codelist["ge:GENC:3:1-2:KWT"] = "KWT"
GE4codelist2IC2codelist["ge:GENC:3:1-2:LAO"] = "LAO"
GE4codelist2IC2codelist["ge:GENC:3:1-2:LBN"] = "LBN"
GE4codelist2IC2codelist["ge:GENC:3:1-2:LBR"] = "LBR"
GE4codelist2IC2codelist["ge:GENC:3:1-2:LIE"] = "LIE"
GE4codelist2IC2codelist["ge:GENC:3:1-2:LKA"] = "LKA"
GE4codelist2IC2codelist["ge:GENC:3:1-2:LSO"] = "LSO"
GE4codelist2IC2codelist["ge:GENC:3:1-2:LTU"] = "LTU"
GE4codelist2IC2codelist["ge:GENC:3:1-2:LUX"] = "LUX"
GE4codelist2IC2codelist["ge:GENC:3:1-2:LVA"] = "LVA"
GE4codelist2IC2codelist["ge:GENC:3:1-2:MAC"] = "MAC"
GE4codelist2IC2codelist["ge:GENC:3:1-2:MAF"] = "MAF"
GE4codelist2IC2codelist["ge:GENC:3:1-2:MAR"] = "MAR"
GE4codelist2IC2codelist["ge:GENC:3:1-2:MCO"] = "MCO"
GE4codelist2IC2codelist["ge:GENC:3:1-2:MDA"] = "MDA"
GE4codelist2IC2codelist["ge:GENC:3:1-2:MDG"] = "MDG"
GE4codelist2IC2codelist["ge:GENC:3:1-2:MDV"] = "MDV"
GE4codelist2IC2codelist["ge:GENC:3:1-2:MEX"] = "MEX"
GE4codelist2IC2codelist["ge:GENC:3:1-2:MHL"] = "MHL"
GE4codelist2IC2codelist["ge:GENC:3:1-2:MKD"] = "MKD"
GE4codelist2IC2codelist["ge:GENC:3:1-2:MLI"] = "MLI"
GE4codelist2IC2codelist["ge:GENC:3:1-2:MLT"] = "MLT"
GE4codelist2IC2codelist["ge:GENC:3:1-2:MMR"] = "MMR"
GE4codelist2IC2codelist["ge:GENC:3:1-2:MNG"] = "MNG"
GE4codelist2IC2codelist["ge:GENC:3:1-2:MNP"] = "MNP"
GE4codelist2IC2codelist["ge:GENC:3:1-2:MOZ"] = "MOZ"
GE4codelist2IC2codelist["ge:GENC:3:1-2:MRT"] = "MRT"
GE4codelist2IC2codelist["ge:GENC:3:1-2:MTQ"] = "MTQ"
GE4codelist2IC2codelist["ge:GENC:3:1-2:MUS"] = "MUS"
GE4codelist2IC2codelist["ge:GENC:3:1-2:MWI"] = "MWI"
GE4codelist2IC2codelist["ge:GENC:3:1-2:MYS"] = "MYS"
GE4codelist2IC2codelist["ge:GENC:3:1-2:MYT"] = "MYT"
GE4codelist2IC2codelist["ge:GENC:3:1-2:NAM"] = "NAM"
GE4codelist2IC2codelist["ge:GENC:3:1-2:NCL"] = "NCL"
GE4codelist2IC2codelist["ge:GENC:3:1-2:NER"] = "NER"
GE4codelist2IC2codelist["ge:GENC:3:1-2:NFK"] = "NFK"
GE4codelist2IC2codelist["ge:GENC:3:1-2:NGA"] = "NGA"
GE4codelist2IC2codelist["ge:GENC:3:1-2:NIC"] = "NIC"
GE4codelist2IC2codelist["ge:GENC:3:1-2:NLD"] = "NLD"
GE4codelist2IC2codelist["ge:GENC:3:1-2:NOR"] = "NOR"
GE4codelist2IC2codelist["ge:GENC:3:1-2:NPL"] = "NPL"
GE4codelist2IC2codelist["ge:GENC:3:1-2:NRU"] = "NRU"
GE4codelist2IC2codelist["ge:GENC:3:1-2:NZL"] = "NZL"
GE4codelist2IC2codelist["ge:GENC:3:1-2:OMN"] = "OMN"
GE4codelist2IC2codelist["ge:GENC:3:1-2:PAK"] = "PAK"
GE4codelist2IC2codelist["ge:GENC:3:1-2:PAN"] = "PAN"
GE4codelist2IC2codelist["ge:GENC:3:1-2:PCN"] = "PCN"
GE4codelist2IC2codelist["ge:GENC:3:1-2:PER"] = "PER"
GE4codelist2IC2codelist["ge:GENC:3:1-2:PHL"] = "PHL"
GE4codelist2IC2codelist["ge:GENC:3:1-2:PLW"] = "PLW"
GE4codelist2IC2codelist["ge:GENC:3:1-2:POL"] = "POL"
GE4codelist2IC2codelist["ge:GENC:3:1-2:PRI"] = "PRI"
GE4codelist2IC2codelist["ge:GENC:3:1-2:PRK"] = "PRK"
GE4codelist2IC2codelist["ge:GENC:3:1-2:PRT"] = "PRT"
GE4codelist2IC2codelist["ge:GENC:3:1-2:PRY"] = "PRY"
GE4codelist2IC2codelist["ge:GENC:3:1-2:PSE"] = "PSE"
GE4codelist2IC2codelist["ge:GENC:3:1-2:PYF"] = "PYF"
GE4codelist2IC2codelist["ge:GENC:3:1-2:QAT"] = "QAT"
GE4codelist2IC2codelist["ge:GENC:3:1-2:REU"] = "REU"
GE4codelist2IC2codelist["ge:GENC:3:1-2:RUS"] = "RUS"
GE4codelist2IC2codelist["ge:GENC:3:1-2:RWA"] = "RWA"
GE4codelist2IC2codelist["ge:GENC:3:1-2:SAU"] = "SAU"
GE4codelist2IC2codelist["ge:GENC:3:1-2:SDN"] = "SDN"
GE4codelist2IC2codelist["ge:GENC:3:1-2:SEN"] = "SEN"
GE4codelist2IC2codelist["ge:GENC:3:1-2:SGP"] = "SGP"
GE4codelist2IC2codelist["ge:GENC:3:1-2:SGS"] = "SGS"
GE4codelist2IC2codelist["ge:GENC:3:1-2:SHN"] = "SHN"
GE4codelist2IC2codelist["ge:GENC:3:1-2:SLB"] = "SLB"
GE4codelist2IC2codelist["ge:GENC:3:1-2:SLE"] = "SLE"
GE4codelist2IC2codelist["ge:GENC:3:1-2:SLV"] = "SLV"
GE4codelist2IC2codelist["ge:GENC:3:1-2:SMR"] = "SMR"
GE4codelist2IC2codelist["ge:GENC:3:1-2:SOM"] = "SOM"
GE4codelist2IC2codelist["ge:GENC:3:1-2:SPM"] = "SPM"
GE4codelist2IC2codelist["ge:GENC:3:1-2:SRB"] = "SRB"
GE4codelist2IC2codelist["ge:GENC:3:1-2:SSD"] = "SSD"
GE4codelist2IC2codelist["ge:GENC:3:1-2:STP"] = "STP"
GE4codelist2IC2codelist["ge:GENC:3:1-2:SUR"] = "SUR"
GE4codelist2IC2codelist["ge:GENC:3:1-2:SVK"] = "SVK"
GE4codelist2IC2codelist["ge:GENC:3:1-2:SVN"] = "SVN"
GE4codelist2IC2codelist["ge:GENC:3:1-2:SWE"] = "SWE"
GE4codelist2IC2codelist["ge:GENC:3:1-2:SWZ"] = "SWZ"
GE4codelist2IC2codelist["ge:GENC:3:1-2:SXM"] = "SXM"
GE4codelist2IC2codelist["ge:GENC:3:1-2:SYC"] = "SYC"
GE4codelist2IC2codelist["ge:GENC:3:1-2:SYR"] = "SYR"
GE4codelist2IC2codelist["ge:GENC:3:1-2:TCA"] = "TCA"
GE4codelist2IC2codelist["ge:GENC:3:1-2:TCD"] = "TCD"
GE4codelist2IC2codelist["ge:GENC:3:1-2:TGO"] = "TGO"
GE4codelist2IC2codelist["ge:GENC:3:1-2:THA"] = "THA"
GE4codelist2IC2codelist["ge:GENC:3:1-2:TJK"] = "TJK"
GE4codelist2IC2codelist["ge:GENC:3:1-2:TLS"] = "TLS"
GE4codelist2IC2codelist["ge:GENC:3:1-2:TON"] = "TON"
GE4codelist2IC2codelist["ge:GENC:3:1-2:TTO"] = "TTO"
GE4codelist2IC2codelist["ge:GENC:3:1-2:TUN"] = "TUN"
GE4codelist2IC2codelist["ge:GENC:3:1-2:TUR"] = "TUR"
GE4codelist2IC2codelist["ge:GENC:3:1-2:TWN"] = "TWN"
GE4codelist2IC2codelist["ge:GENC:3:1-2:TZA"] = "TZA"
GE4codelist2IC2codelist["ge:GENC:3:1-2:UGA"] = "UGA"
GE4codelist2IC2codelist["ge:GENC:3:1-2:UKR"] = "UKR"
GE4codelist2IC2codelist["ge:GENC:3:1-2:URY"] = "URY"
GE4codelist2IC2codelist["ge:GENC:3:1-2:USA"] = "USA"
GE4codelist2IC2codelist["ge:GENC:3:1-2:UZB"] = "UZB"
GE4codelist2IC2codelist["ge:GENC:3:1-2:VAT"] = "VAT"
GE4codelist2IC2codelist["ge:GENC:3:1-2:VCT"] = "VCT"
GE4codelist2IC2codelist["ge:GENC:3:1-2:VEN"] = "VEN"
GE4codelist2IC2codelist["ge:GENC:3:1-2:VGB"] = "VGB"
GE4codelist2IC2codelist["ge:GENC:3:1-2:VIR"] = "VIR"
GE4codelist2IC2codelist["ge:GENC:3:1-2:VNM"] = "VNM"
GE4codelist2IC2codelist["ge:GENC:3:1-2:VUT"] = "VUT"
GE4codelist2IC2codelist["ge:GENC:3:1-2:WLF"] = "WLF"
GE4codelist2IC2codelist["ge:GENC:3:1-2:WSM"] = "WSM"
GE4codelist2IC2codelist["ge:GENC:3:1-2:XAC"] = "XAC"
GE4codelist2IC2codelist["ge:GENC:3:1-2:XAZ"] = "XAZ"
GE4codelist2IC2codelist["ge:GENC:3:1-2:XBI"] = "XBI"
GE4codelist2IC2codelist["ge:GENC:3:1-2:XBK"] = "XBK"
GE4codelist2IC2codelist["ge:GENC:3:1-2:XCR"] = "XCR"
GE4codelist2IC2codelist["ge:GENC:3:1-2:XCS"] = "XCS"
GE4codelist2IC2codelist["ge:GENC:3:1-2:XCY"] = "XCY"
GE4codelist2IC2codelist["ge:GENC:3:1-2:XEU"] = "XEU"
GE4codelist2IC2codelist["ge:GENC:3:1-2:XGL"] = "XGL"
GE4codelist2IC2codelist["ge:GENC:3:1-2:XGZ"] = "XGZ"
GE4codelist2IC2codelist["ge:GENC:3:1-2:XHO"] = "XHO"
GE4codelist2IC2codelist["ge:GENC:3:1-2:XJA"] = "XJA"
GE4codelist2IC2codelist["ge:GENC:3:1-2:XJM"] = "XJM"
GE4codelist2IC2codelist["ge:GENC:3:1-2:XJN"] = "XJN"
GE4codelist2IC2codelist["ge:GENC:3:1-2:XJV"] = "XJV"
GE4codelist2IC2codelist["ge:GENC:3:1-2:XKM"] = "XKM"
GE4codelist2IC2codelist["ge:GENC:3:1-2:XKN"] = "XKN"
GE4codelist2IC2codelist["ge:GENC:3:1-2:XKR"] = "XKR"
GE4codelist2IC2codelist["ge:GENC:3:1-2:XKS"] = "XKS"
GE4codelist2IC2codelist["ge:GENC:3:1-2:XMW"] = "XMW"
GE4codelist2IC2codelist["ge:GENC:3:1-2:XNV"] = "XNV"
GE4codelist2IC2codelist["ge:GENC:3:1-2:XPL"] = "XPL"
GE4codelist2IC2codelist["ge:GENC:3:1-2:XPR"] = "XPR"
GE4codelist2IC2codelist["ge:GENC:3:1-2:XQP"] = "XQP"
GE4codelist2IC2codelist["ge:GENC:3:1-2:XQZ"] = "XQZ"
GE4codelist2IC2codelist["ge:GENC:3:1-2:XSP"] = "XSP"
GE4codelist2IC2codelist["ge:GENC:3:1-2:XSV"] = "XSV"
GE4codelist2IC2codelist["ge:GENC:3:1-2:XTR"] = "XTR"
GE4codelist2IC2codelist["ge:GENC:3:1-2:XWB"] = "XWB"
GE4codelist2IC2codelist["ge:GENC:3:1-2:XWK"] = "XWK"
GE4codelist2IC2codelist["ge:GENC:3:1-2:XXD"] = "XXD"
GE4codelist2IC2codelist["ge:GENC:3:1-2:XXX"] = "XXX"
GE4codelist2IC2codelist["ge:GENC:3:1-2:YEM"] = "YEM"
GE4codelist2IC2codelist["ge:GENC:3:1-2:ZAF"] = "ZAF"
GE4codelist2IC2codelist["ge:GENC:3:1-2:ZMB"] = "ZMB"
GE4codelist2IC2codelist["ge:GENC:3:1-2:ZWE"] = "ZWE"
GE4codelist2IC2codelist["ge:GENC:3:ed3:AX3"] = "AX3"
GE4codelist2IC2codelist["ge:ISO1:3:VI-15:AIA"] = "AIA"
GE4codelist2IC2codelist["ge:ISO1:3:VI-15:ATA"] = "ATA"
GE4codelist2IC2codelist["ge:ISO1:3:VI-15:BIH"] = "BIH"
GE4codelist2IC2codelist["ge:ISO1:3:VI-15:BLZ"] = "BLZ"
GE4codelist2IC2codelist["ge:ISO1:3:VI-15:BMU"] = "BMU"
GE4codelist2IC2codelist["ge:ISO1:3:VI-15:BRB"] = "BRB"
GE4codelist2IC2codelist["ge:ISO1:3:VI-15:BVT"] = "BVT"
GE4codelist2IC2codelist["ge:ISO1:3:VI-15:GIB"] = "GIB"
GE4codelist2IC2codelist["ge:ISO1:3:VI-15:GRD"] = "GRD"
GE4codelist2IC2codelist["ge:ISO1:3:VI-15:GRL"] = "GRL"
GE4codelist2IC2codelist["ge:ISO1:3:VI-15:HUN"] = "HUN"
GE4codelist2IC2codelist["ge:ISO1:3:VI-15:IMN"] = "IMN"
GE4codelist2IC2codelist["ge:ISO1:3:VI-15:IRL"] = "IRL"
GE4codelist2IC2codelist["ge:ISO1:3:VI-15:JAM"] = "JAM"
GE4codelist2IC2codelist["ge:ISO1:3:VI-15:JPN"] = "JPN"
GE4codelist2IC2codelist["ge:ISO1:3:VI-15:LBY"] = "LBY"
GE4codelist2IC2codelist["ge:ISO1:3:VI-15:LCA"] = "LCA"
GE4codelist2IC2codelist["ge:ISO1:3:VI-15:MNE"] = "MNE"
GE4codelist2IC2codelist["ge:ISO1:3:VI-15:MSR"] = "MSR"
GE4codelist2IC2codelist["ge:ISO1:3:VI-15:NIU"] = "NIU"
GE4codelist2IC2codelist["ge:ISO1:3:VI-15:PNG"] = "PNG"
GE4codelist2IC2codelist["ge:ISO1:3:VI-15:ROU"] = "ROU"
GE4codelist2IC2codelist["ge:ISO1:3:VI-15:TKL"] = "TKL"
GE4codelist2IC2codelist["ge:ISO1:3:VI-15:TKM"] = "TKM"
GE4codelist2IC2codelist["ge:ISO1:3:VI-15:TUV"] = "TUV"
GE4codelist2IC2codelist["------"] = "noInformation"
GE4codelist2IC2codelist["noInformation"] = "noInformation"
GE4codelist2IC2codelist["No Information"] = "noInformation"
GE4codelist2IC2codelist["no information"] = "noInformation"
GE4codelist2IC2codelist["other"] = "other"
GE4codelist2IC2codelist["Other"] = "other"

# lowercase option
GE4codelist2IC2codelist["ge:genc:3:1-2:abw"] = "ABW"
GE4codelist2IC2codelist["ge:genc:3:1-2:afg"] = "AFG"
GE4codelist2IC2codelist["ge:genc:3:1-2:ago"] = "AGO"
GE4codelist2IC2codelist["ge:genc:3:1-2:alb"] = "ALB"
GE4codelist2IC2codelist["ge:genc:3:1-2:and"] = "AND"
GE4codelist2IC2codelist["ge:genc:3:1-2:are"] = "ARE"
GE4codelist2IC2codelist["ge:genc:3:1-2:arg"] = "ARG"
GE4codelist2IC2codelist["ge:genc:3:1-2:arm"] = "ARM"
GE4codelist2IC2codelist["ge:genc:3:1-2:asm"] = "ASM"
GE4codelist2IC2codelist["ge:genc:3:1-2:atf"] = "ATF"
GE4codelist2IC2codelist["ge:genc:3:1-2:atg"] = "ATG"
GE4codelist2IC2codelist["ge:genc:3:1-2:aus"] = "AUS"
GE4codelist2IC2codelist["ge:genc:3:1-2:aut"] = "AUT"
GE4codelist2IC2codelist["ge:genc:3:1-2:ax1"] = "AX1"
GE4codelist2IC2codelist["ge:genc:3:1-2:ax2"] = "AX2"
GE4codelist2IC2codelist["ge:genc:3:1-2:aze"] = "AZE"
GE4codelist2IC2codelist["ge:genc:3:1-2:bdi"] = "BDI"
GE4codelist2IC2codelist["ge:genc:3:1-2:bel"] = "BEL"
GE4codelist2IC2codelist["ge:genc:3:1-2:ben"] = "BEN"
GE4codelist2IC2codelist["ge:genc:3:1-2:bes"] = "BES"
GE4codelist2IC2codelist["ge:genc:3:1-2:bfa"] = "BFA"
GE4codelist2IC2codelist["ge:genc:3:1-2:bgd"] = "BGD"
GE4codelist2IC2codelist["ge:genc:3:1-2:bgr"] = "BGR"
GE4codelist2IC2codelist["ge:genc:3:1-2:bhr"] = "BHR"
GE4codelist2IC2codelist["ge:genc:3:1-2:bhs"] = "BHS"
GE4codelist2IC2codelist["ge:genc:3:1-2:blm"] = "BLM"
GE4codelist2IC2codelist["ge:genc:3:1-2:blr"] = "BLR"
GE4codelist2IC2codelist["ge:genc:3:1-2:bol"] = "BOL"
GE4codelist2IC2codelist["ge:genc:3:1-2:bra"] = "BRA"
GE4codelist2IC2codelist["ge:genc:3:1-2:brn"] = "BRN"
GE4codelist2IC2codelist["ge:genc:3:1-2:btn"] = "BTN"
GE4codelist2IC2codelist["ge:genc:3:1-2:bwa"] = "BWA"
GE4codelist2IC2codelist["ge:genc:3:1-2:caf"] = "CAF"
GE4codelist2IC2codelist["ge:genc:3:1-2:can"] = "CAN"
GE4codelist2IC2codelist["ge:genc:3:1-2:cck"] = "CCK"
GE4codelist2IC2codelist["ge:genc:3:1-2:che"] = "CHE"
GE4codelist2IC2codelist["ge:genc:3:1-2:chl"] = "CHL"
GE4codelist2IC2codelist["ge:genc:3:1-2:chn"] = "CHN"
GE4codelist2IC2codelist["ge:genc:3:1-2:civ"] = "CIV"
GE4codelist2IC2codelist["ge:genc:3:1-2:cmr"] = "CMR"
GE4codelist2IC2codelist["ge:genc:3:1-2:cod"] = "COD"
GE4codelist2IC2codelist["ge:genc:3:1-2:cog"] = "COG"
GE4codelist2IC2codelist["ge:genc:3:1-2:cok"] = "COK"
GE4codelist2IC2codelist["ge:genc:3:1-2:col"] = "COL"
GE4codelist2IC2codelist["ge:genc:3:1-2:com"] = "COM"
GE4codelist2IC2codelist["ge:genc:3:1-2:cpt"] = "CPT"
GE4codelist2IC2codelist["ge:genc:3:1-2:cpv"] = "CPV"
GE4codelist2IC2codelist["ge:genc:3:1-2:cri"] = "CRI"
GE4codelist2IC2codelist["ge:genc:3:1-2:cub"] = "CUB"
GE4codelist2IC2codelist["ge:genc:3:1-2:cuw"] = "CUW"
GE4codelist2IC2codelist["ge:genc:3:1-2:cxr"] = "CXR"
GE4codelist2IC2codelist["ge:genc:3:1-2:cym"] = "CYM"
GE4codelist2IC2codelist["ge:genc:3:1-2:cyp"] = "CYP"
GE4codelist2IC2codelist["ge:genc:3:1-2:cze"] = "CZE"
GE4codelist2IC2codelist["ge:genc:3:1-2:deu"] = "DEU"
GE4codelist2IC2codelist["ge:genc:3:1-2:dga"] = "DGA"
GE4codelist2IC2codelist["ge:genc:3:1-2:dji"] = "DJI"
GE4codelist2IC2codelist["ge:genc:3:1-2:dma"] = "DMA"
GE4codelist2IC2codelist["ge:genc:3:1-2:dnk"] = "DNK"
GE4codelist2IC2codelist["ge:genc:3:1-2:dom"] = "DOM"
GE4codelist2IC2codelist["ge:genc:3:1-2:dza"] = "DZA"
GE4codelist2IC2codelist["ge:genc:3:1-2:ecu"] = "ECU"
GE4codelist2IC2codelist["ge:genc:3:1-2:egy"] = "EGY"
GE4codelist2IC2codelist["ge:genc:3:1-2:eri"] = "ERI"
GE4codelist2IC2codelist["ge:genc:3:1-2:esh"] = "ESH"
GE4codelist2IC2codelist["ge:genc:3:1-2:esp"] = "ESP"
GE4codelist2IC2codelist["ge:genc:3:1-2:est"] = "EST"
GE4codelist2IC2codelist["ge:genc:3:1-2:eth"] = "ETH"
GE4codelist2IC2codelist["ge:genc:3:1-2:fin"] = "FIN"
GE4codelist2IC2codelist["ge:genc:3:1-2:fji"] = "FJI"
GE4codelist2IC2codelist["ge:genc:3:1-2:flk"] = "FLK"
GE4codelist2IC2codelist["ge:genc:3:1-2:fra"] = "FRA"
GE4codelist2IC2codelist["ge:genc:3:1-2:fro"] = "FRO"
GE4codelist2IC2codelist["ge:genc:3:1-2:fsm"] = "FSM"
GE4codelist2IC2codelist["ge:genc:3:1-2:gab"] = "GAB"
GE4codelist2IC2codelist["ge:genc:3:1-2:gbr"] = "GBR"
GE4codelist2IC2codelist["ge:genc:3:1-2:geo"] = "GEO"
GE4codelist2IC2codelist["ge:genc:3:1-2:ggy"] = "GGY"
GE4codelist2IC2codelist["ge:genc:3:1-2:gha"] = "GHA"
GE4codelist2IC2codelist["ge:genc:3:1-2:gin"] = "GIN"
GE4codelist2IC2codelist["ge:genc:3:1-2:glp"] = "GLP"
GE4codelist2IC2codelist["ge:genc:3:1-2:gmb"] = "GMB"
GE4codelist2IC2codelist["ge:genc:3:1-2:gnb"] = "GNB"
GE4codelist2IC2codelist["ge:genc:3:1-2:gnq"] = "GNQ"
GE4codelist2IC2codelist["ge:genc:3:1-2:grc"] = "GRC"
GE4codelist2IC2codelist["ge:genc:3:1-2:gtm"] = "GTM"
GE4codelist2IC2codelist["ge:genc:3:1-2:guf"] = "GUF"
GE4codelist2IC2codelist["ge:genc:3:1-2:gum"] = "GUM"
GE4codelist2IC2codelist["ge:genc:3:1-2:guy"] = "GUY"
GE4codelist2IC2codelist["ge:genc:3:1-2:hkg"] = "HKG"
GE4codelist2IC2codelist["ge:genc:3:1-2:hmd"] = "HMD"
GE4codelist2IC2codelist["ge:genc:3:1-2:hnd"] = "HND"
GE4codelist2IC2codelist["ge:genc:3:1-2:hrv"] = "HRV"
GE4codelist2IC2codelist["ge:genc:3:1-2:hti"] = "HTI"
GE4codelist2IC2codelist["ge:genc:3:1-2:idn"] = "IDN"
GE4codelist2IC2codelist["ge:genc:3:1-2:ind"] = "IND"
GE4codelist2IC2codelist["ge:genc:3:1-2:iot"] = "IOT"
GE4codelist2IC2codelist["ge:genc:3:1-2:irn"] = "IRN"
GE4codelist2IC2codelist["ge:genc:3:1-2:irq"] = "IRQ"
GE4codelist2IC2codelist["ge:genc:3:1-2:isl"] = "ISL"
GE4codelist2IC2codelist["ge:genc:3:1-2:isr"] = "ISR"
GE4codelist2IC2codelist["ge:genc:3:1-2:ita"] = "ITA"
GE4codelist2IC2codelist["ge:genc:3:1-2:jey"] = "JEY"
GE4codelist2IC2codelist["ge:genc:3:1-2:jor"] = "JOR"
GE4codelist2IC2codelist["ge:genc:3:1-2:kaz"] = "KAZ"
GE4codelist2IC2codelist["ge:genc:3:1-2:ken"] = "KEN"
GE4codelist2IC2codelist["ge:genc:3:1-2:kgz"] = "KGZ"
GE4codelist2IC2codelist["ge:genc:3:1-2:khm"] = "KHM"
GE4codelist2IC2codelist["ge:genc:3:1-2:kir"] = "KIR"
GE4codelist2IC2codelist["ge:genc:3:1-2:kna"] = "KNA"
GE4codelist2IC2codelist["ge:genc:3:1-2:kor"] = "KOR"
GE4codelist2IC2codelist["ge:genc:3:1-2:kwt"] = "KWT"
GE4codelist2IC2codelist["ge:genc:3:1-2:lao"] = "LAO"
GE4codelist2IC2codelist["ge:genc:3:1-2:lbn"] = "LBN"
GE4codelist2IC2codelist["ge:genc:3:1-2:lbr"] = "LBR"
GE4codelist2IC2codelist["ge:genc:3:1-2:lie"] = "LIE"
GE4codelist2IC2codelist["ge:genc:3:1-2:lka"] = "LKA"
GE4codelist2IC2codelist["ge:genc:3:1-2:lso"] = "LSO"
GE4codelist2IC2codelist["ge:genc:3:1-2:ltu"] = "LTU"
GE4codelist2IC2codelist["ge:genc:3:1-2:lux"] = "LUX"
GE4codelist2IC2codelist["ge:genc:3:1-2:lva"] = "LVA"
GE4codelist2IC2codelist["ge:genc:3:1-2:mac"] = "MAC"
GE4codelist2IC2codelist["ge:genc:3:1-2:maf"] = "MAF"
GE4codelist2IC2codelist["ge:genc:3:1-2:mar"] = "MAR"
GE4codelist2IC2codelist["ge:genc:3:1-2:mco"] = "MCO"
GE4codelist2IC2codelist["ge:genc:3:1-2:mda"] = "MDA"
GE4codelist2IC2codelist["ge:genc:3:1-2:mdg"] = "MDG"
GE4codelist2IC2codelist["ge:genc:3:1-2:mdv"] = "MDV"
GE4codelist2IC2codelist["ge:genc:3:1-2:mex"] = "MEX"
GE4codelist2IC2codelist["ge:genc:3:1-2:mhl"] = "MHL"
GE4codelist2IC2codelist["ge:genc:3:1-2:mkd"] = "MKD"
GE4codelist2IC2codelist["ge:genc:3:1-2:mli"] = "MLI"
GE4codelist2IC2codelist["ge:genc:3:1-2:mlt"] = "MLT"
GE4codelist2IC2codelist["ge:genc:3:1-2:mmr"] = "MMR"
GE4codelist2IC2codelist["ge:genc:3:1-2:mng"] = "MNG"
GE4codelist2IC2codelist["ge:genc:3:1-2:mnp"] = "MNP"
GE4codelist2IC2codelist["ge:genc:3:1-2:moz"] = "MOZ"
GE4codelist2IC2codelist["ge:genc:3:1-2:mrt"] = "MRT"
GE4codelist2IC2codelist["ge:genc:3:1-2:mtq"] = "MTQ"
GE4codelist2IC2codelist["ge:genc:3:1-2:mus"] = "MUS"
GE4codelist2IC2codelist["ge:genc:3:1-2:mwi"] = "MWI"
GE4codelist2IC2codelist["ge:genc:3:1-2:mys"] = "MYS"
GE4codelist2IC2codelist["ge:genc:3:1-2:myt"] = "MYT"
GE4codelist2IC2codelist["ge:genc:3:1-2:nam"] = "NAM"
GE4codelist2IC2codelist["ge:genc:3:1-2:ncl"] = "NCL"
GE4codelist2IC2codelist["ge:genc:3:1-2:ner"] = "NER"
GE4codelist2IC2codelist["ge:genc:3:1-2:nfk"] = "NFK"
GE4codelist2IC2codelist["ge:genc:3:1-2:nga"] = "NGA"
GE4codelist2IC2codelist["ge:genc:3:1-2:nic"] = "NIC"
GE4codelist2IC2codelist["ge:genc:3:1-2:nld"] = "NLD"
GE4codelist2IC2codelist["ge:genc:3:1-2:nor"] = "NOR"
GE4codelist2IC2codelist["ge:genc:3:1-2:npl"] = "NPL"
GE4codelist2IC2codelist["ge:genc:3:1-2:nru"] = "NRU"
GE4codelist2IC2codelist["ge:genc:3:1-2:nzl"] = "NZL"
GE4codelist2IC2codelist["ge:genc:3:1-2:omn"] = "OMN"
GE4codelist2IC2codelist["ge:genc:3:1-2:pak"] = "PAK"
GE4codelist2IC2codelist["ge:genc:3:1-2:pan"] = "PAN"
GE4codelist2IC2codelist["ge:genc:3:1-2:pcn"] = "PCN"
GE4codelist2IC2codelist["ge:genc:3:1-2:per"] = "PER"
GE4codelist2IC2codelist["ge:genc:3:1-2:phl"] = "PHL"
GE4codelist2IC2codelist["ge:genc:3:1-2:plw"] = "PLW"
GE4codelist2IC2codelist["ge:genc:3:1-2:pol"] = "POL"
GE4codelist2IC2codelist["ge:genc:3:1-2:pri"] = "PRI"
GE4codelist2IC2codelist["ge:genc:3:1-2:prk"] = "PRK"
GE4codelist2IC2codelist["ge:genc:3:1-2:prt"] = "PRT"
GE4codelist2IC2codelist["ge:genc:3:1-2:pry"] = "PRY"
GE4codelist2IC2codelist["ge:genc:3:1-2:pse"] = "PSE"
GE4codelist2IC2codelist["ge:genc:3:1-2:pyf"] = "PYF"
GE4codelist2IC2codelist["ge:genc:3:1-2:qat"] = "QAT"
GE4codelist2IC2codelist["ge:genc:3:1-2:reu"] = "REU"
GE4codelist2IC2codelist["ge:genc:3:1-2:rus"] = "RUS"
GE4codelist2IC2codelist["ge:genc:3:1-2:rwa"] = "RWA"
GE4codelist2IC2codelist["ge:genc:3:1-2:sau"] = "SAU"
GE4codelist2IC2codelist["ge:genc:3:1-2:sdn"] = "SDN"
GE4codelist2IC2codelist["ge:genc:3:1-2:sen"] = "SEN"
GE4codelist2IC2codelist["ge:genc:3:1-2:sgp"] = "SGP"
GE4codelist2IC2codelist["ge:genc:3:1-2:sgs"] = "SGS"
GE4codelist2IC2codelist["ge:genc:3:1-2:shn"] = "SHN"
GE4codelist2IC2codelist["ge:genc:3:1-2:slb"] = "SLB"
GE4codelist2IC2codelist["ge:genc:3:1-2:sle"] = "SLE"
GE4codelist2IC2codelist["ge:genc:3:1-2:slv"] = "SLV"
GE4codelist2IC2codelist["ge:genc:3:1-2:smr"] = "SMR"
GE4codelist2IC2codelist["ge:genc:3:1-2:som"] = "SOM"
GE4codelist2IC2codelist["ge:genc:3:1-2:spm"] = "SPM"
GE4codelist2IC2codelist["ge:genc:3:1-2:srb"] = "SRB"
GE4codelist2IC2codelist["ge:genc:3:1-2:ssd"] = "SSD"
GE4codelist2IC2codelist["ge:genc:3:1-2:stp"] = "STP"
GE4codelist2IC2codelist["ge:genc:3:1-2:sur"] = "SUR"
GE4codelist2IC2codelist["ge:genc:3:1-2:svk"] = "SVK"
GE4codelist2IC2codelist["ge:genc:3:1-2:svn"] = "SVN"
GE4codelist2IC2codelist["ge:genc:3:1-2:swe"] = "SWE"
GE4codelist2IC2codelist["ge:genc:3:1-2:swz"] = "SWZ"
GE4codelist2IC2codelist["ge:genc:3:1-2:sxm"] = "SXM"
GE4codelist2IC2codelist["ge:genc:3:1-2:syc"] = "SYC"
GE4codelist2IC2codelist["ge:genc:3:1-2:syr"] = "SYR"
GE4codelist2IC2codelist["ge:genc:3:1-2:tca"] = "TCA"
GE4codelist2IC2codelist["ge:genc:3:1-2:tcd"] = "TCD"
GE4codelist2IC2codelist["ge:genc:3:1-2:tgo"] = "TGO"
GE4codelist2IC2codelist["ge:genc:3:1-2:tha"] = "THA"
GE4codelist2IC2codelist["ge:genc:3:1-2:tjk"] = "TJK"
GE4codelist2IC2codelist["ge:genc:3:1-2:tls"] = "TLS"
GE4codelist2IC2codelist["ge:genc:3:1-2:ton"] = "TON"
GE4codelist2IC2codelist["ge:genc:3:1-2:tto"] = "TTO"
GE4codelist2IC2codelist["ge:genc:3:1-2:tun"] = "TUN"
GE4codelist2IC2codelist["ge:genc:3:1-2:tur"] = "TUR"
GE4codelist2IC2codelist["ge:genc:3:1-2:twn"] = "TWN"
GE4codelist2IC2codelist["ge:genc:3:1-2:tza"] = "TZA"
GE4codelist2IC2codelist["ge:genc:3:1-2:uga"] = "UGA"
GE4codelist2IC2codelist["ge:genc:3:1-2:ukr"] = "UKR"
GE4codelist2IC2codelist["ge:genc:3:1-2:ury"] = "URY"
GE4codelist2IC2codelist["ge:genc:3:1-2:usa"] = "USA"
GE4codelist2IC2codelist["ge:genc:3:1-2:uzb"] = "UZB"
GE4codelist2IC2codelist["ge:genc:3:1-2:vat"] = "VAT"
GE4codelist2IC2codelist["ge:genc:3:1-2:vct"] = "VCT"
GE4codelist2IC2codelist["ge:genc:3:1-2:ven"] = "VEN"
GE4codelist2IC2codelist["ge:genc:3:1-2:vgb"] = "VGB"
GE4codelist2IC2codelist["ge:genc:3:1-2:vir"] = "VIR"
GE4codelist2IC2codelist["ge:genc:3:1-2:vnm"] = "VNM"
GE4codelist2IC2codelist["ge:genc:3:1-2:vut"] = "VUT"
GE4codelist2IC2codelist["ge:genc:3:1-2:wlf"] = "WLF"
GE4codelist2IC2codelist["ge:genc:3:1-2:wsm"] = "WSM"
GE4codelist2IC2codelist["ge:genc:3:1-2:xac"] = "XAC"
GE4codelist2IC2codelist["ge:genc:3:1-2:xaz"] = "XAZ"
GE4codelist2IC2codelist["ge:genc:3:1-2:xbi"] = "XBI"
GE4codelist2IC2codelist["ge:genc:3:1-2:xbk"] = "XBK"
GE4codelist2IC2codelist["ge:genc:3:1-2:xcr"] = "XCR"
GE4codelist2IC2codelist["ge:genc:3:1-2:xcs"] = "XCS"
GE4codelist2IC2codelist["ge:genc:3:1-2:xcy"] = "XCY"
GE4codelist2IC2codelist["ge:genc:3:1-2:xeu"] = "XEU"
GE4codelist2IC2codelist["ge:genc:3:1-2:xgl"] = "XGL"
GE4codelist2IC2codelist["ge:genc:3:1-2:xgz"] = "XGZ"
GE4codelist2IC2codelist["ge:genc:3:1-2:xho"] = "XHO"
GE4codelist2IC2codelist["ge:genc:3:1-2:xja"] = "XJA"
GE4codelist2IC2codelist["ge:genc:3:1-2:xjm"] = "XJM"
GE4codelist2IC2codelist["ge:genc:3:1-2:xjn"] = "XJN"
GE4codelist2IC2codelist["ge:genc:3:1-2:xjv"] = "XJV"
GE4codelist2IC2codelist["ge:genc:3:1-2:xkm"] = "XKM"
GE4codelist2IC2codelist["ge:genc:3:1-2:xkn"] = "XKN"
GE4codelist2IC2codelist["ge:genc:3:1-2:xkr"] = "XKR"
GE4codelist2IC2codelist["ge:genc:3:1-2:xks"] = "XKS"
GE4codelist2IC2codelist["ge:genc:3:1-2:xmw"] = "XMW"
GE4codelist2IC2codelist["ge:genc:3:1-2:xnv"] = "XNV"
GE4codelist2IC2codelist["ge:genc:3:1-2:xpl"] = "XPL"
GE4codelist2IC2codelist["ge:genc:3:1-2:xpr"] = "XPR"
GE4codelist2IC2codelist["ge:genc:3:1-2:xqp"] = "XQP"
GE4codelist2IC2codelist["ge:genc:3:1-2:xqz"] = "XQZ"
GE4codelist2IC2codelist["ge:genc:3:1-2:xsp"] = "XSP"
GE4codelist2IC2codelist["ge:genc:3:1-2:xsv"] = "XSV"
GE4codelist2IC2codelist["ge:genc:3:1-2:xtr"] = "XTR"
GE4codelist2IC2codelist["ge:genc:3:1-2:xwb"] = "XWB"
GE4codelist2IC2codelist["ge:genc:3:1-2:xwk"] = "XWK"
GE4codelist2IC2codelist["ge:genc:3:1-2:xxd"] = "XXD"
GE4codelist2IC2codelist["ge:genc:3:1-2:xxx"] = "XXX"
GE4codelist2IC2codelist["ge:genc:3:1-2:yem"] = "YEM"
GE4codelist2IC2codelist["ge:genc:3:1-2:zaf"] = "ZAF"
GE4codelist2IC2codelist["ge:genc:3:1-2:zmb"] = "ZMB"
GE4codelist2IC2codelist["ge:genc:3:1-2:zwe"] = "ZWE"
GE4codelist2IC2codelist["ge:genc:3:ed3:ax3"] = "AX3"
GE4codelist2IC2codelist["ge:iso1:3:vi-15:aia"] = "AIA"
GE4codelist2IC2codelist["ge:iso1:3:vi-15:ata"] = "ATA"
GE4codelist2IC2codelist["ge:iso1:3:vi-15:bih"] = "BIH"
GE4codelist2IC2codelist["ge:iso1:3:vi-15:blz"] = "BLZ"
GE4codelist2IC2codelist["ge:iso1:3:vi-15:bmu"] = "BMU"
GE4codelist2IC2codelist["ge:iso1:3:vi-15:brb"] = "BRB"
GE4codelist2IC2codelist["ge:iso1:3:vi-15:bvt"] = "BVT"
GE4codelist2IC2codelist["ge:iso1:3:vi-15:gib"] = "GIB"
GE4codelist2IC2codelist["ge:iso1:3:vi-15:grd"] = "GRD"
GE4codelist2IC2codelist["ge:iso1:3:vi-15:grl"] = "GRL"
GE4codelist2IC2codelist["ge:iso1:3:vi-15:hun"] = "HUN"
GE4codelist2IC2codelist["ge:iso1:3:vi-15:imn"] = "IMN"
GE4codelist2IC2codelist["ge:iso1:3:vi-15:irl"] = "IRL"
GE4codelist2IC2codelist["ge:iso1:3:vi-15:jam"] = "JAM"
GE4codelist2IC2codelist["ge:iso1:3:vi-15:jpn"] = "JPN"
GE4codelist2IC2codelist["ge:iso1:3:vi-15:lby"] = "LBY"
GE4codelist2IC2codelist["ge:iso1:3:vi-15:lca"] = "LCA"
GE4codelist2IC2codelist["ge:iso1:3:vi-15:mne"] = "MNE"
GE4codelist2IC2codelist["ge:iso1:3:vi-15:msr"] = "MSR"
GE4codelist2IC2codelist["ge:iso1:3:vi-15:niu"] = "NIU"
GE4codelist2IC2codelist["ge:iso1:3:vi-15:png"] = "PNG"
GE4codelist2IC2codelist["ge:iso1:3:vi-15:rou"] = "ROU"
GE4codelist2IC2codelist["ge:iso1:3:vi-15:tkl"] = "TKL"
GE4codelist2IC2codelist["ge:iso1:3:vi-15:tkm"] = "TKM"
GE4codelist2IC2codelist["ge:iso1:3:vi-15:tuv"] = "TUV"
GE4codelist2IC2codelist["noinformation"] = "noInformation"

IC2codelist2GE4codelist = {}
IC2codelist2GE4codelist["ABW"] = "ge:GENC:3:1-2:ABW"
IC2codelist2GE4codelist["AFG"] = "ge:GENC:3:1-2:AFG"
IC2codelist2GE4codelist["AGO"] = "ge:GENC:3:1-2:AGO"
IC2codelist2GE4codelist["ALB"] = "ge:GENC:3:1-2:ALB"
IC2codelist2GE4codelist["AND"] = "ge:GENC:3:1-2:AND"
IC2codelist2GE4codelist["ARE"] = "ge:GENC:3:1-2:ARE"
IC2codelist2GE4codelist["ARG"] = "ge:GENC:3:1-2:ARG"
IC2codelist2GE4codelist["ARM"] = "ge:GENC:3:1-2:ARM"
IC2codelist2GE4codelist["ASM"] = "ge:GENC:3:1-2:ASM"
IC2codelist2GE4codelist["ATF"] = "ge:GENC:3:1-2:ATF"
IC2codelist2GE4codelist["ATG"] = "ge:GENC:3:1-2:ATG"
IC2codelist2GE4codelist["AUS"] = "ge:GENC:3:1-2:AUS"
IC2codelist2GE4codelist["AUT"] = "ge:GENC:3:1-2:AUT"
IC2codelist2GE4codelist["AX1"] = "ge:GENC:3:1-2:AX1"
IC2codelist2GE4codelist["AX2"] = "ge:GENC:3:1-2:AX2"
IC2codelist2GE4codelist["AZE"] = "ge:GENC:3:1-2:AZE"
IC2codelist2GE4codelist["BDI"] = "ge:GENC:3:1-2:BDI"
IC2codelist2GE4codelist["BEL"] = "ge:GENC:3:1-2:BEL"
IC2codelist2GE4codelist["BEN"] = "ge:GENC:3:1-2:BEN"
IC2codelist2GE4codelist["BES"] = "ge:GENC:3:1-2:BES"
IC2codelist2GE4codelist["BFA"] = "ge:GENC:3:1-2:BFA"
IC2codelist2GE4codelist["BGD"] = "ge:GENC:3:1-2:BGD"
IC2codelist2GE4codelist["BGR"] = "ge:GENC:3:1-2:BGR"
IC2codelist2GE4codelist["BHR"] = "ge:GENC:3:1-2:BHR"
IC2codelist2GE4codelist["BHS"] = "ge:GENC:3:1-2:BHS"
IC2codelist2GE4codelist["BLM"] = "ge:GENC:3:1-2:BLM"
IC2codelist2GE4codelist["BLR"] = "ge:GENC:3:1-2:BLR"
IC2codelist2GE4codelist["BOL"] = "ge:GENC:3:1-2:BOL"
IC2codelist2GE4codelist["BRA"] = "ge:GENC:3:1-2:BRA"
IC2codelist2GE4codelist["BRN"] = "ge:GENC:3:1-2:BRN"
IC2codelist2GE4codelist["BTN"] = "ge:GENC:3:1-2:BTN"
IC2codelist2GE4codelist["BWA"] = "ge:GENC:3:1-2:BWA"
IC2codelist2GE4codelist["CAF"] = "ge:GENC:3:1-2:CAF"
IC2codelist2GE4codelist["CAN"] = "ge:GENC:3:1-2:CAN"
IC2codelist2GE4codelist["CCK"] = "ge:GENC:3:1-2:CCK"
IC2codelist2GE4codelist["CHE"] = "ge:GENC:3:1-2:CHE"
IC2codelist2GE4codelist["CHL"] = "ge:GENC:3:1-2:CHL"
IC2codelist2GE4codelist["CHN"] = "ge:GENC:3:1-2:CHN"
IC2codelist2GE4codelist["CIV"] = "ge:GENC:3:1-2:CIV"
IC2codelist2GE4codelist["CMR"] = "ge:GENC:3:1-2:CMR"
IC2codelist2GE4codelist["COD"] = "ge:GENC:3:1-2:COD"
IC2codelist2GE4codelist["COG"] = "ge:GENC:3:1-2:COG"
IC2codelist2GE4codelist["COK"] = "ge:GENC:3:1-2:COK"
IC2codelist2GE4codelist["COL"] = "ge:GENC:3:1-2:COL"
IC2codelist2GE4codelist["COM"] = "ge:GENC:3:1-2:COM"
IC2codelist2GE4codelist["CPT"] = "ge:GENC:3:1-2:CPT"
IC2codelist2GE4codelist["CPV"] = "ge:GENC:3:1-2:CPV"
IC2codelist2GE4codelist["CRI"] = "ge:GENC:3:1-2:CRI"
IC2codelist2GE4codelist["CUB"] = "ge:GENC:3:1-2:CUB"
IC2codelist2GE4codelist["CUW"] = "ge:GENC:3:1-2:CUW"
IC2codelist2GE4codelist["CXR"] = "ge:GENC:3:1-2:CXR"
IC2codelist2GE4codelist["CYM"] = "ge:GENC:3:1-2:CYM"
IC2codelist2GE4codelist["CYP"] = "ge:GENC:3:1-2:CYP"
IC2codelist2GE4codelist["CZE"] = "ge:GENC:3:1-2:CZE"
IC2codelist2GE4codelist["DEU"] = "ge:GENC:3:1-2:DEU"
IC2codelist2GE4codelist["DGA"] = "ge:GENC:3:1-2:DGA"
IC2codelist2GE4codelist["DJI"] = "ge:GENC:3:1-2:DJI"
IC2codelist2GE4codelist["DMA"] = "ge:GENC:3:1-2:DMA"
IC2codelist2GE4codelist["DNK"] = "ge:GENC:3:1-2:DNK"
IC2codelist2GE4codelist["DOM"] = "ge:GENC:3:1-2:DOM"
IC2codelist2GE4codelist["DZA"] = "ge:GENC:3:1-2:DZA"
IC2codelist2GE4codelist["ECU"] = "ge:GENC:3:1-2:ECU"
IC2codelist2GE4codelist["EGY"] = "ge:GENC:3:1-2:EGY"
IC2codelist2GE4codelist["ERI"] = "ge:GENC:3:1-2:ERI"
IC2codelist2GE4codelist["ESH"] = "ge:GENC:3:1-2:ESH"
IC2codelist2GE4codelist["ESP"] = "ge:GENC:3:1-2:ESP"
IC2codelist2GE4codelist["EST"] = "ge:GENC:3:1-2:EST"
IC2codelist2GE4codelist["ETH"] = "ge:GENC:3:1-2:ETH"
IC2codelist2GE4codelist["FIN"] = "ge:GENC:3:1-2:FIN"
IC2codelist2GE4codelist["FJI"] = "ge:GENC:3:1-2:FJI"
IC2codelist2GE4codelist["FLK"] = "ge:GENC:3:1-2:FLK"
IC2codelist2GE4codelist["FRA"] = "ge:GENC:3:1-2:FRA"
IC2codelist2GE4codelist["FRO"] = "ge:GENC:3:1-2:FRO"
IC2codelist2GE4codelist["FSM"] = "ge:GENC:3:1-2:FSM"
IC2codelist2GE4codelist["GAB"] = "ge:GENC:3:1-2:GAB"
IC2codelist2GE4codelist["GBR"] = "ge:GENC:3:1-2:GBR"
IC2codelist2GE4codelist["GEO"] = "ge:GENC:3:1-2:GEO"
IC2codelist2GE4codelist["GGY"] = "ge:GENC:3:1-2:GGY"
IC2codelist2GE4codelist["GHA"] = "ge:GENC:3:1-2:GHA"
IC2codelist2GE4codelist["GIN"] = "ge:GENC:3:1-2:GIN"
IC2codelist2GE4codelist["GLP"] = "ge:GENC:3:1-2:GLP"
IC2codelist2GE4codelist["GMB"] = "ge:GENC:3:1-2:GMB"
IC2codelist2GE4codelist["GNB"] = "ge:GENC:3:1-2:GNB"
IC2codelist2GE4codelist["GNQ"] = "ge:GENC:3:1-2:GNQ"
IC2codelist2GE4codelist["GRC"] = "ge:GENC:3:1-2:GRC"
IC2codelist2GE4codelist["GTM"] = "ge:GENC:3:1-2:GTM"
IC2codelist2GE4codelist["GUF"] = "ge:GENC:3:1-2:GUF"
IC2codelist2GE4codelist["GUM"] = "ge:GENC:3:1-2:GUM"
IC2codelist2GE4codelist["GUY"] = "ge:GENC:3:1-2:GUY"
IC2codelist2GE4codelist["HKG"] = "ge:GENC:3:1-2:HKG"
IC2codelist2GE4codelist["HMD"] = "ge:GENC:3:1-2:HMD"
IC2codelist2GE4codelist["HND"] = "ge:GENC:3:1-2:HND"
IC2codelist2GE4codelist["HRV"] = "ge:GENC:3:1-2:HRV"
IC2codelist2GE4codelist["HTI"] = "ge:GENC:3:1-2:HTI"
IC2codelist2GE4codelist["IDN"] = "ge:GENC:3:1-2:IDN"
IC2codelist2GE4codelist["IND"] = "ge:GENC:3:1-2:IND"
IC2codelist2GE4codelist["IOT"] = "ge:GENC:3:1-2:IOT"
IC2codelist2GE4codelist["IRN"] = "ge:GENC:3:1-2:IRN"
IC2codelist2GE4codelist["IRQ"] = "ge:GENC:3:1-2:IRQ"
IC2codelist2GE4codelist["ISL"] = "ge:GENC:3:1-2:ISL"
IC2codelist2GE4codelist["ISR"] = "ge:GENC:3:1-2:ISR"
IC2codelist2GE4codelist["ITA"] = "ge:GENC:3:1-2:ITA"
IC2codelist2GE4codelist["JEY"] = "ge:GENC:3:1-2:JEY"
IC2codelist2GE4codelist["JOR"] = "ge:GENC:3:1-2:JOR"
IC2codelist2GE4codelist["KAZ"] = "ge:GENC:3:1-2:KAZ"
IC2codelist2GE4codelist["KEN"] = "ge:GENC:3:1-2:KEN"
IC2codelist2GE4codelist["KGZ"] = "ge:GENC:3:1-2:KGZ"
IC2codelist2GE4codelist["KHM"] = "ge:GENC:3:1-2:KHM"
IC2codelist2GE4codelist["KIR"] = "ge:GENC:3:1-2:KIR"
IC2codelist2GE4codelist["KNA"] = "ge:GENC:3:1-2:KNA"
IC2codelist2GE4codelist["KOR"] = "ge:GENC:3:1-2:KOR"
IC2codelist2GE4codelist["KWT"] = "ge:GENC:3:1-2:KWT"
IC2codelist2GE4codelist["LAO"] = "ge:GENC:3:1-2:LAO"
IC2codelist2GE4codelist["LBN"] = "ge:GENC:3:1-2:LBN"
IC2codelist2GE4codelist["LBR"] = "ge:GENC:3:1-2:LBR"
IC2codelist2GE4codelist["LIE"] = "ge:GENC:3:1-2:LIE"
IC2codelist2GE4codelist["LKA"] = "ge:GENC:3:1-2:LKA"
IC2codelist2GE4codelist["LSO"] = "ge:GENC:3:1-2:LSO"
IC2codelist2GE4codelist["LTU"] = "ge:GENC:3:1-2:LTU"
IC2codelist2GE4codelist["LUX"] = "ge:GENC:3:1-2:LUX"
IC2codelist2GE4codelist["LVA"] = "ge:GENC:3:1-2:LVA"
IC2codelist2GE4codelist["MAC"] = "ge:GENC:3:1-2:MAC"
IC2codelist2GE4codelist["MAF"] = "ge:GENC:3:1-2:MAF"
IC2codelist2GE4codelist["MAR"] = "ge:GENC:3:1-2:MAR"
IC2codelist2GE4codelist["MCO"] = "ge:GENC:3:1-2:MCO"
IC2codelist2GE4codelist["MDA"] = "ge:GENC:3:1-2:MDA"
IC2codelist2GE4codelist["MDG"] = "ge:GENC:3:1-2:MDG"
IC2codelist2GE4codelist["MDV"] = "ge:GENC:3:1-2:MDV"
IC2codelist2GE4codelist["MEX"] = "ge:GENC:3:1-2:MEX"
IC2codelist2GE4codelist["MHL"] = "ge:GENC:3:1-2:MHL"
IC2codelist2GE4codelist["MKD"] = "ge:GENC:3:1-2:MKD"
IC2codelist2GE4codelist["MLI"] = "ge:GENC:3:1-2:MLI"
IC2codelist2GE4codelist["MLT"] = "ge:GENC:3:1-2:MLT"
IC2codelist2GE4codelist["MMR"] = "ge:GENC:3:1-2:MMR"
IC2codelist2GE4codelist["MNG"] = "ge:GENC:3:1-2:MNG"
IC2codelist2GE4codelist["MNP"] = "ge:GENC:3:1-2:MNP"
IC2codelist2GE4codelist["MOZ"] = "ge:GENC:3:1-2:MOZ"
IC2codelist2GE4codelist["MRT"] = "ge:GENC:3:1-2:MRT"
IC2codelist2GE4codelist["MTQ"] = "ge:GENC:3:1-2:MTQ"
IC2codelist2GE4codelist["MUS"] = "ge:GENC:3:1-2:MUS"
IC2codelist2GE4codelist["MWI"] = "ge:GENC:3:1-2:MWI"
IC2codelist2GE4codelist["MYS"] = "ge:GENC:3:1-2:MYS"
IC2codelist2GE4codelist["MYT"] = "ge:GENC:3:1-2:MYT"
IC2codelist2GE4codelist["NAM"] = "ge:GENC:3:1-2:NAM"
IC2codelist2GE4codelist["NCL"] = "ge:GENC:3:1-2:NCL"
IC2codelist2GE4codelist["NER"] = "ge:GENC:3:1-2:NER"
IC2codelist2GE4codelist["NFK"] = "ge:GENC:3:1-2:NFK"
IC2codelist2GE4codelist["NGA"] = "ge:GENC:3:1-2:NGA"
IC2codelist2GE4codelist["NIC"] = "ge:GENC:3:1-2:NIC"
IC2codelist2GE4codelist["NLD"] = "ge:GENC:3:1-2:NLD"
IC2codelist2GE4codelist["NOR"] = "ge:GENC:3:1-2:NOR"
IC2codelist2GE4codelist["NPL"] = "ge:GENC:3:1-2:NPL"
IC2codelist2GE4codelist["NRU"] = "ge:GENC:3:1-2:NRU"
IC2codelist2GE4codelist["NZL"] = "ge:GENC:3:1-2:NZL"
IC2codelist2GE4codelist["OMN"] = "ge:GENC:3:1-2:OMN"
IC2codelist2GE4codelist["PAK"] = "ge:GENC:3:1-2:PAK"
IC2codelist2GE4codelist["PAN"] = "ge:GENC:3:1-2:PAN"
IC2codelist2GE4codelist["PCN"] = "ge:GENC:3:1-2:PCN"
IC2codelist2GE4codelist["PER"] = "ge:GENC:3:1-2:PER"
IC2codelist2GE4codelist["PHL"] = "ge:GENC:3:1-2:PHL"
IC2codelist2GE4codelist["PLW"] = "ge:GENC:3:1-2:PLW"
IC2codelist2GE4codelist["POL"] = "ge:GENC:3:1-2:POL"
IC2codelist2GE4codelist["PRI"] = "ge:GENC:3:1-2:PRI"
IC2codelist2GE4codelist["PRK"] = "ge:GENC:3:1-2:PRK"
IC2codelist2GE4codelist["PRT"] = "ge:GENC:3:1-2:PRT"
IC2codelist2GE4codelist["PRY"] = "ge:GENC:3:1-2:PRY"
IC2codelist2GE4codelist["PSE"] = "ge:GENC:3:1-2:PSE"
IC2codelist2GE4codelist["PYF"] = "ge:GENC:3:1-2:PYF"
IC2codelist2GE4codelist["QAT"] = "ge:GENC:3:1-2:QAT"
IC2codelist2GE4codelist["REU"] = "ge:GENC:3:1-2:REU"
IC2codelist2GE4codelist["RUS"] = "ge:GENC:3:1-2:RUS"
IC2codelist2GE4codelist["RWA"] = "ge:GENC:3:1-2:RWA"
IC2codelist2GE4codelist["SAU"] = "ge:GENC:3:1-2:SAU"
IC2codelist2GE4codelist["SDN"] = "ge:GENC:3:1-2:SDN"
IC2codelist2GE4codelist["SEN"] = "ge:GENC:3:1-2:SEN"
IC2codelist2GE4codelist["SGP"] = "ge:GENC:3:1-2:SGP"
IC2codelist2GE4codelist["SGS"] = "ge:GENC:3:1-2:SGS"
IC2codelist2GE4codelist["SHN"] = "ge:GENC:3:1-2:SHN"
IC2codelist2GE4codelist["SLB"] = "ge:GENC:3:1-2:SLB"
IC2codelist2GE4codelist["SLE"] = "ge:GENC:3:1-2:SLE"
IC2codelist2GE4codelist["SLV"] = "ge:GENC:3:1-2:SLV"
IC2codelist2GE4codelist["SMR"] = "ge:GENC:3:1-2:SMR"
IC2codelist2GE4codelist["SOM"] = "ge:GENC:3:1-2:SOM"
IC2codelist2GE4codelist["SPM"] = "ge:GENC:3:1-2:SPM"
IC2codelist2GE4codelist["SRB"] = "ge:GENC:3:1-2:SRB"
IC2codelist2GE4codelist["SSD"] = "ge:GENC:3:1-2:SSD"
IC2codelist2GE4codelist["STP"] = "ge:GENC:3:1-2:STP"
IC2codelist2GE4codelist["SUR"] = "ge:GENC:3:1-2:SUR"
IC2codelist2GE4codelist["SVK"] = "ge:GENC:3:1-2:SVK"
IC2codelist2GE4codelist["SVN"] = "ge:GENC:3:1-2:SVN"
IC2codelist2GE4codelist["SWE"] = "ge:GENC:3:1-2:SWE"
IC2codelist2GE4codelist["SWZ"] = "ge:GENC:3:1-2:SWZ"
IC2codelist2GE4codelist["SXM"] = "ge:GENC:3:1-2:SXM"
IC2codelist2GE4codelist["SYC"] = "ge:GENC:3:1-2:SYC"
IC2codelist2GE4codelist["SYR"] = "ge:GENC:3:1-2:SYR"
IC2codelist2GE4codelist["TCA"] = "ge:GENC:3:1-2:TCA"
IC2codelist2GE4codelist["TCD"] = "ge:GENC:3:1-2:TCD"
IC2codelist2GE4codelist["TGO"] = "ge:GENC:3:1-2:TGO"
IC2codelist2GE4codelist["THA"] = "ge:GENC:3:1-2:THA"
IC2codelist2GE4codelist["TJK"] = "ge:GENC:3:1-2:TJK"
IC2codelist2GE4codelist["TLS"] = "ge:GENC:3:1-2:TLS"
IC2codelist2GE4codelist["TON"] = "ge:GENC:3:1-2:TON"
IC2codelist2GE4codelist["TTO"] = "ge:GENC:3:1-2:TTO"
IC2codelist2GE4codelist["TUN"] = "ge:GENC:3:1-2:TUN"
IC2codelist2GE4codelist["TUR"] = "ge:GENC:3:1-2:TUR"
IC2codelist2GE4codelist["TWN"] = "ge:GENC:3:1-2:TWN"
IC2codelist2GE4codelist["TZA"] = "ge:GENC:3:1-2:TZA"
IC2codelist2GE4codelist["UGA"] = "ge:GENC:3:1-2:UGA"
IC2codelist2GE4codelist["UKR"] = "ge:GENC:3:1-2:UKR"
IC2codelist2GE4codelist["URY"] = "ge:GENC:3:1-2:URY"
IC2codelist2GE4codelist["USA"] = "ge:GENC:3:1-2:USA"
IC2codelist2GE4codelist["UZB"] = "ge:GENC:3:1-2:UZB"
IC2codelist2GE4codelist["VAT"] = "ge:GENC:3:1-2:VAT"
IC2codelist2GE4codelist["VCT"] = "ge:GENC:3:1-2:VCT"
IC2codelist2GE4codelist["VEN"] = "ge:GENC:3:1-2:VEN"
IC2codelist2GE4codelist["VGB"] = "ge:GENC:3:1-2:VGB"
IC2codelist2GE4codelist["VIR"] = "ge:GENC:3:1-2:VIR"
IC2codelist2GE4codelist["VNM"] = "ge:GENC:3:1-2:VNM"
IC2codelist2GE4codelist["VUT"] = "ge:GENC:3:1-2:VUT"
IC2codelist2GE4codelist["WLF"] = "ge:GENC:3:1-2:WLF"
IC2codelist2GE4codelist["WSM"] = "ge:GENC:3:1-2:WSM"
IC2codelist2GE4codelist["XAC"] = "ge:GENC:3:1-2:XAC"
IC2codelist2GE4codelist["XAZ"] = "ge:GENC:3:1-2:XAZ"
IC2codelist2GE4codelist["XBI"] = "ge:GENC:3:1-2:XBI"
IC2codelist2GE4codelist["XBK"] = "ge:GENC:3:1-2:XBK"
IC2codelist2GE4codelist["XCR"] = "ge:GENC:3:1-2:XCR"
IC2codelist2GE4codelist["XCS"] = "ge:GENC:3:1-2:XCS"
IC2codelist2GE4codelist["XCY"] = "ge:GENC:3:1-2:XCY"
IC2codelist2GE4codelist["XEU"] = "ge:GENC:3:1-2:XEU"
IC2codelist2GE4codelist["XGL"] = "ge:GENC:3:1-2:XGL"
IC2codelist2GE4codelist["XGZ"] = "ge:GENC:3:1-2:XGZ"
IC2codelist2GE4codelist["XHO"] = "ge:GENC:3:1-2:XHO"
IC2codelist2GE4codelist["XJA"] = "ge:GENC:3:1-2:XJA"
IC2codelist2GE4codelist["XJM"] = "ge:GENC:3:1-2:XJM"
IC2codelist2GE4codelist["XJN"] = "ge:GENC:3:1-2:XJN"
IC2codelist2GE4codelist["XJV"] = "ge:GENC:3:1-2:XJV"
IC2codelist2GE4codelist["XKM"] = "ge:GENC:3:1-2:XKM"
IC2codelist2GE4codelist["XKN"] = "ge:GENC:3:1-2:XKN"
IC2codelist2GE4codelist["XKR"] = "ge:GENC:3:1-2:XKR"
IC2codelist2GE4codelist["XKS"] = "ge:GENC:3:1-2:XKS"
IC2codelist2GE4codelist["XMW"] = "ge:GENC:3:1-2:XMW"
IC2codelist2GE4codelist["XNV"] = "ge:GENC:3:1-2:XNV"
IC2codelist2GE4codelist["XPL"] = "ge:GENC:3:1-2:XPL"
IC2codelist2GE4codelist["XPR"] = "ge:GENC:3:1-2:XPR"
IC2codelist2GE4codelist["XQP"] = "ge:GENC:3:1-2:XQP"
IC2codelist2GE4codelist["XQZ"] = "ge:GENC:3:1-2:XQZ"
IC2codelist2GE4codelist["XSP"] = "ge:GENC:3:1-2:XSP"
IC2codelist2GE4codelist["XSV"] = "ge:GENC:3:1-2:XSV"
IC2codelist2GE4codelist["XTR"] = "ge:GENC:3:1-2:XTR"
IC2codelist2GE4codelist["XWB"] = "ge:GENC:3:1-2:XWB"
IC2codelist2GE4codelist["XWK"] = "ge:GENC:3:1-2:XWK"
IC2codelist2GE4codelist["XXD"] = "ge:GENC:3:1-2:XXD"
IC2codelist2GE4codelist["XXX"] = "ge:GENC:3:1-2:XXX"
IC2codelist2GE4codelist["YEM"] = "ge:GENC:3:1-2:YEM"
IC2codelist2GE4codelist["ZAF"] = "ge:GENC:3:1-2:ZAF"
IC2codelist2GE4codelist["ZMB"] = "ge:GENC:3:1-2:ZMB"
IC2codelist2GE4codelist["ZWE"] = "ge:GENC:3:1-2:ZWE"
IC2codelist2GE4codelist["AX3"] = "ge:GENC:3:ed3:AX3"
IC2codelist2GE4codelist["AIA"] = "ge:ISO1:3:VI-15:AIA"
IC2codelist2GE4codelist["ATA"] = "ge:ISO1:3:VI-15:ATA"
IC2codelist2GE4codelist["BIH"] = "ge:ISO1:3:VI-15:BIH"
IC2codelist2GE4codelist["BLZ"] = "ge:ISO1:3:VI-15:BLZ"
IC2codelist2GE4codelist["BMU"] = "ge:ISO1:3:VI-15:BMU"
IC2codelist2GE4codelist["BRB"] = "ge:ISO1:3:VI-15:BRB"
IC2codelist2GE4codelist["BVT"] = "ge:ISO1:3:VI-15:BVT"
IC2codelist2GE4codelist["GIB"] = "ge:ISO1:3:VI-15:GIB"
IC2codelist2GE4codelist["GRD"] = "ge:ISO1:3:VI-15:GRD"
IC2codelist2GE4codelist["GRL"] = "ge:ISO1:3:VI-15:GRL"
IC2codelist2GE4codelist["HUN"] = "ge:ISO1:3:VI-15:HUN"
IC2codelist2GE4codelist["IMN"] = "ge:ISO1:3:VI-15:IMN"
IC2codelist2GE4codelist["IRL"] = "ge:ISO1:3:VI-15:IRL"
IC2codelist2GE4codelist["JAM"] = "ge:ISO1:3:VI-15:JAM"
IC2codelist2GE4codelist["JPN"] = "ge:ISO1:3:VI-15:JPN"
IC2codelist2GE4codelist["LBY"] = "ge:ISO1:3:VI-15:LBY"
IC2codelist2GE4codelist["LCA"] = "ge:ISO1:3:VI-15:LCA"
IC2codelist2GE4codelist["MNE"] = "ge:ISO1:3:VI-15:MNE"
IC2codelist2GE4codelist["MSR"] = "ge:ISO1:3:VI-15:MSR"
IC2codelist2GE4codelist["NIU"] = "ge:ISO1:3:VI-15:NIU"
IC2codelist2GE4codelist["PNG"] = "ge:ISO1:3:VI-15:PNG"
IC2codelist2GE4codelist["ROU"] = "ge:ISO1:3:VI-15:ROU"
IC2codelist2GE4codelist["TKL"] = "ge:ISO1:3:VI-15:TKL"
IC2codelist2GE4codelist["TKM"] = "ge:ISO1:3:VI-15:TKM"
IC2codelist2GE4codelist["TUV"] = "ge:ISO1:3:VI-15:TUV"
IC2codelist2GE4codelist["------"] = "noInformation"
IC2codelist2GE4codelist["noInformation"] = "noInformation"
IC2codelist2GE4codelist["No Information"] = "noInformation"
IC2codelist2GE4codelist["no information"] = "noInformation"
IC2codelist2GE4codelist["other"] = "other"
IC2codelist2GE4codelist["Other"] = "other"

# lowercase option
IC2codelist2GE4codelist["abw"] = "ge:GENC:3:1-2:ABW"
IC2codelist2GE4codelist["afg"] = "ge:GENC:3:1-2:AFG"
IC2codelist2GE4codelist["ago"] = "ge:GENC:3:1-2:AGO"
IC2codelist2GE4codelist["alb"] = "ge:GENC:3:1-2:ALB"
IC2codelist2GE4codelist["and"] = "ge:GENC:3:1-2:AND"
IC2codelist2GE4codelist["are"] = "ge:GENC:3:1-2:ARE"
IC2codelist2GE4codelist["arg"] = "ge:GENC:3:1-2:ARG"
IC2codelist2GE4codelist["arm"] = "ge:GENC:3:1-2:ARM"
IC2codelist2GE4codelist["asm"] = "ge:GENC:3:1-2:ASM"
IC2codelist2GE4codelist["atf"] = "ge:GENC:3:1-2:ATF"
IC2codelist2GE4codelist["atg"] = "ge:GENC:3:1-2:ATG"
IC2codelist2GE4codelist["aus"] = "ge:GENC:3:1-2:AUS"
IC2codelist2GE4codelist["aut"] = "ge:GENC:3:1-2:AUT"
IC2codelist2GE4codelist["ax1"] = "ge:GENC:3:1-2:AX1"
IC2codelist2GE4codelist["ax2"] = "ge:GENC:3:1-2:AX2"
IC2codelist2GE4codelist["aze"] = "ge:GENC:3:1-2:AZE"
IC2codelist2GE4codelist["bdi"] = "ge:GENC:3:1-2:BDI"
IC2codelist2GE4codelist["bel"] = "ge:GENC:3:1-2:BEL"
IC2codelist2GE4codelist["ben"] = "ge:GENC:3:1-2:BEN"
IC2codelist2GE4codelist["bes"] = "ge:GENC:3:1-2:BES"
IC2codelist2GE4codelist["bfa"] = "ge:GENC:3:1-2:BFA"
IC2codelist2GE4codelist["bgd"] = "ge:GENC:3:1-2:BGD"
IC2codelist2GE4codelist["bgr"] = "ge:GENC:3:1-2:BGR"
IC2codelist2GE4codelist["bhr"] = "ge:GENC:3:1-2:BHR"
IC2codelist2GE4codelist["bhs"] = "ge:GENC:3:1-2:BHS"
IC2codelist2GE4codelist["blm"] = "ge:GENC:3:1-2:BLM"
IC2codelist2GE4codelist["blr"] = "ge:GENC:3:1-2:BLR"
IC2codelist2GE4codelist["bol"] = "ge:GENC:3:1-2:BOL"
IC2codelist2GE4codelist["bra"] = "ge:GENC:3:1-2:BRA"
IC2codelist2GE4codelist["brn"] = "ge:GENC:3:1-2:BRN"
IC2codelist2GE4codelist["btn"] = "ge:GENC:3:1-2:BTN"
IC2codelist2GE4codelist["bwa"] = "ge:GENC:3:1-2:BWA"
IC2codelist2GE4codelist["caf"] = "ge:GENC:3:1-2:CAF"
IC2codelist2GE4codelist["can"] = "ge:GENC:3:1-2:CAN"
IC2codelist2GE4codelist["cck"] = "ge:GENC:3:1-2:CCK"
IC2codelist2GE4codelist["che"] = "ge:GENC:3:1-2:CHE"
IC2codelist2GE4codelist["chl"] = "ge:GENC:3:1-2:CHL"
IC2codelist2GE4codelist["chn"] = "ge:GENC:3:1-2:CHN"
IC2codelist2GE4codelist["civ"] = "ge:GENC:3:1-2:CIV"
IC2codelist2GE4codelist["cmr"] = "ge:GENC:3:1-2:CMR"
IC2codelist2GE4codelist["cod"] = "ge:GENC:3:1-2:COD"
IC2codelist2GE4codelist["cog"] = "ge:GENC:3:1-2:COG"
IC2codelist2GE4codelist["cok"] = "ge:GENC:3:1-2:COK"
IC2codelist2GE4codelist["col"] = "ge:GENC:3:1-2:COL"
IC2codelist2GE4codelist["com"] = "ge:GENC:3:1-2:COM"
IC2codelist2GE4codelist["cpt"] = "ge:GENC:3:1-2:CPT"
IC2codelist2GE4codelist["cpv"] = "ge:GENC:3:1-2:CPV"
IC2codelist2GE4codelist["cri"] = "ge:GENC:3:1-2:CRI"
IC2codelist2GE4codelist["cub"] = "ge:GENC:3:1-2:CUB"
IC2codelist2GE4codelist["cuw"] = "ge:GENC:3:1-2:CUW"
IC2codelist2GE4codelist["cxr"] = "ge:GENC:3:1-2:CXR"
IC2codelist2GE4codelist["cym"] = "ge:GENC:3:1-2:CYM"
IC2codelist2GE4codelist["cyp"] = "ge:GENC:3:1-2:CYP"
IC2codelist2GE4codelist["cze"] = "ge:GENC:3:1-2:CZE"
IC2codelist2GE4codelist["deu"] = "ge:GENC:3:1-2:DEU"
IC2codelist2GE4codelist["dga"] = "ge:GENC:3:1-2:DGA"
IC2codelist2GE4codelist["dji"] = "ge:GENC:3:1-2:DJI"
IC2codelist2GE4codelist["dma"] = "ge:GENC:3:1-2:DMA"
IC2codelist2GE4codelist["dnk"] = "ge:GENC:3:1-2:DNK"
IC2codelist2GE4codelist["dom"] = "ge:GENC:3:1-2:DOM"
IC2codelist2GE4codelist["dza"] = "ge:GENC:3:1-2:DZA"
IC2codelist2GE4codelist["ecu"] = "ge:GENC:3:1-2:ECU"
IC2codelist2GE4codelist["egy"] = "ge:GENC:3:1-2:EGY"
IC2codelist2GE4codelist["eri"] = "ge:GENC:3:1-2:ERI"
IC2codelist2GE4codelist["esh"] = "ge:GENC:3:1-2:ESH"
IC2codelist2GE4codelist["esp"] = "ge:GENC:3:1-2:ESP"
IC2codelist2GE4codelist["est"] = "ge:GENC:3:1-2:EST"
IC2codelist2GE4codelist["eth"] = "ge:GENC:3:1-2:ETH"
IC2codelist2GE4codelist["fin"] = "ge:GENC:3:1-2:FIN"
IC2codelist2GE4codelist["fji"] = "ge:GENC:3:1-2:FJI"
IC2codelist2GE4codelist["flk"] = "ge:GENC:3:1-2:FLK"
IC2codelist2GE4codelist["fra"] = "ge:GENC:3:1-2:FRA"
IC2codelist2GE4codelist["fro"] = "ge:GENC:3:1-2:FRO"
IC2codelist2GE4codelist["fsm"] = "ge:GENC:3:1-2:FSM"
IC2codelist2GE4codelist["gab"] = "ge:GENC:3:1-2:GAB"
IC2codelist2GE4codelist["gbr"] = "ge:GENC:3:1-2:GBR"
IC2codelist2GE4codelist["geo"] = "ge:GENC:3:1-2:GEO"
IC2codelist2GE4codelist["ggy"] = "ge:GENC:3:1-2:GGY"
IC2codelist2GE4codelist["gha"] = "ge:GENC:3:1-2:GHA"
IC2codelist2GE4codelist["gin"] = "ge:GENC:3:1-2:GIN"
IC2codelist2GE4codelist["glp"] = "ge:GENC:3:1-2:GLP"
IC2codelist2GE4codelist["gmb"] = "ge:GENC:3:1-2:GMB"
IC2codelist2GE4codelist["gnb"] = "ge:GENC:3:1-2:GNB"
IC2codelist2GE4codelist["gnq"] = "ge:GENC:3:1-2:GNQ"
IC2codelist2GE4codelist["grc"] = "ge:GENC:3:1-2:GRC"
IC2codelist2GE4codelist["gtm"] = "ge:GENC:3:1-2:GTM"
IC2codelist2GE4codelist["guf"] = "ge:GENC:3:1-2:GUF"
IC2codelist2GE4codelist["gum"] = "ge:GENC:3:1-2:GUM"
IC2codelist2GE4codelist["guy"] = "ge:GENC:3:1-2:GUY"
IC2codelist2GE4codelist["hkg"] = "ge:GENC:3:1-2:HKG"
IC2codelist2GE4codelist["hmd"] = "ge:GENC:3:1-2:HMD"
IC2codelist2GE4codelist["hnd"] = "ge:GENC:3:1-2:HND"
IC2codelist2GE4codelist["hrv"] = "ge:GENC:3:1-2:HRV"
IC2codelist2GE4codelist["hti"] = "ge:GENC:3:1-2:HTI"
IC2codelist2GE4codelist["idn"] = "ge:GENC:3:1-2:IDN"
IC2codelist2GE4codelist["ind"] = "ge:GENC:3:1-2:IND"
IC2codelist2GE4codelist["iot"] = "ge:GENC:3:1-2:IOT"
IC2codelist2GE4codelist["irn"] = "ge:GENC:3:1-2:IRN"
IC2codelist2GE4codelist["irq"] = "ge:GENC:3:1-2:IRQ"
IC2codelist2GE4codelist["isl"] = "ge:GENC:3:1-2:ISL"
IC2codelist2GE4codelist["isr"] = "ge:GENC:3:1-2:ISR"
IC2codelist2GE4codelist["ita"] = "ge:GENC:3:1-2:ITA"
IC2codelist2GE4codelist["jey"] = "ge:GENC:3:1-2:JEY"
IC2codelist2GE4codelist["jor"] = "ge:GENC:3:1-2:JOR"
IC2codelist2GE4codelist["kaz"] = "ge:GENC:3:1-2:KAZ"
IC2codelist2GE4codelist["ken"] = "ge:GENC:3:1-2:KEN"
IC2codelist2GE4codelist["kgz"] = "ge:GENC:3:1-2:KGZ"
IC2codelist2GE4codelist["khm"] = "ge:GENC:3:1-2:KHM"
IC2codelist2GE4codelist["kir"] = "ge:GENC:3:1-2:KIR"
IC2codelist2GE4codelist["kna"] = "ge:GENC:3:1-2:KNA"
IC2codelist2GE4codelist["kor"] = "ge:GENC:3:1-2:KOR"
IC2codelist2GE4codelist["kwt"] = "ge:GENC:3:1-2:KWT"
IC2codelist2GE4codelist["lao"] = "ge:GENC:3:1-2:LAO"
IC2codelist2GE4codelist["lbn"] = "ge:GENC:3:1-2:LBN"
IC2codelist2GE4codelist["lbr"] = "ge:GENC:3:1-2:LBR"
IC2codelist2GE4codelist["lie"] = "ge:GENC:3:1-2:LIE"
IC2codelist2GE4codelist["lka"] = "ge:GENC:3:1-2:LKA"
IC2codelist2GE4codelist["lso"] = "ge:GENC:3:1-2:LSO"
IC2codelist2GE4codelist["ltu"] = "ge:GENC:3:1-2:LTU"
IC2codelist2GE4codelist["lux"] = "ge:GENC:3:1-2:LUX"
IC2codelist2GE4codelist["lva"] = "ge:GENC:3:1-2:LVA"
IC2codelist2GE4codelist["mac"] = "ge:GENC:3:1-2:MAC"
IC2codelist2GE4codelist["maf"] = "ge:GENC:3:1-2:MAF"
IC2codelist2GE4codelist["mar"] = "ge:GENC:3:1-2:MAR"
IC2codelist2GE4codelist["mco"] = "ge:GENC:3:1-2:MCO"
IC2codelist2GE4codelist["mda"] = "ge:GENC:3:1-2:MDA"
IC2codelist2GE4codelist["mdg"] = "ge:GENC:3:1-2:MDG"
IC2codelist2GE4codelist["mdv"] = "ge:GENC:3:1-2:MDV"
IC2codelist2GE4codelist["mex"] = "ge:GENC:3:1-2:MEX"
IC2codelist2GE4codelist["mhl"] = "ge:GENC:3:1-2:MHL"
IC2codelist2GE4codelist["mkd"] = "ge:GENC:3:1-2:MKD"
IC2codelist2GE4codelist["mli"] = "ge:GENC:3:1-2:MLI"
IC2codelist2GE4codelist["mlt"] = "ge:GENC:3:1-2:MLT"
IC2codelist2GE4codelist["mmr"] = "ge:GENC:3:1-2:MMR"
IC2codelist2GE4codelist["mng"] = "ge:GENC:3:1-2:MNG"
IC2codelist2GE4codelist["mnp"] = "ge:GENC:3:1-2:MNP"
IC2codelist2GE4codelist["moz"] = "ge:GENC:3:1-2:MOZ"
IC2codelist2GE4codelist["mrt"] = "ge:GENC:3:1-2:MRT"
IC2codelist2GE4codelist["mtq"] = "ge:GENC:3:1-2:MTQ"
IC2codelist2GE4codelist["mus"] = "ge:GENC:3:1-2:MUS"
IC2codelist2GE4codelist["mwi"] = "ge:GENC:3:1-2:MWI"
IC2codelist2GE4codelist["mys"] = "ge:GENC:3:1-2:MYS"
IC2codelist2GE4codelist["myt"] = "ge:GENC:3:1-2:MYT"
IC2codelist2GE4codelist["nam"] = "ge:GENC:3:1-2:NAM"
IC2codelist2GE4codelist["ncl"] = "ge:GENC:3:1-2:NCL"
IC2codelist2GE4codelist["ner"] = "ge:GENC:3:1-2:NER"
IC2codelist2GE4codelist["nfk"] = "ge:GENC:3:1-2:NFK"
IC2codelist2GE4codelist["nga"] = "ge:GENC:3:1-2:NGA"
IC2codelist2GE4codelist["nic"] = "ge:GENC:3:1-2:NIC"
IC2codelist2GE4codelist["nld"] = "ge:GENC:3:1-2:NLD"
IC2codelist2GE4codelist["nor"] = "ge:GENC:3:1-2:NOR"
IC2codelist2GE4codelist["npl"] = "ge:GENC:3:1-2:NPL"
IC2codelist2GE4codelist["nru"] = "ge:GENC:3:1-2:NRU"
IC2codelist2GE4codelist["nzl"] = "ge:GENC:3:1-2:NZL"
IC2codelist2GE4codelist["omn"] = "ge:GENC:3:1-2:OMN"
IC2codelist2GE4codelist["pak"] = "ge:GENC:3:1-2:PAK"
IC2codelist2GE4codelist["pan"] = "ge:GENC:3:1-2:PAN"
IC2codelist2GE4codelist["pcn"] = "ge:GENC:3:1-2:PCN"
IC2codelist2GE4codelist["per"] = "ge:GENC:3:1-2:PER"
IC2codelist2GE4codelist["phl"] = "ge:GENC:3:1-2:PHL"
IC2codelist2GE4codelist["plw"] = "ge:GENC:3:1-2:PLW"
IC2codelist2GE4codelist["pol"] = "ge:GENC:3:1-2:POL"
IC2codelist2GE4codelist["pri"] = "ge:GENC:3:1-2:PRI"
IC2codelist2GE4codelist["prk"] = "ge:GENC:3:1-2:PRK"
IC2codelist2GE4codelist["prt"] = "ge:GENC:3:1-2:PRT"
IC2codelist2GE4codelist["pry"] = "ge:GENC:3:1-2:PRY"
IC2codelist2GE4codelist["pse"] = "ge:GENC:3:1-2:PSE"
IC2codelist2GE4codelist["pyf"] = "ge:GENC:3:1-2:PYF"
IC2codelist2GE4codelist["qat"] = "ge:GENC:3:1-2:QAT"
IC2codelist2GE4codelist["reu"] = "ge:GENC:3:1-2:REU"
IC2codelist2GE4codelist["rus"] = "ge:GENC:3:1-2:RUS"
IC2codelist2GE4codelist["rwa"] = "ge:GENC:3:1-2:RWA"
IC2codelist2GE4codelist["sau"] = "ge:GENC:3:1-2:SAU"
IC2codelist2GE4codelist["sdn"] = "ge:GENC:3:1-2:SDN"
IC2codelist2GE4codelist["sen"] = "ge:GENC:3:1-2:SEN"
IC2codelist2GE4codelist["sgp"] = "ge:GENC:3:1-2:SGP"
IC2codelist2GE4codelist["sgs"] = "ge:GENC:3:1-2:SGS"
IC2codelist2GE4codelist["shn"] = "ge:GENC:3:1-2:SHN"
IC2codelist2GE4codelist["slb"] = "ge:GENC:3:1-2:SLB"
IC2codelist2GE4codelist["sle"] = "ge:GENC:3:1-2:SLE"
IC2codelist2GE4codelist["slv"] = "ge:GENC:3:1-2:SLV"
IC2codelist2GE4codelist["smr"] = "ge:GENC:3:1-2:SMR"
IC2codelist2GE4codelist["som"] = "ge:GENC:3:1-2:SOM"
IC2codelist2GE4codelist["spm"] = "ge:GENC:3:1-2:SPM"
IC2codelist2GE4codelist["srb"] = "ge:GENC:3:1-2:SRB"
IC2codelist2GE4codelist["ssd"] = "ge:GENC:3:1-2:SSD"
IC2codelist2GE4codelist["stp"] = "ge:GENC:3:1-2:STP"
IC2codelist2GE4codelist["sur"] = "ge:GENC:3:1-2:SUR"
IC2codelist2GE4codelist["svk"] = "ge:GENC:3:1-2:SVK"
IC2codelist2GE4codelist["svn"] = "ge:GENC:3:1-2:SVN"
IC2codelist2GE4codelist["swe"] = "ge:GENC:3:1-2:SWE"
IC2codelist2GE4codelist["swz"] = "ge:GENC:3:1-2:SWZ"
IC2codelist2GE4codelist["sxm"] = "ge:GENC:3:1-2:SXM"
IC2codelist2GE4codelist["syc"] = "ge:GENC:3:1-2:SYC"
IC2codelist2GE4codelist["syr"] = "ge:GENC:3:1-2:SYR"
IC2codelist2GE4codelist["tca"] = "ge:GENC:3:1-2:TCA"
IC2codelist2GE4codelist["tcd"] = "ge:GENC:3:1-2:TCD"
IC2codelist2GE4codelist["tgo"] = "ge:GENC:3:1-2:TGO"
IC2codelist2GE4codelist["tha"] = "ge:GENC:3:1-2:THA"
IC2codelist2GE4codelist["tjk"] = "ge:GENC:3:1-2:TJK"
IC2codelist2GE4codelist["tls"] = "ge:GENC:3:1-2:TLS"
IC2codelist2GE4codelist["ton"] = "ge:GENC:3:1-2:TON"
IC2codelist2GE4codelist["tto"] = "ge:GENC:3:1-2:TTO"
IC2codelist2GE4codelist["tun"] = "ge:GENC:3:1-2:TUN"
IC2codelist2GE4codelist["tur"] = "ge:GENC:3:1-2:TUR"
IC2codelist2GE4codelist["twn"] = "ge:GENC:3:1-2:TWN"
IC2codelist2GE4codelist["tza"] = "ge:GENC:3:1-2:TZA"
IC2codelist2GE4codelist["uga"] = "ge:GENC:3:1-2:UGA"
IC2codelist2GE4codelist["ukr"] = "ge:GENC:3:1-2:UKR"
IC2codelist2GE4codelist["ury"] = "ge:GENC:3:1-2:URY"
IC2codelist2GE4codelist["usa"] = "ge:GENC:3:1-2:USA"
IC2codelist2GE4codelist["uzb"] = "ge:GENC:3:1-2:UZB"
IC2codelist2GE4codelist["vat"] = "ge:GENC:3:1-2:VAT"
IC2codelist2GE4codelist["vct"] = "ge:GENC:3:1-2:VCT"
IC2codelist2GE4codelist["ven"] = "ge:GENC:3:1-2:VEN"
IC2codelist2GE4codelist["vgb"] = "ge:GENC:3:1-2:VGB"
IC2codelist2GE4codelist["vir"] = "ge:GENC:3:1-2:VIR"
IC2codelist2GE4codelist["vnm"] = "ge:GENC:3:1-2:VNM"
IC2codelist2GE4codelist["vut"] = "ge:GENC:3:1-2:VUT"
IC2codelist2GE4codelist["wlf"] = "ge:GENC:3:1-2:WLF"
IC2codelist2GE4codelist["wsm"] = "ge:GENC:3:1-2:WSM"
IC2codelist2GE4codelist["xac"] = "ge:GENC:3:1-2:XAC"
IC2codelist2GE4codelist["xaz"] = "ge:GENC:3:1-2:XAZ"
IC2codelist2GE4codelist["xbi"] = "ge:GENC:3:1-2:XBI"
IC2codelist2GE4codelist["xbk"] = "ge:GENC:3:1-2:XBK"
IC2codelist2GE4codelist["xcr"] = "ge:GENC:3:1-2:XCR"
IC2codelist2GE4codelist["xcs"] = "ge:GENC:3:1-2:XCS"
IC2codelist2GE4codelist["xcy"] = "ge:GENC:3:1-2:XCY"
IC2codelist2GE4codelist["xeu"] = "ge:GENC:3:1-2:XEU"
IC2codelist2GE4codelist["xgl"] = "ge:GENC:3:1-2:XGL"
IC2codelist2GE4codelist["xgz"] = "ge:GENC:3:1-2:XGZ"
IC2codelist2GE4codelist["xho"] = "ge:GENC:3:1-2:XHO"
IC2codelist2GE4codelist["xja"] = "ge:GENC:3:1-2:XJA"
IC2codelist2GE4codelist["xjm"] = "ge:GENC:3:1-2:XJM"
IC2codelist2GE4codelist["xjn"] = "ge:GENC:3:1-2:XJN"
IC2codelist2GE4codelist["xjv"] = "ge:GENC:3:1-2:XJV"
IC2codelist2GE4codelist["xkm"] = "ge:GENC:3:1-2:XKM"
IC2codelist2GE4codelist["xkn"] = "ge:GENC:3:1-2:XKN"
IC2codelist2GE4codelist["xkr"] = "ge:GENC:3:1-2:XKR"
IC2codelist2GE4codelist["xks"] = "ge:GENC:3:1-2:XKS"
IC2codelist2GE4codelist["xmw"] = "ge:GENC:3:1-2:XMW"
IC2codelist2GE4codelist["xnv"] = "ge:GENC:3:1-2:XNV"
IC2codelist2GE4codelist["xpl"] = "ge:GENC:3:1-2:XPL"
IC2codelist2GE4codelist["xpr"] = "ge:GENC:3:1-2:XPR"
IC2codelist2GE4codelist["xqp"] = "ge:GENC:3:1-2:XQP"
IC2codelist2GE4codelist["xqz"] = "ge:GENC:3:1-2:XQZ"
IC2codelist2GE4codelist["xsp"] = "ge:GENC:3:1-2:XSP"
IC2codelist2GE4codelist["xsv"] = "ge:GENC:3:1-2:XSV"
IC2codelist2GE4codelist["xtr"] = "ge:GENC:3:1-2:XTR"
IC2codelist2GE4codelist["xwb"] = "ge:GENC:3:1-2:XWB"
IC2codelist2GE4codelist["xwk"] = "ge:GENC:3:1-2:XWK"
IC2codelist2GE4codelist["xxd"] = "ge:GENC:3:1-2:XXD"
IC2codelist2GE4codelist["xxx"] = "ge:GENC:3:1-2:XXX"
IC2codelist2GE4codelist["yem"] = "ge:GENC:3:1-2:YEM"
IC2codelist2GE4codelist["zaf"] = "ge:GENC:3:1-2:ZAF"
IC2codelist2GE4codelist["zmb"] = "ge:GENC:3:1-2:ZMB"
IC2codelist2GE4codelist["zwe"] = "ge:GENC:3:1-2:ZWE"
IC2codelist2GE4codelist["ax3"] = "ge:GENC:3:ed3:AX3"
IC2codelist2GE4codelist["aia"] = "ge:ISO1:3:VI-15:AIA"
IC2codelist2GE4codelist["ata"] = "ge:ISO1:3:VI-15:ATA"
IC2codelist2GE4codelist["bih"] = "ge:ISO1:3:VI-15:BIH"
IC2codelist2GE4codelist["blz"] = "ge:ISO1:3:VI-15:BLZ"
IC2codelist2GE4codelist["bmu"] = "ge:ISO1:3:VI-15:BMU"
IC2codelist2GE4codelist["brb"] = "ge:ISO1:3:VI-15:BRB"
IC2codelist2GE4codelist["bvt"] = "ge:ISO1:3:VI-15:BVT"
IC2codelist2GE4codelist["gib"] = "ge:ISO1:3:VI-15:GIB"
IC2codelist2GE4codelist["grd"] = "ge:ISO1:3:VI-15:GRD"
IC2codelist2GE4codelist["grl"] = "ge:ISO1:3:VI-15:GRL"
IC2codelist2GE4codelist["hun"] = "ge:ISO1:3:VI-15:HUN"
IC2codelist2GE4codelist["imn"] = "ge:ISO1:3:VI-15:IMN"
IC2codelist2GE4codelist["irl"] = "ge:ISO1:3:VI-15:IRL"
IC2codelist2GE4codelist["jam"] = "ge:ISO1:3:VI-15:JAM"
IC2codelist2GE4codelist["jpn"] = "ge:ISO1:3:VI-15:JPN"
IC2codelist2GE4codelist["lby"] = "ge:ISO1:3:VI-15:LBY"
IC2codelist2GE4codelist["lca"] = "ge:ISO1:3:VI-15:LCA"
IC2codelist2GE4codelist["mne"] = "ge:ISO1:3:VI-15:MNE"
IC2codelist2GE4codelist["msr"] = "ge:ISO1:3:VI-15:MSR"
IC2codelist2GE4codelist["niu"] = "ge:ISO1:3:VI-15:NIU"
IC2codelist2GE4codelist["png"] = "ge:ISO1:3:VI-15:PNG"
IC2codelist2GE4codelist["rou"] = "ge:ISO1:3:VI-15:ROU"
IC2codelist2GE4codelist["tkl"] = "ge:ISO1:3:VI-15:TKL"
IC2codelist2GE4codelist["tkm"] = "ge:ISO1:3:VI-15:TKM"
IC2codelist2GE4codelist["tuv"] = "ge:ISO1:3:VI-15:TUV"
IC2codelist2GE4codelist["noinformation"] = "noInformation"



CPScodelist2CPSenumvalue = {}
CPScodelist2CPSenumvalue["fixed0r25"] = "4"
CPScodelist2CPSenumvalue["fixed0r5"] = "3"
CPScodelist2CPSenumvalue["fixed1r0"] = "2"
CPScodelist2CPSenumvalue["fixed5r0"] = "1"
CPScodelist2CPSenumvalue["------"] = "-999999"
CPScodelist2CPSenumvalue["noInformation"] = "-999999"
CPScodelist2CPSenumvalue["No Information"] = "-999999"
CPScodelist2CPSenumvalue["no information"] = "-999999"
CPScodelist2CPSenumvalue["Not Applicable"] = "998"
CPScodelist2CPSenumvalue["notApplicable"] = "998"
CPScodelist2CPSenumvalue["not applicable"] = "998"
CPScodelist2CPSenumvalue["other"] = "999"
CPScodelist2CPSenumvalue["Other"] = "999"
CPScodelist2CPSenumvalue["variable"] = "5"

ETScodelist2ETSenumvalue = {}
ETScodelist2ETSenumvalue["atc"] = "26"
ETScodelist2ETSenumvalue["combat"] = "17"
ETScodelist2ETSenumvalue["dfad1"] = "5"
ETScodelist2ETSenumvalue["dfad2"] = "7"
ETScodelist2ETSenumvalue["digitalFeg"] = "56"
ETScodelist2ETSenumvalue["dnc"] = "43"
ETScodelist2ETSenumvalue["dted1"] = "4"
ETScodelist2ETSenumvalue["dted2"] = "6"
ETScodelist2ETSenumvalue["dtop"] = "21"
ETScodelist2ETSenumvalue["ffd"] = "31"
ETScodelist2ETSenumvalue["globalTdsEg"] = "57"
ETScodelist2ETSenumvalue["hac1"] = "8"
ETScodelist2ETSenumvalue["hac2"] = "9"
ETScodelist2ETSenumvalue["hac3"] = "10"
ETScodelist2ETSenumvalue["hac4"] = "11"
ETScodelist2ETSenumvalue["hac5"] = "12"
ETScodelist2ETSenumvalue["hac6"] = "13"
ETScodelist2ETSenumvalue["hac7"] = "14"
ETScodelist2ETSenumvalue["hac8"] = "15"
ETScodelist2ETSenumvalue["hac9"] = "16"
ETScodelist2ETSenumvalue["jogAirGround"] = "3"
ETScodelist2ETSenumvalue["jogRadar"] = "27"
ETScodelist2ETSenumvalue["localTdsEg"] = "59"
ETScodelist2ETSenumvalue["mgcpTrd"] = "61"
ETScodelist2ETSenumvalue["msd1"] = "44"
ETScodelist2ETSenumvalue["msd2"] = "45"
ETScodelist2ETSenumvalue["msd3"] = "46"
ETScodelist2ETSenumvalue["msd4"] = "47"
ETScodelist2ETSenumvalue["msd5"] = "48"
ETScodelist2ETSenumvalue["------"] = "-999999"
ETScodelist2ETSenumvalue["noInformation"] = "-999999"
ETScodelist2ETSenumvalue["No Information"] = "-999999"
ETScodelist2ETSenumvalue["no information"] = "-999999"
ETScodelist2ETSenumvalue["onc"] = "2"
ETScodelist2ETSenumvalue["notApplicable"] = "998"
ETScodelist2ETSenumvalue["not applicable"] = "998"
ETScodelist2ETSenumvalue["Not Applicable"] = "998"
ETScodelist2ETSenumvalue["other"] = "999"
ETScodelist2ETSenumvalue["Other"] = "999"
ETScodelist2ETSenumvalue["regionalTdsEg"] = "58"
ETScodelist2ETSenumvalue["specUrbanTdsEg"] = "60"
ETScodelist2ETSenumvalue["tercomE"] = "29"
ETScodelist2ETSenumvalue["tercomL"] = "28"
ETScodelist2ETSenumvalue["tercomT"] = "30"
ETScodelist2ETSenumvalue["tlm100"] = "19"
ETScodelist2ETSenumvalue["tlm50"] = "18"
ETScodelist2ETSenumvalue["tod0"] = "49"
ETScodelist2ETSenumvalue["tod1"] = "50"
ETScodelist2ETSenumvalue["tod2"] = "51"
ETScodelist2ETSenumvalue["tod3"] = "52"
ETScodelist2ETSenumvalue["tod4"] = "53"
ETScodelist2ETSenumvalue["tpc"] = "1"
ETScodelist2ETSenumvalue["uvmap"] = "25"
ETScodelist2ETSenumvalue["vitd"] = "20"
ETScodelist2ETSenumvalue["vmap0"] = "23"
ETScodelist2ETSenumvalue["vmap1"] = "24"
ETScodelist2ETSenumvalue["vmap2"] = "22"

HZDcodelist2HZDenumvalue = {}
HZDcodelist2HZDenumvalue["adindanBurkinaFaso"] = "6"
HZDcodelist2HZDenumvalue["adindanCameroon"] = "7"
HZDcodelist2HZDenumvalue["adindanEthiopia"] = "2"
HZDcodelist2HZDenumvalue["adindanMali"] = "4"
HZDcodelist2HZDenumvalue["adindanMeanValue"] = "8"
HZDcodelist2HZDenumvalue["adindanSenegal"] = "5"
HZDcodelist2HZDenumvalue["adindanSudan"] = "3"
HZDcodelist2HZDenumvalue["afgooyeSomalia"] = "9"
HZDcodelist2HZDenumvalue["ainelAbd1970BahrainIsland"] = "12"
HZDcodelist2HZDenumvalue["ainelAbd1970SaudiArabia"] = "13"
HZDcodelist2HZDenumvalue["americanSamoaDatum1962"] = "14"
HZDcodelist2HZDenumvalue["amersfoort1885dash1903"] = "15"
HZDcodelist2HZDenumvalue["anna1Astro1965CocosIslands"] = "16"
HZDcodelist2HZDenumvalue["antiguaIslandAstro1943"] = "10"
HZDcodelist2HZDenumvalue["approximateLuzonDatum"] = "17"
HZDcodelist2HZDenumvalue["arc1935Africa"] = "32"
HZDcodelist2HZDenumvalue["arc1950Botswana"] = "19"
HZDcodelist2HZDenumvalue["arc1950Burundi"] = "26"
HZDcodelist2HZDenumvalue["arc1950Lesotho"] = "20"
HZDcodelist2HZDenumvalue["arc1950Malawi"] = "21"
HZDcodelist2HZDenumvalue["arc1950MeanValue"] = "27"
HZDcodelist2HZDenumvalue["arc1950Swaziland"] = "22"
HZDcodelist2HZDenumvalue["arc1950Zaire"] = "23"
HZDcodelist2HZDenumvalue["arc1950Zambia"] = "24"
HZDcodelist2HZDenumvalue["arc1950Zimbabwe"] = "25"
HZDcodelist2HZDenumvalue["arc1960Kenya"] = "29"
HZDcodelist2HZDenumvalue["arc1960MeanValue"] = "31"
HZDcodelist2HZDenumvalue["arc1960Tanzania"] = "30"
HZDcodelist2HZDenumvalue["ascensionIsland1958"] = "33"
HZDcodelist2HZDenumvalue["astroBeaconEIwoJimaIsland"] = "36"
HZDcodelist2HZDenumvalue["astroDos71dash4StHelena"] = "272"
HZDcodelist2HZDenumvalue["astroStation1952MarcusIs"] = "35"
HZDcodelist2HZDenumvalue["astroTernIsland1961Hawaii"] = "290"
HZDcodelist2HZDenumvalue["australianGeodetic1966"] = "38"
HZDcodelist2HZDenumvalue["australianGeodetic1984"] = "39"
HZDcodelist2HZDenumvalue["averageTerrestrialSys1977"] = "37"
HZDcodelist2HZDenumvalue["ayabelleLighthouseDjibouti"] = "225"
HZDcodelist2HZDenumvalue["bekaaBaseSouthEndLebanon"] = "42"
HZDcodelist2HZDenumvalue["belgium1950SystemLommelSig"] = "43"
HZDcodelist2HZDenumvalue["belgium1972Observatoire"] = "206"
HZDcodelist2HZDenumvalue["bellevueIgnEfateErromango"] = "115"
HZDcodelist2HZDenumvalue["bermuda1957BermudaIslands"] = "44"
HZDcodelist2HZDenumvalue["bern1898Switzerland"] = "50"
HZDcodelist2HZDenumvalue["bern1898ZeroMeridian"] = "51"
HZDcodelist2HZDenumvalue["bissauGuineaBissau"] = "45"
HZDcodelist2HZDenumvalue["bjz54A954BeijingCoord"] = "47"
HZDcodelist2HZDenumvalue["bogotaObservatoryColombia"] = "48"
HZDcodelist2HZDenumvalue["bogotaObsZeroMeridian"] = "49"
HZDcodelist2HZDenumvalue["bukitRimpahIndonesia"] = "52"
HZDcodelist2HZDenumvalue["camacupaBaseSwEndAngola"] = "55"
HZDcodelist2HZDenumvalue["campAreaAstroAntarctica"] = "58"
HZDcodelist2HZDenumvalue["campoInchauspeArgentina"] = "54"
HZDcodelist2HZDenumvalue["cantonAstro1966PhoenixIs"] = "56"
HZDcodelist2HZDenumvalue["capeCanaveralMeanValue"] = "53"
HZDcodelist2HZDenumvalue["capeSouthAfrica"] = "57"
HZDcodelist2HZDenumvalue["carthageTunisia"] = "60"
HZDcodelist2HZDenumvalue["chatham1971NewZealand"] = "62"
HZDcodelist2HZDenumvalue["chuaAstroParaguay"] = "63"
HZDcodelist2HZDenumvalue["compensationGeoQuebec1977"] = "61"
HZDcodelist2HZDenumvalue["conakryPyramidGuinea"] = "65"
HZDcodelist2HZDenumvalue["corregoAlegreBrazil"] = "64"
HZDcodelist2HZDenumvalue["dabolaGuinea"] = "67"
HZDcodelist2HZDenumvalue["dcs3LighthouseLesserAnt"] = "68"
HZDcodelist2HZDenumvalue["deceptionIslAntarctica"] = "69"
HZDcodelist2HZDenumvalue["djakartaBataviaIndonesia"] = "40"
HZDcodelist2HZDenumvalue["djakartaBataviaZeroMerid"] = "41"
HZDcodelist2HZDenumvalue["dominicaAstroM12LesserAnt"] = "71"
HZDcodelist2HZDenumvalue["dos1968GizoNewGeorgiaIs"] = "100"
HZDcodelist2HZDenumvalue["easterIsland1967EasterIs"] = "72"
HZDcodelist2HZDenumvalue["estonia1937"] = "305"
HZDcodelist2HZDenumvalue["etrs1989"] = "91"
HZDcodelist2HZDenumvalue["european1950BritishIsles"] = "85"
HZDcodelist2HZDenumvalue["european1950Cyprus"] = "79"
HZDcodelist2HZDenumvalue["european1950Egypt"] = "80"
HZDcodelist2HZDenumvalue["european1950England"] = "81"
HZDcodelist2HZDenumvalue["european1950Greece"] = "76"
HZDcodelist2HZDenumvalue["european1950Iran"] = "82"
HZDcodelist2HZDenumvalue["european1950IraqSyria"] = "88"
HZDcodelist2HZDenumvalue["european1950Malta"] = "86"
HZDcodelist2HZDenumvalue["european1950MeanValue"] = "87"
HZDcodelist2HZDenumvalue["european1950NorwayFinland"] = "77"
HZDcodelist2HZDenumvalue["european1950PortugalSpain"] = "78"
HZDcodelist2HZDenumvalue["european1950Sardinia"] = "83"
HZDcodelist2HZDenumvalue["european1950Sicily"] = "84"
HZDcodelist2HZDenumvalue["european1950Tunisia"] = "89"
HZDcodelist2HZDenumvalue["european1950WesternEurope"] = "75"
HZDcodelist2HZDenumvalue["european1979MeanValue"] = "90"
HZDcodelist2HZDenumvalue["fortThomas1955LeewardIs"] = "94"
HZDcodelist2HZDenumvalue["gan1970AdduAtoll"] = "95"
HZDcodelist2HZDenumvalue["gandajikaBaseZaire"] = "96"
HZDcodelist2HZDenumvalue["gdz80China"] = "98"
HZDcodelist2HZDenumvalue["geocentricDatumOfAustralia"] = "97"
HZDcodelist2HZDenumvalue["geodeticDatum1949Zealand"] = "99"
HZDcodelist2HZDenumvalue["graciosaBaseSWFaialAzores"] = "101"
HZDcodelist2HZDenumvalue["greekDatumGreece"] = "102"
HZDcodelist2HZDenumvalue["greekGeodeticRefSystem1987"] = "103"
HZDcodelist2HZDenumvalue["guam1963"] = "106"
HZDcodelist2HZDenumvalue["gunongSegaraKalimantanIs"] = "104"
HZDcodelist2HZDenumvalue["gunongSerindung"] = "105"
HZDcodelist2HZDenumvalue["gux1AstroGuadacanalIs"] = "70"
HZDcodelist2HZDenumvalue["guyanaCSG67"] = "66"
HZDcodelist2HZDenumvalue["heratNorthAfganistan"] = "107"
HZDcodelist2HZDenumvalue["hermannskogel"] = "108"
HZDcodelist2HZDenumvalue["hjorsey1955Iceland"] = "110"
HZDcodelist2HZDenumvalue["hongKong1929"] = "112"
HZDcodelist2HZDenumvalue["hongKong1963HongKong"] = "111"
HZDcodelist2HZDenumvalue["hungarian1972"] = "114"
HZDcodelist2HZDenumvalue["huTzuShan"] = "113"
HZDcodelist2HZDenumvalue["indian1954Thailand"] = "123"
HZDcodelist2HZDenumvalue["indian1960ConSonIsland"] = "126"
HZDcodelist2HZDenumvalue["indian1960Vietnam"] = "125"
HZDcodelist2HZDenumvalue["indian1975Thailand"] = "128"
HZDcodelist2HZDenumvalue["indian1975ThailandCycle1"] = "306"
HZDcodelist2HZDenumvalue["indianBangladesh"] = "119"
HZDcodelist2HZDenumvalue["indianIndiaNepal"] = "120"
HZDcodelist2HZDenumvalue["indianPakistan"] = "121"
HZDcodelist2HZDenumvalue["indianThailandVietnam"] = "118"
HZDcodelist2HZDenumvalue["indonesian1974"] = "116"
HZDcodelist2HZDenumvalue["ireland1965IrelandNorthern"] = "129"
HZDcodelist2HZDenumvalue["ists061Astro1968GeorgiaIs"] = "130"
HZDcodelist2HZDenumvalue["ists073Astro1969DiegoGar"] = "131"
HZDcodelist2HZDenumvalue["johnstonIsland1961"] = "132"
HZDcodelist2HZDenumvalue["kalianpurIndia"] = "133"
HZDcodelist2HZDenumvalue["kandawalaSriLanka"] = "134"
HZDcodelist2HZDenumvalue["kcs2SierraLeone"] = "136"
HZDcodelist2HZDenumvalue["kerguelenIsland1949"] = "137"
HZDcodelist2HZDenumvalue["kertau1948RevisedMalaysia"] = "135"
HZDcodelist2HZDenumvalue["kkjFinland"] = "139"
HZDcodelist2HZDenumvalue["koreanGeodeticSystem1995"] = "138"
HZDcodelist2HZDenumvalue["kusaieAstro1951"] = "140"
HZDcodelist2HZDenumvalue["kuwaitOilCompanyK28"] = "141"
HZDcodelist2HZDenumvalue["lc5Astro1961CaymanBracIs"] = "142"
HZDcodelist2HZDenumvalue["leigonGhana"] = "143"
HZDcodelist2HZDenumvalue["liberia1964Liberia"] = "144"
HZDcodelist2HZDenumvalue["lisbonCastelodiSaoJorge"] = "145"
HZDcodelist2HZDenumvalue["localAstro"] = "146"
HZDcodelist2HZDenumvalue["lomaQuintanaVenezuela"] = "147"
HZDcodelist2HZDenumvalue["luzonMindanaoIsland"] = "150"
HZDcodelist2HZDenumvalue["luzonPhilipinesNotMindanao"] = "149"
HZDcodelist2HZDenumvalue["mahe1971MaheIsland"] = "159"
HZDcodelist2HZDenumvalue["manokwariWestIrian"] = "154"
HZDcodelist2HZDenumvalue["marcoAstroSalvageIslands"] = "151"
HZDcodelist2HZDenumvalue["martiniqueFortDesaix"] = "152"
HZDcodelist2HZDenumvalue["massawEritreaEthiopia"] = "153"
HZDcodelist2HZDenumvalue["mayotteCombani"] = "155"
HZDcodelist2HZDenumvalue["merchichMorocco"] = "157"
HZDcodelist2HZDenumvalue["midwayAstro1961MidwayIs"] = "158"
HZDcodelist2HZDenumvalue["minnaCameroon"] = "161"
HZDcodelist2HZDenumvalue["minnaNigeria"] = "162"
HZDcodelist2HZDenumvalue["modifiedBJZ54China"] = "46"
HZDcodelist2HZDenumvalue["montjongLowe"] = "165"
HZDcodelist2HZDenumvalue["montserratIslandAstro1958"] = "34"
HZDcodelist2HZDenumvalue["mountDillonTobago"] = "156"
HZDcodelist2HZDenumvalue["mPoralokoGabon"] = "166"
HZDcodelist2HZDenumvalue["nahrwanMasirahIslandOman"] = "169"
HZDcodelist2HZDenumvalue["nahrwanSaudiArabia"] = "171"
HZDcodelist2HZDenumvalue["nahrwanUnitedArabEmirates"] = "170"
HZDcodelist2HZDenumvalue["naparimaBwiTrinidadTobago"] = "172"
HZDcodelist2HZDenumvalue["newFrenchZeroMeridianParis"] = "202"
HZDcodelist2HZDenumvalue["------"] = "-999999"
HZDcodelist2HZDenumvalue["noInformation"] = "-999999"
HZDcodelist2HZDenumvalue["No Information"] = "-999999"
HZDcodelist2HZDenumvalue["no information"] = "-999999"
HZDcodelist2HZDenumvalue["northAm1927Alaska"] = "184"
HZDcodelist2HZDenumvalue["northAm1927Alberta"] = "186"
HZDcodelist2HZDenumvalue["northAm1927AleutianE"] = "199"
HZDcodelist2HZDenumvalue["northAm1927AleutianW"] = "200"
HZDcodelist2HZDenumvalue["northAm1927Bahamas"] = "195"
HZDcodelist2HZDenumvalue["northAm1927CanadMean"] = "185"
HZDcodelist2HZDenumvalue["northAm1927CanalZone"] = "193"
HZDcodelist2HZDenumvalue["northAm1927Caribbean"] = "194"
HZDcodelist2HZDenumvalue["northAm1927CentAmer"] = "192"
HZDcodelist2HZDenumvalue["northAm1927ConusMean"] = "183"
HZDcodelist2HZDenumvalue["northAm1927Cuba"] = "197"
HZDcodelist2HZDenumvalue["northAm1927EasternUs"] = "181"
HZDcodelist2HZDenumvalue["northAm1927HayesPen"] = "198"
HZDcodelist2HZDenumvalue["northAm1927Manitoba"] = "188"
HZDcodelist2HZDenumvalue["northAm1927Mexico"] = "191"
HZDcodelist2HZDenumvalue["northAm1927Newfound"] = "187"
HZDcodelist2HZDenumvalue["northAm1927NwTerSaskat"] = "189"
HZDcodelist2HZDenumvalue["northAm1927Salvador"] = "196"
HZDcodelist2HZDenumvalue["northAm1927WesternUs"] = "182"
HZDcodelist2HZDenumvalue["northAm1927Yukon"] = "190"
HZDcodelist2HZDenumvalue["northAm1983AlaskaExAleut"] = "174"
HZDcodelist2HZDenumvalue["northAm1983Aleutian"] = "178"
HZDcodelist2HZDenumvalue["northAm1983Canada"] = "175"
HZDcodelist2HZDenumvalue["northAm1983Conus"] = "176"
HZDcodelist2HZDenumvalue["northAm1983Hawaii"] = "179"
HZDcodelist2HZDenumvalue["northAm1983Mexico"] = "177"
HZDcodelist2HZDenumvalue["northSahara1959"] = "204"
HZDcodelist2HZDenumvalue["observMeteorologico1939"] = "93"
HZDcodelist2HZDenumvalue["ocotopequeGuatemala"] = "205"
HZDcodelist2HZDenumvalue["oldEgyptian"] = "207"
HZDcodelist2HZDenumvalue["oldHawaiianHawaiiIsland"] = "215"
HZDcodelist2HZDenumvalue["oldHawaiianKauaiIsland"] = "216"
HZDcodelist2HZDenumvalue["oldHawaiianMauiIsland"] = "217"
HZDcodelist2HZDenumvalue["oldHawaiianMeanValue"] = "219"
HZDcodelist2HZDenumvalue["oldHawaiianOahuIsland"] = "218"
HZDcodelist2HZDenumvalue["oman"] = "92"
HZDcodelist2HZDenumvalue["ordnanceSurvGB1936England"] = "209"
HZDcodelist2HZDenumvalue["ordnanceSurvGB1936MeanVal"] = "213"
HZDcodelist2HZDenumvalue["ordnanceSurvGB1936ScotShet"] = "211"
HZDcodelist2HZDenumvalue["ordnanceSurvGB1936ScotWale"] = "210"
HZDcodelist2HZDenumvalue["ordnanceSurvGB1936Wales"] = "212"
HZDcodelist2HZDenumvalue["osloObservatoryOld"] = "220"
HZDcodelist2HZDenumvalue["other"] = "999"
HZDcodelist2HZDenumvalue["Other"] = "999"
HZDcodelist2HZDenumvalue["padangBaseWestEnd"] = "221"
HZDcodelist2HZDenumvalue["padangBaseWestEndZeroMerid"] = "222"
HZDcodelist2HZDenumvalue["palestine1928"] = "223"
HZDcodelist2HZDenumvalue["picoDeLasNievesCanaryIs"] = "227"
HZDcodelist2HZDenumvalue["pitcairnAstro1967"] = "226"
HZDcodelist2HZDenumvalue["point58MeanSolution"] = "239"
HZDcodelist2HZDenumvalue["pointeNoire1948"] = "240"
HZDcodelist2HZDenumvalue["potsdamHelmertturmGermany"] = "224"
HZDcodelist2HZDenumvalue["provSouthAm1956Bolivia"] = "230"
HZDcodelist2HZDenumvalue["provSouthAm1956Columbia"] = "233"
HZDcodelist2HZDenumvalue["provSouthAm1956Ecuador"] = "234"
HZDcodelist2HZDenumvalue["provSouthAm1956Guyana"] = "235"
HZDcodelist2HZDenumvalue["provSouthAm1956MeanValue"] = "238"
HZDcodelist2HZDenumvalue["provSouthAm1956NChile"] = "231"
HZDcodelist2HZDenumvalue["provSouthAm1956Peru"] = "236"
HZDcodelist2HZDenumvalue["provSouthAm1956SChile"] = "232"
HZDcodelist2HZDenumvalue["provSouthAm1956Venezuela"] = "237"
HZDcodelist2HZDenumvalue["provSouthChilean1963"] = "109"
HZDcodelist2HZDenumvalue["puertoRicoVirginIslands"] = "242"
HZDcodelist2HZDenumvalue["pulkovo1942Albania"] = "313"
HZDcodelist2HZDenumvalue["pulkovo1942Czechoslovakia"] = "310"
HZDcodelist2HZDenumvalue["pulkovo1942Hungary"] = "308"
HZDcodelist2HZDenumvalue["pulkovo1942Kazakhstan"] = "312"
HZDcodelist2HZDenumvalue["pulkovo1942Latvia"] = "311"
HZDcodelist2HZDenumvalue["pulkovo1942Poland"] = "309"
HZDcodelist2HZDenumvalue["pulkovo1942Romania"] = "314"
HZDcodelist2HZDenumvalue["pulkovo1942Russia"] = "241"
HZDcodelist2HZDenumvalue["qatarNationalQatar"] = "243"
HZDcodelist2HZDenumvalue["qornoqSouthGreenland"] = "244"
HZDcodelist2HZDenumvalue["rauenbergBerlinGermany"] = "245"
HZDcodelist2HZDenumvalue["reconTriangulationMorocco"] = "246"
HZDcodelist2HZDenumvalue["reunion1947"] = "247"
HZDcodelist2HZDenumvalue["revisedNahrwan"] = "201"
HZDcodelist2HZDenumvalue["rome1940"] = "163"
HZDcodelist2HZDenumvalue["rome1940ZeroMeridianRome"] = "164"
HZDcodelist2HZDenumvalue["rt90StockholmSweden"] = "248"
HZDcodelist2HZDenumvalue["sainteAnneI1984Guadeloupe"] = "251"
HZDcodelist2HZDenumvalue["santoDos1965EspiritoSanto"] = "249"
HZDcodelist2HZDenumvalue["saoBrazSaoMiguelAzores"] = "266"
HZDcodelist2HZDenumvalue["sapperHill1943EastFalkland"] = "267"
HZDcodelist2HZDenumvalue["schwarzeckNamibia"] = "268"
HZDcodelist2HZDenumvalue["seBasePortoSanto"] = "228"
HZDcodelist2HZDenumvalue["selvagemGrande1938Salvage"] = "271"
HZDcodelist2HZDenumvalue["sierraLeone1960"] = "273"
HZDcodelist2HZDenumvalue["sirgas"] = "307"
HZDcodelist2HZDenumvalue["sJtsk"] = "59"
HZDcodelist2HZDenumvalue["southAfricanSouthAfrica"] = "250"
HZDcodelist2HZDenumvalue["southAmerican1969Argentina"] = "253"
HZDcodelist2HZDenumvalue["southAmerican1969BaltraIs"] = "262"
HZDcodelist2HZDenumvalue["southAmerican1969Bolivia"] = "254"
HZDcodelist2HZDenumvalue["southAmerican1969Brazil"] = "255"
HZDcodelist2HZDenumvalue["southAmerican1969Chile"] = "256"
HZDcodelist2HZDenumvalue["southAmerican1969Columbia"] = "257"
HZDcodelist2HZDenumvalue["southAmerican1969Ecuador"] = "258"
HZDcodelist2HZDenumvalue["southAmerican1969Guyana"] = "259"
HZDcodelist2HZDenumvalue["southAmerican1969MeanValue"] = "265"
HZDcodelist2HZDenumvalue["southAmerican1969Paraguay"] = "260"
HZDcodelist2HZDenumvalue["southAmerican1969Peru"] = "261"
HZDcodelist2HZDenumvalue["southAmerican1969Trinidad"] = "263"
HZDcodelist2HZDenumvalue["southAmerican1969Venezuela"] = "264"
HZDcodelist2HZDenumvalue["southAsiaSingapore"] = "274"
HZDcodelist2HZDenumvalue["sovietGeodeticSystem1985"] = "269"
HZDcodelist2HZDenumvalue["sovietGeodeticSystem1990"] = "270"
HZDcodelist2HZDenumvalue["stockholm1938Sweden"] = "277"
HZDcodelist2HZDenumvalue["stPierreetMiquelon1950"] = "276"
HZDcodelist2HZDenumvalue["sydneyObservatoryNewSouth"] = "278"
HZDcodelist2HZDenumvalue["tananariveObs1925ZerMerPar"] = "280"
HZDcodelist2HZDenumvalue["tananariveObservatory1925"] = "279"
HZDcodelist2HZDenumvalue["timbalai1948BruneiMalaysia"] = "282"
HZDcodelist2HZDenumvalue["timbalai1968"] = "283"
HZDcodelist2HZDenumvalue["tokyoJapan"] = "285"
HZDcodelist2HZDenumvalue["tokyoKorea"] = "286"
HZDcodelist2HZDenumvalue["tokyoKoreaCycle1"] = "315"
HZDcodelist2HZDenumvalue["tokyoMeanValue"] = "288"
HZDcodelist2HZDenumvalue["tokyoOkinawa"] = "287"
HZDcodelist2HZDenumvalue["trinidad1903"] = "289"
HZDcodelist2HZDenumvalue["tristanAstro1968Cunha"] = "281"
HZDcodelist2HZDenumvalue["vitiLevu1916FijiIslands"] = "167"
HZDcodelist2HZDenumvalue["voirol1875"] = "292"
HZDcodelist2HZDenumvalue["voirol1875ZeroMeridParis"] = "293"
HZDcodelist2HZDenumvalue["voirol1960Algeria"] = "294"
HZDcodelist2HZDenumvalue["voirol1960ZeroMeridParis"] = "295"
HZDcodelist2HZDenumvalue["wakeEniwetok1960MarshallIs"] = "73"
HZDcodelist2HZDenumvalue["wakeIslandAstro1952"] = "296"
HZDcodelist2HZDenumvalue["worldGeodeticSystem1960"] = "297"
HZDcodelist2HZDenumvalue["worldGeodeticSystem1966"] = "298"
HZDcodelist2HZDenumvalue["worldGeodeticSystem1972"] = "299"
HZDcodelist2HZDenumvalue["worldGeodeticSystem1984"] = "300"
HZDcodelist2HZDenumvalue["yacareUruguay"] = "301"
HZDcodelist2HZDenumvalue["zanderijSurinam"] = "302"

VDTcodelist2VDTenumvalue = {}
VDTcodelist2VDTenumvalue["groundLevel"] = "6"
VDTcodelist2VDTenumvalue["meanSeaLevel"] = "3"
VDTcodelist2VDTenumvalue["navd88"] = "4"
VDTcodelist2VDTenumvalue["ngvd29"] = "5"
VDTcodelist2VDTenumvalue["------"] = "-999999"
VDTcodelist2VDTenumvalue["noInformation"] = "-999999"
VDTcodelist2VDTenumvalue["No Information"] = "-999999"
VDTcodelist2VDTenumvalue["no information"] = "-999999"
VDTcodelist2VDTenumvalue["other"] = "999"
VDTcodelist2VDTenumvalue["Other"] = "999"
VDTcodelist2VDTenumvalue["wgs84"] = "1"
VDTcodelist2VDTenumvalue["WGS 84 Ellipsoid"] = "1"     # This has been seen in data sets 12/16/16
VDTcodelist2VDTenumvalue["wgs 84 ellipsoid"] = "1"     # This has been seen in data sets 12/16/16
VDTcodelist2VDTenumvalue["wgs84Egm08"] = "7"
VDTcodelist2VDTenumvalue["wgs84Egm96"] = "2"

ZI001_SRTcodelist2ZI001_SRTenumvalue = {}
ZI001_SRTcodelist2ZI001_SRTenumvalue["commercial"] = "159"
ZI001_SRTcodelist2ZI001_SRTenumvalue["commercialData"] = "159"
ZI001_SRTcodelist2ZI001_SRTenumvalue["deLormeDigitalAtlasEarth"] = "166"
ZI001_SRTcodelist2ZI001_SRTenumvalue["gpsBasedFieldCollect"] = "26"
ZI001_SRTcodelist2ZI001_SRTenumvalue["ikonosImagery"] = "28"
ZI001_SRTcodelist2ZI001_SRTenumvalue["imageryUnspecified"] = "30"
ZI001_SRTcodelist2ZI001_SRTenumvalue["militaryMapData"] = "167"
ZI001_SRTcodelist2ZI001_SRTenumvalue["navteqData"] = "108"
ZI001_SRTcodelist2ZI001_SRTenumvalue["ngaAutoAirFacInfoFile"] = "2"
ZI001_SRTcodelist2ZI001_SRTenumvalue["ngaControlledImageBase1"] = "7"
ZI001_SRTcodelist2ZI001_SRTenumvalue["ngaDigitalAirFltInfoFile"] = "165"
ZI001_SRTcodelist2ZI001_SRTenumvalue["ngaDigitalNauticalChart"] = "10"
ZI001_SRTcodelist2ZI001_SRTenumvalue["ngaDigitalVertObstruction"] = "21"
ZI001_SRTcodelist2ZI001_SRTenumvalue["ngaFoundationFeatureData"] = "22"
ZI001_SRTcodelist2ZI001_SRTenumvalue["ngaGeoNames"] = "25"
ZI001_SRTcodelist2ZI001_SRTenumvalue["ngaInterimTerrainData"] = "31"
ZI001_SRTcodelist2ZI001_SRTenumvalue["ngaInterimVectorData"] = "32"
ZI001_SRTcodelist2ZI001_SRTenumvalue["ngaStereoAirfieldCollect"] = "170"
ZI001_SRTcodelist2ZI001_SRTenumvalue["ngaUrbanVectorMap"] = "60"
ZI001_SRTcodelist2ZI001_SRTenumvalue["ngaVectorInterimTerrain"] = "61"
ZI001_SRTcodelist2ZI001_SRTenumvalue["ngaVectorMap2"] = "64"
ZI001_SRTcodelist2ZI001_SRTenumvalue["------"] = "-999999"
ZI001_SRTcodelist2ZI001_SRTenumvalue["noInformation"] = "-999999"
ZI001_SRTcodelist2ZI001_SRTenumvalue["No Information"] = "-999999"
ZI001_SRTcodelist2ZI001_SRTenumvalue["no information"] = "-999999"
ZI001_SRTcodelist2ZI001_SRTenumvalue["nonMilitaryMap"] = "168"
ZI001_SRTcodelist2ZI001_SRTenumvalue["openSource"] = "160"
ZI001_SRTcodelist2ZI001_SRTenumvalue["openSourceInfo"] = "160"
ZI001_SRTcodelist2ZI001_SRTenumvalue["operationsData"] = "169"
ZI001_SRTcodelist2ZI001_SRTenumvalue["other"] = "999"
ZI001_SRTcodelist2ZI001_SRTenumvalue["Other"] = "999"
ZI001_SRTcodelist2ZI001_SRTenumvalue["quickBirdImagery"] = "9"
ZI001_SRTcodelist2ZI001_SRTenumvalue["tomTomData"] = "171"
ZI001_SRTcodelist2ZI001_SRTenumvalue["usModernizedIntegratedDB"] = "43"
ZI001_SRTcodelist2ZI001_SRTenumvalue["usNtmImagery"] = "29"

# These are not allowed in GGDM 3.0 but may have been used in previous datasets
ZI001_SRTcodelist2ZI001_SRTenumvalue["digitalGlobeImagery"] = "999"
ZI001_SRTcodelist2ZI001_SRTenumvalue["geoEye1"] = "999"
ZI001_SRTcodelist2ZI001_SRTenumvalue["landsatImagery"] = "999"
ZI001_SRTcodelist2ZI001_SRTenumvalue["orbimageImagery"] = "999"
# and include the all lower case versions
ZI001_SRTcodelist2ZI001_SRTenumvalue["digitalglobeimagery"] = "999"
ZI001_SRTcodelist2ZI001_SRTenumvalue["geoeye1"] = "999"
ZI001_SRTcodelist2ZI001_SRTenumvalue["landsatimagery"] = "999"
ZI001_SRTcodelist2ZI001_SRTenumvalue["orbimageimagery"] = "999"

ZI001_VSCcodelist2ZI001_VSCenumvalue = {}
ZI001_VSCcodelist2ZI001_VSCenumvalue["interpolatedDted1"] = "1"
ZI001_VSCcodelist2ZI001_VSCenumvalue["interpolatedDted2"] = "2"
ZI001_VSCcodelist2ZI001_VSCenumvalue["noElevations"] = "3"
ZI001_VSCcodelist2ZI001_VSCenumvalue["------"] = "-999999"
ZI001_VSCcodelist2ZI001_VSCenumvalue["noInformation"] = "-999999"
ZI001_VSCcodelist2ZI001_VSCenumvalue["No Information"] = "-999999"
ZI001_VSCcodelist2ZI001_VSCenumvalue["no information"] = "-999999"
ZI001_VSCcodelist2ZI001_VSCenumvalue["other"] = "999"
ZI001_VSCcodelist2ZI001_VSCenumvalue["Other"] = "999"
ZI001_VSCcodelist2ZI001_VSCenumvalue["reflectiveSurface"] = "4"
ZI001_VSCcodelist2ZI001_VSCenumvalue["stereoscopicImagery"] = "5"
ZI001_VSCcodelist2ZI001_VSCenumvalue["tinData"] = "6"


#codelist2enumvalue_mappings["ZI001_SSY2ZI001_SRT"] = "ZI001_SSYcodelist2ZI001_SRTenumvalue"
#codelist2enumvalue_mappings["ZI001_NSP2ZI001_SRT"] = "ZI001_NSPcodelist2ZI001_SRTenumvalue"

CPSenumvalue2CPScodelist = {}
CPSenumvalue2CPScodelist["4"] = "fixed0r25"
CPSenumvalue2CPScodelist["3"] = "fixed0r5"
CPSenumvalue2CPScodelist["2"] = "fixed1r0"
CPSenumvalue2CPScodelist["1"] = "fixed5r0"
CPSenumvalue2CPScodelist["-999999"] = "noInformation"
CPSenumvalue2CPScodelist["999"] = "other"
CPSenumvalue2CPScodelist["5"] = "variable"


ETSenumvalue2ETScodelist = {}
ETSenumvalue2ETScodelist["26"] = "atc"
ETSenumvalue2ETScodelist["17"] = "combat"
ETSenumvalue2ETScodelist["5"] = "dfad1"
ETSenumvalue2ETScodelist["7"] = "dfad2"
ETSenumvalue2ETScodelist["56"] = "digitalFeg"
ETSenumvalue2ETScodelist["43"] = "dnc"
ETSenumvalue2ETScodelist["4"] = "dted1"
ETSenumvalue2ETScodelist["6"] = "dted2"
ETSenumvalue2ETScodelist["21"] = "dtop"
ETSenumvalue2ETScodelist["31"] = "ffd"
ETSenumvalue2ETScodelist["57"] = "globalTdsEg"
ETSenumvalue2ETScodelist["8"] = "hac1"
ETSenumvalue2ETScodelist["9"] = "hac2"
ETSenumvalue2ETScodelist["10"] = "hac3"
ETSenumvalue2ETScodelist["11"] = "hac4"
ETSenumvalue2ETScodelist["12"] = "hac5"
ETSenumvalue2ETScodelist["13"] = "hac6"
ETSenumvalue2ETScodelist["14"] = "hac7"
ETSenumvalue2ETScodelist["15"] = "hac8"
ETSenumvalue2ETScodelist["16"] = "hac9"
ETSenumvalue2ETScodelist["3"] = "jogAirGround"
ETSenumvalue2ETScodelist["27"] = "jogRadar"
ETSenumvalue2ETScodelist["59"] = "localTdsEg"
ETSenumvalue2ETScodelist["61"] = "mgcpTrd"
ETSenumvalue2ETScodelist["44"] = "msd1"
ETSenumvalue2ETScodelist["45"] = "msd2"
ETSenumvalue2ETScodelist["46"] = "msd3"
ETSenumvalue2ETScodelist["47"] = "msd4"
ETSenumvalue2ETScodelist["48"] = "msd5"
ETSenumvalue2ETScodelist["-999999"] = "noInformation"
ETSenumvalue2ETScodelist["2"] = "onc"
ETSenumvalue2ETScodelist["998"] = "notApplicable"
ETSenumvalue2ETScodelist["999"] = "other"
ETSenumvalue2ETScodelist["58"] = "regionalTdsEg"
ETSenumvalue2ETScodelist["60"] = "specUrbanTdsEg"
ETSenumvalue2ETScodelist["29"] = "tercomE"
ETSenumvalue2ETScodelist["28"] = "tercomL"
ETSenumvalue2ETScodelist["30"] = "tercomT"
ETSenumvalue2ETScodelist["19"] = "tlm100"
ETSenumvalue2ETScodelist["18"] = "tlm50"
ETSenumvalue2ETScodelist["49"] = "tod0"
ETSenumvalue2ETScodelist["50"] = "tod1"
ETSenumvalue2ETScodelist["51"] = "tod2"
ETSenumvalue2ETScodelist["52"] = "tod3"
ETSenumvalue2ETScodelist["53"] = "tod4"
ETSenumvalue2ETScodelist["1"] = "tpc"
ETSenumvalue2ETScodelist["25"] = "uvmap"
ETSenumvalue2ETScodelist["20"] = "vitd"
ETSenumvalue2ETScodelist["23"] = "vmap0"
ETSenumvalue2ETScodelist["24"] = "vmap1"
ETSenumvalue2ETScodelist["22"] = "vmap2"

HZDenumvalue2HZDcodelist = {}
HZDenumvalue2HZDcodelist["6"] = "adindanBurkinaFaso"
HZDenumvalue2HZDcodelist["7"] = "adindanCameroon"
HZDenumvalue2HZDcodelist["2"] = "adindanEthiopia"
HZDenumvalue2HZDcodelist["4"] = "adindanMali"
HZDenumvalue2HZDcodelist["8"] = "adindanMeanValue"
HZDenumvalue2HZDcodelist["5"] = "adindanSenegal"
HZDenumvalue2HZDcodelist["3"] = "adindanSudan"
HZDenumvalue2HZDcodelist["9"] = "afgooyeSomalia"
HZDenumvalue2HZDcodelist["12"] = "ainelAbd1970BahrainIsland"
HZDenumvalue2HZDcodelist["13"] = "ainelAbd1970SaudiArabia"
HZDenumvalue2HZDcodelist["14"] = "americanSamoaDatum1962"
HZDenumvalue2HZDcodelist["15"] = "amersfoort1885dash1903"
HZDenumvalue2HZDcodelist["16"] = "anna1Astro1965CocosIslands"
HZDenumvalue2HZDcodelist["10"] = "antiguaIslandAstro1943"
HZDenumvalue2HZDcodelist["17"] = "approximateLuzonDatum"
HZDenumvalue2HZDcodelist["32"] = "arc1935Africa"
HZDenumvalue2HZDcodelist["19"] = "arc1950Botswana"
HZDenumvalue2HZDcodelist["26"] = "arc1950Burundi"
HZDenumvalue2HZDcodelist["20"] = "arc1950Lesotho"
HZDenumvalue2HZDcodelist["21"] = "arc1950Malawi"
HZDenumvalue2HZDcodelist["27"] = "arc1950MeanValue"
HZDenumvalue2HZDcodelist["22"] = "arc1950Swaziland"
HZDenumvalue2HZDcodelist["23"] = "arc1950Zaire"
HZDenumvalue2HZDcodelist["24"] = "arc1950Zambia"
HZDenumvalue2HZDcodelist["25"] = "arc1950Zimbabwe"
HZDenumvalue2HZDcodelist["29"] = "arc1960Kenya"
HZDenumvalue2HZDcodelist["31"] = "arc1960MeanValue"
HZDenumvalue2HZDcodelist["30"] = "arc1960Tanzania"
HZDenumvalue2HZDcodelist["33"] = "ascensionIsland1958"
HZDenumvalue2HZDcodelist["36"] = "astroBeaconEIwoJimaIsland"
HZDenumvalue2HZDcodelist["272"] = "astroDos71dash4StHelena"
HZDenumvalue2HZDcodelist["35"] = "astroStation1952MarcusIs"
HZDenumvalue2HZDcodelist["290"] = "astroTernIsland1961Hawaii"
HZDenumvalue2HZDcodelist["38"] = "australianGeodetic1966"
HZDenumvalue2HZDcodelist["39"] = "australianGeodetic1984"
HZDenumvalue2HZDcodelist["37"] = "averageTerrestrialSys1977"
HZDenumvalue2HZDcodelist["225"] = "ayabelleLighthouseDjibouti"
HZDenumvalue2HZDcodelist["42"] = "bekaaBaseSouthEndLebanon"
HZDenumvalue2HZDcodelist["43"] = "belgium1950SystemLommelSig"
HZDenumvalue2HZDcodelist["206"] = "belgium1972Observatoire"
HZDenumvalue2HZDcodelist["115"] = "bellevueIgnEfateErromango"
HZDenumvalue2HZDcodelist["44"] = "bermuda1957BermudaIslands"
HZDenumvalue2HZDcodelist["50"] = "bern1898Switzerland"
HZDenumvalue2HZDcodelist["51"] = "bern1898ZeroMeridian"
HZDenumvalue2HZDcodelist["45"] = "bissauGuineaBissau"
HZDenumvalue2HZDcodelist["47"] = "bjz54A954BeijingCoord"
HZDenumvalue2HZDcodelist["48"] = "bogotaObservatoryColombia"
HZDenumvalue2HZDcodelist["49"] = "bogotaObsZeroMeridian"
HZDenumvalue2HZDcodelist["52"] = "bukitRimpahIndonesia"
HZDenumvalue2HZDcodelist["55"] = "camacupaBaseSwEndAngola"
HZDenumvalue2HZDcodelist["58"] = "campAreaAstroAntarctica"
HZDenumvalue2HZDcodelist["54"] = "campoInchauspeArgentina"
HZDenumvalue2HZDcodelist["56"] = "cantonAstro1966PhoenixIs"
HZDenumvalue2HZDcodelist["53"] = "capeCanaveralMeanValue"
HZDenumvalue2HZDcodelist["57"] = "capeSouthAfrica"
HZDenumvalue2HZDcodelist["60"] = "carthageTunisia"
HZDenumvalue2HZDcodelist["62"] = "chatham1971NewZealand"
HZDenumvalue2HZDcodelist["63"] = "chuaAstroParaguay"
HZDenumvalue2HZDcodelist["61"] = "compensationGeoQuebec1977"
HZDenumvalue2HZDcodelist["65"] = "conakryPyramidGuinea"
HZDenumvalue2HZDcodelist["64"] = "corregoAlegreBrazil"
HZDenumvalue2HZDcodelist["67"] = "dabolaGuinea"
HZDenumvalue2HZDcodelist["68"] = "dcs3LighthouseLesserAnt"
HZDenumvalue2HZDcodelist["69"] = "deceptionIslAntarctica"
HZDenumvalue2HZDcodelist["40"] = "djakartaBataviaIndonesia"
HZDenumvalue2HZDcodelist["41"] = "djakartaBataviaZeroMerid"
HZDenumvalue2HZDcodelist["71"] = "dominicaAstroM12LesserAnt"
HZDenumvalue2HZDcodelist["100"] = "dos1968GizoNewGeorgiaIs"
HZDenumvalue2HZDcodelist["72"] = "easterIsland1967EasterIs"
HZDenumvalue2HZDcodelist["305"] = "estonia1937"
HZDenumvalue2HZDcodelist["91"] = "etrs1989"
HZDenumvalue2HZDcodelist["85"] = "european1950BritishIsles"
HZDenumvalue2HZDcodelist["79"] = "european1950Cyprus"
HZDenumvalue2HZDcodelist["80"] = "european1950Egypt"
HZDenumvalue2HZDcodelist["81"] = "european1950England"
HZDenumvalue2HZDcodelist["76"] = "european1950Greece"
HZDenumvalue2HZDcodelist["82"] = "european1950Iran"
HZDenumvalue2HZDcodelist["88"] = "european1950IraqSyria"
HZDenumvalue2HZDcodelist["86"] = "european1950Malta"
HZDenumvalue2HZDcodelist["87"] = "european1950MeanValue"
HZDenumvalue2HZDcodelist["77"] = "european1950NorwayFinland"
HZDenumvalue2HZDcodelist["78"] = "european1950PortugalSpain"
HZDenumvalue2HZDcodelist["83"] = "european1950Sardinia"
HZDenumvalue2HZDcodelist["84"] = "european1950Sicily"
HZDenumvalue2HZDcodelist["89"] = "european1950Tunisia"
HZDenumvalue2HZDcodelist["75"] = "european1950WesternEurope"
HZDenumvalue2HZDcodelist["90"] = "european1979MeanValue"
HZDenumvalue2HZDcodelist["94"] = "fortThomas1955LeewardIs"
HZDenumvalue2HZDcodelist["95"] = "gan1970AdduAtoll"
HZDenumvalue2HZDcodelist["96"] = "gandajikaBaseZaire"
HZDenumvalue2HZDcodelist["98"] = "gdz80China"
HZDenumvalue2HZDcodelist["97"] = "geocentricDatumOfAustralia"
HZDenumvalue2HZDcodelist["99"] = "geodeticDatum1949Zealand"
HZDenumvalue2HZDcodelist["101"] = "graciosaBaseSWFaialAzores"
HZDenumvalue2HZDcodelist["102"] = "greekDatumGreece"
HZDenumvalue2HZDcodelist["103"] = "greekGeodeticRefSystem1987"
HZDenumvalue2HZDcodelist["106"] = "guam1963"
HZDenumvalue2HZDcodelist["104"] = "gunongSegaraKalimantanIs"
HZDenumvalue2HZDcodelist["105"] = "gunongSerindung"
HZDenumvalue2HZDcodelist["70"] = "gux1AstroGuadacanalIs"
HZDenumvalue2HZDcodelist["66"] = "guyanaCSG67"
HZDenumvalue2HZDcodelist["107"] = "heratNorthAfganistan"
HZDenumvalue2HZDcodelist["108"] = "hermannskogel"
HZDenumvalue2HZDcodelist["110"] = "hjorsey1955Iceland"
HZDenumvalue2HZDcodelist["112"] = "hongKong1929"
HZDenumvalue2HZDcodelist["111"] = "hongKong1963HongKong"
HZDenumvalue2HZDcodelist["114"] = "hungarian1972"
HZDenumvalue2HZDcodelist["113"] = "huTzuShan"
HZDenumvalue2HZDcodelist["123"] = "indian1954Thailand"
HZDenumvalue2HZDcodelist["126"] = "indian1960ConSonIsland"
HZDenumvalue2HZDcodelist["125"] = "indian1960Vietnam"
HZDenumvalue2HZDcodelist["128"] = "indian1975Thailand"
HZDenumvalue2HZDcodelist["306"] = "indian1975ThailandCycle1"
HZDenumvalue2HZDcodelist["119"] = "indianBangladesh"
HZDenumvalue2HZDcodelist["120"] = "indianIndiaNepal"
HZDenumvalue2HZDcodelist["121"] = "indianPakistan"
HZDenumvalue2HZDcodelist["118"] = "indianThailandVietnam"
HZDenumvalue2HZDcodelist["116"] = "indonesian1974"
HZDenumvalue2HZDcodelist["129"] = "ireland1965IrelandNorthern"
HZDenumvalue2HZDcodelist["130"] = "ists061Astro1968GeorgiaIs"
HZDenumvalue2HZDcodelist["131"] = "ists073Astro1969DiegoGar"
HZDenumvalue2HZDcodelist["132"] = "johnstonIsland1961"
HZDenumvalue2HZDcodelist["133"] = "kalianpurIndia"
HZDenumvalue2HZDcodelist["134"] = "kandawalaSriLanka"
HZDenumvalue2HZDcodelist["136"] = "kcs2SierraLeone"
HZDenumvalue2HZDcodelist["137"] = "kerguelenIsland1949"
HZDenumvalue2HZDcodelist["135"] = "kertau1948RevisedMalaysia"
HZDenumvalue2HZDcodelist["139"] = "kkjFinland"
HZDenumvalue2HZDcodelist["138"] = "koreanGeodeticSystem1995"
HZDenumvalue2HZDcodelist["140"] = "kusaieAstro1951"
HZDenumvalue2HZDcodelist["141"] = "kuwaitOilCompanyK28"
HZDenumvalue2HZDcodelist["142"] = "lc5Astro1961CaymanBracIs"
HZDenumvalue2HZDcodelist["143"] = "leigonGhana"
HZDenumvalue2HZDcodelist["144"] = "liberia1964Liberia"
HZDenumvalue2HZDcodelist["145"] = "lisbonCastelodiSaoJorge"
HZDenumvalue2HZDcodelist["146"] = "localAstro"
HZDenumvalue2HZDcodelist["147"] = "lomaQuintanaVenezuela"
HZDenumvalue2HZDcodelist["150"] = "luzonMindanaoIsland"
HZDenumvalue2HZDcodelist["149"] = "luzonPhilipinesNotMindanao"
HZDenumvalue2HZDcodelist["159"] = "mahe1971MaheIsland"
HZDenumvalue2HZDcodelist["154"] = "manokwariWestIrian"
HZDenumvalue2HZDcodelist["151"] = "marcoAstroSalvageIslands"
HZDenumvalue2HZDcodelist["152"] = "martiniqueFortDesaix"
HZDenumvalue2HZDcodelist["153"] = "massawEritreaEthiopia"
HZDenumvalue2HZDcodelist["155"] = "mayotteCombani"
HZDenumvalue2HZDcodelist["157"] = "merchichMorocco"
HZDenumvalue2HZDcodelist["158"] = "midwayAstro1961MidwayIs"
HZDenumvalue2HZDcodelist["161"] = "minnaCameroon"
HZDenumvalue2HZDcodelist["162"] = "minnaNigeria"
HZDenumvalue2HZDcodelist["46"] = "modifiedBJZ54China"
HZDenumvalue2HZDcodelist["165"] = "montjongLowe"
HZDenumvalue2HZDcodelist["34"] = "montserratIslandAstro1958"
HZDenumvalue2HZDcodelist["156"] = "mountDillonTobago"
HZDenumvalue2HZDcodelist["166"] = "mPoralokoGabon"
HZDenumvalue2HZDcodelist["169"] = "nahrwanMasirahIslandOman"
HZDenumvalue2HZDcodelist["171"] = "nahrwanSaudiArabia"
HZDenumvalue2HZDcodelist["170"] = "nahrwanUnitedArabEmirates"
HZDenumvalue2HZDcodelist["172"] = "naparimaBwiTrinidadTobago"
HZDenumvalue2HZDcodelist["202"] = "newFrenchZeroMeridianParis"
HZDenumvalue2HZDcodelist["-999999"] = "noInformation"
HZDenumvalue2HZDcodelist["184"] = "northAm1927Alaska"
HZDenumvalue2HZDcodelist["186"] = "northAm1927Alberta"
HZDenumvalue2HZDcodelist["199"] = "northAm1927AleutianE"
HZDenumvalue2HZDcodelist["200"] = "northAm1927AleutianW"
HZDenumvalue2HZDcodelist["195"] = "northAm1927Bahamas"
HZDenumvalue2HZDcodelist["185"] = "northAm1927CanadMean"
HZDenumvalue2HZDcodelist["193"] = "northAm1927CanalZone"
HZDenumvalue2HZDcodelist["194"] = "northAm1927Caribbean"
HZDenumvalue2HZDcodelist["192"] = "northAm1927CentAmer"
HZDenumvalue2HZDcodelist["183"] = "northAm1927ConusMean"
HZDenumvalue2HZDcodelist["197"] = "northAm1927Cuba"
HZDenumvalue2HZDcodelist["181"] = "northAm1927EasternUs"
HZDenumvalue2HZDcodelist["198"] = "northAm1927HayesPen"
HZDenumvalue2HZDcodelist["188"] = "northAm1927Manitoba"
HZDenumvalue2HZDcodelist["191"] = "northAm1927Mexico"
HZDenumvalue2HZDcodelist["187"] = "northAm1927Newfound"
HZDenumvalue2HZDcodelist["189"] = "northAm1927NwTerSaskat"
HZDenumvalue2HZDcodelist["196"] = "northAm1927Salvador"
HZDenumvalue2HZDcodelist["182"] = "northAm1927WesternUs"
HZDenumvalue2HZDcodelist["190"] = "northAm1927Yukon"
HZDenumvalue2HZDcodelist["174"] = "northAm1983AlaskaExAleut"
HZDenumvalue2HZDcodelist["178"] = "northAm1983Aleutian"
HZDenumvalue2HZDcodelist["175"] = "northAm1983Canada"
HZDenumvalue2HZDcodelist["176"] = "northAm1983Conus"
HZDenumvalue2HZDcodelist["179"] = "northAm1983Hawaii"
HZDenumvalue2HZDcodelist["177"] = "northAm1983Mexico"
HZDenumvalue2HZDcodelist["204"] = "northSahara1959"
HZDenumvalue2HZDcodelist["93"] = "observMeteorologico1939"
HZDenumvalue2HZDcodelist["205"] = "ocotopequeGuatemala"
HZDenumvalue2HZDcodelist["207"] = "oldEgyptian"
HZDenumvalue2HZDcodelist["215"] = "oldHawaiianHawaiiIsland"
HZDenumvalue2HZDcodelist["216"] = "oldHawaiianKauaiIsland"
HZDenumvalue2HZDcodelist["217"] = "oldHawaiianMauiIsland"
HZDenumvalue2HZDcodelist["219"] = "oldHawaiianMeanValue"
HZDenumvalue2HZDcodelist["218"] = "oldHawaiianOahuIsland"
HZDenumvalue2HZDcodelist["92"] = "oman"
HZDenumvalue2HZDcodelist["209"] = "ordnanceSurvGB1936England"
HZDenumvalue2HZDcodelist["213"] = "ordnanceSurvGB1936MeanVal"
HZDenumvalue2HZDcodelist["211"] = "ordnanceSurvGB1936ScotShet"
HZDenumvalue2HZDcodelist["210"] = "ordnanceSurvGB1936ScotWale"
HZDenumvalue2HZDcodelist["212"] = "ordnanceSurvGB1936Wales"
HZDenumvalue2HZDcodelist["220"] = "osloObservatoryOld"
HZDenumvalue2HZDcodelist["999"] = "other"
HZDenumvalue2HZDcodelist["221"] = "padangBaseWestEnd"
HZDenumvalue2HZDcodelist["222"] = "padangBaseWestEndZeroMerid"
HZDenumvalue2HZDcodelist["223"] = "palestine1928"
HZDenumvalue2HZDcodelist["227"] = "picoDeLasNievesCanaryIs"
HZDenumvalue2HZDcodelist["226"] = "pitcairnAstro1967"
HZDenumvalue2HZDcodelist["239"] = "point58MeanSolution"
HZDenumvalue2HZDcodelist["240"] = "pointeNoire1948"
HZDenumvalue2HZDcodelist["224"] = "potsdamHelmertturmGermany"
HZDenumvalue2HZDcodelist["230"] = "provSouthAm1956Bolivia"
HZDenumvalue2HZDcodelist["233"] = "provSouthAm1956Columbia"
HZDenumvalue2HZDcodelist["234"] = "provSouthAm1956Ecuador"
HZDenumvalue2HZDcodelist["235"] = "provSouthAm1956Guyana"
HZDenumvalue2HZDcodelist["238"] = "provSouthAm1956MeanValue"
HZDenumvalue2HZDcodelist["231"] = "provSouthAm1956NChile"
HZDenumvalue2HZDcodelist["236"] = "provSouthAm1956Peru"
HZDenumvalue2HZDcodelist["232"] = "provSouthAm1956SChile"
HZDenumvalue2HZDcodelist["237"] = "provSouthAm1956Venezuela"
HZDenumvalue2HZDcodelist["109"] = "provSouthChilean1963"
HZDenumvalue2HZDcodelist["242"] = "puertoRicoVirginIslands"
HZDenumvalue2HZDcodelist["313"] = "pulkovo1942Albania"
HZDenumvalue2HZDcodelist["310"] = "pulkovo1942Czechoslovakia"
HZDenumvalue2HZDcodelist["308"] = "pulkovo1942Hungary"
HZDenumvalue2HZDcodelist["312"] = "pulkovo1942Kazakhstan"
HZDenumvalue2HZDcodelist["311"] = "pulkovo1942Latvia"
HZDenumvalue2HZDcodelist["309"] = "pulkovo1942Poland"
HZDenumvalue2HZDcodelist["314"] = "pulkovo1942Romania"
HZDenumvalue2HZDcodelist["241"] = "pulkovo1942Russia"
HZDenumvalue2HZDcodelist["243"] = "qatarNationalQatar"
HZDenumvalue2HZDcodelist["244"] = "qornoqSouthGreenland"
HZDenumvalue2HZDcodelist["245"] = "rauenbergBerlinGermany"
HZDenumvalue2HZDcodelist["246"] = "reconTriangulationMorocco"
HZDenumvalue2HZDcodelist["247"] = "reunion1947"
HZDenumvalue2HZDcodelist["201"] = "revisedNahrwan"
HZDenumvalue2HZDcodelist["163"] = "rome1940"
HZDenumvalue2HZDcodelist["164"] = "rome1940ZeroMeridianRome"
HZDenumvalue2HZDcodelist["248"] = "rt90StockholmSweden"
HZDenumvalue2HZDcodelist["251"] = "sainteAnneI1984Guadeloupe"
HZDenumvalue2HZDcodelist["249"] = "santoDos1965EspiritoSanto"
HZDenumvalue2HZDcodelist["266"] = "saoBrazSaoMiguelAzores"
HZDenumvalue2HZDcodelist["267"] = "sapperHill1943EastFalkland"
HZDenumvalue2HZDcodelist["268"] = "schwarzeckNamibia"
HZDenumvalue2HZDcodelist["228"] = "seBasePortoSanto"
HZDenumvalue2HZDcodelist["271"] = "selvagemGrande1938Salvage"
HZDenumvalue2HZDcodelist["273"] = "sierraLeone1960"
HZDenumvalue2HZDcodelist["307"] = "sirgas"
HZDenumvalue2HZDcodelist["59"] = "sJtsk"
HZDenumvalue2HZDcodelist["250"] = "southAfricanSouthAfrica"
HZDenumvalue2HZDcodelist["253"] = "southAmerican1969Argentina"
HZDenumvalue2HZDcodelist["262"] = "southAmerican1969BaltraIs"
HZDenumvalue2HZDcodelist["254"] = "southAmerican1969Bolivia"
HZDenumvalue2HZDcodelist["255"] = "southAmerican1969Brazil"
HZDenumvalue2HZDcodelist["256"] = "southAmerican1969Chile"
HZDenumvalue2HZDcodelist["257"] = "southAmerican1969Columbia"
HZDenumvalue2HZDcodelist["258"] = "southAmerican1969Ecuador"
HZDenumvalue2HZDcodelist["259"] = "southAmerican1969Guyana"
HZDenumvalue2HZDcodelist["265"] = "southAmerican1969MeanValue"
HZDenumvalue2HZDcodelist["260"] = "southAmerican1969Paraguay"
HZDenumvalue2HZDcodelist["261"] = "southAmerican1969Peru"
HZDenumvalue2HZDcodelist["263"] = "southAmerican1969Trinidad"
HZDenumvalue2HZDcodelist["264"] = "southAmerican1969Venezuela"
HZDenumvalue2HZDcodelist["274"] = "southAsiaSingapore"
HZDenumvalue2HZDcodelist["269"] = "sovietGeodeticSystem1985"
HZDenumvalue2HZDcodelist["270"] = "sovietGeodeticSystem1990"
HZDenumvalue2HZDcodelist["277"] = "stockholm1938Sweden"
HZDenumvalue2HZDcodelist["276"] = "stPierreetMiquelon1950"
HZDenumvalue2HZDcodelist["278"] = "sydneyObservatoryNewSouth"
HZDenumvalue2HZDcodelist["280"] = "tananariveObs1925ZerMerPar"
HZDenumvalue2HZDcodelist["279"] = "tananariveObservatory1925"
HZDenumvalue2HZDcodelist["282"] = "timbalai1948BruneiMalaysia"
HZDenumvalue2HZDcodelist["283"] = "timbalai1968"
HZDenumvalue2HZDcodelist["285"] = "tokyoJapan"
HZDenumvalue2HZDcodelist["286"] = "tokyoKorea"
HZDenumvalue2HZDcodelist["315"] = "tokyoKoreaCycle1"
HZDenumvalue2HZDcodelist["288"] = "tokyoMeanValue"
HZDenumvalue2HZDcodelist["287"] = "tokyoOkinawa"
HZDenumvalue2HZDcodelist["289"] = "trinidad1903"
HZDenumvalue2HZDcodelist["281"] = "tristanAstro1968Cunha"
HZDenumvalue2HZDcodelist["167"] = "vitiLevu1916FijiIslands"
HZDenumvalue2HZDcodelist["292"] = "voirol1875"
HZDenumvalue2HZDcodelist["293"] = "voirol1875ZeroMeridParis"
HZDenumvalue2HZDcodelist["294"] = "voirol1960Algeria"
HZDenumvalue2HZDcodelist["295"] = "voirol1960ZeroMeridParis"
HZDenumvalue2HZDcodelist["73"] = "wakeEniwetok1960MarshallIs"
HZDenumvalue2HZDcodelist["296"] = "wakeIslandAstro1952"
HZDenumvalue2HZDcodelist["297"] = "worldGeodeticSystem1960"
HZDenumvalue2HZDcodelist["298"] = "worldGeodeticSystem1966"
HZDenumvalue2HZDcodelist["299"] = "worldGeodeticSystem1972"
HZDenumvalue2HZDcodelist["300"] = "worldGeodeticSystem1984"
HZDenumvalue2HZDcodelist["301"] = "yacareUruguay"
HZDenumvalue2HZDcodelist["302"] = "zanderijSurinam"
HZDenumvalue2HZDcodelist["998"] = "notApplicable"
HZDenumvalue2HZDcodelist[998] = "notApplicable"

VDTenumvalue2VDTcodelist = {}
VDTenumvalue2VDTcodelist["6"] = "groundLevel"
VDTenumvalue2VDTcodelist["3"] = "meanSeaLevel"
VDTenumvalue2VDTcodelist["4"] = "navd88"
VDTenumvalue2VDTcodelist["5"] = "ngvd29"
VDTenumvalue2VDTcodelist["-999999"] = "noInformation"
VDTenumvalue2VDTcodelist["999"] = "other"
VDTenumvalue2VDTcodelist["998"] = "notApplicable"
VDTenumvalue2VDTcodelist[998] = "notApplicable"
VDTenumvalue2VDTcodelist["1"] = "wgs84"
VDTenumvalue2VDTcodelist["7"] = "wgs84Egm08"
VDTenumvalue2VDTcodelist["2"] = "wgs84Egm96"

ZI001_SRTenumvalue2ZI001_SRTcodelist = {}
ZI001_SRTenumvalue2ZI001_SRTcodelist["159"] = "commercial"
ZI001_SRTenumvalue2ZI001_SRTcodelist["166"] = "deLormeDigitalAtlasEarth"
ZI001_SRTenumvalue2ZI001_SRTcodelist["26"] = "gpsBasedFieldCollect"
ZI001_SRTenumvalue2ZI001_SRTcodelist["28"] = "ikonosImagery"
ZI001_SRTenumvalue2ZI001_SRTcodelist["30"] = "imageryUnspecified"
ZI001_SRTenumvalue2ZI001_SRTcodelist["167"] = "militaryMapData"
ZI001_SRTenumvalue2ZI001_SRTcodelist["108"] = "navteqData"
ZI001_SRTenumvalue2ZI001_SRTcodelist["2"] = "ngaAutoAirFacInfoFile"
ZI001_SRTenumvalue2ZI001_SRTcodelist["7"] = "ngaControlledImageBase1"
ZI001_SRTenumvalue2ZI001_SRTcodelist["165"] = "ngaDigitalAirFltInfoFile"
ZI001_SRTenumvalue2ZI001_SRTcodelist["10"] = "ngaDigitalNauticalChart"
ZI001_SRTenumvalue2ZI001_SRTcodelist["21"] = "ngaDigitalVertObstruction"
ZI001_SRTenumvalue2ZI001_SRTcodelist["22"] = "ngaFoundationFeatureData"
ZI001_SRTenumvalue2ZI001_SRTcodelist["25"] = "ngaGeoNames"
ZI001_SRTenumvalue2ZI001_SRTcodelist["31"] = "ngaInterimTerrainData"
ZI001_SRTenumvalue2ZI001_SRTcodelist["32"] = "ngaInterimVectorData"
ZI001_SRTenumvalue2ZI001_SRTcodelist["170"] = "ngaStereoAirfieldCollect"
ZI001_SRTenumvalue2ZI001_SRTcodelist["60"] = "ngaUrbanVectorMap"
ZI001_SRTenumvalue2ZI001_SRTcodelist["61"] = "ngaVectorInterimTerrain"
ZI001_SRTenumvalue2ZI001_SRTcodelist["64"] = "ngaVectorMap2"
ZI001_SRTenumvalue2ZI001_SRTcodelist["-999999"] = "noInformation"
ZI001_SRTenumvalue2ZI001_SRTcodelist["168"] = "nonMilitaryMap"
ZI001_SRTenumvalue2ZI001_SRTcodelist["160"] = "openSource"
ZI001_SRTenumvalue2ZI001_SRTcodelist["169"] = "operationsData"
ZI001_SRTenumvalue2ZI001_SRTcodelist["999"] = "other"
ZI001_SRTenumvalue2ZI001_SRTcodelist["9"] = "quickBirdImagery"
ZI001_SRTenumvalue2ZI001_SRTcodelist["171"] = "tomTomData"
ZI001_SRTenumvalue2ZI001_SRTcodelist["43"] = "usModernizedIntegratedDB"
ZI001_SRTenumvalue2ZI001_SRTcodelist["29"] = "usNtmImagery"

ZI001_VSCenumvalue2ZI001_VSCcodelist = {}
ZI001_VSCenumvalue2ZI001_VSCcodelist["1"] = "interpolatedDted1"
ZI001_VSCenumvalue2ZI001_VSCcodelist["2"] = "interpolatedDted2"
ZI001_VSCenumvalue2ZI001_VSCcodelist["3"] = "noElevations"
ZI001_VSCenumvalue2ZI001_VSCcodelist["-999999"] = "noInformation"
ZI001_VSCenumvalue2ZI001_VSCcodelist["999"] = "other"
ZI001_VSCenumvalue2ZI001_VSCcodelist["998"] = "notApplicable"
ZI001_VSCenumvalue2ZI001_VSCcodelist["4"] = "reflectiveSurface"
ZI001_VSCenumvalue2ZI001_VSCcodelist["5"] = "stereoscopicImagery"
ZI001_VSCenumvalue2ZI001_VSCcodelist["6"] = "tinData"

ZI001_SRTenumvalue2ZI001_SSYcodelist = {}
ZI001_SRTenumvalue2ZI001_SSYcodelist["26"] = "gpsBasedFieldCollect"
ZI001_SRTenumvalue2ZI001_SSYcodelist["28"] = "ikonosImagery"
ZI001_SRTenumvalue2ZI001_SSYcodelist["30"] = "imageryUnspecified"
ZI001_SRTenumvalue2ZI001_SSYcodelist["7"] = "ngaControlledImageBase1"
ZI001_SRTenumvalue2ZI001_SSYcodelist["10"] = "ngaDigitalNauticalChart"
ZI001_SRTenumvalue2ZI001_SSYcodelist["22"] = "ngaFoundationFeatureData"
ZI001_SRTenumvalue2ZI001_SSYcodelist["31"] = "ngaInterimTerrainData"
ZI001_SRTenumvalue2ZI001_SSYcodelist["169"] = "operationsData"
ZI001_SRTenumvalue2ZI001_SSYcodelist["9"] = "quickBirdImagery"
ZI001_SRTenumvalue2ZI001_SSYcodelist["43"] = "usModernizedIntegratedDB"
ZI001_SRTenumvalue2ZI001_SSYcodelist["29"] = "usNtmImagery"
ZI001_SRTenumvalue2ZI001_SSYcodelist["-999999"] = "noInformation"
ZI001_SRTenumvalue2ZI001_SSYcodelist["999"] = "other"
ZI001_SRTenumvalue2ZI001_SSYcodelist["998"] = "notApplicable"

ZI001_SRTenumvalue2ZI001_NSPcodelist = {}
ZI001_SRTenumvalue2ZI001_NSPcodelist["159"] = "commercialData"
ZI001_SRTenumvalue2ZI001_NSPcodelist["26"] = "gpsBasedFieldCollect"
ZI001_SRTenumvalue2ZI001_NSPcodelist["28"] = "ikonosImagery"
ZI001_SRTenumvalue2ZI001_NSPcodelist["30"] = "imageryUnspecified"
ZI001_SRTenumvalue2ZI001_NSPcodelist["167"] = "militaryMapData"
ZI001_SRTenumvalue2ZI001_NSPcodelist["2"] = "ngaAutoAirFacInfoFile"
ZI001_SRTenumvalue2ZI001_NSPcodelist["7"] = "ngaControlledImageBase1"
ZI001_SRTenumvalue2ZI001_NSPcodelist["165"] = "ngaDigitalAirFltInfoFile"
ZI001_SRTenumvalue2ZI001_NSPcodelist["10"] = "ngaDigitalNauticalChart"
ZI001_SRTenumvalue2ZI001_NSPcodelist["21"] = "ngaDigitalVertObstruction"
ZI001_SRTenumvalue2ZI001_NSPcodelist["22"] = "ngaFoundationFeatureData"
ZI001_SRTenumvalue2ZI001_NSPcodelist["25"] = "ngaGeoNames"
ZI001_SRTenumvalue2ZI001_NSPcodelist["31"] = "ngaInterimTerrainData"
ZI001_SRTenumvalue2ZI001_NSPcodelist["32"] = "ngaInterimVectorData"
ZI001_SRTenumvalue2ZI001_NSPcodelist["170"] = "ngaStereoAirfieldCollect"
ZI001_SRTenumvalue2ZI001_NSPcodelist["60"] = "ngaUrbanVectorMap"
ZI001_SRTenumvalue2ZI001_NSPcodelist["61"] = "ngaVectorInterimTerrain"
ZI001_SRTenumvalue2ZI001_NSPcodelist["64"] = "ngaVectorMap2"
ZI001_SRTenumvalue2ZI001_NSPcodelist["168"] = "nonMilitaryMap"
ZI001_SRTenumvalue2ZI001_NSPcodelist["160"] = "openSourceInfo"
ZI001_SRTenumvalue2ZI001_NSPcodelist["169"] = "operationsData"
ZI001_SRTenumvalue2ZI001_NSPcodelist["9"] = "quickBirdImagery"
ZI001_SRTenumvalue2ZI001_NSPcodelist["43"] = "usModernizedIntegratedDB"
ZI001_SRTenumvalue2ZI001_NSPcodelist["29"] = "usNtmImagery"
ZI001_SRTenumvalue2ZI001_NSPcodelist["-999999"] = "noInformation"
ZI001_SRTenumvalue2ZI001_NSPcodelist["999"] = "other"


# Add lower case values:
CPScodelist2CPSenumvalue["noinformation"] = "-999999"

ETScodelist2ETSenumvalue["digitalfeg"] = "56"
ETScodelist2ETSenumvalue["globaltdseg"] = "57"
ETScodelist2ETSenumvalue["jogairground"] = "3"
ETScodelist2ETSenumvalue["jogradar"] = "27"
ETScodelist2ETSenumvalue["localtdseg"] = "59"
ETScodelist2ETSenumvalue["mgcptrd"] = "61"
ETScodelist2ETSenumvalue["noinformation"] = "-999999"
ETScodelist2ETSenumvalue["regionaltdseg"] = "58"
ETScodelist2ETSenumvalue["specurbantdseg"] = "60"
ETScodelist2ETSenumvalue["tercome"] = "29"
ETScodelist2ETSenumvalue["tercoml"] = "28"
ETScodelist2ETSenumvalue["tercomt"] = "30"

HZDcodelist2HZDenumvalue["adindanburkinafaso"] = "6"
HZDcodelist2HZDenumvalue["adindancameroon"] = "7"
HZDcodelist2HZDenumvalue["adindanethiopia"] = "2"
HZDcodelist2HZDenumvalue["adindanmali"] = "4"
HZDcodelist2HZDenumvalue["adindanmeanvalue"] = "8"
HZDcodelist2HZDenumvalue["adindansenegal"] = "5"
HZDcodelist2HZDenumvalue["adindansudan"] = "3"
HZDcodelist2HZDenumvalue["afgooyesomalia"] = "9"
HZDcodelist2HZDenumvalue["ainelabd1970bahrainisland"] = "12"
HZDcodelist2HZDenumvalue["ainelabd1970saudiarabia"] = "13"
HZDcodelist2HZDenumvalue["americansamoadatum1962"] = "14"
HZDcodelist2HZDenumvalue["anna1astro1965cocosislands"] = "16"
HZDcodelist2HZDenumvalue["antiguaislandastro1943"] = "10"
HZDcodelist2HZDenumvalue["approximateluzondatum"] = "17"
HZDcodelist2HZDenumvalue["arc1935africa"] = "32"
HZDcodelist2HZDenumvalue["arc1950botswana"] = "19"
HZDcodelist2HZDenumvalue["arc1950burundi"] = "26"
HZDcodelist2HZDenumvalue["arc1950lesotho"] = "20"
HZDcodelist2HZDenumvalue["arc1950malawi"] = "21"
HZDcodelist2HZDenumvalue["arc1950meanvalue"] = "27"
HZDcodelist2HZDenumvalue["arc1950swaziland"] = "22"
HZDcodelist2HZDenumvalue["arc1950zaire"] = "23"
HZDcodelist2HZDenumvalue["arc1950zambia"] = "24"
HZDcodelist2HZDenumvalue["arc1950zimbabwe"] = "25"
HZDcodelist2HZDenumvalue["arc1960kenya"] = "29"
HZDcodelist2HZDenumvalue["arc1960meanvalue"] = "31"
HZDcodelist2HZDenumvalue["arc1960tanzania"] = "30"
HZDcodelist2HZDenumvalue["ascensionisland1958"] = "33"
HZDcodelist2HZDenumvalue["astrobeaconeiwojimaisland"] = "36"
HZDcodelist2HZDenumvalue["astrodos71dash4sthelena"] = "272"
HZDcodelist2HZDenumvalue["astrostation1952marcusis"] = "35"
HZDcodelist2HZDenumvalue["astroternisland1961hawaii"] = "290"
HZDcodelist2HZDenumvalue["australiangeodetic1966"] = "38"
HZDcodelist2HZDenumvalue["australiangeodetic1984"] = "39"
HZDcodelist2HZDenumvalue["averageterrestrialsys1977"] = "37"
HZDcodelist2HZDenumvalue["ayabellelighthousedjibouti"] = "225"
HZDcodelist2HZDenumvalue["bekaabasesouthendlebanon"] = "42"
HZDcodelist2HZDenumvalue["belgium1950systemlommelsig"] = "43"
HZDcodelist2HZDenumvalue["belgium1972observatoire"] = "206"
HZDcodelist2HZDenumvalue["bellevueignefateerromango"] = "115"
HZDcodelist2HZDenumvalue["bermuda1957bermudaislands"] = "44"
HZDcodelist2HZDenumvalue["bern1898switzerland"] = "50"
HZDcodelist2HZDenumvalue["bern1898zeromeridian"] = "51"
HZDcodelist2HZDenumvalue["bissauguineabissau"] = "45"
HZDcodelist2HZDenumvalue["bjz54a954beijingcoord"] = "47"
HZDcodelist2HZDenumvalue["bogotaobservatorycolombia"] = "48"
HZDcodelist2HZDenumvalue["bogotaobszeromeridian"] = "49"
HZDcodelist2HZDenumvalue["bukitrimpahindonesia"] = "52"
HZDcodelist2HZDenumvalue["camacupabaseswendangola"] = "55"
HZDcodelist2HZDenumvalue["campareaastroantarctica"] = "58"
HZDcodelist2HZDenumvalue["campoinchauspeargentina"] = "54"
HZDcodelist2HZDenumvalue["cantonastro1966phoenixis"] = "56"
HZDcodelist2HZDenumvalue["capecanaveralmeanvalue"] = "53"
HZDcodelist2HZDenumvalue["capesouthafrica"] = "57"
HZDcodelist2HZDenumvalue["carthagetunisia"] = "60"
HZDcodelist2HZDenumvalue["chatham1971newzealand"] = "62"
HZDcodelist2HZDenumvalue["chuaastroparaguay"] = "63"
HZDcodelist2HZDenumvalue["compensationgeoquebec1977"] = "61"
HZDcodelist2HZDenumvalue["conakrypyramidguinea"] = "65"
HZDcodelist2HZDenumvalue["corregoalegrebrazil"] = "64"
HZDcodelist2HZDenumvalue["dabolaguinea"] = "67"
HZDcodelist2HZDenumvalue["dcs3lighthouselesserant"] = "68"
HZDcodelist2HZDenumvalue["deceptionislantarctica"] = "69"
HZDcodelist2HZDenumvalue["djakartabataviaindonesia"] = "40"
HZDcodelist2HZDenumvalue["djakartabataviazeromerid"] = "41"
HZDcodelist2HZDenumvalue["dominicaastrom12lesserant"] = "71"
HZDcodelist2HZDenumvalue["dos1968gizonewgeorgiais"] = "100"
HZDcodelist2HZDenumvalue["easterisland1967easteris"] = "72"
HZDcodelist2HZDenumvalue["european1950britishisles"] = "85"
HZDcodelist2HZDenumvalue["european1950cyprus"] = "79"
HZDcodelist2HZDenumvalue["european1950egypt"] = "80"
HZDcodelist2HZDenumvalue["european1950england"] = "81"
HZDcodelist2HZDenumvalue["european1950greece"] = "76"
HZDcodelist2HZDenumvalue["european1950iran"] = "82"
HZDcodelist2HZDenumvalue["european1950iraqsyria"] = "88"
HZDcodelist2HZDenumvalue["european1950malta"] = "86"
HZDcodelist2HZDenumvalue["european1950meanvalue"] = "87"
HZDcodelist2HZDenumvalue["european1950norwayfinland"] = "77"
HZDcodelist2HZDenumvalue["european1950portugalspain"] = "78"
HZDcodelist2HZDenumvalue["european1950sardinia"] = "83"
HZDcodelist2HZDenumvalue["european1950sicily"] = "84"
HZDcodelist2HZDenumvalue["european1950tunisia"] = "89"
HZDcodelist2HZDenumvalue["european1950westerneurope"] = "75"
HZDcodelist2HZDenumvalue["european1979meanvalue"] = "90"
HZDcodelist2HZDenumvalue["fortthomas1955leewardis"] = "94"
HZDcodelist2HZDenumvalue["gan1970adduatoll"] = "95"
HZDcodelist2HZDenumvalue["gandajikabasezaire"] = "96"
HZDcodelist2HZDenumvalue["gdz80china"] = "98"
HZDcodelist2HZDenumvalue["geocentricdatumofaustralia"] = "97"
HZDcodelist2HZDenumvalue["geodeticdatum1949zealand"] = "99"
HZDcodelist2HZDenumvalue["graciosabaseswfaialazores"] = "101"
HZDcodelist2HZDenumvalue["greekdatumgreece"] = "102"
HZDcodelist2HZDenumvalue["greekgeodeticrefsystem1987"] = "103"
HZDcodelist2HZDenumvalue["gunongsegarakalimantanis"] = "104"
HZDcodelist2HZDenumvalue["gunongserindung"] = "105"
HZDcodelist2HZDenumvalue["gux1astroguadacanalis"] = "70"
HZDcodelist2HZDenumvalue["guyanacsg67"] = "66"
HZDcodelist2HZDenumvalue["heratnorthafganistan"] = "107"
HZDcodelist2HZDenumvalue["hjorsey1955iceland"] = "110"
HZDcodelist2HZDenumvalue["hongkong1929"] = "112"
HZDcodelist2HZDenumvalue["hongkong1963hongkong"] = "111"
HZDcodelist2HZDenumvalue["hutzushan"] = "113"
HZDcodelist2HZDenumvalue["indian1954thailand"] = "123"
HZDcodelist2HZDenumvalue["indian1960consonisland"] = "126"
HZDcodelist2HZDenumvalue["indian1960vietnam"] = "125"
HZDcodelist2HZDenumvalue["indian1975thailand"] = "128"
HZDcodelist2HZDenumvalue["indian1975thailandcycle1"] = "306"
HZDcodelist2HZDenumvalue["indianbangladesh"] = "119"
HZDcodelist2HZDenumvalue["indianindianepal"] = "120"
HZDcodelist2HZDenumvalue["indianpakistan"] = "121"
HZDcodelist2HZDenumvalue["indianthailandvietnam"] = "118"
HZDcodelist2HZDenumvalue["ireland1965irelandnorthern"] = "129"
HZDcodelist2HZDenumvalue["ists061astro1968georgiais"] = "130"
HZDcodelist2HZDenumvalue["ists073astro1969diegogar"] = "131"
HZDcodelist2HZDenumvalue["johnstonisland1961"] = "132"
HZDcodelist2HZDenumvalue["kalianpurindia"] = "133"
HZDcodelist2HZDenumvalue["kandawalasrilanka"] = "134"
HZDcodelist2HZDenumvalue["kcs2sierraleone"] = "136"
HZDcodelist2HZDenumvalue["kerguelenisland1949"] = "137"
HZDcodelist2HZDenumvalue["kertau1948revisedmalaysia"] = "135"
HZDcodelist2HZDenumvalue["kkjfinland"] = "139"
HZDcodelist2HZDenumvalue["koreangeodeticsystem1995"] = "138"
HZDcodelist2HZDenumvalue["kusaieastro1951"] = "140"
HZDcodelist2HZDenumvalue["kuwaitoilcompanyk28"] = "141"
HZDcodelist2HZDenumvalue["lc5astro1961caymanbracis"] = "142"
HZDcodelist2HZDenumvalue["leigonghana"] = "143"
HZDcodelist2HZDenumvalue["liberia1964liberia"] = "144"
HZDcodelist2HZDenumvalue["lisboncastelodisaojorge"] = "145"
HZDcodelist2HZDenumvalue["localastro"] = "146"
HZDcodelist2HZDenumvalue["lomaquintanavenezuela"] = "147"
HZDcodelist2HZDenumvalue["luzonmindanaoisland"] = "150"
HZDcodelist2HZDenumvalue["luzonphilipinesnotmindanao"] = "149"
HZDcodelist2HZDenumvalue["mahe1971maheisland"] = "159"
HZDcodelist2HZDenumvalue["manokwariwestirian"] = "154"
HZDcodelist2HZDenumvalue["marcoastrosalvageislands"] = "151"
HZDcodelist2HZDenumvalue["martiniquefortdesaix"] = "152"
HZDcodelist2HZDenumvalue["massaweritreaethiopia"] = "153"
HZDcodelist2HZDenumvalue["mayottecombani"] = "155"
HZDcodelist2HZDenumvalue["merchichmorocco"] = "157"
HZDcodelist2HZDenumvalue["midwayastro1961midwayis"] = "158"
HZDcodelist2HZDenumvalue["minnacameroon"] = "161"
HZDcodelist2HZDenumvalue["minnanigeria"] = "162"
HZDcodelist2HZDenumvalue["modifiedbjz54china"] = "46"
HZDcodelist2HZDenumvalue["montjonglowe"] = "165"
HZDcodelist2HZDenumvalue["montserratislandastro1958"] = "34"
HZDcodelist2HZDenumvalue["mountdillontobago"] = "156"
HZDcodelist2HZDenumvalue["mporalokogabon"] = "166"
HZDcodelist2HZDenumvalue["nahrwanmasirahislandoman"] = "169"
HZDcodelist2HZDenumvalue["nahrwansaudiarabia"] = "171"
HZDcodelist2HZDenumvalue["nahrwanunitedarabemirates"] = "170"
HZDcodelist2HZDenumvalue["naparimabwitrinidadtobago"] = "172"
HZDcodelist2HZDenumvalue["newfrenchzeromeridianparis"] = "202"
HZDcodelist2HZDenumvalue["noinformation"] = "-999999"
HZDcodelist2HZDenumvalue["northam1927alaska"] = "184"
HZDcodelist2HZDenumvalue["northam1927alberta"] = "186"
HZDcodelist2HZDenumvalue["northam1927aleutiane"] = "199"
HZDcodelist2HZDenumvalue["northam1927aleutianw"] = "200"
HZDcodelist2HZDenumvalue["northam1927bahamas"] = "195"
HZDcodelist2HZDenumvalue["northam1927canadmean"] = "185"
HZDcodelist2HZDenumvalue["northam1927canalzone"] = "193"
HZDcodelist2HZDenumvalue["northam1927caribbean"] = "194"
HZDcodelist2HZDenumvalue["northam1927centamer"] = "192"
HZDcodelist2HZDenumvalue["northam1927conusmean"] = "183"
HZDcodelist2HZDenumvalue["northam1927cuba"] = "197"
HZDcodelist2HZDenumvalue["northam1927easternus"] = "181"
HZDcodelist2HZDenumvalue["northam1927hayespen"] = "198"
HZDcodelist2HZDenumvalue["northam1927manitoba"] = "188"
HZDcodelist2HZDenumvalue["northam1927mexico"] = "191"
HZDcodelist2HZDenumvalue["northam1927newfound"] = "187"
HZDcodelist2HZDenumvalue["northam1927nwtersaskat"] = "189"
HZDcodelist2HZDenumvalue["northam1927salvador"] = "196"
HZDcodelist2HZDenumvalue["northam1927westernus"] = "182"
HZDcodelist2HZDenumvalue["northam1927yukon"] = "190"
HZDcodelist2HZDenumvalue["northam1983alaskaexaleut"] = "174"
HZDcodelist2HZDenumvalue["northam1983aleutian"] = "178"
HZDcodelist2HZDenumvalue["northam1983canada"] = "175"
HZDcodelist2HZDenumvalue["northam1983conus"] = "176"
HZDcodelist2HZDenumvalue["northam1983hawaii"] = "179"
HZDcodelist2HZDenumvalue["northam1983mexico"] = "177"
HZDcodelist2HZDenumvalue["northsahara1959"] = "204"
HZDcodelist2HZDenumvalue["observmeteorologico1939"] = "93"
HZDcodelist2HZDenumvalue["ocotopequeguatemala"] = "205"
HZDcodelist2HZDenumvalue["oldegyptian"] = "207"
HZDcodelist2HZDenumvalue["oldhawaiianhawaiiisland"] = "215"
HZDcodelist2HZDenumvalue["oldhawaiiankauaiisland"] = "216"
HZDcodelist2HZDenumvalue["oldhawaiianmauiisland"] = "217"
HZDcodelist2HZDenumvalue["oldhawaiianmeanvalue"] = "219"
HZDcodelist2HZDenumvalue["oldhawaiianoahuisland"] = "218"
HZDcodelist2HZDenumvalue["ordnancesurvgb1936england"] = "209"
HZDcodelist2HZDenumvalue["ordnancesurvgb1936meanval"] = "213"
HZDcodelist2HZDenumvalue["ordnancesurvgb1936scotshet"] = "211"
HZDcodelist2HZDenumvalue["ordnancesurvgb1936scotwale"] = "210"
HZDcodelist2HZDenumvalue["ordnancesurvgb1936wales"] = "212"
HZDcodelist2HZDenumvalue["osloobservatoryold"] = "220"
HZDcodelist2HZDenumvalue["padangbasewestend"] = "221"
HZDcodelist2HZDenumvalue["padangbasewestendzeromerid"] = "222"
HZDcodelist2HZDenumvalue["picodelasnievescanaryis"] = "227"
HZDcodelist2HZDenumvalue["pitcairnastro1967"] = "226"
HZDcodelist2HZDenumvalue["point58meansolution"] = "239"
HZDcodelist2HZDenumvalue["pointenoire1948"] = "240"
HZDcodelist2HZDenumvalue["potsdamhelmertturmgermany"] = "224"
HZDcodelist2HZDenumvalue["provsoutham1956bolivia"] = "230"
HZDcodelist2HZDenumvalue["provsoutham1956columbia"] = "233"
HZDcodelist2HZDenumvalue["provsoutham1956ecuador"] = "234"
HZDcodelist2HZDenumvalue["provsoutham1956guyana"] = "235"
HZDcodelist2HZDenumvalue["provsoutham1956meanvalue"] = "238"
HZDcodelist2HZDenumvalue["provsoutham1956nchile"] = "231"
HZDcodelist2HZDenumvalue["provsoutham1956peru"] = "236"
HZDcodelist2HZDenumvalue["provsoutham1956schile"] = "232"
HZDcodelist2HZDenumvalue["provsoutham1956venezuela"] = "237"
HZDcodelist2HZDenumvalue["provsouthchilean1963"] = "109"
HZDcodelist2HZDenumvalue["puertoricovirginislands"] = "242"
HZDcodelist2HZDenumvalue["pulkovo1942albania"] = "313"
HZDcodelist2HZDenumvalue["pulkovo1942czechoslovakia"] = "310"
HZDcodelist2HZDenumvalue["pulkovo1942hungary"] = "308"
HZDcodelist2HZDenumvalue["pulkovo1942kazakhstan"] = "312"
HZDcodelist2HZDenumvalue["pulkovo1942latvia"] = "311"
HZDcodelist2HZDenumvalue["pulkovo1942poland"] = "309"
HZDcodelist2HZDenumvalue["pulkovo1942romania"] = "314"
HZDcodelist2HZDenumvalue["pulkovo1942russia"] = "241"
HZDcodelist2HZDenumvalue["qatarnationalqatar"] = "243"
HZDcodelist2HZDenumvalue["qornoqsouthgreenland"] = "244"
HZDcodelist2HZDenumvalue["rauenbergberlingermany"] = "245"
HZDcodelist2HZDenumvalue["recontriangulationmorocco"] = "246"
HZDcodelist2HZDenumvalue["revisednahrwan"] = "201"
HZDcodelist2HZDenumvalue["rome1940zeromeridianrome"] = "164"
HZDcodelist2HZDenumvalue["rt90stockholmsweden"] = "248"
HZDcodelist2HZDenumvalue["sainteannei1984guadeloupe"] = "251"
HZDcodelist2HZDenumvalue["santodos1965espiritosanto"] = "249"
HZDcodelist2HZDenumvalue["saobrazsaomiguelazores"] = "266"
HZDcodelist2HZDenumvalue["sapperhill1943eastfalkland"] = "267"
HZDcodelist2HZDenumvalue["schwarzecknamibia"] = "268"
HZDcodelist2HZDenumvalue["sebaseportosanto"] = "228"
HZDcodelist2HZDenumvalue["selvagemgrande1938salvage"] = "271"
HZDcodelist2HZDenumvalue["sierraleone1960"] = "273"
HZDcodelist2HZDenumvalue["sjtsk"] = "59"
HZDcodelist2HZDenumvalue["southafricansouthafrica"] = "250"
HZDcodelist2HZDenumvalue["southamerican1969argentina"] = "253"
HZDcodelist2HZDenumvalue["southamerican1969baltrais"] = "262"
HZDcodelist2HZDenumvalue["southamerican1969bolivia"] = "254"
HZDcodelist2HZDenumvalue["southamerican1969brazil"] = "255"
HZDcodelist2HZDenumvalue["southamerican1969chile"] = "256"
HZDcodelist2HZDenumvalue["southamerican1969columbia"] = "257"
HZDcodelist2HZDenumvalue["southamerican1969ecuador"] = "258"
HZDcodelist2HZDenumvalue["southamerican1969guyana"] = "259"
HZDcodelist2HZDenumvalue["southamerican1969meanvalue"] = "265"
HZDcodelist2HZDenumvalue["southamerican1969paraguay"] = "260"
HZDcodelist2HZDenumvalue["southamerican1969peru"] = "261"
HZDcodelist2HZDenumvalue["southamerican1969trinidad"] = "263"
HZDcodelist2HZDenumvalue["southamerican1969venezuela"] = "264"
HZDcodelist2HZDenumvalue["southasiasingapore"] = "274"
HZDcodelist2HZDenumvalue["sovietgeodeticsystem1985"] = "269"
HZDcodelist2HZDenumvalue["sovietgeodeticsystem1990"] = "270"
HZDcodelist2HZDenumvalue["stockholm1938sweden"] = "277"
HZDcodelist2HZDenumvalue["stpierreetmiquelon1950"] = "276"
HZDcodelist2HZDenumvalue["sydneyobservatorynewsouth"] = "278"
HZDcodelist2HZDenumvalue["tananariveobs1925zermerpar"] = "280"
HZDcodelist2HZDenumvalue["tananariveobservatory1925"] = "279"
HZDcodelist2HZDenumvalue["timbalai1948bruneimalaysia"] = "282"
HZDcodelist2HZDenumvalue["tokyojapan"] = "285"
HZDcodelist2HZDenumvalue["tokyokorea"] = "286"
HZDcodelist2HZDenumvalue["tokyokoreacycle1"] = "315"
HZDcodelist2HZDenumvalue["tokyomeanvalue"] = "288"
HZDcodelist2HZDenumvalue["tokyookinawa"] = "287"
HZDcodelist2HZDenumvalue["tristanastro1968cunha"] = "281"
HZDcodelist2HZDenumvalue["vitilevu1916fijiislands"] = "167"
HZDcodelist2HZDenumvalue["voirol1875zeromeridparis"] = "293"
HZDcodelist2HZDenumvalue["voirol1960algeria"] = "294"
HZDcodelist2HZDenumvalue["voirol1960zeromeridparis"] = "295"
HZDcodelist2HZDenumvalue["wakeeniwetok1960marshallis"] = "73"
HZDcodelist2HZDenumvalue["wakeislandastro1952"] = "296"
HZDcodelist2HZDenumvalue["worldgeodeticsystem1960"] = "297"
HZDcodelist2HZDenumvalue["worldgeodeticsystem1966"] = "298"
HZDcodelist2HZDenumvalue["worldgeodeticsystem1972"] = "299"
HZDcodelist2HZDenumvalue["worldgeodeticsystem1984"] = "300"
HZDcodelist2HZDenumvalue["yacareuruguay"] = "301"
HZDcodelist2HZDenumvalue["zanderijsurinam"] = "302"

VDTcodelist2VDTenumvalue["groundlevel"] = "6"
VDTcodelist2VDTenumvalue["meansealevel"] = "3"
VDTcodelist2VDTenumvalue["noinformation"] = "-999999"
VDTcodelist2VDTenumvalue["wgs84egm08"] = "7"
VDTcodelist2VDTenumvalue["wgs84egm96"] = "2"

ZI001_SRTcodelist2ZI001_SRTenumvalue["commercialdata"] = "159"
ZI001_SRTcodelist2ZI001_SRTenumvalue["delormedigitalatlasearth"] = "166"
ZI001_SRTcodelist2ZI001_SRTenumvalue["gpsbasedfieldcollect"] = "26"
ZI001_SRTcodelist2ZI001_SRTenumvalue["ikonosimagery"] = "28"
ZI001_SRTcodelist2ZI001_SRTenumvalue["imageryunspecified"] = "30"
ZI001_SRTcodelist2ZI001_SRTenumvalue["militarymapdata"] = "167"
ZI001_SRTcodelist2ZI001_SRTenumvalue["navteqdata"] = "108"
ZI001_SRTcodelist2ZI001_SRTenumvalue["ngaautoairfacinfofile"] = "2"
ZI001_SRTcodelist2ZI001_SRTenumvalue["ngacontrolledimagebase1"] = "7"
ZI001_SRTcodelist2ZI001_SRTenumvalue["ngadigitalairfltinfofile"] = "165"
ZI001_SRTcodelist2ZI001_SRTenumvalue["ngadigitalnauticalchart"] = "10"
ZI001_SRTcodelist2ZI001_SRTenumvalue["ngadigitalvertobstruction"] = "21"
ZI001_SRTcodelist2ZI001_SRTenumvalue["ngafoundationfeaturedata"] = "22"
ZI001_SRTcodelist2ZI001_SRTenumvalue["ngageonames"] = "25"
ZI001_SRTcodelist2ZI001_SRTenumvalue["ngainterimterraindata"] = "31"
ZI001_SRTcodelist2ZI001_SRTenumvalue["ngainterimvectordata"] = "32"
ZI001_SRTcodelist2ZI001_SRTenumvalue["ngastereoairfieldcollect"] = "170"
ZI001_SRTcodelist2ZI001_SRTenumvalue["ngaurbanvectormap"] = "60"
ZI001_SRTcodelist2ZI001_SRTenumvalue["ngavectorinterimterrain"] = "61"
ZI001_SRTcodelist2ZI001_SRTenumvalue["ngavectormap2"] = "64"
ZI001_SRTcodelist2ZI001_SRTenumvalue["noinformation"] = "-999999"
ZI001_SRTcodelist2ZI001_SRTenumvalue["nonmilitarymap"] = "168"
ZI001_SRTcodelist2ZI001_SRTenumvalue["opensource"] = "160"
ZI001_SRTcodelist2ZI001_SRTenumvalue["opensourceinfo"] = "160"
ZI001_SRTcodelist2ZI001_SRTenumvalue["operationsdata"] = "169"
ZI001_SRTcodelist2ZI001_SRTenumvalue["quickbirdimagery"] = "9"
ZI001_SRTcodelist2ZI001_SRTenumvalue["tomtomdata"] = "171"
ZI001_SRTcodelist2ZI001_SRTenumvalue["usmodernizedintegrateddb"] = "43"
ZI001_SRTcodelist2ZI001_SRTenumvalue["usntmimagery"] = "29"

ZI001_VSCcodelist2ZI001_VSCenumvalue["interpolateddted1"] = "1"
ZI001_VSCcodelist2ZI001_VSCenumvalue["interpolateddted2"] = "2"
ZI001_VSCcodelist2ZI001_VSCenumvalue["noelevations"] = "3"
ZI001_VSCcodelist2ZI001_VSCenumvalue["noinformation"] = "-999999"
ZI001_VSCcodelist2ZI001_VSCenumvalue["reflectivesurface"] = "4"
ZI001_VSCcodelist2ZI001_VSCenumvalue["stereoscopicimagery"] = "5"
ZI001_VSCcodelist2ZI001_VSCenumvalue["tindata"] = "6"

# 2020 - updated with new potential values, see nsgreg: ResourceOrganisation, items 57 and higher are new
RCGcodelist2RCGenumvalue = {}
RCGcodelist2RCGenumvalue['------'] = '-999999'
RCGcodelist2RCGenumvalue['armedForcesGeneralHqQatar'] = '69'
RCGcodelist2RCGenumvalue['armyAustralia'] = '56'
RCGcodelist2RCGenumvalue['armyGeoAgencyNetherlands'] = '44'
RCGcodelist2RCGenumvalue['armyGeographicCentreSpain'] = '51'
RCGcodelist2RCGenumvalue['armyGeoInstitutePortugal'] = '48'
RCGcodelist2RCGenumvalue['bundeswehrGeoinfoOffice'] = '37'
RCGcodelist2RCGenumvalue['defenceAcqLogOrgDenmark'] = '33'
RCGcodelist2RCGenumvalue['defenceGeoCentreIntColGrp'] = '54'
RCGcodelist2RCGenumvalue['defenceImageryGeoOrg'] = '28'
RCGcodelist2RCGenumvalue['defenseInfoSecurityItaly'] = '40'
RCGcodelist2RCGenumvalue['direcServGeoMilParaguay'] = '78'
RCGcodelist2RCGenumvalue['directGeoInfoSouthAfrica'] = '58'
RCGcodelist2RCGenumvalue['directorateSurveyKuwait'] = '71'
RCGcodelist2RCGenumvalue['diretoriaServicoGeoBrazil'] = '90'
RCGcodelist2RCGenumvalue['dirGenRegistrosCatastroGeo'] = '86'
RCGcodelist2RCGenumvalue['generalCommandMapping'] = '53'
RCGcodelist2RCGenumvalue['geoInfoAgencyLatvia'] = '41'
RCGcodelist2RCGenumvalue['geoIntelOrgNewZealand'] = '45'
RCGcodelist2RCGenumvalue['geoServCzechArmedForces'] = '32'
RCGcodelist2RCGenumvalue['geoServiceBelgium'] = '29'
RCGcodelist2RCGenumvalue['hellenicMilitaryGeoServ'] = '38'
RCGcodelist2RCGenumvalue['imagerySupportGrpSingapore'] = '61'
RCGcodelist2RCGenumvalue['infoNetworkSecurityAgency'] = '73'
RCGcodelist2RCGenumvalue['instGeoNacTommyGuardia'] = '88'
RCGcodelist2RCGenumvalue['institutoCartoMilitarDomRp'] = '84'
RCGcodelist2RCGenumvalue['institutoGeoAgustinCodazzi'] = '80'
RCGcodelist2RCGenumvalue['institutoGeoCatastroNacl'] = '81'
RCGcodelist2RCGenumvalue['institutoGeoMilitarChile'] = '76'
RCGcodelist2RCGenumvalue['institutoGeoMilitarEcuador'] = '87'
RCGcodelist2RCGenumvalue['institutoGeoNacionalPeru'] = '79'
RCGcodelist2RCGenumvalue['institutoGeoNaclArgentina'] = '89'
RCGcodelist2RCGenumvalue['institutoGeoNaclGuatemala'] = '82'
RCGcodelist2RCGenumvalue['institutoNaclEstadisticaGeo'] = '75'
RCGcodelist2RCGenumvalue['institutoNicaragEstudiosTrr'] = '85'
RCGcodelist2RCGenumvalue['jointGeoBureauFrance'] = '36'
RCGcodelist2RCGenumvalue['koreanDefenseIntelAgency'] = '59'
RCGcodelist2RCGenumvalue['mapChartEstablishment'] = '31'
RCGcodelist2RCGenumvalue['mappingServiceHungary'] = '39'
RCGcodelist2RCGenumvalue['materielProdCenterTaiwan'] = '63'
RCGcodelist2RCGenumvalue['milGeogDivisionPoland'] = '47'
RCGcodelist2RCGenumvalue['milGeoGroupEstonia'] = '34'
RCGcodelist2RCGenumvalue['milGeoServiceNorway'] = '46'
RCGcodelist2RCGenumvalue['militaryGeoDivisionCroatia'] = '57'
RCGcodelist2RCGenumvalue['militarySurveyDeptUAE'] = '72'
RCGcodelist2RCGenumvalue['milMapCentreLithuania'] = '42'
RCGcodelist2RCGenumvalue['milTopoDirectRomania'] = '49'
RCGcodelist2RCGenumvalue['milTopoServiceBulgaria'] = '30'
RCGcodelist2RCGenumvalue['ministryConstructUrbanDev'] = '65'
RCGcodelist2RCGenumvalue['ministryDefenseJapan'] = '64'
RCGcodelist2RCGenumvalue['ministryDefenseSaudiArabia'] = '70'
RCGcodelist2RCGenumvalue['ministryStateDefenseKenya'] = '74'
RCGcodelist2RCGenumvalue['natArmyTopoServiceMoldova'] = '43'
RCGcodelist2RCGenumvalue['natIntelServiceSouthKorea'] = '60'
RCGcodelist2RCGenumvalue['nationalSurveyAuthorityOman'] = '68'
RCGcodelist2RCGenumvalue['natMappingResourceInfoAuth'] = '66'
RCGcodelist2RCGenumvalue['natSecurityBureauTaiwan'] = '62'
RCGcodelist2RCGenumvalue['noInformation'] = '-999999'
RCGcodelist2RCGenumvalue['NoInformation'] = '-999999'
RCGcodelist2RCGenumvalue['notApplicable'] = '998'
RCGcodelist2RCGenumvalue['NotApplicable'] = '998'
RCGcodelist2RCGenumvalue['other'] = '999'
RCGcodelist2RCGenumvalue['Other'] = '999'
RCGcodelist2RCGenumvalue['royalJordanianGeoCentre'] = '67'
RCGcodelist2RCGenumvalue['servicioGeoMilitarGuatemala'] = '83'
RCGcodelist2RCGenumvalue['servicioGeoMilitarUruguay'] = '77'
RCGcodelist2RCGenumvalue['swedishArmedForces'] = '52'
RCGcodelist2RCGenumvalue['topoInstituteSlovakia'] = '50'
RCGcodelist2RCGenumvalue['topoServiceFinland'] = '35'
RCGcodelist2RCGenumvalue['usAfricaCommand'] = '6'
RCGcodelist2RCGenumvalue['usAirForce'] = '3'
RCGcodelist2RCGenumvalue['usArmy'] = '1'
RCGcodelist2RCGenumvalue['usArmyGeospatialCenter'] = '55'
RCGcodelist2RCGenumvalue['usCentralCommand'] = '7'
RCGcodelist2RCGenumvalue['usCentralIntelAgency'] = '16'
RCGcodelist2RCGenumvalue['usCoastGuard'] = '5'
RCGcodelist2RCGenumvalue['usDefenseIntelAgency'] = '17'
RCGcodelist2RCGenumvalue['usDeptOfEnergy'] = '23'
RCGcodelist2RCGenumvalue['usDeptOfHomelandSecurity'] = '22'
RCGcodelist2RCGenumvalue['usDeptOfState'] = '21'
RCGcodelist2RCGenumvalue['usEuropeanCommand'] = '8'
RCGcodelist2RCGenumvalue['usFedBurOfInvestigation'] = '24'
RCGcodelist2RCGenumvalue['usGeologicalSurvey'] = '25'
RCGcodelist2RCGenumvalue['usJointForcesCommand'] = '9'
RCGcodelist2RCGenumvalue['usMarineCorps'] = '4'
RCGcodelist2RCGenumvalue['usNatCivilAppsProgram'] = '26'
RCGcodelist2RCGenumvalue['usNationalGeoIntelAgency'] = '19'
RCGcodelist2RCGenumvalue['usNationalReconnOffice'] = '20'
RCGcodelist2RCGenumvalue['usNationalSecurityAgency'] = '18'
RCGcodelist2RCGenumvalue['usNatOceanAtmosAdmin'] = '27'
RCGcodelist2RCGenumvalue['usNavy'] = '2'
RCGcodelist2RCGenumvalue['usNorthernCommand'] = '10'
RCGcodelist2RCGenumvalue['usPacificCommand'] = '11'
RCGcodelist2RCGenumvalue['usSouthernCommand'] = '13'
RCGcodelist2RCGenumvalue['usSpecialOperCommand'] = '12'
RCGcodelist2RCGenumvalue['usStrategicCommand'] = '14'
RCGcodelist2RCGenumvalue['usTransportationCommand'] = '15'

# lower case versions
RCGcodelist2RCGenumvalue['armedforcesgeneralhqqatar'] = '69'
RCGcodelist2RCGenumvalue['armyaustralia'] = '56'
RCGcodelist2RCGenumvalue['armygeoagencynetherlands'] = '44'
RCGcodelist2RCGenumvalue['armygeographiccentrespain'] = '51'
RCGcodelist2RCGenumvalue['armygeoinstituteportugal'] = '48'
RCGcodelist2RCGenumvalue['bundeswehrgeoinfooffice'] = '37'
RCGcodelist2RCGenumvalue['defenceacqlogorgdenmark'] = '33'
RCGcodelist2RCGenumvalue['defencegeocentreintcolgrp'] = '54'
RCGcodelist2RCGenumvalue['defenceimagerygeoorg'] = '28'
RCGcodelist2RCGenumvalue['defenseinfosecurityitaly'] = '40'
RCGcodelist2RCGenumvalue['direcservgeomilparaguay'] = '78'
RCGcodelist2RCGenumvalue['directgeoinfosouthafrica'] = '58'
RCGcodelist2RCGenumvalue['directoratesurveykuwait'] = '71'
RCGcodelist2RCGenumvalue['diretoriaservicogeobrazil'] = '90'
RCGcodelist2RCGenumvalue['dirgenregistroscatastrogeo'] = '86'
RCGcodelist2RCGenumvalue['generalcommandmapping'] = '53'
RCGcodelist2RCGenumvalue['geoinfoagencylatvia'] = '41'
RCGcodelist2RCGenumvalue['geointelorgnewzealand'] = '45'
RCGcodelist2RCGenumvalue['geoservczecharmedforces'] = '32'
RCGcodelist2RCGenumvalue['geoservicebelgium'] = '29'
RCGcodelist2RCGenumvalue['hellenicmilitarygeoserv'] = '38'
RCGcodelist2RCGenumvalue['imagerysupportgrpsingapore'] = '61'
RCGcodelist2RCGenumvalue['infonetworksecurityagency'] = '73'
RCGcodelist2RCGenumvalue['instgeonactommyguardia'] = '88'
RCGcodelist2RCGenumvalue['institutocartomilitardomrp'] = '84'
RCGcodelist2RCGenumvalue['institutogeoagustincodazzi'] = '80'
RCGcodelist2RCGenumvalue['institutogeocatastronacl'] = '81'
RCGcodelist2RCGenumvalue['institutogeomilitarchile'] = '76'
RCGcodelist2RCGenumvalue['institutogeomilitarecuador'] = '87'
RCGcodelist2RCGenumvalue['institutogeonacionalperu'] = '79'
RCGcodelist2RCGenumvalue['institutogeonaclargentina'] = '89'
RCGcodelist2RCGenumvalue['institutogeonaclguatemala'] = '82'
RCGcodelist2RCGenumvalue['institutonaclestadisticageo'] = '75'
RCGcodelist2RCGenumvalue['institutonicaragestudiostrr'] = '85'
RCGcodelist2RCGenumvalue['jointgeobureaufrance'] = '36'
RCGcodelist2RCGenumvalue['koreandefenseintelagency'] = '59'
RCGcodelist2RCGenumvalue['mapchartestablishment'] = '31'
RCGcodelist2RCGenumvalue['mappingservicehungary'] = '39'
RCGcodelist2RCGenumvalue['materielprodcentertaiwan'] = '63'
RCGcodelist2RCGenumvalue['milgeogdivisionpoland'] = '47'
RCGcodelist2RCGenumvalue['milgeogroupestonia'] = '34'
RCGcodelist2RCGenumvalue['milgeoservicenorway'] = '46'
RCGcodelist2RCGenumvalue['militarygeodivisioncroatia'] = '57'
RCGcodelist2RCGenumvalue['militarysurveydeptuae'] = '72'
RCGcodelist2RCGenumvalue['milmapcentrelithuania'] = '42'
RCGcodelist2RCGenumvalue['miltopodirectromania'] = '49'
RCGcodelist2RCGenumvalue['miltoposervicebulgaria'] = '30'
RCGcodelist2RCGenumvalue['ministryconstructurbandev'] = '65'
RCGcodelist2RCGenumvalue['ministrydefensejapan'] = '64'
RCGcodelist2RCGenumvalue['ministrydefensesaudiarabia'] = '70'
RCGcodelist2RCGenumvalue['ministrystatedefensekenya'] = '74'
RCGcodelist2RCGenumvalue['natarmytoposervicemoldova'] = '43'
RCGcodelist2RCGenumvalue['natintelservicesouthkorea'] = '60'
RCGcodelist2RCGenumvalue['nationalsurveyauthorityoman'] = '68'
RCGcodelist2RCGenumvalue['natmappingresourceinfoauth'] = '66'
RCGcodelist2RCGenumvalue['natsecuritybureautaiwan'] = '62'
RCGcodelist2RCGenumvalue['noinformation'] = '-999999'
RCGcodelist2RCGenumvalue['notapplicable'] = '998'
RCGcodelist2RCGenumvalue['other'] = '999'
RCGcodelist2RCGenumvalue['royaljordaniangeocentre'] = '67'
RCGcodelist2RCGenumvalue['serviciogeomilitarguatemala'] = '83'
RCGcodelist2RCGenumvalue['serviciogeomilitaruruguay'] = '77'
RCGcodelist2RCGenumvalue['swedisharmedforces'] = '52'
RCGcodelist2RCGenumvalue['topoinstituteslovakia'] = '50'
RCGcodelist2RCGenumvalue['toposervicefinland'] = '35'
RCGcodelist2RCGenumvalue['usafricacommand'] = '6'
RCGcodelist2RCGenumvalue['usairforce'] = '3'
RCGcodelist2RCGenumvalue['usarmy'] = '1'
RCGcodelist2RCGenumvalue['usarmygeospatialcenter'] = '55'
RCGcodelist2RCGenumvalue['uscentralcommand'] = '7'
RCGcodelist2RCGenumvalue['uscentralintelagency'] = '16'
RCGcodelist2RCGenumvalue['uscoastguard'] = '5'
RCGcodelist2RCGenumvalue['usdefenseintelagency'] = '17'
RCGcodelist2RCGenumvalue['usdeptofenergy'] = '23'
RCGcodelist2RCGenumvalue['usdeptofhomelandsecurity'] = '22'
RCGcodelist2RCGenumvalue['usdeptofstate'] = '21'
RCGcodelist2RCGenumvalue['useuropeancommand'] = '8'
RCGcodelist2RCGenumvalue['usfedburofinvestigation'] = '24'
RCGcodelist2RCGenumvalue['usgeologicalsurvey'] = '25'
RCGcodelist2RCGenumvalue['usjointforcescommand'] = '9'
RCGcodelist2RCGenumvalue['usmarinecorps'] = '4'
RCGcodelist2RCGenumvalue['usnatcivilappsprogram'] = '26'
RCGcodelist2RCGenumvalue['usnationalgeointelagency'] = '19'
RCGcodelist2RCGenumvalue['usnationalreconnoffice'] = '20'
RCGcodelist2RCGenumvalue['usnationalsecurityagency'] = '18'
RCGcodelist2RCGenumvalue['usnatoceanatmosadmin'] = '27'
RCGcodelist2RCGenumvalue['usnavy'] = '2'
RCGcodelist2RCGenumvalue['usnortherncommand'] = '10'
RCGcodelist2RCGenumvalue['uspacificcommand'] = '11'
RCGcodelist2RCGenumvalue['ussoutherncommand'] = '13'
RCGcodelist2RCGenumvalue['usspecialopercommand'] = '12'
RCGcodelist2RCGenumvalue['usstrategiccommand'] = '14'
RCGcodelist2RCGenumvalue['ustransportationcommand'] = '15'

ZI004_RCGcodelist2ZI004_RCGenumvalue = RCGcodelist2RCGenumvalue

# Numeric to textual values
RCGenumvalue2RCGcodelist = {}
RCGenumvalue2RCGcodelist['69'] = 'armedForcesGeneralHqQatar'
RCGenumvalue2RCGcodelist['56'] = 'armyAustralia'
RCGenumvalue2RCGcodelist['44'] = 'armyGeoAgencyNetherlands'
RCGenumvalue2RCGcodelist['51'] = 'armyGeographicCentreSpain'
RCGenumvalue2RCGcodelist['48'] = 'armyGeoInstitutePortugal'
RCGenumvalue2RCGcodelist['37'] = 'bundeswehrGeoinfoOffice'
RCGenumvalue2RCGcodelist['33'] = 'defenceAcqLogOrgDenmark'
RCGenumvalue2RCGcodelist['54'] = 'defenceGeoCentreIntColGrp'
RCGenumvalue2RCGcodelist['28'] = 'defenceImageryGeoOrg'
RCGenumvalue2RCGcodelist['40'] = 'defenseInfoSecurityItaly'
RCGenumvalue2RCGcodelist['78'] = 'direcServGeoMilParaguay'
RCGenumvalue2RCGcodelist['58'] = 'directGeoInfoSouthAfrica'
RCGenumvalue2RCGcodelist['71'] = 'directorateSurveyKuwait'
RCGenumvalue2RCGcodelist['90'] = 'diretoriaServicoGeoBrazil'
RCGenumvalue2RCGcodelist['86'] = 'dirGenRegistrosCatastroGeo'
RCGenumvalue2RCGcodelist['53'] = 'generalCommandMapping'
RCGenumvalue2RCGcodelist['41'] = 'geoInfoAgencyLatvia'
RCGenumvalue2RCGcodelist['45'] = 'geoIntelOrgNewZealand'
RCGenumvalue2RCGcodelist['32'] = 'geoServCzechArmedForces'
RCGenumvalue2RCGcodelist['29'] = 'geoServiceBelgium'
RCGenumvalue2RCGcodelist['38'] = 'hellenicMilitaryGeoServ'
RCGenumvalue2RCGcodelist['61'] = 'imagerySupportGrpSingapore'
RCGenumvalue2RCGcodelist['73'] = 'infoNetworkSecurityAgency'
RCGenumvalue2RCGcodelist['88'] = 'instGeoNacTommyGuardia'
RCGenumvalue2RCGcodelist['84'] = 'institutoCartoMilitarDomRp'
RCGenumvalue2RCGcodelist['80'] = 'institutoGeoAgustinCodazzi'
RCGenumvalue2RCGcodelist['81'] = 'institutoGeoCatastroNacl'
RCGenumvalue2RCGcodelist['76'] = 'institutoGeoMilitarChile'
RCGenumvalue2RCGcodelist['87'] = 'institutoGeoMilitarEcuador'
RCGenumvalue2RCGcodelist['79'] = 'institutoGeoNacionalPeru'
RCGenumvalue2RCGcodelist['89'] = 'institutoGeoNaclArgentina'
RCGenumvalue2RCGcodelist['82'] = 'institutoGeoNaclGuatemala'
RCGenumvalue2RCGcodelist['75'] = 'institutoNaclEstadisticaGeo'
RCGenumvalue2RCGcodelist['85'] = 'institutoNicaragEstudiosTrr'
RCGenumvalue2RCGcodelist['36'] = 'jointGeoBureauFrance'
RCGenumvalue2RCGcodelist['59'] = 'koreanDefenseIntelAgency'
RCGenumvalue2RCGcodelist['31'] = 'mapChartEstablishment'
RCGenumvalue2RCGcodelist['39'] = 'mappingServiceHungary'
RCGenumvalue2RCGcodelist['63'] = 'materielProdCenterTaiwan'
RCGenumvalue2RCGcodelist['47'] = 'milGeogDivisionPoland'
RCGenumvalue2RCGcodelist['34'] = 'milGeoGroupEstonia'
RCGenumvalue2RCGcodelist['46'] = 'milGeoServiceNorway'
RCGenumvalue2RCGcodelist['57'] = 'militaryGeoDivisionCroatia'
RCGenumvalue2RCGcodelist['72'] = 'militarySurveyDeptUAE'
RCGenumvalue2RCGcodelist['42'] = 'milMapCentreLithuania'
RCGenumvalue2RCGcodelist['49'] = 'milTopoDirectRomania'
RCGenumvalue2RCGcodelist['30'] = 'milTopoServiceBulgaria'
RCGenumvalue2RCGcodelist['65'] = 'ministryConstructUrbanDev'
RCGenumvalue2RCGcodelist['64'] = 'ministryDefenseJapan'
RCGenumvalue2RCGcodelist['70'] = 'ministryDefenseSaudiArabia'
RCGenumvalue2RCGcodelist['74'] = 'ministryStateDefenseKenya'
RCGenumvalue2RCGcodelist['43'] = 'natArmyTopoServiceMoldova'
RCGenumvalue2RCGcodelist['60'] = 'natIntelServiceSouthKorea'
RCGenumvalue2RCGcodelist['68'] = 'nationalSurveyAuthorityOman'
RCGenumvalue2RCGcodelist['66'] = 'natMappingResourceInfoAuth'
RCGenumvalue2RCGcodelist['62'] = 'natSecurityBureauTaiwan'
RCGenumvalue2RCGcodelist['-999999'] = 'noInformation'
RCGenumvalue2RCGcodelist['998'] = 'notApplicable'
RCGenumvalue2RCGcodelist['999'] = 'other'
RCGenumvalue2RCGcodelist['67'] = 'royalJordanianGeoCentre'
RCGenumvalue2RCGcodelist['83'] = 'servicioGeoMilitarGuatemala'
RCGenumvalue2RCGcodelist['77'] = 'servicioGeoMilitarUruguay'
RCGenumvalue2RCGcodelist['52'] = 'swedishArmedForces'
RCGenumvalue2RCGcodelist['50'] = 'topoInstituteSlovakia'
RCGenumvalue2RCGcodelist['35'] = 'topoServiceFinland'
RCGenumvalue2RCGcodelist['6'] = 'usAfricaCommand'
RCGenumvalue2RCGcodelist['3'] = 'usAirForce'
RCGenumvalue2RCGcodelist['1'] = 'usArmy'
RCGenumvalue2RCGcodelist['55'] = 'usArmyGeospatialCenter'
RCGenumvalue2RCGcodelist['7'] = 'usCentralCommand'
RCGenumvalue2RCGcodelist['16'] = 'usCentralIntelAgency'
RCGenumvalue2RCGcodelist['5'] = 'usCoastGuard'
RCGenumvalue2RCGcodelist['17'] = 'usDefenseIntelAgency'
RCGenumvalue2RCGcodelist['23'] = 'usDeptOfEnergy'
RCGenumvalue2RCGcodelist['22'] = 'usDeptOfHomelandSecurity'
RCGenumvalue2RCGcodelist['21'] = 'usDeptOfState'
RCGenumvalue2RCGcodelist['8'] = 'usEuropeanCommand'
RCGenumvalue2RCGcodelist['24'] = 'usFedBurOfInvestigation'
RCGenumvalue2RCGcodelist['25'] = 'usGeologicalSurvey'
RCGenumvalue2RCGcodelist['9'] = 'usJointForcesCommand'
RCGenumvalue2RCGcodelist['4'] = 'usMarineCorps'
RCGenumvalue2RCGcodelist['26'] = 'usNatCivilAppsProgram'
RCGenumvalue2RCGcodelist['19'] = 'usNationalGeoIntelAgency'
RCGenumvalue2RCGcodelist['20'] = 'usNationalReconnOffice'
RCGenumvalue2RCGcodelist['18'] = 'usNationalSecurityAgency'
RCGenumvalue2RCGcodelist['27'] = 'usNatOceanAtmosAdmin'
RCGenumvalue2RCGcodelist['2'] = 'usNavy'
RCGenumvalue2RCGcodelist['10'] = 'usNorthernCommand'
RCGenumvalue2RCGcodelist['11'] = 'usPacificCommand'
RCGenumvalue2RCGcodelist['13'] = 'usSouthernCommand'
RCGenumvalue2RCGcodelist['12'] = 'usSpecialOperCommand'
RCGenumvalue2RCGcodelist['14'] = 'usStrategicCommand'
RCGenumvalue2RCGcodelist['15'] = 'usTransportationCommand'

ZI004_RCGenumvalue2ZI004_RCGcodelist = RCGenumvalue2RCGcodelist

### Numeric values
CPSenumvalue2CPScodelist[4] = "fixed0r25"
CPSenumvalue2CPScodelist[3] = "fixed0r5"
CPSenumvalue2CPScodelist[2] = "fixed1r0"
CPSenumvalue2CPScodelist[1] = "fixed5r0"
CPSenumvalue2CPScodelist[-999999] = "noInformation"
CPSenumvalue2CPScodelist[998] = "notApplicable"
CPSenumvalue2CPScodelist[999] = "other"
CPSenumvalue2CPScodelist[5] = "variable"

ETSenumvalue2ETScodelist[26] = "atc"
ETSenumvalue2ETScodelist[17] = "combat"
ETSenumvalue2ETScodelist[5] = "dfad1"
ETSenumvalue2ETScodelist[7] = "dfad2"
ETSenumvalue2ETScodelist[56] = "digitalFeg"
ETSenumvalue2ETScodelist[43] = "dnc"
ETSenumvalue2ETScodelist[4] = "dted1"
ETSenumvalue2ETScodelist[6] = "dted2"
ETSenumvalue2ETScodelist[21] = "dtop"
ETSenumvalue2ETScodelist[31] = "ffd"
ETSenumvalue2ETScodelist[57] = "globalTdsEg"
ETSenumvalue2ETScodelist[8] = "hac1"
ETSenumvalue2ETScodelist[9] = "hac2"
ETSenumvalue2ETScodelist[10] = "hac3"
ETSenumvalue2ETScodelist[11] = "hac4"
ETSenumvalue2ETScodelist[12] = "hac5"
ETSenumvalue2ETScodelist[13] = "hac6"
ETSenumvalue2ETScodelist[14] = "hac7"
ETSenumvalue2ETScodelist[15] = "hac8"
ETSenumvalue2ETScodelist[16] = "hac9"
ETSenumvalue2ETScodelist[3] = "jogAirGround"
ETSenumvalue2ETScodelist[27] = "jogRadar"
ETSenumvalue2ETScodelist[59] = "localTdsEg"
ETSenumvalue2ETScodelist[61] = "mgcpTrd"
ETSenumvalue2ETScodelist[44] = "msd1"
ETSenumvalue2ETScodelist[45] = "msd2"
ETSenumvalue2ETScodelist[46] = "msd3"
ETSenumvalue2ETScodelist[47] = "msd4"
ETSenumvalue2ETScodelist[48] = "msd5"
ETSenumvalue2ETScodelist[-999999] = "noInformation"
ETSenumvalue2ETScodelist[2] = "onc"
ETSenumvalue2ETScodelist[998] = "notApplicable"
ETSenumvalue2ETScodelist[999] = "other"
ETSenumvalue2ETScodelist[58] = "regionalTdsEg"
ETSenumvalue2ETScodelist[60] = "specUrbanTdsEg"
ETSenumvalue2ETScodelist[29] = "tercomE"
ETSenumvalue2ETScodelist[28] = "tercomL"
ETSenumvalue2ETScodelist[30] = "tercomT"
ETSenumvalue2ETScodelist[19] = "tlm100"
ETSenumvalue2ETScodelist[18] = "tlm50"
ETSenumvalue2ETScodelist[49] = "tod0"
ETSenumvalue2ETScodelist[50] = "tod1"
ETSenumvalue2ETScodelist[51] = "tod2"
ETSenumvalue2ETScodelist[52] = "tod3"
ETSenumvalue2ETScodelist[53] = "tod4"
ETSenumvalue2ETScodelist[1] = "tpc"
ETSenumvalue2ETScodelist[25] = "uvmap"
ETSenumvalue2ETScodelist[20] = "vitd"
ETSenumvalue2ETScodelist[23] = "vmap0"
ETSenumvalue2ETScodelist[24] = "vmap1"
ETSenumvalue2ETScodelist[22] = "vmap2"

HZDenumvalue2HZDcodelist[6] = "adindanBurkinaFaso"
HZDenumvalue2HZDcodelist[7] = "adindanCameroon"
HZDenumvalue2HZDcodelist[2] = "adindanEthiopia"
HZDenumvalue2HZDcodelist[4] = "adindanMali"
HZDenumvalue2HZDcodelist[8] = "adindanMeanValue"
HZDenumvalue2HZDcodelist[5] = "adindanSenegal"
HZDenumvalue2HZDcodelist[3] = "adindanSudan"
HZDenumvalue2HZDcodelist[9] = "afgooyeSomalia"
HZDenumvalue2HZDcodelist[12] = "ainelAbd1970BahrainIsland"
HZDenumvalue2HZDcodelist[13] = "ainelAbd1970SaudiArabia"
HZDenumvalue2HZDcodelist[14] = "americanSamoaDatum1962"
HZDenumvalue2HZDcodelist[15] = "amersfoort1885dash1903"
HZDenumvalue2HZDcodelist[16] = "anna1Astro1965CocosIslands"
HZDenumvalue2HZDcodelist[10] = "antiguaIslandAstro1943"
HZDenumvalue2HZDcodelist[17] = "approximateLuzonDatum"
HZDenumvalue2HZDcodelist[32] = "arc1935Africa"
HZDenumvalue2HZDcodelist[19] = "arc1950Botswana"
HZDenumvalue2HZDcodelist[26] = "arc1950Burundi"
HZDenumvalue2HZDcodelist[20] = "arc1950Lesotho"
HZDenumvalue2HZDcodelist[21] = "arc1950Malawi"
HZDenumvalue2HZDcodelist[27] = "arc1950MeanValue"
HZDenumvalue2HZDcodelist[22] = "arc1950Swaziland"
HZDenumvalue2HZDcodelist[23] = "arc1950Zaire"
HZDenumvalue2HZDcodelist[24] = "arc1950Zambia"
HZDenumvalue2HZDcodelist[25] = "arc1950Zimbabwe"
HZDenumvalue2HZDcodelist[29] = "arc1960Kenya"
HZDenumvalue2HZDcodelist[31] = "arc1960MeanValue"
HZDenumvalue2HZDcodelist[30] = "arc1960Tanzania"
HZDenumvalue2HZDcodelist[33] = "ascensionIsland1958"
HZDenumvalue2HZDcodelist[36] = "astroBeaconEIwoJimaIsland"
HZDenumvalue2HZDcodelist[272] = "astroDos71dash4StHelena"
HZDenumvalue2HZDcodelist[35] = "astroStation1952MarcusIs"
HZDenumvalue2HZDcodelist[290] = "astroTernIsland1961Hawaii"
HZDenumvalue2HZDcodelist[38] = "australianGeodetic1966"
HZDenumvalue2HZDcodelist[39] = "australianGeodetic1984"
HZDenumvalue2HZDcodelist[37] = "averageTerrestrialSys1977"
HZDenumvalue2HZDcodelist[225] = "ayabelleLighthouseDjibouti"
HZDenumvalue2HZDcodelist[42] = "bekaaBaseSouthEndLebanon"
HZDenumvalue2HZDcodelist[43] = "belgium1950SystemLommelSig"
HZDenumvalue2HZDcodelist[206] = "belgium1972Observatoire"
HZDenumvalue2HZDcodelist[115] = "bellevueIgnEfateErromango"
HZDenumvalue2HZDcodelist[44] = "bermuda1957BermudaIslands"
HZDenumvalue2HZDcodelist[50] = "bern1898Switzerland"
HZDenumvalue2HZDcodelist[51] = "bern1898ZeroMeridian"
HZDenumvalue2HZDcodelist[45] = "bissauGuineaBissau"
HZDenumvalue2HZDcodelist[47] = "bjz54A954BeijingCoord"
HZDenumvalue2HZDcodelist[48] = "bogotaObservatoryColombia"
HZDenumvalue2HZDcodelist[49] = "bogotaObsZeroMeridian"
HZDenumvalue2HZDcodelist[52] = "bukitRimpahIndonesia"
HZDenumvalue2HZDcodelist[55] = "camacupaBaseSwEndAngola"
HZDenumvalue2HZDcodelist[58] = "campAreaAstroAntarctica"
HZDenumvalue2HZDcodelist[54] = "campoInchauspeArgentina"
HZDenumvalue2HZDcodelist[56] = "cantonAstro1966PhoenixIs"
HZDenumvalue2HZDcodelist[53] = "capeCanaveralMeanValue"
HZDenumvalue2HZDcodelist[57] = "capeSouthAfrica"
HZDenumvalue2HZDcodelist[60] = "carthageTunisia"
HZDenumvalue2HZDcodelist[62] = "chatham1971NewZealand"
HZDenumvalue2HZDcodelist[63] = "chuaAstroParaguay"
HZDenumvalue2HZDcodelist[61] = "compensationGeoQuebec1977"
HZDenumvalue2HZDcodelist[65] = "conakryPyramidGuinea"
HZDenumvalue2HZDcodelist[64] = "corregoAlegreBrazil"
HZDenumvalue2HZDcodelist[67] = "dabolaGuinea"
HZDenumvalue2HZDcodelist[68] = "dcs3LighthouseLesserAnt"
HZDenumvalue2HZDcodelist[69] = "deceptionIslAntarctica"
HZDenumvalue2HZDcodelist[40] = "djakartaBataviaIndonesia"
HZDenumvalue2HZDcodelist[41] = "djakartaBataviaZeroMerid"
HZDenumvalue2HZDcodelist[71] = "dominicaAstroM12LesserAnt"
HZDenumvalue2HZDcodelist[100] = "dos1968GizoNewGeorgiaIs"
HZDenumvalue2HZDcodelist[72] = "easterIsland1967EasterIs"
HZDenumvalue2HZDcodelist[305] = "estonia1937"
HZDenumvalue2HZDcodelist[91] = "etrs1989"
HZDenumvalue2HZDcodelist[85] = "european1950BritishIsles"
HZDenumvalue2HZDcodelist[79] = "european1950Cyprus"
HZDenumvalue2HZDcodelist[80] = "european1950Egypt"
HZDenumvalue2HZDcodelist[81] = "european1950England"
HZDenumvalue2HZDcodelist[76] = "european1950Greece"
HZDenumvalue2HZDcodelist[82] = "european1950Iran"
HZDenumvalue2HZDcodelist[88] = "european1950IraqSyria"
HZDenumvalue2HZDcodelist[86] = "european1950Malta"
HZDenumvalue2HZDcodelist[87] = "european1950MeanValue"
HZDenumvalue2HZDcodelist[77] = "european1950NorwayFinland"
HZDenumvalue2HZDcodelist[78] = "european1950PortugalSpain"
HZDenumvalue2HZDcodelist[83] = "european1950Sardinia"
HZDenumvalue2HZDcodelist[84] = "european1950Sicily"
HZDenumvalue2HZDcodelist[89] = "european1950Tunisia"
HZDenumvalue2HZDcodelist[75] = "european1950WesternEurope"
HZDenumvalue2HZDcodelist[90] = "european1979MeanValue"
HZDenumvalue2HZDcodelist[94] = "fortThomas1955LeewardIs"
HZDenumvalue2HZDcodelist[95] = "gan1970AdduAtoll"
HZDenumvalue2HZDcodelist[96] = "gandajikaBaseZaire"
HZDenumvalue2HZDcodelist[98] = "gdz80China"
HZDenumvalue2HZDcodelist[97] = "geocentricDatumOfAustralia"
HZDenumvalue2HZDcodelist[99] = "geodeticDatum1949Zealand"
HZDenumvalue2HZDcodelist[101] = "graciosaBaseSWFaialAzores"
HZDenumvalue2HZDcodelist[102] = "greekDatumGreece"
HZDenumvalue2HZDcodelist[103] = "greekGeodeticRefSystem1987"
HZDenumvalue2HZDcodelist[106] = "guam1963"
HZDenumvalue2HZDcodelist[104] = "gunongSegaraKalimantanIs"
HZDenumvalue2HZDcodelist[105] = "gunongSerindung"
HZDenumvalue2HZDcodelist[70] = "gux1AstroGuadacanalIs"
HZDenumvalue2HZDcodelist[66] = "guyanaCSG67"
HZDenumvalue2HZDcodelist[107] = "heratNorthAfganistan"
HZDenumvalue2HZDcodelist[108] = "hermannskogel"
HZDenumvalue2HZDcodelist[110] = "hjorsey1955Iceland"
HZDenumvalue2HZDcodelist[112] = "hongKong1929"
HZDenumvalue2HZDcodelist[111] = "hongKong1963HongKong"
HZDenumvalue2HZDcodelist[114] = "hungarian1972"
HZDenumvalue2HZDcodelist[113] = "huTzuShan"
HZDenumvalue2HZDcodelist[123] = "indian1954Thailand"
HZDenumvalue2HZDcodelist[126] = "indian1960ConSonIsland"
HZDenumvalue2HZDcodelist[125] = "indian1960Vietnam"
HZDenumvalue2HZDcodelist[128] = "indian1975Thailand"
HZDenumvalue2HZDcodelist[306] = "indian1975ThailandCycle1"
HZDenumvalue2HZDcodelist[119] = "indianBangladesh"
HZDenumvalue2HZDcodelist[120] = "indianIndiaNepal"
HZDenumvalue2HZDcodelist[121] = "indianPakistan"
HZDenumvalue2HZDcodelist[118] = "indianThailandVietnam"
HZDenumvalue2HZDcodelist[116] = "indonesian1974"
HZDenumvalue2HZDcodelist[129] = "ireland1965IrelandNorthern"
HZDenumvalue2HZDcodelist[130] = "ists061Astro1968GeorgiaIs"
HZDenumvalue2HZDcodelist[131] = "ists073Astro1969DiegoGar"
HZDenumvalue2HZDcodelist[132] = "johnstonIsland1961"
HZDenumvalue2HZDcodelist[133] = "kalianpurIndia"
HZDenumvalue2HZDcodelist[134] = "kandawalaSriLanka"
HZDenumvalue2HZDcodelist[136] = "kcs2SierraLeone"
HZDenumvalue2HZDcodelist[137] = "kerguelenIsland1949"
HZDenumvalue2HZDcodelist[135] = "kertau1948RevisedMalaysia"
HZDenumvalue2HZDcodelist[139] = "kkjFinland"
HZDenumvalue2HZDcodelist[138] = "koreanGeodeticSystem1995"
HZDenumvalue2HZDcodelist[140] = "kusaieAstro1951"
HZDenumvalue2HZDcodelist[141] = "kuwaitOilCompanyK28"
HZDenumvalue2HZDcodelist[142] = "lc5Astro1961CaymanBracIs"
HZDenumvalue2HZDcodelist[143] = "leigonGhana"
HZDenumvalue2HZDcodelist[144] = "liberia1964Liberia"
HZDenumvalue2HZDcodelist[145] = "lisbonCastelodiSaoJorge"
HZDenumvalue2HZDcodelist[146] = "localAstro"
HZDenumvalue2HZDcodelist[147] = "lomaQuintanaVenezuela"
HZDenumvalue2HZDcodelist[150] = "luzonMindanaoIsland"
HZDenumvalue2HZDcodelist[149] = "luzonPhilipinesNotMindanao"
HZDenumvalue2HZDcodelist[159] = "mahe1971MaheIsland"
HZDenumvalue2HZDcodelist[154] = "manokwariWestIrian"
HZDenumvalue2HZDcodelist[151] = "marcoAstroSalvageIslands"
HZDenumvalue2HZDcodelist[152] = "martiniqueFortDesaix"
HZDenumvalue2HZDcodelist[153] = "massawEritreaEthiopia"
HZDenumvalue2HZDcodelist[155] = "mayotteCombani"
HZDenumvalue2HZDcodelist[157] = "merchichMorocco"
HZDenumvalue2HZDcodelist[158] = "midwayAstro1961MidwayIs"
HZDenumvalue2HZDcodelist[161] = "minnaCameroon"
HZDenumvalue2HZDcodelist[162] = "minnaNigeria"
HZDenumvalue2HZDcodelist[46] = "modifiedBJZ54China"
HZDenumvalue2HZDcodelist[165] = "montjongLowe"
HZDenumvalue2HZDcodelist[34] = "montserratIslandAstro1958"
HZDenumvalue2HZDcodelist[156] = "mountDillonTobago"
HZDenumvalue2HZDcodelist[166] = "mPoralokoGabon"
HZDenumvalue2HZDcodelist[169] = "nahrwanMasirahIslandOman"
HZDenumvalue2HZDcodelist[171] = "nahrwanSaudiArabia"
HZDenumvalue2HZDcodelist[170] = "nahrwanUnitedArabEmirates"
HZDenumvalue2HZDcodelist[172] = "naparimaBwiTrinidadTobago"
HZDenumvalue2HZDcodelist[202] = "newFrenchZeroMeridianParis"
HZDenumvalue2HZDcodelist[-999999] = "noInformation"
HZDenumvalue2HZDcodelist[184] = "northAm1927Alaska"
HZDenumvalue2HZDcodelist[186] = "northAm1927Alberta"
HZDenumvalue2HZDcodelist[199] = "northAm1927AleutianE"
HZDenumvalue2HZDcodelist[200] = "northAm1927AleutianW"
HZDenumvalue2HZDcodelist[195] = "northAm1927Bahamas"
HZDenumvalue2HZDcodelist[185] = "northAm1927CanadMean"
HZDenumvalue2HZDcodelist[193] = "northAm1927CanalZone"
HZDenumvalue2HZDcodelist[194] = "northAm1927Caribbean"
HZDenumvalue2HZDcodelist[192] = "northAm1927CentAmer"
HZDenumvalue2HZDcodelist[183] = "northAm1927ConusMean"
HZDenumvalue2HZDcodelist[197] = "northAm1927Cuba"
HZDenumvalue2HZDcodelist[181] = "northAm1927EasternUs"
HZDenumvalue2HZDcodelist[198] = "northAm1927HayesPen"
HZDenumvalue2HZDcodelist[188] = "northAm1927Manitoba"
HZDenumvalue2HZDcodelist[191] = "northAm1927Mexico"
HZDenumvalue2HZDcodelist[187] = "northAm1927Newfound"
HZDenumvalue2HZDcodelist[189] = "northAm1927NwTerSaskat"
HZDenumvalue2HZDcodelist[196] = "northAm1927Salvador"
HZDenumvalue2HZDcodelist[182] = "northAm1927WesternUs"
HZDenumvalue2HZDcodelist[190] = "northAm1927Yukon"
HZDenumvalue2HZDcodelist[174] = "northAm1983AlaskaExAleut"
HZDenumvalue2HZDcodelist[178] = "northAm1983Aleutian"
HZDenumvalue2HZDcodelist[175] = "northAm1983Canada"
HZDenumvalue2HZDcodelist[176] = "northAm1983Conus"
HZDenumvalue2HZDcodelist[179] = "northAm1983Hawaii"
HZDenumvalue2HZDcodelist[177] = "northAm1983Mexico"
HZDenumvalue2HZDcodelist[204] = "northSahara1959"
HZDenumvalue2HZDcodelist[93] = "observMeteorologico1939"
HZDenumvalue2HZDcodelist[205] = "ocotopequeGuatemala"
HZDenumvalue2HZDcodelist[207] = "oldEgyptian"
HZDenumvalue2HZDcodelist[215] = "oldHawaiianHawaiiIsland"
HZDenumvalue2HZDcodelist[216] = "oldHawaiianKauaiIsland"
HZDenumvalue2HZDcodelist[217] = "oldHawaiianMauiIsland"
HZDenumvalue2HZDcodelist[219] = "oldHawaiianMeanValue"
HZDenumvalue2HZDcodelist[218] = "oldHawaiianOahuIsland"
HZDenumvalue2HZDcodelist[92] = "oman"
HZDenumvalue2HZDcodelist[209] = "ordnanceSurvGB1936England"
HZDenumvalue2HZDcodelist[213] = "ordnanceSurvGB1936MeanVal"
HZDenumvalue2HZDcodelist[211] = "ordnanceSurvGB1936ScotShet"
HZDenumvalue2HZDcodelist[210] = "ordnanceSurvGB1936ScotWale"
HZDenumvalue2HZDcodelist[212] = "ordnanceSurvGB1936Wales"
HZDenumvalue2HZDcodelist[220] = "osloObservatoryOld"
HZDenumvalue2HZDcodelist[999] = "other"
HZDenumvalue2HZDcodelist[221] = "padangBaseWestEnd"
HZDenumvalue2HZDcodelist[222] = "padangBaseWestEndZeroMerid"
HZDenumvalue2HZDcodelist[223] = "palestine1928"
HZDenumvalue2HZDcodelist[227] = "picoDeLasNievesCanaryIs"
HZDenumvalue2HZDcodelist[226] = "pitcairnAstro1967"
HZDenumvalue2HZDcodelist[239] = "point58MeanSolution"
HZDenumvalue2HZDcodelist[240] = "pointeNoire1948"
HZDenumvalue2HZDcodelist[224] = "potsdamHelmertturmGermany"
HZDenumvalue2HZDcodelist[230] = "provSouthAm1956Bolivia"
HZDenumvalue2HZDcodelist[233] = "provSouthAm1956Columbia"
HZDenumvalue2HZDcodelist[234] = "provSouthAm1956Ecuador"
HZDenumvalue2HZDcodelist[235] = "provSouthAm1956Guyana"
HZDenumvalue2HZDcodelist[238] = "provSouthAm1956MeanValue"
HZDenumvalue2HZDcodelist[231] = "provSouthAm1956NChile"
HZDenumvalue2HZDcodelist[236] = "provSouthAm1956Peru"
HZDenumvalue2HZDcodelist[232] = "provSouthAm1956SChile"
HZDenumvalue2HZDcodelist[237] = "provSouthAm1956Venezuela"
HZDenumvalue2HZDcodelist[109] = "provSouthChilean1963"
HZDenumvalue2HZDcodelist[242] = "puertoRicoVirginIslands"
HZDenumvalue2HZDcodelist[313] = "pulkovo1942Albania"
HZDenumvalue2HZDcodelist[310] = "pulkovo1942Czechoslovakia"
HZDenumvalue2HZDcodelist[308] = "pulkovo1942Hungary"
HZDenumvalue2HZDcodelist[312] = "pulkovo1942Kazakhstan"
HZDenumvalue2HZDcodelist[311] = "pulkovo1942Latvia"
HZDenumvalue2HZDcodelist[309] = "pulkovo1942Poland"
HZDenumvalue2HZDcodelist[314] = "pulkovo1942Romania"
HZDenumvalue2HZDcodelist[241] = "pulkovo1942Russia"
HZDenumvalue2HZDcodelist[243] = "qatarNationalQatar"
HZDenumvalue2HZDcodelist[244] = "qornoqSouthGreenland"
HZDenumvalue2HZDcodelist[245] = "rauenbergBerlinGermany"
HZDenumvalue2HZDcodelist[246] = "reconTriangulationMorocco"
HZDenumvalue2HZDcodelist[247] = "reunion1947"
HZDenumvalue2HZDcodelist[201] = "revisedNahrwan"
HZDenumvalue2HZDcodelist[163] = "rome1940"
HZDenumvalue2HZDcodelist[164] = "rome1940ZeroMeridianRome"
HZDenumvalue2HZDcodelist[248] = "rt90StockholmSweden"
HZDenumvalue2HZDcodelist[251] = "sainteAnneI1984Guadeloupe"
HZDenumvalue2HZDcodelist[249] = "santoDos1965EspiritoSanto"
HZDenumvalue2HZDcodelist[266] = "saoBrazSaoMiguelAzores"
HZDenumvalue2HZDcodelist[267] = "sapperHill1943EastFalkland"
HZDenumvalue2HZDcodelist[268] = "schwarzeckNamibia"
HZDenumvalue2HZDcodelist[228] = "seBasePortoSanto"
HZDenumvalue2HZDcodelist[271] = "selvagemGrande1938Salvage"
HZDenumvalue2HZDcodelist[273] = "sierraLeone1960"
HZDenumvalue2HZDcodelist[307] = "sirgas"
HZDenumvalue2HZDcodelist[59] = "sJtsk"
HZDenumvalue2HZDcodelist[250] = "southAfricanSouthAfrica"
HZDenumvalue2HZDcodelist[253] = "southAmerican1969Argentina"
HZDenumvalue2HZDcodelist[262] = "southAmerican1969BaltraIs"
HZDenumvalue2HZDcodelist[254] = "southAmerican1969Bolivia"
HZDenumvalue2HZDcodelist[255] = "southAmerican1969Brazil"
HZDenumvalue2HZDcodelist[256] = "southAmerican1969Chile"
HZDenumvalue2HZDcodelist[257] = "southAmerican1969Columbia"
HZDenumvalue2HZDcodelist[258] = "southAmerican1969Ecuador"
HZDenumvalue2HZDcodelist[259] = "southAmerican1969Guyana"
HZDenumvalue2HZDcodelist[265] = "southAmerican1969MeanValue"
HZDenumvalue2HZDcodelist[260] = "southAmerican1969Paraguay"
HZDenumvalue2HZDcodelist[261] = "southAmerican1969Peru"
HZDenumvalue2HZDcodelist[263] = "southAmerican1969Trinidad"
HZDenumvalue2HZDcodelist[264] = "southAmerican1969Venezuela"
HZDenumvalue2HZDcodelist[274] = "southAsiaSingapore"
HZDenumvalue2HZDcodelist[269] = "sovietGeodeticSystem1985"
HZDenumvalue2HZDcodelist[270] = "sovietGeodeticSystem1990"
HZDenumvalue2HZDcodelist[277] = "stockholm1938Sweden"
HZDenumvalue2HZDcodelist[276] = "stPierreetMiquelon1950"
HZDenumvalue2HZDcodelist[278] = "sydneyObservatoryNewSouth"
HZDenumvalue2HZDcodelist[280] = "tananariveObs1925ZerMerPar"
HZDenumvalue2HZDcodelist[279] = "tananariveObservatory1925"
HZDenumvalue2HZDcodelist[282] = "timbalai1948BruneiMalaysia"
HZDenumvalue2HZDcodelist[283] = "timbalai1968"
HZDenumvalue2HZDcodelist[285] = "tokyoJapan"
HZDenumvalue2HZDcodelist[286] = "tokyoKorea"
HZDenumvalue2HZDcodelist[315] = "tokyoKoreaCycle1"
HZDenumvalue2HZDcodelist[288] = "tokyoMeanValue"
HZDenumvalue2HZDcodelist[287] = "tokyoOkinawa"
HZDenumvalue2HZDcodelist[289] = "trinidad1903"
HZDenumvalue2HZDcodelist[281] = "tristanAstro1968Cunha"
HZDenumvalue2HZDcodelist[167] = "vitiLevu1916FijiIslands"
HZDenumvalue2HZDcodelist[292] = "voirol1875"
HZDenumvalue2HZDcodelist[293] = "voirol1875ZeroMeridParis"
HZDenumvalue2HZDcodelist[294] = "voirol1960Algeria"
HZDenumvalue2HZDcodelist[295] = "voirol1960ZeroMeridParis"
HZDenumvalue2HZDcodelist[73] = "wakeEniwetok1960MarshallIs"
HZDenumvalue2HZDcodelist[296] = "wakeIslandAstro1952"
HZDenumvalue2HZDcodelist[297] = "worldGeodeticSystem1960"
HZDenumvalue2HZDcodelist[298] = "worldGeodeticSystem1966"
HZDenumvalue2HZDcodelist[299] = "worldGeodeticSystem1972"
HZDenumvalue2HZDcodelist[300] = "worldGeodeticSystem1984"
HZDenumvalue2HZDcodelist[301] = "yacareUruguay"
HZDenumvalue2HZDcodelist[302] = "zanderijSurinam"
HZDenumvalue2HZDcodelist[998] = "notApplicable"

VDTenumvalue2VDTcodelist[6] = "groundLevel"
VDTenumvalue2VDTcodelist[3] = "meanSeaLevel"
VDTenumvalue2VDTcodelist[4] = "navd88"
VDTenumvalue2VDTcodelist[5] = "ngvd29"
VDTenumvalue2VDTcodelist[-999999] = "noInformation"
VDTenumvalue2VDTcodelist[999] = "other"
VDTenumvalue2VDTcodelist[998] = "notApplicable"
VDTenumvalue2VDTcodelist[1] = "wgs84"
VDTenumvalue2VDTcodelist[7] = "wgs84Egm08"
VDTenumvalue2VDTcodelist[2] = "wgs84Egm96"

ZI001_SRTenumvalue2ZI001_SRTcodelist[159] = "commercial"
ZI001_SRTenumvalue2ZI001_SRTcodelist[166] = "deLormeDigitalAtlasEarth"
ZI001_SRTenumvalue2ZI001_SRTcodelist[26] = "gpsBasedFieldCollect"
ZI001_SRTenumvalue2ZI001_SRTcodelist[28] = "ikonosImagery"
ZI001_SRTenumvalue2ZI001_SRTcodelist[30] = "imageryUnspecified"
ZI001_SRTenumvalue2ZI001_SRTcodelist[167] = "militaryMapData"
ZI001_SRTenumvalue2ZI001_SRTcodelist[108] = "navteqData"
ZI001_SRTenumvalue2ZI001_SRTcodelist[2] = "ngaAutoAirFacInfoFile"
ZI001_SRTenumvalue2ZI001_SRTcodelist[7] = "ngaControlledImageBase1"
ZI001_SRTenumvalue2ZI001_SRTcodelist[165] = "ngaDigitalAirFltInfoFile"
ZI001_SRTenumvalue2ZI001_SRTcodelist[10] = "ngaDigitalNauticalChart"
ZI001_SRTenumvalue2ZI001_SRTcodelist[21] = "ngaDigitalVertObstruction"
ZI001_SRTenumvalue2ZI001_SRTcodelist[22] = "ngaFoundationFeatureData"
ZI001_SRTenumvalue2ZI001_SRTcodelist[25] = "ngaGeoNames"
ZI001_SRTenumvalue2ZI001_SRTcodelist[31] = "ngaInterimTerrainData"
ZI001_SRTenumvalue2ZI001_SRTcodelist[32] = "ngaInterimVectorData"
ZI001_SRTenumvalue2ZI001_SRTcodelist[170] = "ngaStereoAirfieldCollect"
ZI001_SRTenumvalue2ZI001_SRTcodelist[60] = "ngaUrbanVectorMap"
ZI001_SRTenumvalue2ZI001_SRTcodelist[61] = "ngaVectorInterimTerrain"
ZI001_SRTenumvalue2ZI001_SRTcodelist[64] = "ngaVectorMap2"
ZI001_SRTenumvalue2ZI001_SRTcodelist[-999999] = "noInformation"
ZI001_SRTenumvalue2ZI001_SRTcodelist[168] = "nonMilitaryMap"
ZI001_SRTenumvalue2ZI001_SRTcodelist[160] = "openSource"
ZI001_SRTenumvalue2ZI001_SRTcodelist[169] = "operationsData"
ZI001_SRTenumvalue2ZI001_SRTcodelist[998] = "notApplicable"
ZI001_SRTenumvalue2ZI001_SRTcodelist[999] = "other"
ZI001_SRTenumvalue2ZI001_SRTcodelist[9] = "quickBirdImagery"
ZI001_SRTenumvalue2ZI001_SRTcodelist[171] = "tomTomData"
ZI001_SRTenumvalue2ZI001_SRTcodelist[43] = "usModernizedIntegratedDB"
ZI001_SRTenumvalue2ZI001_SRTcodelist[29] = "usNtmImagery"

ZI001_VSCenumvalue2ZI001_VSCcodelist[1] = "interpolatedDted1"
ZI001_VSCenumvalue2ZI001_VSCcodelist[2] = "interpolatedDted2"
ZI001_VSCenumvalue2ZI001_VSCcodelist[3] = "noElevations"
ZI001_VSCenumvalue2ZI001_VSCcodelist[-999999] = "noInformation"
ZI001_VSCenumvalue2ZI001_VSCcodelist[999] = "other"
ZI001_VSCenumvalue2ZI001_VSCcodelist[998] = "notApplicable"
ZI001_VSCenumvalue2ZI001_VSCcodelist[4] = "reflectiveSurface"
ZI001_VSCenumvalue2ZI001_VSCcodelist[5] = "stereoscopicImagery"
ZI001_VSCenumvalue2ZI001_VSCcodelist[6] = "tinData"

RCGenumvalue2RCGcodelist[69] = 'armedForcesGeneralHqQatar'
RCGenumvalue2RCGcodelist[56] = 'armyAustralia'
RCGenumvalue2RCGcodelist[44] = 'armyGeoAgencyNetherlands'
RCGenumvalue2RCGcodelist[51] = 'armyGeographicCentreSpain'
RCGenumvalue2RCGcodelist[48] = 'armyGeoInstitutePortugal'
RCGenumvalue2RCGcodelist[37] = 'bundeswehrGeoinfoOffice'
RCGenumvalue2RCGcodelist[33] = 'defenceAcqLogOrgDenmark'
RCGenumvalue2RCGcodelist[54] = 'defenceGeoCentreIntColGrp'
RCGenumvalue2RCGcodelist[28] = 'defenceImageryGeoOrg'
RCGenumvalue2RCGcodelist[40] = 'defenseInfoSecurityItaly'
RCGenumvalue2RCGcodelist[78] = 'direcServGeoMilParaguay'
RCGenumvalue2RCGcodelist[58] = 'directGeoInfoSouthAfrica'
RCGenumvalue2RCGcodelist[71] = 'directorateSurveyKuwait'
RCGenumvalue2RCGcodelist[90] = 'diretoriaServicoGeoBrazil'
RCGenumvalue2RCGcodelist[86] = 'dirGenRegistrosCatastroGeo'
RCGenumvalue2RCGcodelist[53] = 'generalCommandMapping'
RCGenumvalue2RCGcodelist[41] = 'geoInfoAgencyLatvia'
RCGenumvalue2RCGcodelist[45] = 'geoIntelOrgNewZealand'
RCGenumvalue2RCGcodelist[32] = 'geoServCzechArmedForces'
RCGenumvalue2RCGcodelist[29] = 'geoServiceBelgium'
RCGenumvalue2RCGcodelist[38] = 'hellenicMilitaryGeoServ'
RCGenumvalue2RCGcodelist[61] = 'imagerySupportGrpSingapore'
RCGenumvalue2RCGcodelist[73] = 'infoNetworkSecurityAgency'
RCGenumvalue2RCGcodelist[88] = 'instGeoNacTommyGuardia'
RCGenumvalue2RCGcodelist[84] = 'institutoCartoMilitarDomRp'
RCGenumvalue2RCGcodelist[80] = 'institutoGeoAgustinCodazzi'
RCGenumvalue2RCGcodelist[81] = 'institutoGeoCatastroNacl'
RCGenumvalue2RCGcodelist[76] = 'institutoGeoMilitarChile'
RCGenumvalue2RCGcodelist[87] = 'institutoGeoMilitarEcuador'
RCGenumvalue2RCGcodelist[79] = 'institutoGeoNacionalPeru'
RCGenumvalue2RCGcodelist[89] = 'institutoGeoNaclArgentina'
RCGenumvalue2RCGcodelist[82] = 'institutoGeoNaclGuatemala'
RCGenumvalue2RCGcodelist[75] = 'institutoNaclEstadisticaGeo'
RCGenumvalue2RCGcodelist[85] = 'institutoNicaragEstudiosTrr'
RCGenumvalue2RCGcodelist[36] = 'jointGeoBureauFrance'
RCGenumvalue2RCGcodelist[59] = 'koreanDefenseIntelAgency'
RCGenumvalue2RCGcodelist[31] = 'mapChartEstablishment'
RCGenumvalue2RCGcodelist[39] = 'mappingServiceHungary'
RCGenumvalue2RCGcodelist[63] = 'materielProdCenterTaiwan'
RCGenumvalue2RCGcodelist[47] = 'milGeogDivisionPoland'
RCGenumvalue2RCGcodelist[34] = 'milGeoGroupEstonia'
RCGenumvalue2RCGcodelist[46] = 'milGeoServiceNorway'
RCGenumvalue2RCGcodelist[57] = 'militaryGeoDivisionCroatia'
RCGenumvalue2RCGcodelist[72] = 'militarySurveyDeptUAE'
RCGenumvalue2RCGcodelist[42] = 'milMapCentreLithuania'
RCGenumvalue2RCGcodelist[49] = 'milTopoDirectRomania'
RCGenumvalue2RCGcodelist[30] = 'milTopoServiceBulgaria'
RCGenumvalue2RCGcodelist[65] = 'ministryConstructUrbanDev'
RCGenumvalue2RCGcodelist[64] = 'ministryDefenseJapan'
RCGenumvalue2RCGcodelist[70] = 'ministryDefenseSaudiArabia'
RCGenumvalue2RCGcodelist[74] = 'ministryStateDefenseKenya'
RCGenumvalue2RCGcodelist[43] = 'natArmyTopoServiceMoldova'
RCGenumvalue2RCGcodelist[60] = 'natIntelServiceSouthKorea'
RCGenumvalue2RCGcodelist[68] = 'nationalSurveyAuthorityOman'
RCGenumvalue2RCGcodelist[66] = 'natMappingResourceInfoAuth'
RCGenumvalue2RCGcodelist[62] = 'natSecurityBureauTaiwan'
RCGenumvalue2RCGcodelist[-999999] = 'noInformation'
RCGenumvalue2RCGcodelist[998] = 'notApplicable'
RCGenumvalue2RCGcodelist[999] = 'other'
RCGenumvalue2RCGcodelist[67] = 'royalJordanianGeoCentre'
RCGenumvalue2RCGcodelist[83] = 'servicioGeoMilitarGuatemala'
RCGenumvalue2RCGcodelist[77] = 'servicioGeoMilitarUruguay'
RCGenumvalue2RCGcodelist[52] = 'swedishArmedForces'
RCGenumvalue2RCGcodelist[50] = 'topoInstituteSlovakia'
RCGenumvalue2RCGcodelist[35] = 'topoServiceFinland'
RCGenumvalue2RCGcodelist[6] = 'usAfricaCommand'
RCGenumvalue2RCGcodelist[3] = 'usAirForce'
RCGenumvalue2RCGcodelist[1] = 'usArmy'
RCGenumvalue2RCGcodelist[55] = 'usArmyGeospatialCenter'
RCGenumvalue2RCGcodelist[7] = 'usCentralCommand'
RCGenumvalue2RCGcodelist[16] = 'usCentralIntelAgency'
RCGenumvalue2RCGcodelist[5] = 'usCoastGuard'
RCGenumvalue2RCGcodelist[17] = 'usDefenseIntelAgency'
RCGenumvalue2RCGcodelist[23] = 'usDeptOfEnergy'
RCGenumvalue2RCGcodelist[22] = 'usDeptOfHomelandSecurity'
RCGenumvalue2RCGcodelist[21] = 'usDeptOfState'
RCGenumvalue2RCGcodelist[8] = 'usEuropeanCommand'
RCGenumvalue2RCGcodelist[24] = 'usFedBurOfInvestigation'
RCGenumvalue2RCGcodelist[25] = 'usGeologicalSurvey'
RCGenumvalue2RCGcodelist[9] = 'usJointForcesCommand'
RCGenumvalue2RCGcodelist[4] = 'usMarineCorps'
RCGenumvalue2RCGcodelist[26] = 'usNatCivilAppsProgram'
RCGenumvalue2RCGcodelist[19] = 'usNationalGeoIntelAgency'
RCGenumvalue2RCGcodelist[20] = 'usNationalReconnOffice'
RCGenumvalue2RCGcodelist[18] = 'usNationalSecurityAgency'
RCGenumvalue2RCGcodelist[27] = 'usNatOceanAtmosAdmin'
RCGenumvalue2RCGcodelist[2] = 'usNavy'
RCGenumvalue2RCGcodelist[10] = 'usNorthernCommand'
RCGenumvalue2RCGcodelist[11] = 'usPacificCommand'
RCGenumvalue2RCGcodelist[13] = 'usSouthernCommand'
RCGenumvalue2RCGcodelist[12] = 'usSpecialOperCommand'
RCGenumvalue2RCGcodelist[14] = 'usStrategicCommand'
RCGenumvalue2RCGcodelist[15] = 'usTransportationCommand'

############################# Functions begin here ##################################################

# Reports the name of the dictionary if this source and destination
# attribute are represented by a codelist to codelist mapping
def get_codelist2codelistmapping_name(srcattr, destattr):
    keyval = srcattr + "2" + destattr
    if keyval in codelist2codelist_mappings:
        return codelist2codelist_mappings[keyval]
    else:
        return None

# Reports the name of the dictionary if this source and destination
# attribute are represented by a enumerated value to codelist
def get_enumvalue2codelistmapping_name(srcattr, destattr):
    keyval = srcattr + "2" + destattr
    if keyval in enumvalue2codelist_mappings:
        return enumvalue2codelist_mappings[keyval]
    else:
        return None

# Reports the name of the dictionary if this source and destination
# attribute are represented by a codelist to enumerated value mapping
def get_codelist2enumvalue_mapping_name(srcattr, destattr):
    keyval = srcattr + "2" + destattr
    if keyval in codelist2enumvalue_mappings:
        return codelist2enumvalue_mappings[keyval]
    else:
        return None

# Return a mapped value for a codelist to codelist, given a
# source attribute and destination attribute and source value
def get_codelist2codelistmapping_value(srcattr, destattr, srcvalue):
    keyval = srcattr + "2" + destattr
    if keyval in codelist2codelist_mappings:
        if keyval == "GE42IC2":
            if srcvalue in GE4codelist2IC2codelist:
                return GE4codelist2IC2codelist[srcvalue]
            else:
                return None
        elif keyval == "IC22GE4":
            if srcvalue in IC2codelist2GE4codelist:
                return IC2codelist2GE4codelist[srcvalue]
            else:
                return None
    return None


# Return a mapped value for a enumerated value to codelist,
# given a source attribute and destination attribute and source value
def get_enumvalue2codelistmapping_value(srcattr, destattr, srcvalue):
    keyval = srcattr + "2" + destattr
    if keyval in enumvalue2codelist_mappings:
        if keyval == "CPS2CPS":
            if srcvalue in CPSenumvalue2CPScodelist:
                return CPSenumvalue2CPScodelist[srcvalue]
            else:
                return None
        elif keyval == "ETS2ETS":
            if srcvalue in ETSenumvalue2ETScodelist:
                return ETSenumvalue2ETScodelist[srcvalue]
            else:
                return None
        elif keyval == "HZD2HZD":
            if srcvalue in HZDenumvalue2HZDcodelist:
                return HZDenumvalue2HZDcodelist[srcvalue]
            else:
                return None
        elif keyval == "VDT2VDT":
            if srcvalue in VDTenumvalue2VDTcodelist:
                return VDTenumvalue2VDTcodelist[srcvalue]
            else:
                return None
        elif keyval == "ZI001_SRT2ZI001_SRT":
            if srcvalue in ZI001_SRTenumvalue2ZI001_SRTcodelist:
                return ZI001_SRTenumvalue2ZI001_SRTcodelist[srcvalue]
            else:
                return None
        elif keyval == "ZI001_VSC2ZI001_VSC":
            if srcvalue in ZI001_VSCenumvalue2ZI001_VSCcodelist:
                return ZI001_VSCenumvalue2ZI001_VSCcodelist[srcvalue]
            else:
                return None
    return None

# Return a mapped value for a codelist to enumerated value, given a
# source attribute and destination attribute and source value
def get_codelist2enumvaluemapping_value(srcattr, destattr, srcvalue):
    keyval = srcattr + "2" + destattr
    if keyval in codelist2enumvalue_mappings:
        if keyval == "CPS2CPS":
            if srcvalue in CPScodelist2CPSenumvalue:
                return CPScodelist2CPSenumvalue[srcvalue]
            else:
                return None
        elif keyval == "ETS2ETS":
            if srcvalue in ETScodelist2ETSenumvalue:
                return ETScodelist2ETSenumvalue[srcvalue]
            else:
                return None
        elif keyval == "HZD2HZD":
            if srcvalue in HZDcodelist2HZDenumvalue:
                return HZDcodelist2HZDenumvalue[srcvalue]
            else:
                return None
        elif keyval == "VDT2VDT":
            if srcvalue in VDTcodelist2VDTenumvalue:
                return VDTcodelist2VDTenumvalue[srcvalue]
            else:
                return None
        elif keyval == "ZI001_SRT2ZI001_SRT":
            if srcvalue in ZI001_SRTcodelist2ZI001_SRTenumvalue:
                return ZI001_SRTcodelist2ZI001_SRTenumvalue[srcvalue]
            else:
                return None
        elif keyval == "ZI001_VSC2ZI001_VSC":
            if srcvalue in ZI001_VSCcodelist2ZI001_VSCenumvalue:
                return ZI001_VSCcodelist2ZI001_VSCenumvalue[srcvalue]
            else:
                return None
    return None


# Examples of use
#get_codelist2codelistmapping_value("IC2","GE4","BEL")
# returns 'ge:GENC:3:1-2:BEL'
#
#get_codelist2codelistmapping_value("GE4","IC2", "ge:GENC:3:1-2:LKA")
# returns 'LKA'
#
#get_enumvalue2codelistmapping_value("VDT", "VDT", "4")
# returns 'navd88'
#
#get_enumvalue2codelistmapping_value("ETS", "ETS", "999")
# returns 'other'
#
#get_enumvalue2codelistmapping_value("CPS", "CPS", "93")   # out of bounds value
# returns None


