﻿
""" 
 ************************************************************************************************
 **                                                                                            **
 **  File: GGDM30_2_GGDM22_TranslateFeaturesandFields.py                                       **
 **  Copyright (c) June 2017 by Leidos                                                          **
 **  Produced under U.S. Government contract W5J9CQ-12-D-0004  Task Order: 062 and 074          **
 **  As per DFARS, the U.S. Government is granted unlimited rights to use this work            **
 **  in any manner and for any purpose.                                                        **
 **                                                                                            **
 **  Summary:   This file provides the feature class / feature / and field specific            **
 **             mappings and where a translation is involved, that is listed as well.          **
 **             The information in this file is specific to translations from:                 **
 **                 GGDM 3.0 Composite to GGDM 2.2 Composite                                    **
 **             Notes:                                                                         **
 **                 Be sure MEM and OTH transforms are done last in each feature class.        **
 **                                                                                            **
 **  Developed by Leidos, Inc., High Resolution ISR Systems Division, Geospatial Programs       **
 **                                                                                            **
 **  Development History:                                                                      **
 **  June 2017 / Annette Janett Filer                                                           **
 **                                                                                            **
 **                                                                                            **
 ************************************************************************************************
"""


import sys
import os
import copy



current_include_source = "GGDM 3.0"
current_include_target = "GGDM 2.2"

common_fields = [
    ('FCSubtype', 'FCSubtype', 'transform_FCSubtype'),
    ('ObjectID', None, None), 
    ('GLOBALID', None, None)  
]

common_geom_fields =  [
    ('FCSubtype', 'FCSubtype', 'transform_FCSubtype'),
    ('ObjectID', None, None), 
    ('GLOBALID', None, None), 
    ('SHAPE@', 'SHAPE@', None)
    ]

common_Pnt_fields = []

common_Crv_fields = [
    ('SHAPE@Length', 'SHAPE@Length', None)
    ]

common_Srf_fields = [
    ('SHAPE@Length', 'SHAPE@Length', None),
    ('SHAPE@Area', 'SHAPE@Area', None)
    ]

common_Tbl_fields = []

# ('GLOBALID', 'GLOBALID', None)
common_fields_ignore = ['shape@', 'shape@length', 'shape@area', 'fcsubtype', 'objectid', 'globalid']


# A dictionary of fields and values for default restriction information item
RestrictionInfoTargetDefaultFieldValues = {
    'CCN':'No Information',
    'CDR':'No Information',
    'F_CODE':'ZI002',
    'SAX_RY2':'noInformation',
    'SAX_RS1':'No Information',
    'SAX_RS2':'No Information',
    'SAX_RX9':'No Information',
    'SAX_RS4':'noInformation',
    'SAX_RS5':'No Information',
    'SAX_RS6':'noInformation',
    'SAX_RS8':'No Information',
    'SAX_RS9':'No Information',
    'SAX_RY0':'No Information',
    'SAX_RX1':'noInformation',
    'SAX_RX2':'noInformation',
    'SAX_RY1':'noInformation',
    'SAX_RX5':'noInformation',
    'SAX_RX7':'noInformation',
    'SAX_RX6':'noInformation',
    'UFI':'A9593791-4AE9-4180-8E1E-9CB3D239DEE5'
}

RestrictionInfoTblFields = [
    ('CCN','CCN',None),
    ('CDR','CDR',None),
    ('SAX_RS1','SAX_RS1',None),
    ('SAX_RS2','SAX_RS2',None),
    ('SAX_RS4','SAX_RS4',None),
    ('SAX_RS5','SAX_RS5',None),
    ('SAX_RS6','SAX_RS6',None),
    ('SAX_RS8','SAX_RS8',None),
    ('SAX_RS9','SAX_RS9',None),
    ('SAX_RX1','SAX_RX1',None),
    ('SAX_RX2','SAX_RX2',None),
    ('SAX_RX5','SAX_RX5',None),
    ('SAX_RX6','SAX_RX6',None),
    ('SAX_RX7','SAX_RX7',None),
    ('SAX_RX9','SAX_RX9',None),
    ('SAX_RY0','SAX_RY0',None),
    ('SAX_RY1','SAX_RY1',None),
    ('SAX_RY2','SAX_RY2',None),
    (None,'UFI','transform_placeholder_return_None'),
    (None,'F_CODE','transform_placeholder_return_None'),
    ('SAX_RX8',None,None),
    ('SAX_RS3',None,None)
]

EntityCollectionTargetDefaultFieldValues = {
    'FCSubtype':132721,
    'AHA':-999999,
    'AVA':-999999,
    'DQS':'No Information',
    'EQS':-999999,
    'EVA':-999999,
    'F_CODE':'ZI039',
    'HVA':-999999,
    'MDE':'noInformation',
    'OTH':'noInformation',
    'RCG':-999999,
    'SCVN':'No Information',
    'UFI':'noInformation',
    'ZI001_SDP':'No Information',
    'ZI001_SPS':-999999,
    'ZI001_VSC':-999999,
    'ZI001_VSD':'noInformation',
    'ZI001_VSN':'No Information',
    'ZI004_PRE':'No Information'
    }

EntityCollectionFields = [
    ('F_CODE','F_CODE',None),           # It is important that F_CODE be first here
    ('FCSubtype', 'FCSubtype', 'transform_FCSubtype'),
    ('SHAPE@', 'SHAPE@', None),
    ('SHAPE@Length', 'SHAPE@Length', None),
    ('SHAPE@Area', 'SHAPE@Area', None),
    ('AHA','AHA', 'transform_set_EntityCollection_field_to_default'),
    ('AVA','AVA','transform_set_EntityCollection_field_to_default'),
    ('DQS','DQS','transform_set_EntityCollection_field_to_default'),
    ('EQS','EQS','transform_set_EntityCollection_field_to_default'),
    ('EVA','EVA','transform_set_EntityCollection_field_to_default'),
    ('HVA','HVA','transform_set_EntityCollection_field_to_default'),
    ('MDE','MDE','transform_set_EntityCollection_field_to_default'),
    ('RCG','RCG','transform_set_EntityCollection_field_to_default'),
    ('SCVN','SCVN','transform_set_schemaversion'),
    ('UFI','UFI',None),
    ('ZI001_SDP','ZI001_SDP',None),
    #('ZI001_SDV','ZI001_SDV',None),
    #('ZI001_SRT','ZI001_SRT','transformZI001_SRTfromcodelisttoenum'),
    ('ZI001_SPS','ZI001_SPS',None),
    ('ZI001_VSC','ZI001_VSC','transformZI001_VSCfromenumtocodelist'),
    ('ZI001_VSD','ZI001_VSD',None),
    ('ZI001_VSN','ZI001_VSN',None),
    ('ZI004_PRE','ZI004_PRE',None),
    ('OTH','OTH','transformMoveOTHOnlyIfMetaAttribute')
    ]


# Many of these are not used, they will be filtered out by the code that checks
# to see if the field is present.
EntityCollectionTargetFields = [
    ('FCSubtype', 'FCSubtype', 'transform_FCSubtype'),
    ('SHAPE@', 'SHAPE@', None),
    ('SHAPE@Length', 'SHAPE@Length', None),
    ('SHAPE@Area', 'SHAPE@Area', None),
    ('AHA','AHA', 'transform_set_EntityCollection_field_to_default'),
    ('AVA','AVA','transform_set_EntityCollection_field_to_default'),
    ('DQS','DQS','transform_set_EntityCollection_field_to_default'),
    ('EQS','EQS','transform_set_EntityCollection_field_to_default'),
    ('EVA','EVA','transform_set_EntityCollection_field_to_default'),
    ('F_CODE','F_CODE',None),
    ('HVA','HVA','transform_set_EntityCollection_field_to_default'),
    ('MDE','MDE','transform_set_EntityCollection_field_to_default'),
    ('RCG','RCG','transform_set_EntityCollection_field_to_default'),
    ('SCVN','SCVN','transform_set_schemaversion'),
    ('UFI','UFI',None),
    ('ZI001_SDP','ZI001_SSN',None),        # same source to two different target
    ('ZI001_SDP','ZI001_NSN',None),        # same source to two different target
    ('ZI001_SPS','ZI001_SPS',None),
    ('ZI001_VSC','ZI001_VSC','transformZI001_VSCfromenumtocodelist'),
    ('ZI001_VSD','ZI001_VSD',None),
    ('ZI001_VSN','ZI001_VSN',None),
    ('ZI004_PRE','ZI004_PRE',None),
    (None,'ZI001_NSD','transform_ZI001_NSD'),
    (None,'ZI001_NSP','transform_ZI001_NSP'),
    (None,'ZI001_SSD','transform_ZI001_SSD'),
    (None,'ZI001_SSY','transform_ZI001_SSY'),
    ('OTH','OTH','transformMoveOTHOnlyIfMetaAttribute')
    ]

RestrictionInfoMetaConvertSubsetFields = [
    ('CCN','ZI002_CCN',None),
    ('CDR','ZI002_CDR',None)
    ]

# ---------------- Generated data

#  group translations - CommonTranslationGroup
CommonTranslationGroup = [ 
    ('ZI004_RCG','ZI004_RCG','transformZI004_RCGenumeration2ZI004_RCGcodelist'), 
    ('ZSAX_RS0','ZSAX_RS0',None), 
    ('ZSAX_RX3','ZSAX_RX3',None), 
    ('ZSAX_RX4','ZSAX_RX4',None),
    ('ZI006_MEM','ZI006_MEM','transform_MEM'), 
    ('OTH','OTH','transform_OTH') 
]

#  group translations - EntityCollectionOnFeature
EntityCollectionOnFeature = [ 
]

#  group translations - RestrictionInfoTDSGroup
RestrictionInfoTDSGroup = [ 
    (None,'ZI002_CCN','transform_ZI002_CCN'), 
    (None,'ZI002_CDR','transform_ZI002_CDR')
]

EntityCollectionFCSubsetFields = []
RestrictionInfoFCSubsetFields = []
common_metadata_translate_fields = CommonTranslationGroup

# ResourceSrf field translations
ResourceSrfFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Srf_fields) + [ \
    ('AHA','AHA',None),
    ('AVA','AVA',None),
    ('CID','CID',None),
    ('DQS','DQS',None),
    ('ETZ','ETZ',None),
    ('EVA','EVA',None),
    ('F_CODE','F_CODE',None),
    ('FURL','FURL','transform_combine_FURL'),
    ('HVA','HVA',None),
    ('MDE','MDE',None),
    ('SCVN','SCVN',None),
    ('URI','URI',None),
    ('ZI020_GE4','ZI020_GE4',None),
    ('ZI020_GE42','ZI020_GE42',None),
    ('ZI020_GE43','ZI020_GE43',None),
    ('ZI020_GE44','ZI020_GE44',None),
    ('CPS','CPS','transformCPSenumeration2CPScodelist'),
    ('ETS','ETS','transformETSenumeration2ETScodelist'),
    ('HZD','HZD','transformHZDenumeration2HZDcodelist'),
    ('MEM','MEM','transform_MEM'),
    ('EQS',None,None),
    ('RTL',None,None),
    (None,'EQC','transformEQSinteger2EQCcodelist'),
    ('RCG','RCG','transformRCGenumeration2RCGcodelist'),
    ('VDT','VDT','transformVDTenumeration2VDTcodelist'),
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# ResourceTbl field translations
ResourceTblFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Tbl_fields) + [ \
    ('AHA','AHA',None),
    ('AVA','AVA',None),
    ('CID','CID',None),
    ('DQS','DQS',None),
    ('ETZ','ETZ',None),
    ('EVA','EVA',None),
    ('F_CODE','F_CODE',None),
    ('FURL','FURL','transform_combine_FURL'),
    ('HVA','HVA',None),
    ('MDE','MDE',None),
    ('SCVN','SCVN',None),
    ('URI','URI',None),
    ('ZI020_GE4','ZI020_GE4',None),
    ('ZI020_GE42','ZI020_GE42',None),
    ('ZI020_GE43','ZI020_GE43',None),
    ('ZI020_GE44','ZI020_GE44',None),
    ('CPS','CPS','transformCPSenumeration2CPScodelist'),
    ('ETS','ETS','transformETSenumeration2ETScodelist'),
    ('HZD','HZD','transformHZDenumeration2HZDcodelist'),
    ('MEM','MEM','transform_MEM'),
    ('EQS',None,None),
    ('RTL',None,None),
    (None,'EQC','transformEQSinteger2EQCcodelist'),
    ('RCG','RCG','transformRCGenumeration2RCGcodelist'),
    ('VDT','VDT','transformVDTenumeration2VDTcodelist'),
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)




# ResourceSrfDatasetSrf field translations Updated for 30 -> 22
ResourceSrfDatasetSrfFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Srf_fields) + [ \
    ('AHA','AHA',None),
    ('AVA','AVA',None),
    ('CID','CID',None),
    ('DQS','DQS',None),
    ('EQS',None,None),
    ('ETZ','ETZ',None),
    ('EVA','EVA',None),
    ('F_CODE','F_CODE',None),
    ('FURL','FURL','transform_combine_FURL'),
    ('HVA','HVA',None),
    ('MDE','MDE',None),
    ('RTL',None,None),
    ('SCVN','SCVN',None),
    ('URI','URI',None),
    ('ZI002_UFI','ZI002_UFI',None),
    ('ZI020_GE4','ZI020_GE4',None),
    ('ZI020_GE42','ZI020_GE42',None),
    ('ZI020_GE43','ZI020_GE43',None),
    ('ZI020_GE44','ZI020_GE44',None),
    ('CPS','CPS','transformCPSenumeration2CPScodelist'),
    ('ETS','ETS','transformETSenumeration2ETScodelist'),
    ('HZD','HZD','transformHZDenumeration2HZDcodelist'),
    ('MEM','MEM','transform_MEM'),
    (None,'EQC','transformEQSinteger2EQCcodelist'),
    ('RCG','RCG','transformRCGenumeration2RCGcodelist'),
    ('VDT','VDT','transformVDTenumeration2VDTcodelist'),
    ('MEM','MEM','transform_MEM'),
    ('OTH','OTH','transform_OTH') 
     ]

# These Dataset fields are on each feature in GGDM 3.0
GetDatasetFields = [ \
    ('ZI031S_URI', None, None)
    ]


# Updated for 30 -> 22
ResourceTblDatasetSrfFields = [ \
    (None, 'FCSubtype', 'transform_FCSubtype'),
    (None, 'SHAPE@', None),
    (None, 'SHAPE@Length', None),
    (None, 'SHAPE@Area', None),
    ('AHA','AHA',None),
    ('AVA','AVA',None),
    ('CID','CID',None),
    ('DQS','DQS',None),
    ('EQS',None,None),
    ('ETZ','ETZ',None),
    ('EVA','EVA',None),
    ('F_CODE','F_CODE',None),
    ('FURL','FURL','transform_combine_FURL'),
    ('HVA','HVA',None),
    ('MDE','MDE',None),
    ('RTL',None,None),
    ('SCVN','SCVN',None),
    ('URI','URI',None),
    ('ZI002_UFI','ZI002_UFI','transform_SaveSomeRestrictionInfoToOTH'),
    ('ZI020_GE4','ZI020_GE4',None),
    ('ZI020_GE42','ZI020_GE42',None),
    ('ZI020_GE43','ZI020_GE43',None),
    ('ZI020_GE44','ZI020_GE44',None),
    ('CPS','CPS','transformCPSenumeration2CPScodelist'),
    ('ETS','ETS','transformETSenumeration2ETScodelist'),
    ('HZD','HZD','transformHZDenumeration2HZDcodelist'),
    (None,'EQC','transformEQSinteger2EQCcodelist'),
    ('VDT','VDT','transformVDTenumeration2VDTcodelist'),
    ('RCG','RCG','transformRCGenumeration2RCGcodelist'),
    ('MEM','MEM','transform_MEM'),
    ('OTH','OTH','transform_OTH') 
     ]


# These Entity Collection fields are on each feature or derived from each feature in GGDM 3.0.
# Basically, the purpose of this list is to get the 3 fields, the ZI039S_UFI, ZI001_SDV, ZI001_SRT as source content,
# and call the transform_SaveRelatedECInformation which will save the 3 fields into the appropriate entity collection metadata
# dictionary for later output to the target database.
GetECFields = [ \
    ('F_CODE','F_CODE',None),          # Do not use this here, but we just need one field as a default.
    ('UFI', None, 'transform_SaveRelatedECInformation'),              # We need the UFI in order to save values to OTH 
  #  (None, 'FCSubtype', None),     # get this from the related EC
    ('ZI039S_UFI', None, None),
    ('ZI001_SDV','ZI001_SDV',None), 
    ('ZI001_SRT','ZI001_SRT','transform_ZI001_SRT')
   # (None,'ZI001_NSD','transform_ZI001_NSD'),
    #(None,'ZI001_NSP','transform_ZI001_NSP'),
   # (None,'ZI001_SSD','transform_ZI001_SSD'),
   # (None,'ZI001_SSY','transform_ZI001_SSY')
    ]

# MetadataSrfCollectionSrf field translations Updated for 30 -> 2.2
MetadataSrfCollectionSrfFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Srf_fields) + [ \
   ('AHA','AHA',None),
    ('AVA','AVA',None),
    ('DQS','DQS',None),
    ('EVA','EVA',None),
    ('F_CODE','F_CODE',None),
    ('HVA','HVA',None),
    ('MDE','MDE',None),
    ('SCVN','SCVN',None),
    ('ZI004_PRE','ZI004_PRE',None),
    ('EQS','EQS',None),
    ('RCG','RCG','transformRCGenumeration2RCGcodelist'),
    ('UFI','UFI','transform_set_UFI'), 
    ('OTH','OTH','transform_OTH') 
     ]

# MetadataSrfCollectionSrf field translations
MetadataTblCollectionSrfFields =  [ \
    (None, 'FCSubtype', 'transform_FCSubtype'),
    (None, 'SHAPE@', None),
    (None, 'SHAPE@Length', None),
    (None, 'SHAPE@Area', None),
    ('AHA',None,None),
    ('AVA',None,None),
    ('DQS',None,None),
    ('EQS',None,None),
    ('EVA',None,None),
    ('F_CODE','F_CODE','transformMetadataSrfCollectionSrf_F_CODE'),
    ('HVA',None,None),
    ('MDE',None,None),
    ('RCG',None,None),
    ('SCVN',None,None),
    ('UFI','UFI',None),
    ('ZI001_SPS',None,None),
    ('ZI001_VSD','ZI001_VSD',None),
    ('ZI001_VSN','ZI001_VSN',None),
    ('ZI004_PRE','ZI004_PRE',None),
    ('ZI001_SDP','ZI001_SSN',None),
    ('ZI001_SDP','ZI001_NSN',None),
    (None,'ZI001_NSD','transform_ZI001_NSD'),
    (None,'ZI001_NSP','transform_ZI001_NSP'),
    (None,'ZI001_SSD','transform_ZI001_SSD'),
    (None,'ZI001_SSY','transform_ZI001_SSY'),
    ('ZI001_VSC','ZI001_VSC','transformZI001_VSCfromenumtocodelist'),
    ('OTH','OTH','transform_OTH') 
     ]



# ----- Auto generated non-metadata translation rules

# AeronauticCrv field translations
AeronauticCrvFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Crv_fields) + [ \
    ('ARA','ARA',None),
    ('AXS','AXS',None),
    ('BEN','BEN',None),
    ('CNCP',None,None),
    ('COS','COS',None),
    ('DEV','DEV',None),
    ('F_CODE','F_CODE',None),
    ('FUFI','FUFI',None),
    ('FURL','FURL','transform_combine_FURL'),
    ('GDBV',None,None),
    ('LZN','LZN',None),
    ('PCF','PCF',None),
    ('SBB','SBB',None),
    ('TXP','TXP',None),
    ('WID','WID',None),
    ('ZI002_UFI','ZI002_UFI',None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_GNT','ZI005_GNT',None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZI019_ASP','ZI019_ASP',None),
    ('ZI019_ASP2','ZI019_ASP2',None),
    ('ZI019_ASP3','ZI019_ASP3',None),
    ('ZI019_ASU','ZI019_ASU',None),
    ('ZI019_ASU2','ZI019_ASU2',None),
    ('ZI019_ASU3','ZI019_ASU3',None),
    ('ZI019_ASX','ZI019_ASX',None),
    ('ZI019_SFS','ZI019_SFS',None),
    ('ZI020_GE4','ZI020_GE4',None),
    ('ZI026_CTUC','ZI026_CTUC',None),
    ('ZI026_CTUL','ZI026_CTUL',None),
    ('ZI026_CTUU','ZI026_CTUU',None),
    ('ZI031S_URI',None,None),
    ('ZI039S_UFI',None,None),
    ('ZVH','ZVH',None),
    ('UFI','UFI','transform_set_UFI') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# AeronauticPnt field translations
AeronauticPntFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Pnt_fields) + [ \
    ('ADR','ADR',None),
    ('AOO','AOO',None),
    ('APT','APT',None),
    ('APT2','APT2',None),
    ('APT3','APT3',None),
    ('ARA','ARA',None),
    ('ASY','ASY',None),
    ('ATB','ATB',None),
    ('AWP','AWP',None),
    ('AXS','AXS',None),
    ('BEN','BEN',None),
    ('CAA','CAA',None),
    ('CNCP',None,None),
    ('COS','COS',None),
    ('F_CODE','F_CODE',None),
    ('FFN','FFN',None),
    ('FFN2','FFN2',None),
    ('FFN3','FFN3',None),
    ('FPT','FPT',None),
    ('FUFI','FUFI',None),
    ('FURL','FURL','transform_combine_FURL'),
    ('GDBV',None,None),
    ('GUG','GUG',None),
    ('HAF','HAF',None),
    ('HGT','HGT',None),
    ('HST','HST',None),
    ('HST2','HST2',None),
    ('HST3','HST3',None),
    ('HTP','HTP',None),
    ('IKO','IKO',None),
    ('LASZ','LASZ',None),
    ('LMC','LMC',None),
    ('LZN','LZN',None),
    ('MAG','MAG',None),
    ('MCC','MCC',None),
    ('MCC2','MCC2',None),
    ('MCC3','MCC3',None),
    ('MUB','MUB',None),
    ('NA8','NA8',None),
    ('NAO','NAO',None),
    ('PCF','PCF',None),
    ('PEC','PEC',None),
    ('PYM','PYM',None),
    ('SSR','SSR',None),
    ('SSR2','SSR2',None),
    ('SSR3','SSR3',None),
    ('TOS','TOS',None),
    ('VCM','VCM',None),
    ('VCM2','VCM2',None),
    ('VCM3','VCM3',None),
    ('VOI','VOI',None),
    ('WID','WID',None),
    ('ZI002_UFI','ZI002_UFI',None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_GNT','ZI005_GNT',None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZI019_ASP','ZI019_ASP',None),
    ('ZI019_ASP2','ZI019_ASP2',None),
    ('ZI019_ASP3','ZI019_ASP3',None),
    ('ZI019_ASU','ZI019_ASU',None),
    ('ZI019_ASU2','ZI019_ASU2',None),
    ('ZI019_ASU3','ZI019_ASU3',None),
    ('ZI019_ASX','ZI019_ASX',None),
    ('ZI019_SFS','ZI019_SFS',None),
    ('ZI020_GE4','ZI020_GE4',None),
    ('ZI026_CTUC','ZI026_CTUC',None),
    ('ZI026_CTUL','ZI026_CTUL',None),
    ('ZI026_CTUU','ZI026_CTUU',None),
    ('ZI031S_URI',None,None),
    ('ZI039S_UFI',None,None),
    ('ZI103_MVD','ZI103_MVD',None),
    ('ZVA','ZVA',None),
    ('ZVH','ZVH',None),
    ('TRS','TRS','transform_TRS'),
    ('TRS2','TRS2','transform_TRS'),
    ('TRS3','TRS3','transform_TRS'),
    ('UFI','UFI','transform_set_UFI') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# AeronauticPntExt field translations
AeronauticPntExtFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Pnt_fields) + [ \
    ('ARA','ARA',None),
    ('ART','ART',None),
    ('ASO','ASO',None),
    ('AWP','AWP',None),
    ('BEN','BEN',None),
    ('CAA','CAA',None),
    ('CHA','CHA',None),
    ('CMS','CMS',None),
    ('CNCP',None,None),
    ('COC','COC',None),
    ('COL','COL',None),
    ('COS','COS',None),
    ('DIA','DIA',None),
    ('DIR','DIR',None),
    ('F_CODE','F_CODE',None),
    ('FUFI','FUFI',None),
    ('FURL','FURL','transform_combine_FURL'),
    ('GA032_NSX','GA032_NSX',None),
    ('GB001_AID','GB001_AID',None),
    ('GDBV',None,None),
    ('HGT','HGT',None),
    ('LCN','LCN',None),
    ('LZN','LZN',None),
    ('MCA','MCA',None),
    ('MCC','MCC',None),
    ('MCC2','MCC2',None),
    ('MCC3','MCC3',None),
    ('PCF','PCF',None),
    ('PER','PER',None),
    ('PRM','PRM',None),
    ('PWR','PWR',None),
    ('RAC','RAC',None),
    ('RSI','RSI',None),
    ('SPT','SPT',None),
    ('SRL','SRL',None),
    ('VIS','VIS',None),
    ('VIS2','VIS2',None),
    ('VIS3','VIS3',None),
    ('VOI','VOI',None),
    ('WID','WID',None),
    ('ZI002_UFI','ZI002_UFI',None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_GNT','ZI005_GNT',None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZI020_GE4','ZI020_GE4',None),
    ('ZI026_CTUC','ZI026_CTUC',None),
    ('ZI026_CTUL','ZI026_CTUL',None),
    ('ZI026_CTUU','ZI026_CTUU',None),
    ('ZI031S_URI',None,None),
    ('ZI039S_UFI',None,None),
    ('ZVH','ZVH',None),
    ('LOC','LOC','transform_LOC'),
    ('UFI','UFI','transform_set_UFI') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# AeronauticSrf field translations
AeronauticSrfFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Srf_fields) + [ \
    ('ADR','ADR',None),
    ('AOO','AOO',None),
    ('APT','APT',None),
    ('APT2','APT2',None),
    ('APT3','APT3',None),
    ('APU','APU',None),
    ('APU2','APU2',None),
    ('APU3','APU3',None),
    ('APY','APY',None),
    ('ARA','ARA',None),
    ('ASU','ASU',None),
    ('ASU2','ASU2',None),
    ('ASU3','ASU3',None),
    ('ASY','ASY',None),
    ('ATB','ATB',None),
    ('AWP','AWP',None),
    ('AXS','AXS',None),
    ('BEN','BEN',None),
    ('CAA','CAA',None),
    ('CNCP',None,None),
    ('COS','COS',None),
    ('DEV','DEV',None),
    ('F_CODE','F_CODE',None),
    ('FFN','FFN',None),
    ('FFN2','FFN2',None),
    ('FFN3','FFN3',None),
    ('FPT','FPT',None),
    ('FUFI','FUFI',None),
    ('FURL','FURL','transform_combine_FURL'),
    ('GB052_RIDH','GB052_RIDH',None),
    ('GB052_RIDL','GB052_RIDL',None),
    ('GB052_TRHH','GB052_TRHH',None),
    ('GB052_TRHL','GB052_TRHL',None),
    ('GDBV',None,None),
    ('GSGCHC','GSGCHC',None),
    ('GSGCHL','GSGCHL',None),
    ('GSGCHU','GSGCHU',None),
    ('GSGCLC','GSGCLC',None),
    ('GSGCLL','GSGCLL',None),
    ('GSGCLU','GSGCLU',None),
    ('HAF','HAF',None),
    ('HGT','HGT',None),
    ('HST','HST',None),
    ('HST2','HST2',None),
    ('HST3','HST3',None),
    ('HTP','HTP',None),
    ('IKO','IKO',None),
    ('LASZ','LASZ',None),
    ('LMC','LMC',None),
    ('LZN','LZN',None),
    ('MAG','MAG',None),
    ('MCC','MCC',None),
    ('MCC2','MCC2',None),
    ('MCC3','MCC3',None),
    ('MUB','MUB',None),
    ('NA8','NA8',None),
    ('NAO','NAO',None),
    ('PCF','PCF',None),
    ('PEC','PEC',None),
    ('SBB','SBB',None),
    ('SERP','SERP',None),
    ('SSR','SSR',None),
    ('SSR2','SSR2',None),
    ('SSR3','SSR3',None),
    ('TXP','TXP',None),
    ('VCM','VCM',None),
    ('VCM2','VCM2',None),
    ('VCM3','VCM3',None),
    ('VOI','VOI',None),
    ('WID','WID',None),
    ('ZI002_UFI','ZI002_UFI',None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_GNT','ZI005_GNT',None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZI019_ASP','ZI019_ASP',None),
    ('ZI019_ASP2','ZI019_ASP2',None),
    ('ZI019_ASP3','ZI019_ASP3',None),
    ('ZI019_ASU','ZI019_ASU',None),
    ('ZI019_ASU2','ZI019_ASU2',None),
    ('ZI019_ASU3','ZI019_ASU3',None),
    ('ZI019_ASX','ZI019_ASX',None),
    ('ZI019_SFS','ZI019_SFS',None),
    ('ZI020_GE4','ZI020_GE4',None),
    ('ZI026_CTUC','ZI026_CTUC',None),
    ('ZI026_CTUL','ZI026_CTUL',None),
    ('ZI026_CTUU','ZI026_CTUU',None),
    ('ZI031S_URI',None,None),
    ('ZI039S_UFI',None,None),
    ('ZI103_MVD','ZI103_MVD',None),
    ('ZVA','ZVA',None),
    ('ZVH','ZVH',None),
    ('TRS','TRS','transform_TRS'),
    ('TRS2','TRS2','transform_TRS'),
    ('TRS3','TRS3','transform_TRS'),
    ('UFI','UFI','transform_set_UFI') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# AeronauticSrfExt field translations
AeronauticSrfExtFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Srf_fields) + [ \
    ('BEN','BEN',None),
    ('F_CODE','F_CODE',None),
    ('FUFI','FUFI',None),
    ('FURL','FURL','transform_combine_FURL'),
    ('GDBV',None,None),
    ('ZI002_UFI','ZI002_UFI',None),
    ('ZI020_GE4','ZI020_GE4',None),
    ('ZI026_CTUC','ZI026_CTUC',None),
    ('ZI026_CTUL','ZI026_CTUL',None),
    ('ZI026_CTUU','ZI026_CTUU',None),
    ('ZI031S_URI',None,None),
    ('ZI039S_UFI',None,None),
    ('UFI','UFI','transform_set_UFI') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# AgriculturePnt field translations
AgriculturePntFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Pnt_fields) + [ \
    ('ADR','ADR',None),
    ('AOO','AOO',None),
    ('ARA','ARA',None),
    ('ATB','ATB',None),
    ('AWP','AWP',None),
    ('BEN','BEN',None),
    ('BNF','BNF',None),
    ('CAA','CAA',None),
    ('CNCP',None,None),
    ('COS','COS',None),
    ('DMBC','DMBC',None),
    ('DMBL','DMBL',None),
    ('DMBU','DMBU',None),
    ('DMT','DMT',None),
    ('F_CODE','F_CODE',None),
    ('FFN','FFN',None),
    ('FFN2','FFN2',None),
    ('FFN3','FFN3',None),
    ('FUFI','FUFI',None),
    ('FURL','FURL','transform_combine_FURL'),
    ('GDBV',None,None),
    ('HGT','HGT',None),
    ('LMC','LMC',None),
    ('LUN','LUN',None),
    ('LZN','LZN',None),
    ('PCF','PCF',None),
    ('PPO','PPO',None),
    ('PPO2','PPO2',None),
    ('PPO3','PPO3',None),
    ('PVH','PVH',None),
    ('SDSC','SDSC',None),
    ('SSR','SSR',None),
    ('SSR2','SSR2',None),
    ('SSR3','SSR3',None),
    ('TOS','TOS',None),
    ('TRE','TRE',None),
    ('TSCC','TSCC',None),
    ('TSCL','TSCL',None),
    ('TSCU','TSCU',None),
    ('VCM','VCM',None),
    ('VCM2','VCM2',None),
    ('VCM3','VCM3',None),
    ('VLM','VLM',None),
    ('VOI','VOI',None),
    ('VSP','VSP',None),
    ('VSP2','VSP2',None),
    ('VSP3','VSP3',None),
    ('VTI','VTI',None),
    ('WID','WID',None),
    ('ZI002_UFI','ZI002_UFI',None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_GNT','ZI005_GNT',None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZI013_CSP','ZI013_CSP',None),
    ('ZI013_CSP2','ZI013_CSP2',None),
    ('ZI013_CSP3','ZI013_CSP3',None),
    ('ZI013_FFP','ZI013_FFP',None),
    ('ZI013_FFP2','ZI013_FFP2',None),
    ('ZI013_FFP3','ZI013_FFP3',None),
    ('ZI013_PIG','ZI013_PIG',None),
    ('ZI014_PPO','ZI014_PPO',None),
    ('ZI014_PPO2','ZI014_PPO2',None),
    ('ZI014_PPO3','ZI014_PPO3',None),
    ('ZI020_GE4','ZI020_GE4',None),
    ('ZI024_ASE','ZI024_ASE',None),
    ('ZI024_CFR','ZI024_CFR',None),
    ('ZI024_CLO','ZI024_CLO',None),
    ('ZI024_CYN','ZI024_CYN',None),
    ('ZI024_FMR',None,None),
    ('ZI024_FRR',None,None),
    ('ZI024_HAR','ZI024_HAR',None),
    ('ZI024_MGN','ZI024_MGN',None),
    ('ZI024_PHW','ZI024_PHW',None),
    ('ZI024_SCC','ZI024_SCC',None),
    ('ZI024_SUL','ZI024_SUL',None),
    ('ZI024_TDS','ZI024_TDS',None),
    ('ZI024_TEP','ZI024_TEP',None),
    ('ZI024_TUR','ZI024_TUR',None),
    ('ZI024_WAC','ZI024_WAC',None),
    ('ZI024_WTNO',None,None),
    ('ZI024_WUR','ZI024_WUR',None),
    ('ZI024_WUR2','ZI024_WUR2',None),
    ('ZI024_WUR3','ZI024_WUR3',None),
    ('ZI024_WUR4','ZI024_WUR4',None),
    ('ZI024_YWQ','ZI024_YWQ',None),
    ('ZI026_CTUC','ZI026_CTUC',None),
    ('ZI026_CTUL','ZI026_CTUL',None),
    ('ZI026_CTUU','ZI026_CTUU',None),
    ('ZI031S_URI',None,None),
    ('ZI039S_UFI',None,None),
    ('ZVH','ZVH',None),
    ('SDSL','SDSL','transform_decimetre_to_metre'),
    ('SDSU','SDSU','transform_decimetre_to_metre'),
    ('UFI','UFI','transform_set_UFI'),
    ('ZI013_FMM','ZI013_FMM','transform_ZI013_FMM'),
    ('ZI013_FMM2','ZI013_FMM2','transform_ZI013_FMM'),
    ('ZI013_FMM3','ZI013_FMM3','transform_ZI013_FMM'),
    ('ZI024_HYP','ZI024_HYP','transform_ZI024_HYP') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# AgriculturePntExt field translations
AgriculturePntExtFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Pnt_fields) + [ \
    ('ARA','ARA',None),
    ('BEN','BEN',None),
    ('DMBC','DMBC',None),
    ('DMBL','DMBL',None),
    ('DMBU','DMBU',None),
    ('DMT','DMT',None),
    ('F_CODE','F_CODE',None),
    ('FUFI','FUFI',None),
    ('FURL','FURL','transform_combine_FURL'),
    ('GDBV',None,None),
    ('HGT','HGT',None),
    ('LMC','LMC',None),
    ('LZN','LZN',None),
    ('PVH','PVH',None),
    ('SDSC','SDSC',None),
    ('TRE','TRE',None),
    ('TSCC','TSCC',None),
    ('TSCL','TSCL',None),
    ('TSCU','TSCU',None),
    ('VTI','VTI',None),
    ('WID','WID',None),
    ('ZI002_UFI','ZI002_UFI',None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_GNT','ZI005_GNT',None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZI013_CSP','ZI013_CSP',None),
    ('ZI013_CSP2','ZI013_CSP2',None),
    ('ZI013_CSP3','ZI013_CSP3',None),
    ('ZI013_FFP','ZI013_FFP',None),
    ('ZI013_FFP2','ZI013_FFP2',None),
    ('ZI013_FFP3','ZI013_FFP3',None),
    ('ZI013_IRG','ZI013_IRG',None),
    ('ZI020_GE4','ZI020_GE4',None),
    ('ZI026_CTUC','ZI026_CTUC',None),
    ('ZI026_CTUL','ZI026_CTUL',None),
    ('ZI026_CTUU','ZI026_CTUU',None),
    ('ZI031S_URI',None,None),
    ('ZI039S_UFI',None,None),
    ('ZVH','ZVH',None),
    ('SDSL','SDSL','transform_decimetre_to_metre'),
    ('SDSU','SDSU','transform_decimetre_to_metre'),
    ('UFI','UFI','transform_set_UFI') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# AgricultureSrf field translations
AgricultureSrfFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Srf_fields) + [ \
    ('ADR','ADR',None),
    ('AOO','AOO',None),
    ('ARA','ARA',None),
    ('ATB','ATB',None),
    ('AWP','AWP',None),
    ('BEN','BEN',None),
    ('BNF','BNF',None),
    ('CAA','CAA',None),
    ('CNCP',None,None),
    ('COS','COS',None),
    ('DMBC','DMBC',None),
    ('DMBL','DMBL',None),
    ('DMBU','DMBU',None),
    ('DMT','DMT',None),
    ('DZP','DZP',None),
    ('F_CODE','F_CODE',None),
    ('FFN','FFN',None),
    ('FFN2','FFN2',None),
    ('FFN3','FFN3',None),
    ('FUFI','FUFI',None),
    ('FURL','FURL','transform_combine_FURL'),
    ('GDBV',None,None),
    ('HGT','HGT',None),
    ('LMC','LMC',None),
    ('LUN','LUN',None),
    ('LZN','LZN',None),
    ('PCF','PCF',None),
    ('PPO','PPO',None),
    ('PPO2','PPO2',None),
    ('PPO3','PPO3',None),
    ('PVH','PVH',None),
    ('SDSC','SDSC',None),
    ('SSR','SSR',None),
    ('SSR2','SSR2',None),
    ('SSR3','SSR3',None),
    ('TOS','TOS',None),
    ('TRE','TRE',None),
    ('TSCC','TSCC',None),
    ('TSCL','TSCL',None),
    ('TSCU','TSCU',None),
    ('VCM','VCM',None),
    ('VCM2','VCM2',None),
    ('VCM3','VCM3',None),
    ('VLM','VLM',None),
    ('VOI','VOI',None),
    ('VSP','VSP',None),
    ('VSP2','VSP2',None),
    ('VSP3','VSP3',None),
    ('VTI','VTI',None),
    ('WDAC','WDAC',None),
    ('WDAL','WDAL',None),
    ('WDAU','WDAU',None),
    ('WID','WID',None),
    ('ZI002_UFI','ZI002_UFI',None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_GNT','ZI005_GNT',None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZI013_CSP','ZI013_CSP',None),
    ('ZI013_CSP2','ZI013_CSP2',None),
    ('ZI013_CSP3','ZI013_CSP3',None),
    ('ZI013_FFP','ZI013_FFP',None),
    ('ZI013_FFP2','ZI013_FFP2',None),
    ('ZI013_FFP3','ZI013_FFP3',None),
    ('ZI013_IRG','ZI013_IRG',None),
    ('ZI013_PIG','ZI013_PIG',None),
    ('ZI014_PPO','ZI014_PPO',None),
    ('ZI014_PPO2','ZI014_PPO2',None),
    ('ZI014_PPO3','ZI014_PPO3',None),
    ('ZI020_GE4','ZI020_GE4',None),
    ('ZI024_ASE','ZI024_ASE',None),
    ('ZI024_CFR','ZI024_CFR',None),
    ('ZI024_CLO','ZI024_CLO',None),
    ('ZI024_CYN','ZI024_CYN',None),
    ('ZI024_FMR',None,None),
    ('ZI024_FRR',None,None),
    ('ZI024_HAR','ZI024_HAR',None),
    ('ZI024_MGN','ZI024_MGN',None),
    ('ZI024_PHW','ZI024_PHW',None),
    ('ZI024_SCC','ZI024_SCC',None),
    ('ZI024_SUL','ZI024_SUL',None),
    ('ZI024_TDS','ZI024_TDS',None),
    ('ZI024_TEP','ZI024_TEP',None),
    ('ZI024_TUR','ZI024_TUR',None),
    ('ZI024_WAC','ZI024_WAC',None),
    ('ZI024_WTNO',None,None),
    ('ZI024_WUR','ZI024_WUR',None),
    ('ZI024_WUR2','ZI024_WUR2',None),
    ('ZI024_WUR3','ZI024_WUR3',None),
    ('ZI024_WUR4','ZI024_WUR4',None),
    ('ZI024_YWQ','ZI024_YWQ',None),
    ('ZI026_CTUC','ZI026_CTUC',None),
    ('ZI026_CTUL','ZI026_CTUL',None),
    ('ZI026_CTUU','ZI026_CTUU',None),
    ('ZI031S_URI',None,None),
    ('ZI039S_UFI',None,None),
    ('ZVH','ZVH',None),
    ('SDSL','SDSL','transform_decimetre_to_metre'),
    ('SDSU','SDSU','transform_decimetre_to_metre'),
    ('UFI','UFI','transform_set_UFI'),
    ('ZI013_FMM','ZI013_FMM','transform_ZI013_FMM'),
    ('ZI013_FMM2','ZI013_FMM2','transform_ZI013_FMM'),
    ('ZI013_FMM3','ZI013_FMM3','transform_ZI013_FMM'),
    ('ZI024_HYP','ZI024_HYP','transform_ZI024_HYP') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# BoundaryCrvExt field translations
BoundaryCrvExtFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Crv_fields) + [ \
    ('BEN','BEN',None),
    ('BST','BST',None),
    ('CAA','CAA',None),
    ('DSP','DSP',None),
    ('F_CODE','F_CODE',None),
    ('FA003_BAL','FA003_BAL',None),
    ('FUFI','FUFI',None),
    ('FURL','FURL','transform_combine_FURL'),
    ('GDBV',None,None),
    ('LSP','LSP',None),
    ('LZN','LZN',None),
    ('MGL','MGL',None),
    ('MGL2','MGL2',None),
    ('MGL3','MGL3',None),
    ('RPC','RPC',None),
    ('ZI002_UFI','ZI002_UFI',None),
    ('ZI005_FNAA','ZI005_FNAA',None),
    ('ZI005_FNAB','ZI005_FNAB',None),
    ('ZI005_GNTA','ZI005_GNTA',None),
    ('ZI005_GNTB','ZI005_GNTB',None),
    ('ZI005_NFNA','ZI005_NFNA',None),
    ('ZI005_NFNB','ZI005_NFNB',None),
    ('ZI020_FI2A','ZI020_FI2A',None),
    ('ZI020_FI2B','ZI020_FI2B',None),
    ('ZI020_GE4','ZI020_GE4',None),
    ('ZI020_GE4A','ZI020_GE4A',None),
    ('ZI020_GE4B','ZI020_GE4B',None),
    ('ZI026_CTUC','ZI026_CTUC',None),
    ('ZI026_CTUL','ZI026_CTUL',None),
    ('ZI026_CTUU','ZI026_CTUU',None),
    ('ZI031S_URI',None,None),
    ('ZI039S_UFI',None,None),
    ('UFI','UFI','transform_set_UFI') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# BoundaryPnt field translations
BoundaryPntFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Pnt_fields) + [ \
    ('BEN','BEN',None),
    ('CNCP',None,None),
    ('COS','COS',None),
    ('F_CODE','F_CODE',None),
    ('FUFI','FUFI',None),
    ('FURL','FURL','transform_combine_FURL'),
    ('GDBV',None,None),
    ('LZN','LZN',None),
    ('MCC','MCC',None),
    ('MCC2','MCC2',None),
    ('MCC3','MCC3',None),
    ('PCF','PCF',None),
    ('WID','WID',None),
    ('ZI002_UFI','ZI002_UFI',None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_GNT','ZI005_GNT',None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZI020_GE4','ZI020_GE4',None),
    ('ZI026_CTUC','ZI026_CTUC',None),
    ('ZI026_CTUL','ZI026_CTUL',None),
    ('ZI026_CTUU','ZI026_CTUU',None),
    ('ZI031S_URI',None,None),
    ('ZI039S_UFI',None,None),
    ('ZVH','ZVH',None),
    ('UFI','UFI','transform_set_UFI') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# BoundarySrf field translations
BoundarySrfFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Srf_fields) + [ \
    ('ARA','ARA',None),
    ('BEN','BEN',None),
    ('CAA','CAA',None),
    ('CDM','CDM',None),
    ('CDY','CDY',None),
    ('CSI','CSI',None),
    ('CSY','CSY',None),
    ('F_CODE','F_CODE',None),
    ('FUFI','FUFI',None),
    ('FURL','FURL','transform_combine_FURL'),
    ('GDBV',None,None),
    ('ZI002_UFI','ZI002_UFI',None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_GNT','ZI005_GNT',None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZI020_GE4','ZI020_GE4',None),
    ('ZI026_CTUC','ZI026_CTUC',None),
    ('ZI026_CTUL','ZI026_CTUL',None),
    ('ZI026_CTUU','ZI026_CTUU',None),
    ('ZI031S_URI',None,None),
    ('ZI039S_UFI',None,None),
    ('UFI','UFI','transform_set_UFI') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# BoundarySrfExt field translations
BoundarySrfExtFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Srf_fields) + [ \
    ('ARA','ARA',None),
    ('BEN','BEN',None),
    ('CAA','CAA',None),
    ('F_CODE','F_CODE',None),
    ('FUFI','FUFI',None),
    ('FURL','FURL','transform_combine_FURL'),
    ('GDBV',None,None),
    ('GEC','GEC',None),
    (None,'AMB',None),
    ('PPL',None,None),
    ('ZI002_UFI','ZI002_UFI',None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_GNT','ZI005_GNT',None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZI020_GE4','ZI020_GE4',None),
    ('ZI020_IC4','ZI020_IC4',None),
    ('ZI026_CTUC','ZI026_CTUC',None),
    ('ZI026_CTUL','ZI026_CTUL',None),
    ('ZI026_CTUU','ZI026_CTUU',None),
    ('ZI031S_URI',None,None),
    ('ZI039S_UFI',None,None),
    ('UFI','UFI','transform_set_UFI') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)


# CultureCrv field translations
CultureCrvFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Crv_fields) + [ \
    ('AOO','AOO',None),
    ('ARA','ARA',None),
    ('AWP','AWP',None),
    ('BEN','BEN',None),
    ('CAA','CAA',None),
    ('CNCP',None,None),
    ('COS','COS',None),
    ('F_CODE','F_CODE',None),
    ('FUFI','FUFI',None),
    ('FURL','FURL','transform_combine_FURL'),
    ('GDBV',None,None),
    ('HEI','HEI',None),
    ('HGT','HGT',None),
    ('LMC','LMC',None),
    ('LZN','LZN',None),
    ('PCF','PCF',None),
    ('SSC','SSC',None),
    ('SSR','SSR',None),
    ('SSR2','SSR2',None),
    ('SSR3','SSR3',None),
    ('TOS','TOS',None),
    ('VOI','VOI',None),
    ('WID','WID',None),
    ('ZI002_UFI','ZI002_UFI',None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_GNT','ZI005_GNT',None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZI020_GE4','ZI020_GE4',None),
    ('ZI026_CTUC','ZI026_CTUC',None),
    ('ZI026_CTUL','ZI026_CTUL',None),
    ('ZI026_CTUU','ZI026_CTUU',None),
    ('ZI031S_URI',None,None),
    ('ZI039S_UFI',None,None),
    ('ZVH','ZVH',None),
    ('UFI','UFI','transform_set_UFI') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# CulturePnt field translations
CulturePntFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Pnt_fields) + [ \
    ('ADR','ADR',None),
    ('AOO','AOO',None),
    ('ARA','ARA',None),
    ('AWP','AWP',None),
    ('BEN','BEN',None),
    ('CAA','CAA',None),
    ('CCG','CCG',None),
    ('CNCP',None,None),
    ('COS','COS',None),
    ('CSO','CSO',None),
    ('DZP','DZP',None),
    ('F_CODE','F_CODE',None),
    ('FUFI','FUFI',None),
    ('FURL','FURL','transform_combine_FURL'),
    ('GDBV',None,None),
    ('HEI','HEI',None),
    ('HGT','HGT',None),
    ('HSS','HSS',None),
    ('LEA','LEA',None),
    ('LMC','LMC',None),
    ('LZN','LZN',None),
    ('PCF','PCF',None),
    ('SDQ','SDQ',None),
    ('SRL','SRL',None),
    ('SSC','SSC',None),
    ('SSR','SSR',None),
    ('SSR2','SSR2',None),
    ('SSR3','SSR3',None),
    ('TOS','TOS',None),
    ('TTY','TTY',None),
    ('VLM','VLM',None),
    ('VOI','VOI',None),
    ('WID','WID',None),
    ('ZI002_UFI','ZI002_UFI',None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_GNT','ZI005_GNT',None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZI020_GE4','ZI020_GE4',None),
    ('ZI024_ASE','ZI024_ASE',None),
    ('ZI024_CFR','ZI024_CFR',None),
    ('ZI024_CLO','ZI024_CLO',None),
    ('ZI024_CYN','ZI024_CYN',None),
    ('ZI024_FMR',None,None),
    ('ZI024_FRR',None,None),
    ('ZI024_HAR','ZI024_HAR',None),
    ('ZI024_MGN','ZI024_MGN',None),
    ('ZI024_PHW','ZI024_PHW',None),
    ('ZI024_SCC','ZI024_SCC',None),
    ('ZI024_SUL','ZI024_SUL',None),
    ('ZI024_TDS','ZI024_TDS',None),
    ('ZI024_TEP','ZI024_TEP',None),
    ('ZI024_TUR','ZI024_TUR',None),
    ('ZI024_WAC','ZI024_WAC',None),
    ('ZI024_WTNO',None,None),
    ('ZI024_WUR','ZI024_WUR',None),
    ('ZI024_WUR2','ZI024_WUR2',None),
    ('ZI024_WUR3','ZI024_WUR3',None),
    ('ZI024_WUR4','ZI024_WUR4',None),
    ('ZI024_YWQ','ZI024_YWQ',None),
    ('ZI025_HDP','ZI025_HDP',None),
    ('ZI026_CTUC','ZI026_CTUC',None),
    ('ZI026_CTUL','ZI026_CTUL',None),
    ('ZI026_CTUU','ZI026_CTUU',None),
    ('ZI031S_URI',None,None),
    ('ZI037_REL','ZI037_REL',None),
    ('ZI037_RFA','ZI037_RFA',None),
    ('ZI039S_UFI',None,None),
    ('ZVH','ZVH',None),
    ('UFI','UFI','transform_set_UFI') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# CulturePntExt field translations
CulturePntExtFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Pnt_fields) + [ \
    ('ARA','ARA',None),
    ('BEN','BEN',None),
    ('CUL','CUL',None),
    ('F_CODE','F_CODE',None),
    ('FUFI','FUFI',None),
    ('FURL','FURL','transform_combine_FURL'),
    ('GDBV',None,None),
    ('LZN','LZN',None),
    ('WID','WID',None),
    ('ZI002_UFI','ZI002_UFI',None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_GNT','ZI005_GNT',None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZI020_GE4','ZI020_GE4',None),
    ('ZI026_CTUC','ZI026_CTUC',None),
    ('ZI026_CTUL','ZI026_CTUL',None),
    ('ZI026_CTUU','ZI026_CTUU',None),
    ('ZI031S_URI',None,None),
    ('ZI037_REL','ZI037_REL',None),
    ('ZI039S_UFI',None,None),
    ('UFI','UFI','transform_set_UFI') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# CultureSrf field translations
CultureSrfFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Srf_fields) + [ \
    ('ADI','ADI',None),
    ('ADR','ADR',None),
    ('AOO','AOO',None),
    ('ARA','ARA',None),
    ('AWP','AWP',None),
    ('BEN','BEN',None),
    ('CAA','CAA',None),
    ('CAM','CAM',None),
    ('CCG','CCG',None),
    ('CNCP',None,None),
    ('COS','COS',None),
    ('CSO','CSO',None),
    ('DZP','DZP',None),
    ('F_CODE','F_CODE',None),
    ('FFN','FFN',None),
    ('FFN2','FFN2',None),
    ('FFN3','FFN3',None),
    ('FUFI','FUFI',None),
    ('FURL','FURL','transform_combine_FURL'),
    ('GDBV',None,None),
    ('HEI','HEI',None),
    ('HGT','HGT',None),
    ('HSS','HSS',None),
    ('LEA','LEA',None),
    ('LMC','LMC',None),
    ('LZN','LZN',None),
    ('MCC','MCC',None),
    ('MCC2','MCC2',None),
    ('MCC3','MCC3',None),
    ('PCF','PCF',None),
    ('SDQ','SDQ',None),
    ('SRL','SRL',None),
    ('SSC','SSC',None),
    ('SSR','SSR',None),
    ('SSR2','SSR2',None),
    ('SSR3','SSR3',None),
    ('TOS','TOS',None),
    ('TRE',None,None),
    ('TTY','TTY',None),
    ('VLM','VLM',None),
    ('VOI','VOI',None),
    ('WID','WID',None),
    ('ZI002_UFI','ZI002_UFI',None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_GNT','ZI005_GNT',None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZI020_GE4','ZI020_GE4',None),
    ('ZI024_ASE','ZI024_ASE',None),
    ('ZI024_CFR','ZI024_CFR',None),
    ('ZI024_CLO','ZI024_CLO',None),
    ('ZI024_CYN','ZI024_CYN',None),
    ('ZI024_FMR',None,None),
    ('ZI024_FRR',None,None),
    ('ZI024_HAR','ZI024_HAR',None),
    ('ZI024_MGN','ZI024_MGN',None),
    ('ZI024_PHW','ZI024_PHW',None),
    ('ZI024_SCC','ZI024_SCC',None),
    ('ZI024_SUL','ZI024_SUL',None),
    ('ZI024_TDS','ZI024_TDS',None),
    ('ZI024_TEP','ZI024_TEP',None),
    ('ZI024_TUR','ZI024_TUR',None),
    ('ZI024_WAC','ZI024_WAC',None),
    ('ZI024_WTNO',None,None),
    ('ZI024_WUR','ZI024_WUR',None),
    ('ZI024_WUR2','ZI024_WUR2',None),
    ('ZI024_WUR3','ZI024_WUR3',None),
    ('ZI024_WUR4','ZI024_WUR4',None),
    ('ZI024_YWQ','ZI024_YWQ',None),
    ('ZI025_HDP','ZI025_HDP',None),
    ('ZI026_CTUC','ZI026_CTUC',None),
    ('ZI026_CTUL','ZI026_CTUL',None),
    ('ZI026_CTUU','ZI026_CTUU',None),
    ('ZI031S_URI',None,None),
    ('ZI037_REL','ZI037_REL',None),
    ('ZI037_RFA','ZI037_RFA',None),
    ('ZI039S_UFI',None,None),
    ('ZVH','ZVH',None),
    ('UFI','UFI','transform_set_UFI') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# CultureSrfExt field translations
CultureSrfExtFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Srf_fields) + [ \
    ('ARA','ARA',None),
    ('BEN','BEN',None),
    ('CUL','CUL',None),
    ('F_CODE','F_CODE',None),
    ('FUFI','FUFI',None),
    ('FURL','FURL','transform_combine_FURL'),
    ('GDBV',None,None),
    ('LZN','LZN',None),
    ('WID','WID',None),
    ('ZI002_UFI','ZI002_UFI',None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_GNT','ZI005_GNT',None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZI020_GE4','ZI020_GE4',None),
    ('ZI026_CTUC','ZI026_CTUC',None),
    ('ZI026_CTUL','ZI026_CTUL',None),
    ('ZI026_CTUU','ZI026_CTUU',None),
    ('ZI031S_URI',None,None),
    ('ZI037_REL','ZI037_REL',None),
    ('ZI039S_UFI',None,None),
    ('UFI','UFI','transform_set_UFI') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# FacilityPnt field translations
FacilityPntFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Pnt_fields) + [ \
    ('ADR','ADR',None),
    ('ADUR',None,None),
    ('AOO','AOO',None),
    ('ARA','ARA',None),
    ('BEN','BEN',None),
    ('CAA','CAA',None),
    ('CNCP',None,None),
    ('COS','COS',None),
    ('F_CODE','F_CODE',None),
    ('FFN','FFN',None),
    ('FFN2','FFN2',None),
    ('FFN3','FFN3',None),
    ('FUFI','FUFI',None),
    ('FURL','FURL','transform_combine_FURL'),
    ('GDBV',None,None),
    ('HGT','HGT',None),
    ('LMC','LMC',None),
    ('LZN','LZN',None),
    ('PCF','PCF',None),
    ('PRM','PRM',None),
    ('RAS','RAS',None),
    ('VCM','VCM',None),
    ('VCM2','VCM2',None),
    ('VCM3','VCM3',None),
    ('WID','WID',None),
    ('WLSS',None,None),
    ('WSRC',None,None),
    ('YSU','YSU',None),
    ('ZI002_UFI','ZI002_UFI',None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_FNA2','ZI005_FNA2',None),
    ('ZI005_FNA3','ZI005_FNA3',None),
    ('ZI005_GNT','ZI005_GNT',None),
    ('ZI005_GNT2','ZI005_GNT2',None),
    ('ZI005_GNT3','ZI005_GNT3',None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZI005_NFN2','ZI005_NFN2',None),
    ('ZI005_NFN3','ZI005_NFN3',None),
    ('ZI014_PBY','ZI014_PBY',None),
    ('ZI014_PBY2','ZI014_PBY2',None),
    ('ZI014_PBY3','ZI014_PBY3',None),
    ('ZI014_PPO','ZI014_PPO',None),
    ('ZI014_PPO2','ZI014_PPO2',None),
    ('ZI014_PPO3','ZI014_PPO3',None),
    ('ZI014_PRW','ZI014_PRW',None),
    ('ZI014_PRW2','ZI014_PRW2',None),
    ('ZI014_PRW3','ZI014_PRW3',None),
    ('ZI018_WIT','ZI018_WIT',None),
    ('ZI020_GE4','ZI020_GE4',None),
    ('ZI026_CTUC','ZI026_CTUC',None),
    ('ZI026_CTUL','ZI026_CTUL',None),
    ('ZI026_CTUU','ZI026_CTUU',None),
    ('ZI031S_URI',None,None),
    ('ZI037_REL','ZI037_REL',None),
    ('ZI037_RFA','ZI037_RFA',None),
    ('ZI039S_UFI',None,None),
    ('ZVH','ZVH',None),
    ('UFI','UFI','transform_set_UFI') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# FacilitySrf field translations
FacilitySrfFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Srf_fields) + [ \
    ('ADR','ADR',None),
    ('ADUR',None,None),
    ('AOO','AOO',None),
    ('ARA','ARA',None),
    ('BEN','BEN',None),
    ('CAA','CAA',None),
    ('CNCP',None,None),
    ('COS','COS',None),
    ('F_CODE','F_CODE',None),
    ('FFN','FFN',None),
    ('FFN2','FFN2',None),
    ('FFN3','FFN3',None),
    ('FUFI','FUFI',None),
    ('FURL','FURL','transform_combine_FURL'),
    ('GDBV',None,None),
    ('HGT','HGT',None),
    ('LMC','LMC',None),
    ('LZN','LZN',None),
    ('PCF','PCF',None),
    ('PRM','PRM',None),
    ('RAS','RAS',None),
    ('VCM','VCM',None),
    ('VCM2','VCM2',None),
    ('VCM3','VCM3',None),
    ('WID','WID',None),
    ('WLSS',None,None),
    ('WSRC',None,None),
    ('YSU','YSU',None),
    ('ZI002_UFI','ZI002_UFI',None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_FNA2','ZI005_FNA2',None),
    ('ZI005_FNA3','ZI005_FNA3',None),
    ('ZI005_GNT','ZI005_GNT',None),
    ('ZI005_GNT2','ZI005_GNT2',None),
    ('ZI005_GNT3','ZI005_GNT3',None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZI005_NFN2','ZI005_NFN2',None),
    ('ZI005_NFN3','ZI005_NFN3',None),
    ('ZI014_PBY','ZI014_PBY',None),
    ('ZI014_PBY2','ZI014_PBY2',None),
    ('ZI014_PBY3','ZI014_PBY3',None),
    ('ZI014_PPO','ZI014_PPO',None),
    ('ZI014_PPO2','ZI014_PPO2',None),
    ('ZI014_PPO3','ZI014_PPO3',None),
    ('ZI014_PRW','ZI014_PRW',None),
    ('ZI014_PRW2','ZI014_PRW2',None),
    ('ZI014_PRW3','ZI014_PRW3',None),
    ('ZI018_WIT','ZI018_WIT',None),
    ('ZI020_GE4','ZI020_GE4',None),
    ('ZI026_CTUC','ZI026_CTUC',None),
    ('ZI026_CTUL','ZI026_CTUL',None),
    ('ZI026_CTUU','ZI026_CTUU',None),
    ('ZI031S_URI',None,None),
    ('ZI037_REL','ZI037_REL',None),
    ('ZI037_RFA','ZI037_RFA',None),
    ('ZI039S_UFI',None,None),
    ('ZVH','ZVH',None),
    ('UFI','UFI','transform_set_UFI') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# HydroAidNavigationCrvExt field translations
HydroAidNavigationCrvExtFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Crv_fields) + [ \
    ('BEN','BEN',None),
    ('BRR','BRR',None),
    ('F_CODE','F_CODE',None),
    ('FUFI','FUFI',None),
    ('FURL','FURL','transform_combine_FURL'),
    ('GDBV',None,None),
    ('ZI002_UFI','ZI002_UFI',None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_GNT','ZI005_GNT',None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZI020_GE4','ZI020_GE4',None),
    ('ZI026_CTUC','ZI026_CTUC',None),
    ('ZI026_CTUL','ZI026_CTUL',None),
    ('ZI026_CTUU','ZI026_CTUU',None),
    ('ZI031S_URI',None,None),
    ('ZI039S_UFI',None,None),
    ('UFI','UFI','transform_set_UFI') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# HydroAidNavigationPnt field translations
HydroAidNavigationPntFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Pnt_fields) + [ \
    ('ADR','ADR',None),
    ('AOO','AOO',None),
    ('ARA','ARA',None),
    ('ATB','ATB',None),
    ('AWP','AWP',None),
    ('BC034_BRF','BC034_BRF',None),
    ('BC034_BRF2','BC034_BRF2',None),
    ('BC034_MRT','BC034_MRT',None),
    ('BC034_MRT2','BC034_MRT2',None),
    ('BC034_MRT3','BC034_MRT3',None),
    ('BC040_COL','BC040_COL',None),
    ('BC040_EOL','BC040_EOL',None),
    ('BC040_LCN','BC040_LCN',None),
    ('BC040_LVN','BC040_LVN',None),
    ('BC040_MLR','BC040_MLR',None),
    ('BC040_PER','BC040_PER',None),
    ('BC101_SST','BC101_SST',None),
    ('BEN','BEN',None),
    ('CAA','CAA',None),
    ('CNCP',None,None),
    ('COS','COS',None),
    ('F_CODE','F_CODE',None),
    ('FFN','FFN',None),
    ('FFN2','FFN2',None),
    ('FFN3','FFN3',None),
    ('FUFI','FUFI',None),
    ('FURL','FURL','transform_combine_FURL'),
    ('GDBV',None,None),
    ('HGT','HGT',None),
    ('LMC','LMC',None),
    ('LZN','LZN',None),
    ('MAN','MAN',None),
    ('PCF','PCF',None),
    ('REF','REF',None),
    ('SSR','SSR',None),
    ('SSR2','SSR2',None),
    ('SSR3','SSR3',None),
    ('VCM','VCM',None),
    ('VCM2','VCM2',None),
    ('VCM3','VCM3',None),
    ('VOI','VOI',None),
    ('WID','WID',None),
    ('ZI002_UFI','ZI002_UFI',None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_GNT','ZI005_GNT',None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZI020_GE4','ZI020_GE4',None),
    ('ZI026_CTUC','ZI026_CTUC',None),
    ('ZI026_CTUL','ZI026_CTUL',None),
    ('ZI026_CTUU','ZI026_CTUU',None),
    ('ZI031S_URI',None,None),
    ('ZI039S_UFI',None,None),
    ('ZVH','ZVH',None),
    ('UFI','UFI','transform_set_UFI') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# HydroAidNavigationPntExt field translations
HydroAidNavigationPntExtFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Pnt_fields) + [ \
    ('ARA','ARA',None),
    ('BC010_REF','BC010_REF',None),
    ('BC010_TZP','BC010_TZP',None),
    ('BC034_BRF','BC034_BRF',None),
    ('BC034_BRF2','BC034_BRF2',None),
    ('BC034_MRT','BC034_MRT',None),
    ('BC034_MRT2','BC034_MRT2',None),
    ('BC034_MRT3','BC034_MRT3',None),
    ('BC040_CAA','BC040_CAA',None),
    ('BC040_COL','BC040_COL',None),
    ('BC040_EOL','BC040_EOL',None),
    ('BC040_LVN','BC040_LVN',None),
    ('BC040_MLR','BC040_MLR',None),
    ('BC040_ZVH','BC040_ZVH',None),
    ('BC101_SST','BC101_SST',None),
    ('BEN','BEN',None),
    ('BET','BET',None),
    ('BRF','BRF',None),
    ('BRF2','BRF2',None),
    ('BUS','BUS',None),
    ('BUT','BUT',None),
    ('CAA','CAA',None),
    ('CCR','CCR',None),
    ('CNCP',None,None),
    ('COC','COC',None),
    ('COL','COL',None),
    ('COS','COS',None),
    ('CPT','CPT',None),
    ('CSS','CSS',None),
    ('DKS','DKS',None),
    ('EOL','EOL',None),
    ('F_CODE','F_CODE',None),
    ('FLT','FLT',None),
    ('FUFI','FUFI',None),
    ('FURL','FURL','transform_combine_FURL'),
    ('GDBV',None,None),
    ('GUG','GUG',None),
    ('HBH','HBH',None),
    ('HGT','HGT',None),
    ('IAA','IAA',None),
    ('IAS','IAS',None),
    ('LFC','LFC',None),
    ('LFC2','LFC2',None),
    ('LFC3','LFC3',None),
    ('LMC','LMC',None),
    ('LSA','LSA',None),
    ('LSI','LSI',None),
    ('LST','LST',None),
    ('LZN','LZN',None),
    ('MCC','MCC',None),
    ('MCC2','MCC2',None),
    ('MCC3','MCC3',None),
    ('MLR','MLR',None),
    ('MRP','MRP',None),
    ('MRT','MRT',None),
    ('NMC','NMC',None),
    ('NMC2','NMC2',None),
    ('NMC3','NMC3',None),
    ('NSC','NSC',None),
    ('ORC','ORC',None),
    ('PCF','PCF',None),
    ('PRM','PRM',None),
    ('REF','REF',None),
    ('SPT','SPT',None),
    ('SRL','SRL',None),
    ('STA','STA',None),
    ('STA2','STA2',None),
    ('STA3','STA3',None),
    ('TOS','TOS',None),
    ('TZP','TZP',None),
    ('VOI','VOI',None),
    ('WID','WID',None),
    ('ZHBH_DCR','ZHBH_DCR',None),
    ('ZHBH_DKC','ZHBH_DKC',None),
    ('ZHBH_DKC2','ZHBH_DKC2',None),
    ('ZHBH_DKC3','ZHBH_DKC3',None),
    ('ZHBH_SVC','ZHBH_SVC',None),
    ('ZHBH_TEC','ZHBH_TEC',None),
    ('ZHBH_TEC2','ZHBH_TEC2',None),
    ('ZHBH_TEC3','ZHBH_TEC3',None),
    ('ZHBH_VDC','ZHBH_VDC',None),
    ('ZHBH_VDR','ZHBH_VDR',None),
    ('ZI002_UFI','ZI002_UFI',None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_GNT','ZI005_GNT',None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZI018_BRF','ZI018_BRF',None),
    ('ZI018_WIT','ZI018_WIT',None),
    ('ZI020_GE4','ZI020_GE4',None),
    ('ZI026_CTUC','ZI026_CTUC',None),
    ('ZI026_CTUL','ZI026_CTUL',None),
    ('ZI026_CTUU','ZI026_CTUU',None),
    ('ZI031S_URI',None,None),
    ('ZI039S_UFI',None,None),
    ('ZVH','ZVH',None),
    ('LOC','LOC','transform_LOC'),
    ('LVN','LVN','transform_LVN'),
    ('UFI','UFI','transform_set_UFI') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# HydroAidNavigationSrf field translations
HydroAidNavigationSrfFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Srf_fields) + [ \
    ('ADR','ADR',None),
    ('AOO','AOO',None),
    ('ARA','ARA',None),
    ('ATB','ATB',None),
    ('AWP','AWP',None),
    ('BC040_LCN','BC040_LCN',None),
    ('BC040_PER','BC040_PER',None),
    ('BEN','BEN',None),
    ('CAA','CAA',None),
    ('CNCP',None,None),
    ('COS','COS',None),
    ('F_CODE','F_CODE',None),
    ('FFN','FFN',None),
    ('FFN2','FFN2',None),
    ('FFN3','FFN3',None),
    ('FUFI','FUFI',None),
    ('FURL','FURL','transform_combine_FURL'),
    ('GDBV',None,None),
    ('HGT','HGT',None),
    ('LMC','LMC',None),
    ('LZN','LZN',None),
    ('MAN','MAN',None),
    ('PCF','PCF',None),
    ('SSR','SSR',None),
    ('SSR2','SSR2',None),
    ('SSR3','SSR3',None),
    ('VCM','VCM',None),
    ('VCM2','VCM2',None),
    ('VCM3','VCM3',None),
    ('VOI','VOI',None),
    ('WID','WID',None),
    ('ZI002_UFI','ZI002_UFI',None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_GNT','ZI005_GNT',None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZI020_GE4','ZI020_GE4',None),
    ('ZI026_CTUC','ZI026_CTUC',None),
    ('ZI026_CTUL','ZI026_CTUL',None),
    ('ZI026_CTUU','ZI026_CTUU',None),
    ('ZI031S_URI',None,None),
    ('ZI039S_UFI',None,None),
    ('ZVH','ZVH',None),
    ('UFI','UFI','transform_set_UFI') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# HydrographyAONExt field translations
HydrographyAONExtFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Srf_fields) + [ \
    ('AQN','AQN',None),
    ('ARA','ARA',None),
    ('ATC','ATC',None),
    ('AZC','AZC',None),
    ('BBMCA','BBMCA',None),
    ('BBMCA2','BBMCA2',None),
    ('BBMCA3','BBMCA3',None),
    ('BBMCB','BBMCB',None),
    ('BBMCB2','BBMCB2',None),
    ('BBMCB3','BBMCB3',None),
    ('BEN','BEN',None),
    ('BH141_AWBA','BH141_AWBA',None),
    ('BH141_AWBB','BH141_AWBB',None),
    ('BH141_IBOA','BH141_IBOA',None),
    ('BH141_IBOB','BH141_IBOB',None),
    ('BH141_SHDA','BH141_SHDA',None),
    ('BH141_SHDB','BH141_SHDB',None),
    ('BH141_SLTA','BH141_SLTA',None),
    ('BH141_SLTB','BH141_SLTB',None),
    ('BH141_WBHA','BH141_WBHA',None),
    ('BH141_WBHB','BH141_WBHB',None),
    ('BMC','BMC',None),
    ('BMC2','BMC2',None),
    ('BMC3','BMC3',None),
    ('BPWHAC','BPWHAC',None),
    ('BPWHAL','BPWHAL',None),
    ('BPWHAU','BPWHAU',None),
    ('BPWHBC','BPWHBC',None),
    ('BPWHBL','BPWHBL',None),
    ('BPWHBU','BPWHBU',None),
    ('BPWSAC','BPWSAC',None),
    ('BPWSAL','BPWSAL',None),
    ('BPWSAU','BPWSAU',None),
    ('BPWSBC','BPWSBC',None),
    ('BPWSBL','BPWSBL',None),
    ('BPWSBU','BPWSBU',None),
    ('BWVCAC','BWVCAC',None),
    ('BWVCAL','BWVCAL',None),
    ('BWVCAU','BWVCAU',None),
    ('BWVCBC','BWVCBC',None),
    ('BWVCBL','BWVCBL',None),
    ('BWVCBU','BWVCBU',None),
    ('CAA','CAA',None),
    ('CDA','CDA',None),
    ('CDL','CDL',None),
    ('CNCP',None,None),
    ('COS','COS',None),
    ('CWT','CWT',None),
    ('DEV','DEV',None),
    ('DIT',None,None),
    ('DMD','DMD',None),
    ('DMF','DMF',None),
    ('DOF','DOF',None),
    ('DOXY',None,None),
    ('DZP','DZP',None),
    ('F_CODE','F_CODE',None),
    ('FFN','FFN',None),
    ('FFN2','FFN2',None),
    ('FFN3','FFN3',None),
    ('FRZ',None,None),
    ('FUFI','FUFI',None),
    ('FURL','FURL','transform_combine_FURL'),
    ('GDBV',None,None),
    ('HGT','HGT',None),
    ('IWT','IWT',None),
    ('LMC','LMC',None),
    ('LUN','LUN',None),
    ('LZN','LZN',None),
    ('MNS','MNS',None),
    ('MWD','MWD',None),
    ('NVS','NVS',None),
    ('PCF','PCF',None),
    ('PMPR','PMPR',None),
    ('PWA','PWA',None),
    ('PWAC','PWAC',None),
    ('PWAL','PWAL',None),
    ('PWAU','PWAU',None),
    ('RLE','RLE',None),
    ('SBB','SBB',None),
    ('SWT','SWT',None),
    ('SWW','SWW',None),
    ('TID','TID',None),
    ('VCM','VCM',None),
    ('VCM2','VCM2',None),
    ('VCM3','VCM3',None),
    ('VLM','VLM',None),
    ('WAD','WAD',None),
    ('WCC','WCC',None),
    ('WD3','WD3',None),
    ('WDAC','WDAC',None),
    ('WDAL','WDAL',None),
    ('WDAU','WDAU',None),
    ('WDH','WDH',None),
    ('WDL','WDL',None),
    ('WDST',None,None),
    ('WFT','WFT',None),
    ('WID','WID',None),
    ('WMT','WMT',None),
    ('WVA','WVA',None),
    ('WVH','WVH',None),
    ('WVL','WVL',None),
    ('ZI002_UFI','ZI002_UFI',None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_FNA2','ZI005_FNA2',None),
    ('ZI005_FNA3','ZI005_FNA3',None),
    ('ZI005_GNT','ZI005_GNT',None),
    ('ZI005_GNT2','ZI005_GNT2',None),
    ('ZI005_GNT3','ZI005_GNT3',None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZI005_NFN2','ZI005_NFN2',None),
    ('ZI005_NFN3','ZI005_NFN3',None),
    ('ZI020_GE4','ZI020_GE4',None),
    ('ZI024_ASE','ZI024_ASE',None),
    ('ZI024_AWO','ZI024_AWO',None),
    ('ZI024_AWOI',None,None),
    ('ZI024_AWOX',None,None),
    ('ZI024_CFR','ZI024_CFR',None),
    ('ZI024_CLO','ZI024_CLO',None),
    ('ZI024_CYN','ZI024_CYN',None),
    ('ZI024_DRL','ZI024_DRL',None),
    ('ZI024_FMR',None,None),
    ('ZI024_FRR',None,None),
    ('ZI024_HAR','ZI024_HAR',None),
    ('ZI024_MGN','ZI024_MGN',None),
    ('ZI024_PHW','ZI024_PHW',None),
    ('ZI024_PMP','ZI024_PMP',None),
    ('ZI024_RTP','ZI024_RTP',None),
    ('ZI024_SCC','ZI024_SCC',None),
    ('ZI024_SQN','ZI024_SQN',None),
    ('ZI024_SUL','ZI024_SUL',None),
    ('ZI024_TDS','ZI024_TDS',None),
    ('ZI024_TEP','ZI024_TEP',None),
    ('ZI024_TUR','ZI024_TUR',None),
    ('ZI024_WAC','ZI024_WAC',None),
    ('ZI024_WPAC','ZI024_PAC',None),
    ('ZI024_WSG','ZI024_WSG',None),
    ('ZI024_WTNO',None,None),
    ('ZI024_WUR','ZI024_WUR',None),
    ('ZI024_WUR2','ZI024_WUR2',None),
    ('ZI024_WUR3','ZI024_WUR3',None),
    ('ZI024_WUR4','ZI024_WUR4',None),
    ('ZI024_YWQ','ZI024_YWQ',None),
    ('ZI025_HDP','ZI025_HDP',None),
    ('ZI026_CTUC','ZI026_CTUC',None),
    ('ZI026_CTUL','ZI026_CTUL',None),
    ('ZI026_CTUU','ZI026_CTUU',None),
    ('ZI031S_URI',None,None),
    ('ZI039S_UFI',None,None),
    ('ZVH','ZVH',None),
    ('LOC','LOC','transform_LOC'),
    ('TSSM','TSSM','transform_TSSM'),
    ('TSSM2','TSSM2','transform_TSSM'),
    ('TSSM3','TSSM3','transform_TSSM'),
    ('UFI','UFI','transform_set_UFI'),
    ('WWM','WWM','transform_WWM'),
    ('WWM2','WWM2','transform_WWM'),
    ('WWM3','WWM3','transform_WWM'),
    ('ZI024_HYP','ZI024_HYP','transform_ZI024_HYP') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# HydrographyCrv field translations
HydrographyCrvFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Crv_fields) + [ \
    ('AOO','AOO',None),
    ('ARA','ARA',None),
    ('ATC','ATC',None),
    ('AWP','AWP',None),
    ('BBMCA','BBMCA',None),
    ('BBMCA2','BBMCA2',None),
    ('BBMCA3','BBMCA3',None),
    ('BBMCB','BBMCB',None),
    ('BBMCB2','BBMCB2',None),
    ('BBMCB3','BBMCB3',None),
    ('BEN','BEN',None),
    ('BH141_AWBA','BH141_AWBA',None),
    ('BH141_AWBB','BH141_AWBB',None),
    ('BH141_IBOA','BH141_IBOA',None),
    ('BH141_IBOB','BH141_IBOB',None),
    ('BH141_SHDA','BH141_SHDA',None),
    ('BH141_SHDB','BH141_SHDB',None),
    ('BH141_SLTA','BH141_SLTA',None),
    ('BH141_SLTB','BH141_SLTB',None),
    ('BH141_WBHA','BH141_WBHA',None),
    ('BH141_WBHB','BH141_WBHB',None),
    ('BMC','BMC',None),
    ('BMC2','BMC2',None),
    ('BMC3','BMC3',None),
    ('BPWHAC','BPWHAC',None),
    ('BPWHAL','BPWHAL',None),
    ('BPWHAU','BPWHAU',None),
    ('BPWHBC','BPWHBC',None),
    ('BPWHBL','BPWHBL',None),
    ('BPWHBU','BPWHBU',None),
    ('BPWSAC','BPWSAC',None),
    ('BPWSAL','BPWSAL',None),
    ('BPWSAU','BPWSAU',None),
    ('BPWSBC','BPWSBC',None),
    ('BPWSBL','BPWSBL',None),
    ('BPWSBU','BPWSBU',None),
    ('BWVCAC','BWVCAC',None),
    ('BWVCAL','BWVCAL',None),
    ('BWVCAU','BWVCAU',None),
    ('BWVCBC','BWVCBC',None),
    ('BWVCBL','BWVCBL',None),
    ('BWVCBU','BWVCBU',None),
    ('CAA','CAA',None),
    ('CDA','CDA',None),
    ('CDL','CDL',None),
    ('CNCP',None,None),
    ('COS','COS',None),
    ('CWT','CWT',None),
    ('DEV','DEV',None),
    ('DFT','DFT',None),
    ('DFU',None,None),
    ('DFU2',None,None),
    ('DFU3',None,None),
    ('DIM','DIM',None),
    ('DIT',None,None),
    ('DOXY',None,None),
    ('DSD','DSD',None),
    ('DZP','DZP',None),
    ('F_CODE','F_CODE',None),
    ('FCS','FCS',None),
    ('FRZ',None,None),
    ('FUFI','FUFI',None),
    ('FURL','FURL','transform_combine_FURL'),
    ('GDBV',None,None),
    ('HDP','HDP',None),
    ('HGS','HGS',None),
    ('HGT','HGT',None),
    ('LDC','LDC',None),
    ('LEA','LEA',None),
    ('LMC','LMC',None),
    ('LUN','LUN',None),
    ('LZN','LZN',None),
    ('MCC','MCC',None),
    ('MCC2','MCC2',None),
    ('MCC3','MCC3',None),
    ('MWD','MWD',None),
    ('NVS','NVS',None),
    ('PCF','PCF',None),
    ('PWA','PWA',None),
    ('PWAC','PWAC',None),
    ('PWAL','PWAL',None),
    ('PWAU','PWAU',None),
    ('RLE','RLE',None),
    ('SBB','SBB',None),
    ('SPT','SPT',None),
    ('STNB',None,None),
    ('THI','THI',None),
    ('TID','TID',None),
    ('VLM','VLM',None),
    ('VOI','VOI',None),
    ('WCC','WCC',None),
    ('WD3','WD3',None),
    ('WDAC','WDAC',None),
    ('WDAL','WDAL',None),
    ('WDAU','WDAU',None),
    ('WDH','WDH',None),
    ('WDL','WDL',None),
    ('WID','WID',None),
    ('WMT','WMT',None),
    ('WOC','WOC',None),
    ('WRT','WRT',None),
    ('WVA','WVA',None),
    ('WVH','WVH',None),
    ('WVL','WVL',None),
    ('ZI002_UFI','ZI002_UFI',None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_FNA2','ZI005_FNA2',None),
    ('ZI005_FNA3','ZI005_FNA3',None),
    ('ZI005_GNT','ZI005_GNT',None),
    ('ZI005_GNT2','ZI005_GNT2',None),
    ('ZI005_GNT3','ZI005_GNT3',None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZI005_NFN2','ZI005_NFN2',None),
    ('ZI005_NFN3','ZI005_NFN3',None),
    ('ZI020_GE4','ZI020_GE4',None),
    ('ZI024_ASE','ZI024_ASE',None),
    ('ZI024_AWO','ZI024_AWO',None),
    ('ZI024_AWOI',None,None),
    ('ZI024_AWOX',None,None),
    ('ZI024_CFR','ZI024_CFR',None),
    ('ZI024_CLO','ZI024_CLO',None),
    ('ZI024_CYN','ZI024_CYN',None),
    ('ZI024_FMR',None,None),
    ('ZI024_FRR',None,None),
    ('ZI024_HAR','ZI024_HAR',None),
    ('ZI024_MGN','ZI024_MGN',None),
    ('ZI024_PHW','ZI024_PHW',None),
    ('ZI024_SCC','ZI024_SCC',None),
    ('ZI024_SQN','ZI024_SQN',None),
    ('ZI024_SUL','ZI024_SUL',None),
    ('ZI024_TDS','ZI024_TDS',None),
    ('ZI024_TEP','ZI024_TEP',None),
    ('ZI024_TUR','ZI024_TUR',None),
    ('ZI024_WAC','ZI024_WAC',None),
    ('ZI024_WPAC','ZI024_PAC',None),
    ('ZI024_WSG','ZI024_WSG',None),
    ('ZI024_WTNO',None,None),
    ('ZI024_WUR','ZI024_WUR',None),
    ('ZI024_WUR2','ZI024_WUR2',None),
    ('ZI024_WUR3','ZI024_WUR3',None),
    ('ZI024_WUR4','ZI024_WUR4',None),
    ('ZI024_YWQ','ZI024_YWQ',None),
    ('ZI025_HDP','ZI025_HDP',None),
    ('ZI026_CTUC','ZI026_CTUC',None),
    ('ZI026_CTUL','ZI026_CTUL',None),
    ('ZI026_CTUU','ZI026_CTUU',None),
    ('ZI031S_URI',None,None),
    ('ZI039S_UFI',None,None),
    ('ZVH','ZVH',None),
    ('LOC','LOC','transform_LOC'),
    (None,'DWT','transformDFU_to_DWT'),
    ('TRS','TRS','transform_TRS'),
    ('TRS2','TRS2','transform_TRS'),
    ('TRS3','TRS3','transform_TRS'),
    ('UFI','UFI','transform_set_UFI'),
    ('ZI024_HYP','ZI024_HYP','transform_ZI024_HYP') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# HydrographyCrvExt field translations
HydrographyCrvExtFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Crv_fields) + [ \
    ('ARA','ARA',None),
    ('BDS','BDS',None),
    ('BEN','BEN',None),
    ('BRG','BRG',None),
    ('BRR','BRR',None),
    ('BRS','BRS',None),
    ('CAA','CAA',None),
    ('CFT','CFT',None),
    ('CRV','CRV',None),
    ('DAN','DAN',None),
    ('DMC','DMC',None),
    ('DOF','DOF',None),
    ('DPG','DPG',None),
    ('DPG2','DPG2',None),
    ('DPG3','DPG3',None),
    ('DRP','DRP',None),
    ('DSP','DSP',None),
    ('F_CODE','F_CODE',None),
    ('FUFI','FUFI',None),
    ('FURL','FURL','transform_combine_FURL'),
    ('GDBV',None,None),
    ('HDP','HDP',None),
    ('HGT','HGT',None),
    ('IAS','IAS',None),
    ('LAF','LAF',None),
    ('LOR','LOR',None),
    ('LZN','LZN',None),
    ('MAN','MAN',None),
    ('MAS','MAS',None),
    ('MCC','MCC',None),
    ('MCC2','MCC2',None),
    ('MCC3','MCC3',None),
    ('MCY','MCY',None),
    ('MCY2','MCY2',None),
    ('MCY3','MCY3',None),
    ('MLO','MLO',None),
    ('MNR','MNR',None),
    ('MNR2','MNR2',None),
    ('MNR3','MNR3',None),
    ('MRR','MRR',None),
    ('MRR2','MRR2',None),
    ('MRR3','MRR3',None),
    ('NFP','NFP',None),
    ('NFP2','NFP2',None),
    ('NFP3','NFP3',None),
    ('NOA','NOA',None),
    ('NOA2','NOA2',None),
    ('NOA3','NOA3',None),
    ('PCF','PCF',None),
    ('RTT','RTT',None),
    ('TAN','TAN',None),
    ('TSP','TSP',None),
    ('WID','WID',None),
    ('WTT','WTT',None),
    ('ZHDP_DCR','ZHDP_DCR',None),
    ('ZHDP_DKC','ZHDP_DKC',None),
    ('ZHDP_DKC2','ZHDP_DKC2',None),
    ('ZHDP_DKC3','ZHDP_DKC3',None),
    ('ZHDP_SVC','ZHDP_SVC',None),
    ('ZHDP_TEC','ZHDP_TEC',None),
    ('ZHDP_TEC2','ZHDP_TEC2',None),
    ('ZHDP_TEC3','ZHDP_TEC3',None),
    ('ZHDP_VDC','ZHDP_VDC',None),
    ('ZHDP_VDR','ZHDP_VDR',None),
    ('ZI002_UFI','ZI002_UFI',None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_GNT','ZI005_GNT',None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZI012_DCR','ZI012_DCR',None),
    ('ZI012_DKC','ZI012_DKC',None),
    ('ZI012_DKC2','ZI012_DKC2',None),
    ('ZI012_DKC3','ZI012_DKC3',None),
    ('ZI012_SVC','ZI012_SVC',None),
    ('ZI012_TEC','ZI012_TEC',None),
    ('ZI012_TEC2','ZI012_TEC2',None),
    ('ZI012_TEC3','ZI012_TEC3',None),
    ('ZI012_VDC','ZI012_VDC',None),
    ('ZI012_VDR','ZI012_VDR',None),
    ('ZI020_GE4','ZI020_GE4',None),
    ('ZI025_HDP','ZI025_HDP',None),
    ('ZI025_WLE','ZI025_WLE',None),
    ('ZI026_CTUC','ZI026_CTUC',None),
    ('ZI026_CTUL','ZI026_CTUL',None),
    ('ZI026_CTUU','ZI026_CTUU',None),
    ('ZI031S_URI',None,None),
    ('ZI039S_UFI',None,None),
    ('UFI','UFI','transform_set_UFI') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# HydrographyPnt field translations
HydrographyPntFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Pnt_fields) + [ \
    ('AOO','AOO',None),
    ('AQN','AQN',None),
    ('ARA','ARA',None),
    ('AWP','AWP',None),
    ('AZC','AZC',None),
    ('BC034_MRT','BC034_MRT',None),
    ('BC034_MRT2','BC034_MRT2',None),
    ('BC034_MRT3','BC034_MRT3',None),
    ('BC101_SST','BC101_SST',None),
    ('BEN','BEN',None),
    ('BH010_CAA','BH010_CAA',None),
    ('BH141_AWBA','BH141_AWBA',None),
    ('BH141_AWBB','BH141_AWBB',None),
    ('BH141_IBOA','BH141_IBOA',None),
    ('BH141_IBOB','BH141_IBOB',None),
    ('BH141_SHDA','BH141_SHDA',None),
    ('BH141_SHDB','BH141_SHDB',None),
    ('BH141_SLTA','BH141_SLTA',None),
    ('BH141_SLTB','BH141_SLTB',None),
    ('BH141_WBHA','BH141_WBHA',None),
    ('BH141_WBHB','BH141_WBHB',None),
    ('BPWHAC','BPWHAC',None),
    ('BPWHAL','BPWHAL',None),
    ('BPWHAU','BPWHAU',None),
    ('BPWHBC','BPWHBC',None),
    ('BPWHBL','BPWHBL',None),
    ('BPWHBU','BPWHBU',None),
    ('BPWSAC','BPWSAC',None),
    ('BPWSAL','BPWSAL',None),
    ('BPWSAU','BPWSAU',None),
    ('BPWSBC','BPWSBC',None),
    ('BPWSBL','BPWSBL',None),
    ('BPWSBU','BPWSBU',None),
    ('BWVCAC','BWVCAC',None),
    ('BWVCAL','BWVCAL',None),
    ('BWVCAU','BWVCAU',None),
    ('BWVCBC','BWVCBC',None),
    ('BWVCBL','BWVCBL',None),
    ('BWVCBU','BWVCBU',None),
    ('CAA','CAA',None),
    ('CDI','WCSD',None),
    ('CNCP',None,None),
    ('COS','COS',None),
    ('DFT','DFT',None),
    ('DFU',None,None),
    ('DFU2',None,None),
    ('DFU3',None,None),
    ('DMD','DMD',None),
    ('DOF','DOF',None),
    ('DOXY',None,None),
    ('DSD','DSD',None),
    ('DWL','WDWL',None),
    ('DZP','DZP',None),
    ('F_CODE','F_CODE',None),
    ('FCS','FCS',None),
    ('FFN','FFN',None),
    ('FFN2','FFN2',None),
    ('FFN3','FFN3',None),
    ('FRZ',None,None),
    ('FUFI','FUFI',None),
    ('FURL','FURL','transform_combine_FURL'),
    ('GDBV',None,None),
    ('HDP','HDP',None),
    ('HGS','HGS',None),
    ('HGT','HGT',None),
    ('IWT','IWT',None),
    ('LDC','LDC',None),
    ('LEA','LEA',None),
    ('LMC','LMC',None),
    ('LUN','LUN',None),
    ('LZN','LZN',None),
    ('MCC','MCC',None),
    ('MCC2','MCC2',None),
    ('MCC3','MCC3',None),
    ('MNS','MNS',None),
    ('OCS','OCS',None),
    ('PCF','PCF',None),
    ('PMPR','PMPR',None),
    ('PSE','PSE',None),
    ('PUD','WPUP',None),
    ('PWAC','PWAC',None),
    ('PWAL','PWAL',None),
    ('PWAU','PWAU',None),
    ('SCOG',None,None),
    ('SWT','SWT',None),
    ('SWW','SWW',None),
    ('THI','THI',None),
    ('TID','TID',None),
    ('TSTE',None,None),
    ('VCM','VCM',None),
    ('VCM2','VCM2',None),
    ('VCM3','VCM3',None),
    ('VLM','VLM',None),
    ('VOI','VOI',None),
    ('WAD','WAD',None),
    ('WCAC',None,None),
    ('WDAC','WDAC',None),
    ('WDAL','WDAL',None),
    ('WDAU','WDAU',None),
    ('WDH','WDH',None),
    ('WDL','WDL',None),
    ('WDST',None,None),
    ('WFT','WFT',None),
    ('WHCO',None,None),
    ('WID','WID',None),
    ('WOC','WOC',None),
    ('WODR',None,None),
    ('WST','WST',None),
    ('WTBB',None,None),
    ('WTCA',None,None),
    ('WTCL',None,None),
    ('WTFE',None,None),
    ('WTKK',None,None),
    ('WTMN',None,None),
    ('WTNA',None,None),
    ('WTNO',None,None),
    ('WTPO',None,None),
    ('WTSI',None,None),
    ('WTST',None,None),
    ('WVA','WVA',None),
    ('WVH','WVH',None),
    ('WVL','WVL',None),
    ('ZI002_UFI','ZI002_UFI',None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_FNA2','ZI005_FNA2',None),
    ('ZI005_FNA3','ZI005_FNA3',None),
    ('ZI005_GNT','ZI005_GNT',None),
    ('ZI005_GNT2','ZI005_GNT2',None),
    ('ZI005_GNT3','ZI005_GNT3',None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZI005_NFN2','ZI005_NFN2',None),
    ('ZI005_NFN3','ZI005_NFN3',None),
    ('ZI020_GE4','ZI020_GE4',None),
    ('ZI024_ASE','ZI024_ASE',None),
    ('ZI024_AWO','ZI024_AWO',None),
    ('ZI024_AWOI',None,None),
    ('ZI024_AWOX',None,None),
    ('ZI024_CFR','ZI024_CFR',None),
    ('ZI024_CLO','ZI024_CLO',None),
    ('ZI024_CYN','ZI024_CYN',None),
    ('ZI024_DRL','ZI024_DRL',None),
    ('ZI024_DVPT','ZI024_DVT',None),
    ('ZI024_FMR',None,None),
    ('ZI024_FRR',None,None),
    ('ZI024_HAR','ZI024_HAR',None),
    ('ZI024_MGN','ZI024_MGN',None),
    ('ZI024_PHW','ZI024_PHW',None),
    ('ZI024_PMP','ZI024_PMP',None),
    ('ZI024_RTP','ZI024_RTP',None),
    ('ZI024_SCC','ZI024_SCC',None),
    ('ZI024_SUL','ZI024_SUL',None),
    ('ZI024_TDS','ZI024_TDS',None),
    ('ZI024_TEP','ZI024_TEP',None),
    ('ZI024_TUR','ZI024_TUR',None),
    ('ZI024_WAC','ZI024_WAC',None),
    ('ZI024_WPAC','ZI024_PAC',None),
    ('ZI024_WTBB',None,None),
    ('ZI024_WTCA',None,None),
    ('ZI024_WTFE',None,None),
    ('ZI024_WTKK',None,None),
    ('ZI024_WTMN',None,None),
    ('ZI024_WTNA',None,None),
    ('ZI024_WTNO',None,None),
    ('ZI024_WTPO',None,None),
    ('ZI024_WTSI',None,None),
    ('ZI024_WUR','ZI024_WUR',None),
    ('ZI024_WUR2','ZI024_WUR2',None),
    ('ZI024_WUR3','ZI024_WUR3',None),
    ('ZI024_WUR4','ZI024_WUR4',None),
    ('ZI024_YWQ','ZI024_YWQ',None),
    ('ZI025_HDP','ZI025_HDP',None),
    ('ZI025_MAN','ZI025_MAN',None),
    ('ZI026_CTUC','ZI026_CTUC',None),
    ('ZI026_CTUL','ZI026_CTUL',None),
    ('ZI026_CTUU','ZI026_CTUU',None),
    ('ZI031S_URI',None,None),
    ('ZI039S_UFI',None,None),
    ('ZVH','ZVH',None),
    (None,'DWT','transformDFU_to_DWT'),
    ('TRS','TRS','transform_TRS'),
    ('TRS2','TRS2','transform_TRS'),
    ('TRS3','TRS3','transform_TRS'),
    ('TSSM','TSSM','transform_TSSM'),
    ('TSSM2','TSSM2','transform_TSSM'),
    ('TSSM3','TSSM3','transform_TSSM'),
    ('UFI','UFI','transform_set_UFI'),
    ('WWM','WWM','transform_WWM'),
    ('WWM2','WWM2','transform_WWM'),
    ('WWM3','WWM3','transform_WWM'),
    ('ZI024_HYP','ZI024_HYP','transform_ZI024_HYP') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# HydrographyPntExt field translations
HydrographyPntExtFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Pnt_fields) + [ \
    ('ARA','ARA',None),
    ('BEN','BEN',None),
    ('C35','C35',None),
    ('C36','C36',None),
    ('C37','C37',None),
    ('C38','C38',None),
    ('C39','C39',None),
    ('C40','C40',None),
    ('C41','C41',None),
    ('C42','C42',None),
    ('C43','C43',None),
    ('C44','C44',None),
    ('C45','C45',None),
    ('C46','C46',None),
    ('CAA','CAA',None),
    ('CNCP',None,None),
    ('COS','COS',None),
    ('CRN','CRN',None),
    ('CRS','CRS',None),
    ('CRX','CRX',None),
    ('CUR','CUR',None),
    ('D35','D35',None),
    ('D36','D36',None),
    ('D37','D37',None),
    ('D38','D38',None),
    ('D39','D39',None),
    ('D40','D40',None),
    ('D41','D41',None),
    ('D42','D42',None),
    ('D43','D43',None),
    ('D44','D44',None),
    ('D45','D45',None),
    ('D46','D46',None),
    ('DKC','DKC',None),
    ('DKC2','DKC2',None),
    ('DKC3','DKC3',None),
    ('DOF','DOF',None),
    ('DTN','DTN',None),
    ('DZP','DZP',None),
    ('F_CODE','F_CODE',None),
    ('FLO','FLO',None),
    ('FUFI','FUFI',None),
    ('FURL','FURL','transform_combine_FURL'),
    ('GDBV',None,None),
    ('HDH','HDH',None),
    ('HDP','HDP',None),
    ('HSE','HSE',None),
    ('IAS','IAS',None),
    ('LZN','LZN',None),
    ('MAN','MAN',None),
    ('MBC_MCC1','MBC_MCC1',None),
    ('MBC_MCC2','MBC_MCC2',None),
    ('MBC_PSC1','MBC_PSC1',None),
    ('MBC_PSC2','MBC_PSC2',None),
    ('MBC_SCO1','MBC_SCO1',None),
    ('MBC_SCO2','MBC_SCO2',None),
    ('MCC','MCC',None),
    ('MCC2','MCC2',None),
    ('MCC3','MCC3',None),
    ('PCF','PCF',None),
    ('REW','REW',None),
    ('TAN','TAN',None),
    ('TSP','TSP',None),
    ('VSP','VSP',None),
    ('VSP2','VSP2',None),
    ('VSP3','VSP3',None),
    ('WID','WID',None),
    ('WLO','WLO',None),
    ('WTT','WTT',None),
    ('ZHBH_TEC','ZHBH_TEC',None),
    ('ZHBH_TEC2','ZHBH_TEC2',None),
    ('ZHBH_TEC3','ZHBH_TEC3',None),
    ('ZHDP_DCR','ZHDP_DCR',None),
    ('ZHDP_DKC','ZHDP_DKC',None),
    ('ZHDP_DKC2','ZHDP_DKC2',None),
    ('ZHDP_DKC3','ZHDP_DKC3',None),
    ('ZHDP_SVC','ZHDP_SVC',None),
    ('ZHDP_TEC','ZHDP_TEC',None),
    ('ZHDP_TEC2','ZHDP_TEC2',None),
    ('ZHDP_TEC3','ZHDP_TEC3',None),
    ('ZHDP_VDC','ZHDP_VDC',None),
    ('ZHDP_VDR','ZHDP_VDR',None),
    ('ZI002_UFI','ZI002_UFI',None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_GNT','ZI005_GNT',None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZI020_GE4','ZI020_GE4',None),
    ('ZI025_HDP','ZI025_HDP',None),
    ('ZI025_UHS','ZI025_UHS',None),
    ('ZI025_WLE','ZI025_WLE',None),
    ('ZI026_CTUC','ZI026_CTUC',None),
    ('ZI026_CTUL','ZI026_CTUL',None),
    ('ZI026_CTUU','ZI026_CTUU',None),
    ('ZI031S_URI',None,None),
    ('ZI039S_UFI',None,None),
    ('UFI','UFI','transform_set_UFI'),
    ('VEG','VEG','transform_VEG') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# HydrographySrf field translations
HydrographySrfFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Srf_fields) + [ \
    ('AOO','AOO',None),
    ('AQN','AQN',None),
    ('ARA','ARA',None),
    ('ATC','ATC',None),
    ('AWP','AWP',None),
    ('AZC','AZC',None),
    ('BBMCA','BBMCA',None),
    ('BBMCA2','BBMCA2',None),
    ('BBMCA3','BBMCA3',None),
    ('BBMCB','BBMCB',None),
    ('BBMCB2','BBMCB2',None),
    ('BBMCB3','BBMCB3',None),
    ('BC034_MRT','BC034_MRT',None),
    ('BC034_MRT2','BC034_MRT2',None),
    ('BC034_MRT3','BC034_MRT3',None),
    ('BC101_SST','BC101_SST',None),
    ('BEN','BEN',None),
    ('BH141_AWBA','BH141_AWBA',None),
    ('BH141_AWBB','BH141_AWBB',None),
    ('BH141_IBOA','BH141_IBOA',None),
    ('BH141_IBOB','BH141_IBOB',None),
    ('BH141_SHDA','BH141_SHDA',None),
    ('BH141_SHDB','BH141_SHDB',None),
    ('BH141_SLTA','BH141_SLTA',None),
    ('BH141_SLTB','BH141_SLTB',None),
    ('BH141_WBHA','BH141_WBHA',None),
    ('BH141_WBHB','BH141_WBHB',None),
    ('BMC','BMC',None),
    ('BMC2','BMC2',None),
    ('BMC3','BMC3',None),
    ('BPWHAC','BPWHAC',None),
    ('BPWHAL','BPWHAL',None),
    ('BPWHAU','BPWHAU',None),
    ('BPWHBC','BPWHBC',None),
    ('BPWHBL','BPWHBL',None),
    ('BPWHBU','BPWHBU',None),
    ('BPWSAC','BPWSAC',None),
    ('BPWSAL','BPWSAL',None),
    ('BPWSAU','BPWSAU',None),
    ('BPWSBC','BPWSBC',None),
    ('BPWSBL','BPWSBL',None),
    ('BPWSBU','BPWSBU',None),
    ('BWVCAC','BWVCAC',None),
    ('BWVCAL','BWVCAL',None),
    ('BWVCAU','BWVCAU',None),
    ('BWVCBC','BWVCBC',None),
    ('BWVCBL','BWVCBL',None),
    ('BWVCBU','BWVCBU',None),
    ('CAA','CAA',None),
    ('CDA','CDA',None),
    ('CDI','WCSD',None),
    ('CDL','CDL',None),
    ('CNCP',None,None),
    ('COS','COS',None),
    ('CWT','CWT',None),
    ('DEV','DEV',None),
    ('DFT','DFT',None),
    ('DFU',None,None),
    ('DFU2',None,None),
    ('DFU3',None,None),
    ('DIT',None,None),
    ('DMD','DMD',None),
    ('DOF','DOF',None),
    ('DOXY',None,None),
    ('DSD','DSD',None),
    ('DWL','WDWL',None),
    ('DZP','DZP',None),
    ('F_CODE','F_CODE',None),
    ('FCS','FCS',None),
    ('FFN','FFN',None),
    ('FFN2','FFN2',None),
    ('FFN3','FFN3',None),
    ('FRZ',None,None),
    ('FUFI','FUFI',None),
    ('FURL','FURL','transform_combine_FURL'),
    ('GDBV',None,None),
    ('HDP','HDP',None),
    ('HGS','HGS',None),
    ('HGT','HGT',None),
    ('INU','INU',None),
    ('IWT','IWT',None),
    ('LDC','LDC',None),
    ('LEA','LEA',None),
    ('LMC','LMC',None),
    ('LUN','LUN',None),
    ('LZN','LZN',None),
    ('MCC','MCC',None),
    ('MCC2','MCC2',None),
    ('MCC3','MCC3',None),
    ('MNS','MNS',None),
    ('MWD','MWD',None),
    ('NVS','NVS',None),
    ('OCS','OCS',None),
    ('PCF','PCF',None),
    ('PSE','PSE',None),
    ('PUD','WPUP',None),
    ('PWA','PWA',None),
    ('PWAC','PWAC',None),
    ('PWAL','PWAL',None),
    ('PWAU','PWAU',None),
    ('RLE','RLE',None),
    ('SBB','SBB',None),
    ('SCOG',None,None),
    ('STNB',None,None),
    ('SWT','SWT',None),
    ('SWW','SWW',None),
    ('TID','TID',None),
    ('TSTE',None,None),
    ('VCM','VCM',None),
    ('VCM2','VCM2',None),
    ('VCM3','VCM3',None),
    ('VLM','VLM',None),
    ('VOI','VOI',None),
    ('WAD','WAD',None),
    ('WCAC',None,None),
    ('WCC','WCC',None),
    ('WD3','WD3',None),
    ('WDAC','WDAC',None),
    ('WDAL','WDAL',None),
    ('WDAU','WDAU',None),
    ('WDH','WDH',None),
    ('WDL','WDL',None),
    ('WDST',None,None),
    ('WFT','WFT',None),
    ('WHCO',None,None),
    ('WID','WID',None),
    ('WMT','WMT',None),
    ('WOC','WOC',None),
    ('WODR',None,None),
    ('WTBB',None,None),
    ('WTCA',None,None),
    ('WTCL',None,None),
    ('WTFE',None,None),
    ('WTKK',None,None),
    ('WTMN',None,None),
    ('WTNA',None,None),
    ('WTNO',None,None),
    ('WTPO',None,None),
    ('WTSI',None,None),
    ('WTST',None,None),
    ('WVA','WVA',None),
    ('WVH','WVH',None),
    ('WVL','WVL',None),
    ('ZI002_UFI','ZI002_UFI',None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_FNA2','ZI005_FNA2',None),
    ('ZI005_FNA3','ZI005_FNA3',None),
    ('ZI005_GNT','ZI005_GNT',None),
    ('ZI005_GNT2','ZI005_GNT2',None),
    ('ZI005_GNT3','ZI005_GNT3',None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZI005_NFN2','ZI005_NFN2',None),
    ('ZI005_NFN3','ZI005_NFN3',None),
    ('ZI020_GE4','ZI020_GE4',None),
    ('ZI024_ASE','ZI024_ASE',None),
    ('ZI024_AWO','ZI024_AWO',None),
    ('ZI024_AWOI',None,None),
    ('ZI024_AWOX',None,None),
    ('ZI024_CFR','ZI024_CFR',None),
    ('ZI024_CLO','ZI024_CLO',None),
    ('ZI024_CYN','ZI024_CYN',None),
    ('ZI024_DRL','ZI024_DRL',None),
    ('ZI024_DVPT','ZI024_DVT',None),
    ('ZI024_FMR',None,None),
    ('ZI024_FRR',None,None),
    ('ZI024_HAR','ZI024_HAR',None),
    ('ZI024_MGN','ZI024_MGN',None),
    ('ZI024_PHW','ZI024_PHW',None),
    ('ZI024_PMP','ZI024_PMP',None),
    ('ZI024_RTP','ZI024_RTP',None),
    ('ZI024_SCC','ZI024_SCC',None),
    ('ZI024_SQN','ZI024_SQN',None),
    ('ZI024_SUL','ZI024_SUL',None),
    ('ZI024_TDS','ZI024_TDS',None),
    ('ZI024_TEP','ZI024_TEP',None),
    ('ZI024_TUR','ZI024_TUR',None),
    ('ZI024_WAC','ZI024_WAC',None),
    ('ZI024_WPAC','ZI024_PAC',None),
    ('ZI024_WSG','ZI024_WSG',None),
    ('ZI024_WTBB',None,None),
    ('ZI024_WTCA',None,None),
    ('ZI024_WTFE',None,None),
    ('ZI024_WTKK',None,None),
    ('ZI024_WTMN',None,None),
    ('ZI024_WTNA',None,None),
    ('ZI024_WTNO',None,None),
    ('ZI024_WTPO',None,None),
    ('ZI024_WTSI',None,None),
    ('ZI024_WUR','ZI024_WUR',None),
    ('ZI024_WUR2','ZI024_WUR2',None),
    ('ZI024_WUR3','ZI024_WUR3',None),
    ('ZI024_WUR4','ZI024_WUR4',None),
    ('ZI024_YWQ','ZI024_YWQ',None),
    ('ZI025_HDP','ZI025_HDP',None),
    ('ZI025_MAN','ZI025_MAN',None),
    ('ZI026_CTUC','ZI026_CTUC',None),
    ('ZI026_CTUL','ZI026_CTUL',None),
    ('ZI026_CTUU','ZI026_CTUU',None),
    ('ZI031S_URI',None,None),
    ('ZI039S_UFI',None,None),
    ('ZVH','ZVH',None),
    ('LOC','LOC','transform_LOC'),
    (None,'DWT','transformDFU_to_DWT'),
    ('TRS','TRS','transform_TRS'),
    ('TRS2','TRS2','transform_TRS'),
    ('TRS3','TRS3','transform_TRS'),
    ('TSSM','TSSM','transform_TSSM'),
    ('TSSM2','TSSM2','transform_TSSM'),
    ('TSSM3','TSSM3','transform_TSSM'),
    ('UFI','UFI','transform_set_UFI'),
    ('WWM','WWM','transform_WWM'),
    ('WWM2','WWM2','transform_WWM'),
    ('WWM3','WWM3','transform_WWM'),
    ('ZI024_HYP','ZI024_HYP','transform_ZI024_HYP') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# HydrographySrfExt field translations
HydrographySrfExtFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Srf_fields) + [ \
    ('AQF','AQF',None),
    ('ARA','ARA',None),
    ('BDS','BDS',None),
    ('BEN','BEN',None),
    ('BMC','BMC',None),
    ('BMC2','BMC2',None),
    ('BMC3','BMC3',None),
    ('BRR','BRR',None),
    ('BRS','BRS',None),
    ('CAA','CAA',None),
    ('CAB','CAB',None),
    ('CNCP',None,None),
    ('COA','COA',None),
    ('COC','COC',None),
    ('COG','COG',None),
    ('COS','COS',None),
    ('DAN','DAN',None),
    ('DKC','DKC',None),
    ('DKC2','DKC2',None),
    ('DKC3','DKC3',None),
    ('DOF','DOF',None),
    ('DOXY',None,None),
    ('DRP','DRP',None),
    ('DTN','DTN',None),
    ('F_CODE','F_CODE',None),
    ('FLO','FLO',None),
    ('FUFI','FUFI',None),
    ('FURL','FURL','transform_combine_FURL'),
    ('GDBV',None,None),
    ('HDP','HDP',None),
    ('IAS','IAS',None),
    ('LMC','LMC',None),
    ('LZN','LZN',None),
    ('MAN','MAN',None),
    ('MAS','MAS',None),
    ('MBC_MCC1','MBC_MCC1',None),
    ('MBC_MCC2','MBC_MCC2',None),
    ('MBC_PSC1','MBC_PSC1',None),
    ('MBC_PSC2','MBC_PSC2',None),
    ('MBC_SCO1','MBC_SCO1',None),
    ('MBC_SCO2','MBC_SCO2',None),
    ('MCC','MCC',None),
    ('MCC2','MCC2',None),
    ('MCC3','MCC3',None),
    ('MCY','MCY',None),
    ('MCY2','MCY2',None),
    ('MCY3','MCY3',None),
    ('MFE','MFE',None),
    ('MLO','MLO',None),
    ('MNR','MNR',None),
    ('MNR2','MNR2',None),
    ('MNR3','MNR3',None),
    ('MRR','MRR',None),
    ('MRR2','MRR2',None),
    ('MRR3','MRR3',None),
    ('OPT','OPT',None),
    ('ORS','ORS',None),
    ('ORS2','ORS2',None),
    ('ORS3','ORS3',None),
    ('PCF','PCF',None),
    ('PPO','PPO',None),
    ('PPO2','PPO2',None),
    ('PPO3','PPO3',None),
    ('PWAC','PWAC',None),
    ('PWAL','PWAL',None),
    ('PWAU','PWAU',None),
    ('RTT','RTT',None),
    ('TAN','TAN',None),
    ('TSP','TSP',None),
    ('VSP','VSP',None),
    ('VSP2','VSP2',None),
    ('VSP3','VSP3',None),
    ('WDAC','WDAC',None),
    ('WDAL','WDAL',None),
    ('WDAU','WDAU',None),
    ('WDH','WDH',None),
    ('WDL','WDL',None),
    ('WID','WID',None),
    ('WLO','WLO',None),
    ('WPC','WPC',None),
    ('WPC2','WPC2',None),
    ('WPC3','WPC3',None),
    ('WTT','WTT',None),
    ('ZHBH_TEC','ZHBH_TEC',None),
    ('ZHBH_TEC2','ZHBH_TEC2',None),
    ('ZHBH_TEC3','ZHBH_TEC3',None),
    ('ZHDP_DCR','ZHDP_DCR',None),
    ('ZHDP_DKC','ZHDP_DKC',None),
    ('ZHDP_DKC2','ZHDP_DKC2',None),
    ('ZHDP_DKC3','ZHDP_DKC3',None),
    ('ZHDP_SVC','ZHDP_SVC',None),
    ('ZHDP_TEC','ZHDP_TEC',None),
    ('ZHDP_TEC2','ZHDP_TEC2',None),
    ('ZHDP_TEC3','ZHDP_TEC3',None),
    ('ZHDP_VDC','ZHDP_VDC',None),
    ('ZHDP_VDR','ZHDP_VDR',None),
    ('ZI002_UFI','ZI002_UFI',None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_FNA2','ZI005_FNA2',None),
    ('ZI005_FNA3','ZI005_FNA3',None),
    ('ZI005_GNT','ZI005_GNT',None),
    ('ZI005_GNT2','ZI005_GNT2',None),
    ('ZI005_GNT3','ZI005_GNT3',None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZI005_NFN2','ZI005_NFN2',None),
    ('ZI005_NFN3','ZI005_NFN3',None),
    ('ZI020_GE4','ZI020_GE4',None),
    ('ZI024_ASE','ZI024_ASE',None),
    ('ZI024_CFR','ZI024_CFR',None),
    ('ZI024_CLO','ZI024_CLO',None),
    ('ZI024_CYN','ZI024_CYN',None),
    ('ZI024_FMR',None,None),
    ('ZI024_FRR',None,None),
    ('ZI024_HAR','ZI024_HAR',None),
    ('ZI024_MGN','ZI024_MGN',None),
    ('ZI024_PHW','ZI024_PHW',None),
    ('ZI024_SCC','ZI024_SCC',None),
    ('ZI024_SUL','ZI024_SUL',None),
    ('ZI024_TDS','ZI024_TDS',None),
    ('ZI024_TEP','ZI024_TEP',None),
    ('ZI024_TUR','ZI024_TUR',None),
    ('ZI024_WAC','ZI024_WAC',None),
    ('ZI024_WTNO',None,None),
    ('ZI025_HDP','ZI025_HDP',None),
    ('ZI025_WLE','ZI025_WLE',None),
    ('ZI026_CTUC','ZI026_CTUC',None),
    ('ZI026_CTUL','ZI026_CTUL',None),
    ('ZI026_CTUU','ZI026_CTUU',None),
    ('ZI031S_URI',None,None),
    ('ZI039S_UFI',None,None),
    ('UFI','UFI','transform_set_UFI'),
    ('VEG','VEG','transform_VEG'),
    ('ZI024_HYP','ZI024_HYP','transform_ZI024_HYP') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# HypsographyCrv field translations
HypsographyCrvFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Crv_fields) + [ \
    ('BEN','BEN',None),
    ('ESC','ESC',None),
    ('F_CODE','F_CODE',None),
    ('FUFI','FUFI',None),
    ('FURL','FURL','transform_combine_FURL'),
    ('GDBV',None,None),
    ('HQC','HQC',None),
    ('ZI002_UFI','ZI002_UFI',None),
    ('ZI020_GE4','ZI020_GE4',None),
    ('ZI026_CTUC','ZI026_CTUC',None),
    ('ZI026_CTUL','ZI026_CTUL',None),
    ('ZI026_CTUU','ZI026_CTUU',None),
    ('ZI031S_URI',None,None),
    ('ZI039S_UFI',None,None),
    ('ZVH','ZVH',None),
    ('UFI','UFI','transform_set_UFI') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# HypsographyPnt field translations
HypsographyPntFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Pnt_fields) + [ \
    ('BEL','BEL',None),
    ('BEN','BEN',None),
    ('CAA','CAA',None),
    ('ESC','ESC',None),
    ('F_CODE','F_CODE',None),
    ('FUFI','FUFI',None),
    ('FURL','FURL','transform_combine_FURL'),
    ('GDBV',None,None),
    ('PCF','PCF',None),
    ('SUY','SUY',None),
    ('ZI002_UFI','ZI002_UFI',None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_GNT','ZI005_GNT',None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZI020_GE4','ZI020_GE4',None),
    ('ZI026_CTUC','ZI026_CTUC',None),
    ('ZI026_CTUL','ZI026_CTUL',None),
    ('ZI026_CTUU','ZI026_CTUU',None),
    ('ZI031S_URI',None,None),
    ('ZI039S_UFI',None,None),
    ('ZVH','ZVH',None),
    ('ZVH_AVA','ZVH_AVA',None),
    ('UFI','UFI','transform_set_UFI'),
    ('ZVH_VDT','ZVH_VDT','transformVDTenumeration2VDTcodelist') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# HypsographyPntExt field translations
HypsographyPntExtFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Pnt_fields) + [ \
    ('BEN','BEN',None),
    ('CPA','CPA',None),
    ('F_CODE','F_CODE',None),
    ('FUFI','FUFI',None),
    ('FURL','FURL','transform_combine_FURL'),
    ('GDBV',None,None),
    ('PCF','PCF',None),
    ('ZI002_UFI','ZI002_UFI',None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_GNT','ZI005_GNT',None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZI020_GE4','ZI020_GE4',None),
    ('ZI026_CTUC','ZI026_CTUC',None),
    ('ZI026_CTUL','ZI026_CTUL',None),
    ('ZI026_CTUU','ZI026_CTUU',None),
    ('ZI031S_URI',None,None),
    ('ZI039S_UFI',None,None),
    ('ZVH','ZVH',None),
    ('UFI','UFI','transform_set_UFI') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# IndustryCrv field translations
IndustryCrvFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Crv_fields) + [ \
    ('AOO','AOO',None),
    ('ARA','ARA',None),
    ('AWP','AWP',None),
    ('BEN','BEN',None),
    ('CAA','CAA',None),
    ('CNCP',None,None),
    ('COS','COS',None),
    ('CVT','CVT',None),
    ('CVT2','CVT2',None),
    ('CVT3','CVT3',None),
    ('DZP','DZP',None),
    ('F_CODE','F_CODE',None),
    ('FUFI','FUFI',None),
    ('FURL','FURL','transform_combine_FURL'),
    ('GDBV',None,None),
    ('HGT','HGT',None),
    ('LMC','LMC',None),
    ('LZN','LZN',None),
    ('PCF','PCF',None),
    ('PFH','PFH',None),
    ('VCM','VCM',None),
    ('VCM2','VCM2',None),
    ('VCM3','VCM3',None),
    ('VOI','VOI',None),
    ('WID','WID',None),
    ('ZI002_UFI','ZI002_UFI',None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_GNT','ZI005_GNT',None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZI020_GE4','ZI020_GE4',None),
    ('ZI026_CTUC','ZI026_CTUC',None),
    ('ZI026_CTUL','ZI026_CTUL',None),
    ('ZI026_CTUU','ZI026_CTUU',None),
    ('ZI031S_URI',None,None),
    ('ZI039S_UFI',None,None),
    ('ZVH','ZVH',None),
    ('UFI','UFI','transform_set_UFI') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# IndustryPnt field translations
IndustryPntFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Pnt_fields) + [ \
    ('ADR','ADR',None),
    ('AOO','AOO',None),
    ('ARA','ARA',None),
    ('AWP','AWP',None),
    ('AZC','AZC',None),
    ('BEN','BEN',None),
    ('BNF','BNF',None),
    ('CAA','CAA',None),
    ('CNCP',None,None),
    ('COS','COS',None),
    ('CRA','CRA',None),
    ('CRM','CRM',None),
    ('CVT','CVT',None),
    ('CVT2','CVT2',None),
    ('CVT3','CVT3',None),
    ('DZP','DZP',None),
    ('F_CODE','F_CODE',None),
    ('FFN','FFN',None),
    ('FFN2','FFN2',None),
    ('FFN3','FFN3',None),
    ('FUFI','FUFI',None),
    ('FURL','FURL','transform_combine_FURL'),
    ('GDBV',None,None),
    ('GUG','GUG',None),
    ('HGT','HGT',None),
    ('HST','HST',None),
    ('HST2','HST2',None),
    ('HST3','HST3',None),
    ('LCA','LCA',None),
    ('LEA','LEA',None),
    ('LMC','LMC',None),
    ('LZN','LZN',None),
    ('MZN','MZN',None),
    ('PBY','PBY',None),
    ('PBY2','PBY2',None),
    ('PBY3','PBY3',None),
    ('PCF','PCF',None),
    ('PPO','PPO',None),
    ('PPO2','PPO2',None),
    ('PPO3','PPO3',None),
    ('PRW','PRW',None),
    ('PRW2','PRW2',None),
    ('PRW3','PRW3',None),
    ('RIP','RIP',None),
    ('SRL','SRL',None),
    ('UMA','UMA',None),
    ('VCM','VCM',None),
    ('VCM2','VCM2',None),
    ('VCM3','VCM3',None),
    ('VOI','VOI',None),
    ('WEQ','WEQ',None),
    ('WEQ2','WEQ2',None),
    ('WEQ3','WEQ3',None),
    ('WID','WID',None),
    ('ZI002_UFI','ZI002_UFI',None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_GNT','ZI005_GNT',None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZI014_PPO','ZI014_PPO',None),
    ('ZI014_PPO2','ZI014_PPO2',None),
    ('ZI014_PPO3','ZI014_PPO3',None),
    ('ZI020_GE4','ZI020_GE4',None),
    ('ZI025_HDP','ZI025_HDP',None),
    ('ZI026_CTUC','ZI026_CTUC',None),
    ('ZI026_CTUL','ZI026_CTUL',None),
    ('ZI026_CTUU','ZI026_CTUU',None),
    ('ZI031S_URI',None,None),
    ('ZI039S_UFI',None,None),
    ('ZVH','ZVH',None),
    ('LOC','LOC','transform_LOC'),
    ('TRS','TRS','transform_TRS'),
    ('TRS2','TRS2','transform_TRS'),
    ('TRS3','TRS3','transform_TRS'),
    ('UFI','UFI','transform_set_UFI') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# IndustryPntExt field translations
IndustryPntExtFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Pnt_fields) + [ \
    ('ARA','ARA',None),
    ('BEN','BEN',None),
    ('F_CODE','F_CODE',None),
    ('FUFI','FUFI',None),
    ('FURL','FURL','transform_combine_FURL'),
    ('GDBV',None,None),
    ('LZN','LZN',None),
    ('PPO','PPO',None),
    ('PPO2','PPO2',None),
    ('PPO3','PPO3',None),
    ('WID','WID',None),
    ('ZI002_UFI','ZI002_UFI',None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_GNT','ZI005_GNT',None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZI020_GE4','ZI020_GE4',None),
    ('ZI026_CTUC','ZI026_CTUC',None),
    ('ZI026_CTUL','ZI026_CTUL',None),
    ('ZI026_CTUU','ZI026_CTUU',None),
    ('ZI031S_URI',None,None),
    ('ZI039S_UFI',None,None),
    ('UFI','UFI','transform_set_UFI') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# IndustrySrf field translations
IndustrySrfFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Srf_fields) + [ \
    ('ADR','ADR',None),
    ('AOO','AOO',None),
    ('ARA','ARA',None),
    ('AWP','AWP',None),
    ('AZC','AZC',None),
    ('BEN','BEN',None),
    ('BNF','BNF',None),
    ('CAA','CAA',None),
    ('CNCP',None,None),
    ('COS','COS',None),
    ('CRA','CRA',None),
    ('CRM','CRM',None),
    ('DZP','DZP',None),
    ('F_CODE','F_CODE',None),
    ('FFN','FFN',None),
    ('FFN2','FFN2',None),
    ('FFN3','FFN3',None),
    ('FUFI','FUFI',None),
    ('FURL','FURL','transform_combine_FURL'),
    ('GDBV',None,None),
    ('HGT','HGT',None),
    ('HST','HST',None),
    ('HST2','HST2',None),
    ('HST3','HST3',None),
    ('LCA','LCA',None),
    ('LEA','LEA',None),
    ('LMC','LMC',None),
    ('LZN','LZN',None),
    ('MZN','MZN',None),
    ('PBY','PBY',None),
    ('PBY2','PBY2',None),
    ('PBY3','PBY3',None),
    ('PCF','PCF',None),
    ('PPO','PPO',None),
    ('PPO2','PPO2',None),
    ('PPO3','PPO3',None),
    ('PRW','PRW',None),
    ('PRW2','PRW2',None),
    ('PRW3','PRW3',None),
    ('SRL','SRL',None),
    ('UMA','UMA',None),
    ('VCM','VCM',None),
    ('VCM2','VCM2',None),
    ('VCM3','VCM3',None),
    ('VLM','VLM',None),
    ('VOI','VOI',None),
    ('WDAC','WDAC',None),
    ('WDAL','WDAL',None),
    ('WDAU','WDAU',None),
    ('WID','WID',None),
    ('ZI002_UFI','ZI002_UFI',None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_GNT','ZI005_GNT',None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZI014_PPO','ZI014_PPO',None),
    ('ZI014_PPO2','ZI014_PPO2',None),
    ('ZI014_PPO3','ZI014_PPO3',None),
    ('ZI020_GE4','ZI020_GE4',None),
    ('ZI024_ASE','ZI024_ASE',None),
    ('ZI024_CFR','ZI024_CFR',None),
    ('ZI024_CLO','ZI024_CLO',None),
    ('ZI024_CYN','ZI024_CYN',None),
    ('ZI024_FMR',None,None),
    ('ZI024_FRR',None,None),
    ('ZI024_HAR','ZI024_HAR',None),
    ('ZI024_MGN','ZI024_MGN',None),
    ('ZI024_PHW','ZI024_PHW',None),
    ('ZI024_SCC','ZI024_SCC',None),
    ('ZI024_SUL','ZI024_SUL',None),
    ('ZI024_TDS','ZI024_TDS',None),
    ('ZI024_TEP','ZI024_TEP',None),
    ('ZI024_TUR','ZI024_TUR',None),
    ('ZI024_WAC','ZI024_WAC',None),
    ('ZI024_WTNO',None,None),
    ('ZI026_CTUC','ZI026_CTUC',None),
    ('ZI026_CTUL','ZI026_CTUL',None),
    ('ZI026_CTUU','ZI026_CTUU',None),
    ('ZI031S_URI',None,None),
    ('ZI039S_UFI',None,None),
    ('ZVH','ZVH',None),
    ('LOC','LOC','transform_LOC'),
    ('TRS','TRS','transform_TRS'),
    ('TRS2','TRS2','transform_TRS'),
    ('TRS3','TRS3','transform_TRS'),
    ('UFI','UFI','transform_set_UFI') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# InformationCrv field translations
InformationCrvFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Crv_fields) + [ \
    ('BEN','BEN',None),
    ('F_CODE','F_CODE',None),
    ('FUFI','FUFI',None),
    ('FURL','FURL','transform_combine_FURL'),
    ('GDBV',None,None),
    ('ZI002_UFI','ZI002_UFI',None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_FNA2',None,None),
    ('ZI005_FNA3',None,None),
    ('ZI005_GNR',None,None),
    ('ZI005_GNR2',None,None),
    ('ZI005_GNR3',None,None),
    ('ZI005_GNT','ZI005_GNT',None),
    ('ZI005_GNT2',None,None),
    ('ZI005_GNT3',None,None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZI005_NFN2',None,None),
    ('ZI005_NFN3',None,None),
    ('ZI015_GCUC',None,None),
    ('ZI015_GCUL',None,None),
    ('ZI015_GCUU',None,None),
    ('ZI020_GE4','ZI020_GE4',None),
    ('ZI026_CTUC','ZI026_CTUC',None),
    ('ZI026_CTUL','ZI026_CTUL',None),
    ('ZI026_CTUU','ZI026_CTUU',None),
    ('ZI031S_URI',None,None),
    ('ZI039S_UFI',None,None),
    ('UFI','UFI','transform_set_UFI') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# InformationCrvExt field translations
InformationCrvExtFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Crv_fields) + [ \
    ('BEN','BEN',None),
    ('F_CODE','F_CODE',None),
    ('FUFI','FUFI',None),
    ('FURL','FURL','transform_combine_FURL'),
    ('GDBV',None,None),
    ('NLT','NLT',None),
    ('ZI002_UFI','ZI002_UFI',None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_FNA2',None,None),
    ('ZI005_FNA3',None,None),
    ('ZI005_GNR',None,None),
    ('ZI005_GNR2',None,None),
    ('ZI005_GNR3',None,None),
    ('ZI005_GNT','ZI005_GNT',None),
    ('ZI005_GNT2',None,None),
    ('ZI005_GNT3',None,None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZI005_NFN2',None,None),
    ('ZI005_NFN3',None,None),
    ('ZI015_GCUC',None,None),
    ('ZI015_GCUL',None,None),
    ('ZI015_GCUU',None,None),
    ('ZI020_GE4','ZI020_GE4',None),
    ('ZI026_CTUC','ZI026_CTUC',None),
    ('ZI026_CTUL','ZI026_CTUL',None),
    ('ZI026_CTUU','ZI026_CTUU',None),
    ('ZI031S_URI',None,None),
    ('ZI039S_UFI',None,None),
    ('UFI','UFI','transform_set_UFI') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# InformationPnt field translations
InformationPntFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Pnt_fields) + [ \
    ('BEN','BEN',None),
    ('F_CODE','F_CODE',None),
    ('FUFI','FUFI',None),
    ('FURL','FURL','transform_combine_FURL'),
    ('GDBV',None,None),
    ('NLT','NLT',None),
    ('ZI002_UFI','ZI002_UFI',None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_FNA2',None,None),
    ('ZI005_FNA3',None,None),
    ('ZI005_GNR',None,None),
    ('ZI005_GNR2',None,None),
    ('ZI005_GNR3',None,None),
    ('ZI005_GNT','ZI005_GNT',None),
    ('ZI005_GNT2',None,None),
    ('ZI005_GNT3',None,None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZI005_NFN2',None,None),
    ('ZI005_NFN3',None,None),
    ('ZI015_GCUC',None,None),
    ('ZI015_GCUL',None,None),
    ('ZI015_GCUU',None,None),
    ('ZI020_GE4','ZI020_GE4',None),
    ('ZI026_CTUC','ZI026_CTUC',None),
    ('ZI026_CTUL','ZI026_CTUL',None),
    ('ZI026_CTUU','ZI026_CTUU',None),
    ('ZI031S_URI',None,None),
    ('ZI039S_UFI',None,None),
    ('UFI','UFI','transform_set_UFI') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# InformationSrf field translations
InformationSrfFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Srf_fields) + [ \
    ('ARA','ARA',None),
    ('BEN','BEN',None),
    ('F_CODE','F_CODE',None),
    ('FUFI','FUFI',None),
    ('FURL','FURL','transform_combine_FURL'),
    ('GDBV',None,None),
    ('LZN','LZN',None),
    ('VCA','VCA',None),
    ('VCA2','VCA2',None),
    ('VCA3','VCA3',None),
    ('VCT','VCT',None),
    ('VCT2','VCT2',None),
    ('VCT3','VCT3',None),
    ('WID','WID',None),
    ('ZI002_UFI','ZI002_UFI',None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_FNA2',None,None),
    ('ZI005_FNA3',None,None),
    ('ZI005_GNR',None,None),
    ('ZI005_GNR2',None,None),
    ('ZI005_GNR3',None,None),
    ('ZI005_GNT','ZI005_GNT',None),
    ('ZI005_GNT2',None,None),
    ('ZI005_GNT3',None,None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZI005_NFN2',None,None),
    ('ZI005_NFN3',None,None),
    ('ZI015_GCUC',None,None),
    ('ZI015_GCUL',None,None),
    ('ZI015_GCUU',None,None),
    ('ZI020_GE4','ZI020_GE4',None),
    ('ZI026_CTUC','ZI026_CTUC',None),
    ('ZI026_CTUL','ZI026_CTUL',None),
    ('ZI026_CTUU','ZI026_CTUU',None),
    ('ZI031S_URI',None,None),
    ('ZI039S_UFI',None,None),
    ('UFI','UFI','transform_set_UFI') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# InformationSrfExt field translations
InformationSrfExtFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Srf_fields) + [ \
    ('BEN','BEN',None),
    ('F_CODE','F_CODE',None),
    ('FUFI','FUFI',None),
    ('FURL','FURL','transform_combine_FURL'),
    ('GDBV',None,None),
    ('NLT','NLT',None),
    ('VAVC','VAVC',None),
    ('VAVL','VAVL',None),
    ('VAVU','VAVU',None),
    ('ZI002_UFI','ZI002_UFI',None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_FNA2',None,None),
    ('ZI005_FNA3',None,None),
    ('ZI005_GNR',None,None),
    ('ZI005_GNR2',None,None),
    ('ZI005_GNR3',None,None),
    ('ZI005_GNT','ZI005_GNT',None),
    ('ZI005_GNT2',None,None),
    ('ZI005_GNT3',None,None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZI005_NFN2',None,None),
    ('ZI005_NFN3',None,None),
    ('ZI015_GCUC',None,None),
    ('ZI015_GCUL',None,None),
    ('ZI015_GCUU',None,None),
    ('ZI020_GE4','ZI020_GE4',None),
    ('ZI026_CTUC','ZI026_CTUC',None),
    ('ZI026_CTUL','ZI026_CTUL',None),
    ('ZI026_CTUU','ZI026_CTUU',None),
    ('ZI031S_URI',None,None),
    ('ZI039S_UFI',None,None),
    ('UFI','UFI','transform_set_UFI') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# MetadataSrf field translations
MetadataSrfFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Srf_fields) + [ \
    ('AHA','AHA',None),
    ('AVA','AVA',None),
    ('DQS','DQS',None),
    ('EVA','EVA',None),
    ('F_CODE','F_CODE',None),
    ('HVA','HVA',None),
    ('MDE','MDE',None),
    ('SCVN','SCVN',None),
    ('ZI004_PRE','ZI004_PRE',None),
    ('EQS','EQS','transformEQSinteger2EQCcodelist'),
    ('RCG','RCG','transformRCGenumeration2RCGcodelist'),
    ('UFI','UFI','transform_set_UFI') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# MetadataTbl field translations
MetadataTblFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Tbl_fields) + [ \
    ('AHA','AHA',None),
    ('AVA','AVA',None),
    ('DQS','DQS',None),
    ('EVA','EVA',None),
    ('F_CODE','F_CODE',None),
    ('HVA','HVA',None),
    ('MDE','MDE',None),
    (None,'COD',None),
    (None,'COE',None),
    (None,'CUD',None),
    (None,'FURL',None),
    (None,'PDA',None),
    (None,'SUR',None),
    (None,'UDQ',None),
    (None,'ZI010_ACC',None),
    ('SCVN','SCVN',None),
    ('ZI004_PRE','ZI004_PRE',None),
    ('EQS','EQS','transformEQSinteger2EQCcodelist'),
    ('RCG','RCG','transformRCGenumeration2RCGcodelist'),
    ('UFI','UFI','transform_set_UFI') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# MilitaryCrv field translations
MilitaryCrvFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Crv_fields) + [ \
    ('ARA','ARA',None),
    ('BEN','BEN',None),
    ('CNCP',None,None),
    ('COS','COS',None),
    ('DZP','DZP',None),
    ('EET','EET',None),
    ('F_CODE','F_CODE',None),
    ('FUFI','FUFI',None),
    ('FURL','FURL','transform_combine_FURL'),
    ('GDBV',None,None),
    ('HGT','HGT',None),
    ('HST','HST',None),
    ('HST2','HST2',None),
    ('HST3','HST3',None),
    ('LMC','LMC',None),
    ('LNU','LNU',None),
    ('LZN','LZN',None),
    ('MCC','MCC',None),
    ('MCC2','MCC2',None),
    ('MCC3','MCC3',None),
    ('PCF','PCF',None),
    ('PFHC','PFHC',None),
    ('PFHL','PFHL',None),
    ('PFHU','PFHU',None),
    ('VOI','VOI',None),
    ('WD3','WD3',None),
    ('WID','WID',None),
    ('YSU','YSU',None),
    ('ZI002_UFI','ZI002_UFI',None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_GNT','ZI005_GNT',None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZI020_GE4','ZI020_GE4',None),
    ('ZI026_CTUC','ZI026_CTUC',None),
    ('ZI026_CTUL','ZI026_CTUL',None),
    ('ZI026_CTUU','ZI026_CTUU',None),
    ('ZI031S_URI',None,None),
    ('ZI039S_UFI',None,None),
    ('ZVH','ZVH',None),
    ('UFI','UFI','transform_set_UFI') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# MilitaryCrvExt field translations
MilitaryCrvExtFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Crv_fields) + [ \
    ('BEN','BEN',None),
    ('CAA','CAA',None),
    ('DSP','DSP',None),
    ('F_CODE','F_CODE',None),
    ('FUFI','FUFI',None),
    ('FURL','FURL','transform_combine_FURL'),
    ('GDBV',None,None),
    ('LZN','LZN',None),
    ('MLUS','MLUS',None),
    ('ZI002_UFI','ZI002_UFI',None),
    ('ZI005_FNAA','ZI005_FNAA',None),
    ('ZI005_FNAB','ZI005_FNAB',None),
    ('ZI005_GNTA','ZI005_GNTA',None),
    ('ZI005_GNTB','ZI005_GNTB',None),
    ('ZI005_NFNA','ZI005_NFNA',None),
    ('ZI005_NFNB','ZI005_NFNB',None),
    ('ZI020_FI2A','ZI020_FI2A',None),
    ('ZI020_FI2B','ZI020_FI2B',None),
    ('ZI020_GE4','ZI020_GE4',None),
    ('ZI020_GE4A','ZI020_GE4A',None),
    ('ZI020_GE4B','ZI020_GE4B',None),
    ('ZI026_CTUC','ZI026_CTUC',None),
    ('ZI026_CTUL','ZI026_CTUL',None),
    ('ZI026_CTUU','ZI026_CTUU',None),
    ('ZI031S_URI',None,None),
    ('ZI039S_UFI',None,None),
    ('UFI','UFI','transform_set_UFI') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# MilitaryPnt field translations
MilitaryPntFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Pnt_fields) + [ \
    ('ADR','ADR',None),
    ('AOO','AOO',None),
    ('ARA','ARA',None),
    ('ATB','ATB',None),
    ('AWP','AWP',None),
    ('BEN','BEN',None),
    ('BNF','BNF',None),
    ('CAA','CAA',None),
    ('CNCP',None,None),
    ('COS','COS',None),
    ('DZP','DZP',None),
    ('F_CODE','F_CODE',None),
    ('FFN','FFN',None),
    ('FFN2','FFN2',None),
    ('FFN3','FFN3',None),
    ('FRT','FRT',None),
    ('FRT2','FRT2',None),
    ('FRT3','FRT3',None),
    ('FUFI','FUFI',None),
    ('FURL','FURL','transform_combine_FURL'),
    ('FZR','FZR',None),
    ('GDBV',None,None),
    ('HGT','HGT',None),
    ('HST','HST',None),
    ('HST2','HST2',None),
    ('HST3','HST3',None),
    ('LEA','LEA',None),
    ('LMC','LMC',None),
    ('LUN','LUN',None),
    ('LZN','LZN',None),
    ('MCC','MCC',None),
    ('MCC2','MCC2',None),
    ('MCC3','MCC3',None),
    ('MLOP','MLOP',None),
    ('MLUS','MLUS',None),
    ('MST','MST',None),
    ('MST2','MST2',None),
    ('MST3','MST3',None),
    ('MUB','MUB',None),
    ('PCF','PCF',None),
    ('PPO','PPO',None),
    ('PPO2','PPO2',None),
    ('PPO3','PPO3',None),
    ('PRM','PRM',None),
    ('RLE','RLE',None),
    ('SSR','SSR',None),
    ('SSR2','SSR2',None),
    ('SSR3','SSR3',None),
    ('VCM','VCM',None),
    ('VCM2','VCM2',None),
    ('VCM3','VCM3',None),
    ('VOI','VOI',None),
    ('WID','WID',None),
    ('WPST','WPST',None),
    ('WTYP','WTYP',None),
    ('YSU','YSU',None),
    ('ZI002_UFI','ZI002_UFI',None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_GNT','ZI005_GNT',None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZI014_PBY','ZI014_PBY',None),
    ('ZI014_PBY2','ZI014_PBY2',None),
    ('ZI014_PBY3','ZI014_PBY3',None),
    ('ZI014_PPO','ZI014_PPO',None),
    ('ZI014_PPO2','ZI014_PPO2',None),
    ('ZI014_PPO3','ZI014_PPO3',None),
    ('ZI014_PRW','ZI014_PRW',None),
    ('ZI014_PRW2','ZI014_PRW2',None),
    ('ZI014_PRW3','ZI014_PRW3',None),
    ('ZI018_WIT','ZI018_WIT',None),
    ('ZI020_GE4','ZI020_GE4',None),
    ('ZI025_HDP','ZI025_HDP',None),
    ('ZI026_CTUC','ZI026_CTUC',None),
    ('ZI026_CTUL','ZI026_CTUL',None),
    ('ZI026_CTUU','ZI026_CTUU',None),
    ('ZI031S_URI',None,None),
    ('ZI039S_UFI',None,None),
    ('ZVH','ZVH',None),
    ('UFI','UFI','transform_set_UFI') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# MilitaryPntExt field translations
MilitaryPntExtFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Pnt_fields) + [ \
    ('ARA','ARA',None),
    ('AZC','AZC',None),
    ('BEN','BEN',None),
    ('CAA','CAA',None),
    ('CNCP',None,None),
    ('COS','COS',None),
    ('F_CODE','F_CODE',None),
    ('FUFI','FUFI',None),
    ('FURL','FURL','transform_combine_FURL'),
    ('GDBV',None,None),
    ('HGT','HGT',None),
    ('LMC','LMC',None),
    ('LZN','LZN',None),
    ('PCF','PCF',None),
    ('VCM','VCM',None),
    ('VCM2','VCM2',None),
    ('VCM3','VCM3',None),
    ('WID','WID',None),
    ('YSU','YSU',None),
    ('ZI002_UFI','ZI002_UFI',None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_GNT','ZI005_GNT',None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZI020_GE4','ZI020_GE4',None),
    ('ZI026_CTUC','ZI026_CTUC',None),
    ('ZI026_CTUL','ZI026_CTUL',None),
    ('ZI026_CTUU','ZI026_CTUU',None),
    ('ZI031S_URI',None,None),
    ('ZI039S_UFI',None,None),
    ('UFI','UFI','transform_set_UFI') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# MilitarySrf field translations
MilitarySrfFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Srf_fields) + [ \
    ('ADR','ADR',None),
    ('AOO','AOO',None),
    ('ARA','ARA',None),
    ('ATB','ATB',None),
    ('AWP','AWP',None),
    ('BEN','BEN',None),
    ('BNF','BNF',None),
    ('CAA','CAA',None),
    ('CNCP',None,None),
    ('COS','COS',None),
    ('DZP','DZP',None),
    ('EET','EET',None),
    ('F_CODE','F_CODE',None),
    ('FFN','FFN',None),
    ('FFN2','FFN2',None),
    ('FFN3','FFN3',None),
    ('FRT','FRT',None),
    ('FRT2','FRT2',None),
    ('FRT3','FRT3',None),
    ('FUFI','FUFI',None),
    ('FURL','FURL','transform_combine_FURL'),
    ('FZR','FZR',None),
    ('GDBV',None,None),
    ('HGT','HGT',None),
    ('HST','HST',None),
    ('HST2','HST2',None),
    ('HST3','HST3',None),
    ('LEA','LEA',None),
    ('LMC','LMC',None),
    ('LUN','LUN',None),
    ('LZN','LZN',None),
    ('MCC','MCC',None),
    ('MCC2','MCC2',None),
    ('MCC3','MCC3',None),
    ('MLOP','MLOP',None),
    ('MLUS','MLUS',None),
    ('MST','MST',None),
    ('MST2','MST2',None),
    ('MST3','MST3',None),
    ('MUB','MUB',None),
    ('PCF','PCF',None),
    ('PFHC','PFHC',None),
    ('PFHL','PFHL',None),
    ('PFHU','PFHU',None),
    ('PPO','PPO',None),
    ('PPO2','PPO2',None),
    ('PPO3','PPO3',None),
    ('PRM','PRM',None),
    ('RLE','RLE',None),
    ('SSR','SSR',None),
    ('SSR2','SSR2',None),
    ('SSR3','SSR3',None),
    ('VCM','VCM',None),
    ('VCM2','VCM2',None),
    ('VCM3','VCM3',None),
    ('VOI','VOI',None),
    ('WD3','WD3',None),
    ('WID','WID',None),
    ('WPST','WPST',None),
    ('WTYP','WTYP',None),
    ('YSU','YSU',None),
    ('ZI002_UFI','ZI002_UFI',None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_GNT','ZI005_GNT',None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZI014_PBY','ZI014_PBY',None),
    ('ZI014_PBY2','ZI014_PBY2',None),
    ('ZI014_PBY3','ZI014_PBY3',None),
    ('ZI014_PPO','ZI014_PPO',None),
    ('ZI014_PPO2','ZI014_PPO2',None),
    ('ZI014_PPO3','ZI014_PPO3',None),
    ('ZI014_PRW','ZI014_PRW',None),
    ('ZI014_PRW2','ZI014_PRW2',None),
    ('ZI014_PRW3','ZI014_PRW3',None),
    ('ZI018_WIT','ZI018_WIT',None),
    ('ZI020_GE4','ZI020_GE4',None),
    ('ZI025_HDP','ZI025_HDP',None),
    ('ZI026_CTUC','ZI026_CTUC',None),
    ('ZI026_CTUL','ZI026_CTUL',None),
    ('ZI026_CTUU','ZI026_CTUU',None),
    ('ZI031S_URI',None,None),
    ('ZI039S_UFI',None,None),
    ('ZVH','ZVH',None),
    ('UFI','UFI','transform_set_UFI') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# MilitarySrfExt field translations
MilitarySrfExtFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Srf_fields) + [ \
    ('ARA','ARA',None),
    ('AZC','AZC',None),
    ('BEN','BEN',None),
    ('CAA','CAA',None),
    ('CNCP',None,None),
    ('COS','COS',None),
    ('F_CODE','F_CODE',None),
    ('FUFI','FUFI',None),
    ('FURL','FURL','transform_combine_FURL'),
    ('GDBV',None,None),
    ('HGT','HGT',None),
    ('LMC','LMC',None),
    ('LZN','LZN',None),
    ('PCF','PCF',None),
    ('VCM','VCM',None),
    ('VCM2','VCM2',None),
    ('VCM3','VCM3',None),
    ('WID','WID',None),
    ('YSU','YSU',None),
    ('ZI002_UFI','ZI002_UFI',None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_GNT','ZI005_GNT',None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZI020_GE4','ZI020_GE4',None),
    ('ZI026_CTUC','ZI026_CTUC',None),
    ('ZI026_CTUL','ZI026_CTUL',None),
    ('ZI026_CTUU','ZI026_CTUU',None),
    ('ZI031S_URI',None,None),
    ('ZI039S_UFI',None,None),
    ('UFI','UFI','transform_set_UFI') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# PhysiographyAONExt field translations
PhysiographyAONExtFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Srf_fields) + [ \
    ('ARA','ARA',None),
    ('BEN','BEN',None),
    ('DMF','DMF',None),
    ('F_CODE','F_CODE',None),
    ('FUFI','FUFI',None),
    ('FURL','FURL','transform_combine_FURL'),
    ('GDBV',None,None),
    ('LMC','LMC',None),
    ('LZN','LZN',None),
    ('WID','WID',None),
    ('ZI002_UFI','ZI002_UFI',None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_GNT','ZI005_GNT',None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZI020_GE4','ZI020_GE4',None),
    ('ZI026_CTUC','ZI026_CTUC',None),
    ('ZI026_CTUL','ZI026_CTUL',None),
    ('ZI026_CTUU','ZI026_CTUU',None),
    ('ZI031S_URI',None,None),
    ('ZI039S_UFI',None,None),
    ('UFI','UFI','transform_set_UFI') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# PhysiographyCrv field translations
PhysiographyCrvFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Crv_fields) + [ \
    ('ARA','ARA',None),
    ('AZC','AZC',None),
    ('BA000_VDC','BA000_VDC',None),
    ('BA000_VDR','BA000_VDR',None),
    ('BEN','BEN',None),
    ('CAA','CAA',None),
    ('CET','CET',None),
    ('CNCP',None,None),
    ('COS','COS',None),
    ('DZP','DZP',None),
    ('F_CODE','F_CODE',None),
    ('FDI','FDI',None),
    ('FIC','FIC',None),
    ('FUFI','FUFI',None),
    ('FURL','FURL','transform_combine_FURL'),
    ('GDBV',None,None),
    ('GFT','GFT',None),
    ('GFY','WFTT',None),
    ('HDP','HDP',None),
    ('HGT','HGT',None),
    ('LMC','LMC',None),
    ('LZN','LZN',None),
    ('MCC','MCC',None),
    ('MCC2','MCC2',None),
    ('MCC3','MCC3',None),
    ('PCF','PCF',None),
    ('PFD','PFD',None),
    ('PFH','PFH',None),
    ('SDI','SDI',None),
    ('SGCC','SGCC',None),
    ('SGCL','SGCL',None),
    ('SGCU','SGCU',None),
    ('SHD','SHD',None),
    ('SHO',None,None),
    ('SLT','SLT',None),
    ('SNDC','SNDC',None),
    ('SNDL','SNDL',None),
    ('SNDU','SNDU',None),
    ('WID','WID',None),
    ('WLE','WLE',None),
    ('ZI002_UFI','ZI002_UFI',None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_GNT','ZI005_GNT',None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZI020_GE4','ZI020_GE4',None),
    ('ZI026_CTUC','ZI026_CTUC',None),
    ('ZI026_CTUL','ZI026_CTUL',None),
    ('ZI026_CTUU','ZI026_CTUU',None),
    ('ZI031S_URI',None,None),
    ('ZI039S_UFI',None,None),
    ('ZVH','ZVH',None),
    ('TRS','TRS','transform_TRS'),
    ('TRS2','TRS2','transform_TRS'),
    ('TRS3','TRS3','transform_TRS'),
    ('UFI','UFI','transform_set_UFI') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# PhysiographyCrvExt field translations
PhysiographyCrvExtFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Crv_fields) + [ \
    ('AZC','AZC',None),
    ('BEN','BEN',None),
    ('F_CODE','F_CODE',None),
    ('FUFI','FUFI',None),
    ('FURL','FURL','transform_combine_FURL'),
    ('GDBV',None,None),
    ('SLT','SLT',None),
    ('SSE','SSE',None),
    ('ZI002_UFI','ZI002_UFI',None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_GNT','ZI005_GNT',None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZI020_GE4','ZI020_GE4',None),
    ('ZI026_CTUC','ZI026_CTUC',None),
    ('ZI026_CTUL','ZI026_CTUL',None),
    ('ZI026_CTUU','ZI026_CTUU',None),
    ('ZI031S_URI',None,None),
    ('ZI039S_UFI',None,None),
    ('UFI','UFI','transform_set_UFI') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# PhysiographyPnt field translations
PhysiographyPntFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Pnt_fields) + [ \
    ('AOO','AOO',None),
    ('AQN','AQN',None),
    ('ARA','ARA',None),
    ('BA000_VDC','BA000_VDC',None),
    ('BA000_VDR','BA000_VDR',None),
    ('BEN','BEN',None),
    ('CAA','CAA',None),
    ('DOF','DOF',None),
    ('F_CODE','F_CODE',None),
    ('FUFI','FUFI',None),
    ('FURL','FURL','transform_combine_FURL'),
    ('GDBV',None,None),
    ('GOT','GOT',None),
    ('HGT','HGT',None),
    ('LMC','LMC',None),
    ('LZN','LZN',None),
    ('MCC','MCC',None),
    ('MCC2','MCC2',None),
    ('MCC3','MCC3',None),
    ('OHC','OHC',None),
    ('PCF','PCF',None),
    ('PFH','PFH',None),
    ('RKF','RKF',None),
    ('SHD','SHD',None),
    ('SLT','SLT',None),
    ('SNDC','SNDC',None),
    ('SNDL','SNDL',None),
    ('SNDU','SNDU',None),
    ('VGT','VGT',None),
    ('VOA','VOA',None),
    ('VTI','VTI',None),
    ('WID','WID',None),
    ('ZI002_UFI','ZI002_UFI',None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_FNA2','ZI005_FNA2',None),
    ('ZI005_FNA3','ZI005_FNA3',None),
    ('ZI005_GNT','ZI005_GNT',None),
    ('ZI005_GNT2','ZI005_GNT2',None),
    ('ZI005_GNT3','ZI005_GNT3',None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZI005_NFN2','ZI005_NFN2',None),
    ('ZI005_NFN3','ZI005_NFN3',None),
    ('ZI020_GE4','ZI020_GE4',None),
    ('ZI024_ASE','ZI024_ASE',None),
    ('ZI024_AWO','ZI024_AWO',None),
    ('ZI024_AWOI',None,None),
    ('ZI024_AWOX',None,None),
    ('ZI024_CFR','ZI024_CFR',None),
    ('ZI024_CLO','ZI024_CLO',None),
    ('ZI024_CYN','ZI024_CYN',None),
    ('ZI024_FMR',None,None),
    ('ZI024_FRR',None,None),
    ('ZI024_HAR','ZI024_HAR',None),
    ('ZI024_MGN','ZI024_MGN',None),
    ('ZI024_PHW','ZI024_PHW',None),
    ('ZI024_SCC','ZI024_SCC',None),
    ('ZI024_SUL','ZI024_SUL',None),
    ('ZI024_TDS','ZI024_TDS',None),
    ('ZI024_TEP','ZI024_TEP',None),
    ('ZI024_TUR','ZI024_TUR',None),
    ('ZI024_WAC','ZI024_WAC',None),
    ('ZI024_WTNO',None,None),
    ('ZI024_WUR','ZI024_WUR',None),
    ('ZI024_WUR2','ZI024_WUR2',None),
    ('ZI024_WUR3','ZI024_WUR3',None),
    ('ZI024_WUR4','ZI024_WUR4',None),
    ('ZI024_YWQ','ZI024_YWQ',None),
    ('ZI025_HDP','ZI025_HDP',None),
    ('ZI026_CTUC','ZI026_CTUC',None),
    ('ZI026_CTUL','ZI026_CTUL',None),
    ('ZI026_CTUU','ZI026_CTUU',None),
    ('ZI031S_URI',None,None),
    ('ZI039S_UFI',None,None),
    ('ZI071_CTX','ZI071_CTX',None),
    ('ZI071_FFN','ZI071_FFN',None),
    ('ZI071_FFN2','ZI071_FFN2',None),
    ('ZI071_FFN3','ZI071_FFN3',None),
    ('ZI071_UAO','ZI071_UAO',None),
    ('ZVH','ZVH',None),
    ('UFI','UFI','transform_set_UFI'),
    ('ZI024_HYP','ZI024_HYP','transform_ZI024_HYP') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# PhysiographyPntExt field translations
PhysiographyPntExtFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Pnt_fields) + [ \
    ('ARA','ARA',None),
    ('BEN','BEN',None),
    ('DZP','DZP',None),
    ('F_CODE','F_CODE',None),
    ('FUFI','FUFI',None),
    ('FURL','FURL','transform_combine_FURL'),
    ('GDBV',None,None),
    ('LMC','LMC',None),
    ('LZN','LZN',None),
    ('PFD','PFD',None),
    ('SGCC','SGCC',None),
    ('SGCL','SGCL',None),
    ('SGCU','SGCU',None),
    ('WID','WID',None),
    ('ZI002_UFI','ZI002_UFI',None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_GNT','ZI005_GNT',None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZI020_GE4','ZI020_GE4',None),
    ('ZI026_CTUC','ZI026_CTUC',None),
    ('ZI026_CTUL','ZI026_CTUL',None),
    ('ZI026_CTUU','ZI026_CTUU',None),
    ('ZI031S_URI',None,None),
    ('ZI039S_UFI',None,None),
    ('UFI','UFI','transform_set_UFI') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# PhysiographySrf field translations
PhysiographySrfFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Srf_fields) + [ \
    ('AOO','AOO',None),
    ('AQN','AQN',None),
    ('ARA','ARA',None),
    ('BA000_VDC','BA000_VDC',None),
    ('BA000_VDR','BA000_VDR',None),
    ('BEN','BEN',None),
    ('CAA','CAA',None),
    ('CET','CET',None),
    ('CNCP',None,None),
    ('COS','COS',None),
    ('DOF','DOF',None),
    ('DZP','DZP',None),
    ('F_CODE','F_CODE',None),
    ('FIC','FIC',None),
    ('FUFI','FUFI',None),
    ('FURL','FURL','transform_combine_FURL'),
    ('GDBV',None,None),
    ('GOT','GOT',None),
    ('HGT','HGT',None),
    ('LMC','LMC',None),
    ('LND','LND',None),
    ('LZN','LZN',None),
    ('MCC','MCC',None),
    ('MCC2','MCC2',None),
    ('MCC3','MCC3',None),
    ('PCF','PCF',None),
    ('PFD','PFD',None),
    ('PFH','PFH',None),
    ('RKF','RKF',None),
    ('SAD','SAD',None),
    ('SDCC','SDCC',None),
    ('SDCL','SDCL',None),
    ('SDCU','SDCU',None),
    ('SDO','SDO',None),
    ('SDT','SDT',None),
    ('SGCC','SGCC',None),
    ('SGCL','SGCL',None),
    ('SGCU','SGCU',None),
    ('SHD','SHD',None),
    ('SIC','SIC',None),
    ('SLT','SLT',None),
    ('SNDC','SNDC',None),
    ('SNDL','SNDL',None),
    ('SNDU','SNDU',None),
    ('SRD','SRD',None),
    ('SSE','SSE',None),
    ('STP','STP',None),
    ('SWC','SWC',None),
    ('TSM','TSM',None),
    ('TSM2','TSM2',None),
    ('TSM3','TSM3',None),
    ('VGT','VGT',None),
    ('VOA','VOA',None),
    ('VTI','VTI',None),
    ('WID','WID',None),
    ('WLE','WLE',None),
    ('ZI002_UFI','ZI002_UFI',None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_FNA2','ZI005_FNA2',None),
    ('ZI005_FNA3','ZI005_FNA3',None),
    ('ZI005_GNT','ZI005_GNT',None),
    ('ZI005_GNT2','ZI005_GNT2',None),
    ('ZI005_GNT3','ZI005_GNT3',None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZI005_NFN2','ZI005_NFN2',None),
    ('ZI005_NFN3','ZI005_NFN3',None),
    ('ZI020_GE4','ZI020_GE4',None),
    ('ZI024_ASE','ZI024_ASE',None),
    ('ZI024_AWO','ZI024_AWO',None),
    ('ZI024_AWOI',None,None),
    ('ZI024_AWOX',None,None),
    ('ZI024_CFR','ZI024_CFR',None),
    ('ZI024_CLO','ZI024_CLO',None),
    ('ZI024_CYN','ZI024_CYN',None),
    ('ZI024_FMR',None,None),
    ('ZI024_FRR',None,None),
    ('ZI024_HAR','ZI024_HAR',None),
    ('ZI024_MGN','ZI024_MGN',None),
    ('ZI024_PHW','ZI024_PHW',None),
    ('ZI024_SCC','ZI024_SCC',None),
    ('ZI024_SUL','ZI024_SUL',None),
    ('ZI024_TDS','ZI024_TDS',None),
    ('ZI024_TEP','ZI024_TEP',None),
    ('ZI024_TUR','ZI024_TUR',None),
    ('ZI024_WAC','ZI024_WAC',None),
    ('ZI024_WTNO',None,None),
    ('ZI024_WUR','ZI024_WUR',None),
    ('ZI024_WUR2','ZI024_WUR2',None),
    ('ZI024_WUR3','ZI024_WUR3',None),
    ('ZI024_WUR4','ZI024_WUR4',None),
    ('ZI024_YWQ','ZI024_YWQ',None),
    ('ZI025_HDP','ZI025_HDP',None),
    ('ZI026_CTUC','ZI026_CTUC',None),
    ('ZI026_CTUL','ZI026_CTUL',None),
    ('ZI026_CTUU','ZI026_CTUU',None),
    ('ZI031S_URI',None,None),
    ('ZI039S_UFI',None,None),
    ('ZVH','ZVH',None),
    ('TRS','TRS','transform_TRS'),
    ('TRS2','TRS2','transform_TRS'),
    ('TRS3','TRS3','transform_TRS'),
    ('UFI','UFI','transform_set_UFI'),
    ('ZI024_HYP','ZI024_HYP','transform_ZI024_HYP') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# PhysiographySrfExt field translations
PhysiographySrfExtFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Srf_fields) + [ \
    ('ARA','ARA',None),
    ('BEN','BEN',None),
    ('DZP','DZP',None),
    ('F_CODE','F_CODE',None),
    ('FUFI','FUFI',None),
    ('FURL','FURL','transform_combine_FURL'),
    ('GDBV',None,None),
    ('LMC','LMC',None),
    ('LZN','LZN',None),
    ('MBC_MCC1','MBC_MCC1',None),
    ('MBC_MCC2','MBC_MCC2',None),
    ('MBC_PSC1','MBC_PSC1',None),
    ('MBC_PSC2','MBC_PSC2',None),
    ('MBC_SCO1','MBC_SCO1',None),
    ('MBC_SCO2','MBC_SCO2',None),
    ('PCF',None,None),
    ('PRVR',None,None),
    ('SGCC','SGCC',None),
    ('SGCL','SGCL',None),
    ('SGCU','SGCU',None),
    ('SSE','SSE',None),
    ('STP',None,None),
    ('SWC',None,None),
    ('VTI',None,None),
    ('WID','WID',None),
    ('ZI002_UFI','ZI002_UFI',None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_GNT','ZI005_GNT',None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZI020_GE4','ZI020_GE4',None),
    ('ZI026_CTUC','ZI026_CTUC',None),
    ('ZI026_CTUL','ZI026_CTUL',None),
    ('ZI026_CTUU','ZI026_CTUU',None),
    ('ZI031S_URI',None,None),
    ('ZI039S_UFI',None,None),
    ('UFI','UFI','transform_set_UFI') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# PortHarbourCrv field translations
PortHarbourCrvFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Crv_fields) + [ \
    ('AOO','AOO',None),
    ('ARA','ARA',None),
    ('BEN','BEN',None),
    ('CAA','CAA',None),
    ('CNCP',None,None),
    ('COS','COS',None),
    ('F_CODE','F_CODE',None),
    ('FAC','FAC',None),
    ('FFN','FFN',None),
    ('FFN2','FFN2',None),
    ('FFN3','FFN3',None),
    ('FLO','FLO',None),
    ('FUFI','FUFI',None),
    ('FURL','FURL','transform_combine_FURL'),
    ('GDBV',None,None),
    ('HGT','HGT',None),
    ('LMC','LMC',None),
    ('LZN','LZN',None),
    ('MCC','MCC',None),
    ('MCC2','MCC2',None),
    ('MCC3','MCC3',None),
    ('PCF','PCF',None),
    ('PWC','PWC',None),
    ('SGCC','SGCC',None),
    ('SGCL','SGCL',None),
    ('SGCU','SGCU',None),
    ('SLR','SLR',None),
    ('WID','WID',None),
    ('WLE','WLE',None),
    ('ZI002_UFI','ZI002_UFI',None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_GNT','ZI005_GNT',None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZI020_GE4','ZI020_GE4',None),
    ('ZI026_CTUC','ZI026_CTUC',None),
    ('ZI026_CTUL','ZI026_CTUL',None),
    ('ZI026_CTUU','ZI026_CTUU',None),
    ('ZI031S_URI',None,None),
    ('ZI039S_UFI',None,None),
    ('ZVH','ZVH',None),
    ('UFI','UFI','transform_set_UFI') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# PortHarbourPnt field translations
PortHarbourPntFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Pnt_fields) + [ \
    ('ADR','ADR',None),
    ('AOO','AOO',None),
    ('ARA','ARA',None),
    ('BEN','BEN',None),
    ('CAA','CAA',None),
    ('CNCP',None,None),
    ('COS','COS',None),
    ('F_CODE','F_CODE',None),
    ('FFN','FFN',None),
    ('FFN2','FFN2',None),
    ('FFN3','FFN3',None),
    ('FUFI','FUFI',None),
    ('FURL','FURL','transform_combine_FURL'),
    ('GDBV',None,None),
    ('HGT','HGT',None),
    ('LMC','LMC',None),
    ('LZN','LZN',None),
    ('MCC','MCC',None),
    ('MCC2','MCC2',None),
    ('MCC3','MCC3',None),
    ('PCF','PCF',None),
    ('PLC',None,None),
    ('TID','TID',None),
    ('WID','WID',None),
    ('WPI','WPI',None),
    ('YSU','YSU',None),
    ('ZI002_UFI','ZI002_UFI',None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_GNT','ZI005_GNT',None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZI014_PBY','ZI014_PBY',None),
    ('ZI014_PBY2','ZI014_PBY2',None),
    ('ZI014_PBY3','ZI014_PBY3',None),
    ('ZI014_PPO','ZI014_PPO',None),
    ('ZI014_PPO2','ZI014_PPO2',None),
    ('ZI014_PPO3','ZI014_PPO3',None),
    ('ZI014_PRW','ZI014_PRW',None),
    ('ZI014_PRW2','ZI014_PRW2',None),
    ('ZI014_PRW3','ZI014_PRW3',None),
    ('ZI020_GE4','ZI020_GE4',None),
    ('ZI025_HDP','ZI025_HDP',None),
    ('ZI025_WLE','ZI025_WLE',None),
    ('ZI026_CTUC','ZI026_CTUC',None),
    ('ZI026_CTUL','ZI026_CTUL',None),
    ('ZI026_CTUU','ZI026_CTUU',None),
    ('ZI031S_URI',None,None),
    ('ZI039S_UFI',None,None),
    ('ZVH','ZVH',None),
    ('UFI','UFI','transform_set_UFI') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# PortHarbourPntExt field translations
PortHarbourPntExtFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Pnt_fields) + [ \
    ('ACH',None,None),
    ('ARA','ARA',None),
    ('BEN','BEN',None),
    ('BER','BER',None),
    ('CNCP',None,None),
    ('COS','COS',None),
    ('DF1','DF1',None),
    ('DF2','DF2',None),
    ('DF3','DF3',None),
    ('DF4','DF4',None),
    ('F_CODE','F_CODE',None),
    ('FUFI','FUFI',None),
    ('FURL','FURL','transform_combine_FURL'),
    ('GDBV',None,None),
    ('HDP','HDP',None),
    ('LZN','LZN',None),
    ('PCF','PCF',None),
    ('ZI002_UFI','ZI002_UFI',None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_GNT','ZI005_GNT',None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZI020_GE4','ZI020_GE4',None),
    ('ZI026_CTUC','ZI026_CTUC',None),
    ('ZI026_CTUL','ZI026_CTUL',None),
    ('ZI026_CTUU','ZI026_CTUU',None),
    ('ZI031S_URI',None,None),
    ('ZI039S_UFI',None,None),
    ('UFI','UFI','transform_set_UFI') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# PortHarbourSrf field translations
PortHarbourSrfFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Srf_fields) + [ \
    ('ADR','ADR',None),
    ('AOO','AOO',None),
    ('ARA','ARA',None),
    ('BEN','BEN',None),
    ('CAA','CAA',None),
    ('CNCP',None,None),
    ('COS','COS',None),
    ('DZP','DZP',None),
    ('F_CODE','F_CODE',None),
    ('FAC','FAC',None),
    ('FFN','FFN',None),
    ('FFN2','FFN2',None),
    ('FFN3','FFN3',None),
    ('FHC','FHC',None),
    ('FHC2','FHC2',None),
    ('FHC3','FHC3',None),
    ('FLO','FLO',None),
    ('FUFI','FUFI',None),
    ('FURL','FURL','transform_combine_FURL'),
    ('GDBV',None,None),
    ('HGT','HGT',None),
    ('LCA','LCA',None),
    ('LMC','LMC',None),
    ('LNU','LNU',None),
    ('LZN','LZN',None),
    ('MCC','MCC',None),
    ('MCC2','MCC2',None),
    ('MCC3','MCC3',None),
    ('MWD','MWD',None),
    ('PCF','PCF',None),
    ('PLC',None,None),
    ('PWC','PWC',None),
    ('SGCC','SGCC',None),
    ('SGCL','SGCL',None),
    ('SGCU','SGCU',None),
    ('SLR','SLR',None),
    ('TID','TID',None),
    ('WDU','WDU',None),
    ('WID','WID',None),
    ('WLE','WLE',None),
    ('WPI','WPI',None),
    ('YSU','YSU',None),
    ('ZI002_UFI','ZI002_UFI',None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_FNA2','ZI005_FNA2',None),
    ('ZI005_GNT','ZI005_GNT',None),
    ('ZI005_GNT2','ZI005_GNT2',None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZI005_NFN2','ZI005_NFN2',None),
    ('ZI014_PBY','ZI014_PBY',None),
    ('ZI014_PBY2','ZI014_PBY2',None),
    ('ZI014_PBY3','ZI014_PBY3',None),
    ('ZI014_PPO','ZI014_PPO',None),
    ('ZI014_PPO2','ZI014_PPO2',None),
    ('ZI014_PPO3','ZI014_PPO3',None),
    ('ZI014_PRW','ZI014_PRW',None),
    ('ZI014_PRW2','ZI014_PRW2',None),
    ('ZI014_PRW3','ZI014_PRW3',None),
    ('ZI020_GE4','ZI020_GE4',None),
    ('ZI025_HDP','ZI025_HDP',None),
    ('ZI025_WLE','ZI025_WLE',None),
    ('ZI026_CTUC','ZI026_CTUC',None),
    ('ZI026_CTUL','ZI026_CTUL',None),
    ('ZI026_CTUU','ZI026_CTUU',None),
    ('ZI031S_URI',None,None),
    ('ZI039S_UFI',None,None),
    ('ZVH','ZVH',None),
    ('UFI','UFI','transform_set_UFI') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# PortHarbourSrfExt field translations
PortHarbourSrfExtFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Srf_fields) + [ \
    ('ACH',None,None),
    ('ARA','ARA',None),
    ('BEN','BEN',None),
    ('CNCP',None,None),
    ('COS','COS',None),
    ('F_CODE','F_CODE',None),
    ('FUFI','FUFI',None),
    ('FURL','FURL','transform_combine_FURL'),
    ('GDBV',None,None),
    ('HDP','HDP',None),
    ('LZN','LZN',None),
    ('MCC','MCC',None),
    ('MCC2','MCC2',None),
    ('MCC3','MCC3',None),
    ('PCF','PCF',None),
    ('WID','WID',None),
    ('WLE','WLE',None),
    ('ZI002_UFI','ZI002_UFI',None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_GNT','ZI005_GNT',None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZI020_GE4','ZI020_GE4',None),
    ('ZI026_CTUC','ZI026_CTUC',None),
    ('ZI026_CTUL','ZI026_CTUL',None),
    ('ZI026_CTUU','ZI026_CTUU',None),
    ('ZI031S_URI',None,None),
    ('ZI039S_UFI',None,None),
    ('UFI','UFI','transform_set_UFI') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# RecreationAONExt field translations
RecreationAONExtFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Srf_fields) + [ \
    ('ARA','ARA',None),
    ('BEN','BEN',None),
    ('CAA','CAA',None),
    ('CNCP',None,None),
    ('COS','COS',None),
    ('DMF','DMF',None),
    ('DZP','DZP',None),
    ('F_CODE','F_CODE',None),
    ('FUFI','FUFI',None),
    ('FURL','FURL','transform_combine_FURL'),
    ('GDBV',None,None),
    ('HGT','HGT',None),
    ('LMC','LMC',None),
    ('LZN','LZN',None),
    ('PCF','PCF',None),
    ('VLM','VLM',None),
    ('WID','WID',None),
    ('ZI002_UFI','ZI002_UFI',None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_GNT','ZI005_GNT',None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZI020_GE4','ZI020_GE4',None),
    ('ZI024_ASE','ZI024_ASE',None),
    ('ZI024_CFR','ZI024_CFR',None),
    ('ZI024_CLO','ZI024_CLO',None),
    ('ZI024_CYN','ZI024_CYN',None),
    ('ZI024_FMR',None,None),
    ('ZI024_FRR',None,None),
    ('ZI024_HAR','ZI024_HAR',None),
    ('ZI024_MGN','ZI024_MGN',None),
    ('ZI024_PHW','ZI024_PHW',None),
    ('ZI024_SCC','ZI024_SCC',None),
    ('ZI024_SUL','ZI024_SUL',None),
    ('ZI024_TDS','ZI024_TDS',None),
    ('ZI024_TEP','ZI024_TEP',None),
    ('ZI024_TUR','ZI024_TUR',None),
    ('ZI024_WAC','ZI024_WAC',None),
    ('ZI024_WTNO',None,None),
    ('ZI024_WUR','ZI024_WUR',None),
    ('ZI024_WUR2','ZI024_WUR2',None),
    ('ZI024_WUR3','ZI024_WUR3',None),
    ('ZI024_WUR4','ZI024_WUR4',None),
    ('ZI026_CTUC','ZI026_CTUC',None),
    ('ZI026_CTUL','ZI026_CTUL',None),
    ('ZI026_CTUU','ZI026_CTUU',None),
    ('ZI031S_URI',None,None),
    ('ZI039S_UFI',None,None),
    ('LOC','LOC','transform_LOC'),
    ('UFI','UFI','transform_set_UFI'),
    ('ZI024_HYP','ZI024_HYP','transform_ZI024_HYP') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# RecreationCrv field translations
RecreationCrvFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Crv_fields) + [ \
    ('ADR','ADR',None),
    ('AMA','AMA',None),
    ('AOO','AOO',None),
    ('ARA','ARA',None),
    ('AWP','AWP',None),
    ('BEN','BEN',None),
    ('CAA','CAA',None),
    ('CNCP',None,None),
    ('COS','COS',None),
    ('F_CODE','F_CODE',None),
    ('FUFI','FUFI',None),
    ('FURL','FURL','transform_combine_FURL'),
    ('GDBV',None,None),
    ('HEI','HEI',None),
    ('HGT','HGT',None),
    ('LMC','LMC',None),
    ('LZN','LZN',None),
    ('PCF','PCF',None),
    ('RAY',None,None),
    ('THI','THI',None),
    ('VOI','VOI',None),
    ('WID','WID',None),
    ('ZI002_UFI','ZI002_UFI',None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_GNT','ZI005_GNT',None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZI020_GE4','ZI020_GE4',None),
    ('ZI026_CTUC','ZI026_CTUC',None),
    ('ZI026_CTUL','ZI026_CTUL',None),
    ('ZI026_CTUU','ZI026_CTUU',None),
    ('ZI031S_URI',None,None),
    ('ZI039S_UFI',None,None),
    ('ZVH','ZVH',None),
    ('UFI','UFI','transform_set_UFI') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# RecreationPnt field translations
RecreationPntFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Pnt_fields) + [ \
    ('ADR','ADR',None),
    ('AMA','AMA',None),
    ('AOO','AOO',None),
    ('ARA','ARA',None),
    ('AWP','AWP',None),
    ('BEN','BEN',None),
    ('CAA','CAA',None),
    ('CCT','CCT',None),
    ('CNCP',None,None),
    ('COS','COS',None),
    ('DZP','DZP',None),
    ('F_CODE','F_CODE',None),
    ('FFN','FFN',None),
    ('FFN2','FFN2',None),
    ('FFN3','FFN3',None),
    ('FUFI','FUFI',None),
    ('FURL','FURL','transform_combine_FURL'),
    ('GDBV',None,None),
    ('HEI','HEI',None),
    ('HGT','HGT',None),
    ('LMC','LMC',None),
    ('LZN','LZN',None),
    ('PCF','PCF',None),
    ('SSR','SSR',None),
    ('SSR2','SSR2',None),
    ('SSR3','SSR3',None),
    ('THI','THI',None),
    ('VLM','VLM',None),
    ('VOI','VOI',None),
    ('WID','WID',None),
    ('ZI002_UFI','ZI002_UFI',None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_GNT','ZI005_GNT',None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZI020_GE4','ZI020_GE4',None),
    ('ZI024_ASE','ZI024_ASE',None),
    ('ZI024_CFR','ZI024_CFR',None),
    ('ZI024_CLO','ZI024_CLO',None),
    ('ZI024_CYN','ZI024_CYN',None),
    ('ZI024_FMR',None,None),
    ('ZI024_FRR',None,None),
    ('ZI024_HAR','ZI024_HAR',None),
    ('ZI024_MGN','ZI024_MGN',None),
    ('ZI024_PHW','ZI024_PHW',None),
    ('ZI024_SCC','ZI024_SCC',None),
    ('ZI024_SUL','ZI024_SUL',None),
    ('ZI024_TDS','ZI024_TDS',None),
    ('ZI024_TEP','ZI024_TEP',None),
    ('ZI024_TUR','ZI024_TUR',None),
    ('ZI024_WAC','ZI024_WAC',None),
    ('ZI024_WTNO',None,None),
    ('ZI024_WUR','ZI024_WUR',None),
    ('ZI024_WUR2','ZI024_WUR2',None),
    ('ZI024_WUR3','ZI024_WUR3',None),
    ('ZI024_WUR4','ZI024_WUR4',None),
    ('ZI026_CTUC','ZI026_CTUC',None),
    ('ZI026_CTUL','ZI026_CTUL',None),
    ('ZI026_CTUU','ZI026_CTUU',None),
    ('ZI031S_URI',None,None),
    ('ZI039S_UFI',None,None),
    ('ZVH','ZVH',None),
    ('LOC','LOC','transform_LOC'),
    ('UFI','UFI','transform_set_UFI'),
    ('ZI024_HYP','ZI024_HYP','transform_ZI024_HYP') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# RecreationSrf field translations
RecreationSrfFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Srf_fields) + [ \
    ('ADR','ADR',None),
    ('AMA','AMA',None),
    ('AOO','AOO',None),
    ('ARA','ARA',None),
    ('AWP','AWP',None),
    ('BEN','BEN',None),
    ('CAA','CAA',None),
    ('CCT','CCT',None),
    ('CNCP',None,None),
    ('COS','COS',None),
    ('DZP','DZP',None),
    ('F_CODE','F_CODE',None),
    ('FFN','FFN',None),
    ('FFN2','FFN2',None),
    ('FFN3','FFN3',None),
    ('FUFI','FUFI',None),
    ('FURL','FURL','transform_combine_FURL'),
    ('GDBV',None,None),
    ('HGT','HGT',None),
    ('LMC','LMC',None),
    ('LZN','LZN',None),
    ('PCF','PCF',None),
    ('RAY',None,None),
    ('SSR','SSR',None),
    ('SSR2','SSR2',None),
    ('SSR3','SSR3',None),
    ('VLM','VLM',None),
    ('VOI','VOI',None),
    ('WID','WID',None),
    ('ZI002_UFI','ZI002_UFI',None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_GNT','ZI005_GNT',None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZI020_GE4','ZI020_GE4',None),
    ('ZI024_ASE','ZI024_ASE',None),
    ('ZI024_CFR','ZI024_CFR',None),
    ('ZI024_CLO','ZI024_CLO',None),
    ('ZI024_CYN','ZI024_CYN',None),
    ('ZI024_FMR',None,None),
    ('ZI024_FRR',None,None),
    ('ZI024_HAR','ZI024_HAR',None),
    ('ZI024_MGN','ZI024_MGN',None),
    ('ZI024_PHW','ZI024_PHW',None),
    ('ZI024_SCC','ZI024_SCC',None),
    ('ZI024_SUL','ZI024_SUL',None),
    ('ZI024_TDS','ZI024_TDS',None),
    ('ZI024_TEP','ZI024_TEP',None),
    ('ZI024_TUR','ZI024_TUR',None),
    ('ZI024_WAC','ZI024_WAC',None),
    ('ZI024_WTNO',None,None),
    ('ZI024_WUR','ZI024_WUR',None),
    ('ZI024_WUR2','ZI024_WUR2',None),
    ('ZI024_WUR3','ZI024_WUR3',None),
    ('ZI024_WUR4','ZI024_WUR4',None),
    ('ZI026_CTUC','ZI026_CTUC',None),
    ('ZI026_CTUL','ZI026_CTUL',None),
    ('ZI026_CTUU','ZI026_CTUU',None),
    ('ZI031S_URI',None,None),
    ('ZI039S_UFI',None,None),
    ('ZVH','ZVH',None),
    ('LOC','LOC','transform_LOC'),
    ('UFI','UFI','transform_set_UFI'),
    ('ZI024_HYP','ZI024_HYP','transform_ZI024_HYP') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)


# SettlementPnt field translations
SettlementPntFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Pnt_fields) + [ \
    ('ADR','ADR',None),
    ('AOO','AOO',None),
    ('ARA','ARA',None),
    ('BAC','BAC',None),
    ('BEN','BEN',None),
    ('BNF','BNF',None),
    ('CAA','CAA',None),
    ('CNCP',None,None),
    ('COS','COS',None),
    ('DNE','DNE',None),
    ('F_CODE','F_CODE',None),
    ('FFN','FFN',None),
    ('FFN2','FFN2',None),
    ('FFN3','FFN3',None),
    ('FUFI','FUFI',None),
    ('FURL','FURL','transform_combine_FURL'),
    ('GDBV',None,None),
    ('HGT','HGT',None),
    ('HHD','HHD',None),
    ('LMC','LMC',None),
    ('LZN','LZN',None),
    ('PCF','PCF',None),
    ('STL','STL',None),
    ('STL2','STL2',None),
    ('STL3','STL3',None),
    ('WID','WID',None),
    ('WPI','WPI',None),
    ('ZI002_UFI','ZI002_UFI',None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_FNA2','ZI005_FNA2',None),
    ('ZI005_GNT','ZI005_GNT',None),
    ('ZI005_GNT2','ZI005_GNT2',None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZI005_NFN2','ZI005_NFN2',None),
    ('ZI020_GE4','ZI020_GE4',None),
    ('ZI026_CTUC','ZI026_CTUC',None),
    ('ZI026_CTUL','ZI026_CTUL',None),
    ('ZI026_CTUU','ZI026_CTUU',None),
    ('ZI031S_URI',None,None),
    ('ZI039S_UFI',None,None),
    ('ZVH','ZVH',None),
    ('UFI','UFI','transform_set_UFI') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# SettlementSrf field translations
SettlementSrfFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Srf_fields) + [ \
    ('ADR','ADR',None),
    ('AOO','AOO',None),
    ('ARA','ARA',None),
    ('BAC','BAC',None),
    ('BEN','BEN',None),
    ('BNF','BNF',None),
    ('CAA','CAA',None),
    ('CNCP',None,None),
    ('COS','COS',None),
    ('DNE','DNE',None),
    ('F_CODE','F_CODE',None),
    ('FFN','FFN',None),
    ('FFN2','FFN2',None),
    ('FFN3','FFN3',None),
    ('FUFI','FUFI',None),
    ('FURL','FURL','transform_combine_FURL'),
    ('GDBV',None,None),
    ('HGT','HGT',None),
    ('HHD','HHD',None),
    ('LMC','LMC',None),
    ('LZN','LZN',None),
    ('PCF','PCF',None),
    ('STL','STL',None),
    ('STL2','STL2',None),
    ('STL3','STL3',None),
    ('WID','WID',None),
    ('WPI','WPI',None),
    ('ZI002_UFI','ZI002_UFI',None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_FNA2','ZI005_FNA2',None),
    ('ZI005_GNT','ZI005_GNT',None),
    ('ZI005_GNT2','ZI005_GNT2',None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZI005_NFN2','ZI005_NFN2',None),
    ('ZI020_GE4','ZI020_GE4',None),
    ('ZI026_CTUC','ZI026_CTUC',None),
    ('ZI026_CTUL','ZI026_CTUL',None),
    ('ZI026_CTUU','ZI026_CTUU',None),
    ('ZI031S_URI',None,None),
    ('ZI039S_UFI',None,None),
    ('ZVH','ZVH',None),
    ('UFI','UFI','transform_set_UFI') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# SettlementSrfExt field translations
SettlementSrfExtFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Srf_fields) + [ \
    ('ARA',None,None),
    ('BEN',None,None),
    ('F_CODE',None,None),
    ('FUFI',None,None),
    ('FURL',None,None),
    ('GDBV',None,None),
    ('NDX',None,None),
    ('NDX2',None,None),
    ('NDX3',None,None),
    ('UFI',None,None),
    ('ZI002_UFI',None,None),
    ('ZI005_FNA',None,None),
    ('ZI005_GNT',None,None),
    ('ZI005_NFN',None,None),
    ('ZI020_GE4',None,None),
    ('ZI026_CTUC',None,None),
    ('ZI026_CTUL',None,None),
    ('ZI026_CTUU',None,None),
    ('ZI031S_URI',None,None),
    ('ZI039S_UFI',None,None)
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# StorageAONExt field translations
StorageAONExtFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Srf_fields) + [ \
    ('ARA','ARA',None),
    ('AWP','AWP',None),
    ('BEN','BEN',None),
    ('CAA','CAA',None),
    ('CBP','CBP',None),
    ('CNCP',None,None),
    ('COS','COS',None),
    ('DMF','DMF',None),
    ('F_CODE','F_CODE',None),
    ('FUFI','FUFI',None),
    ('FURL','FURL','transform_combine_FURL'),
    ('GDBV',None,None),
    ('HEI','HEI',None),
    ('HGT','HGT',None),
    ('LMC','LMC',None),
    ('LUN','LUN',None),
    ('LZN','LZN',None),
    ('PCF','PCF',None),
    ('PPO','PPO',None),
    ('PPO2','PPO2',None),
    ('PPO3','PPO3',None),
    ('SPT','SPT',None),
    ('SSC','SSC',None),
    ('VCM','VCM',None),
    ('VCM2','VCM2',None),
    ('VCM3','VCM3',None),
    ('VLM','VLM',None),
    ('VOI','VOI',None),
    ('WID','WID',None),
    ('YWQ','YWQ',None),
    ('ZI002_UFI','ZI002_UFI',None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_FNA2','ZI005_FNA2',None),
    ('ZI005_GNT','ZI005_GNT',None),
    ('ZI005_GNT2','ZI005_GNT2',None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZI005_NFN2','ZI005_NFN2',None),
    ('ZI020_GE4','ZI020_GE4',None),
    ('ZI024_ASE','ZI024_ASE',None),
    ('ZI024_CFR','ZI024_CFR',None),
    ('ZI024_CLO','ZI024_CLO',None),
    ('ZI024_CYN','ZI024_CYN',None),
    ('ZI024_FMR',None,None),
    ('ZI024_FRR',None,None),
    ('ZI024_HAR','ZI024_HAR',None),
    ('ZI024_MGN','ZI024_MGN',None),
    ('ZI024_PHW','ZI024_PHW',None),
    ('ZI024_SCC','ZI024_SCC',None),
    ('ZI024_SUL','ZI024_SUL',None),
    ('ZI024_TDS','ZI024_TDS',None),
    ('ZI024_TEP','ZI024_TEP',None),
    ('ZI024_TUR','ZI024_TUR',None),
    ('ZI024_WAC','ZI024_WAC',None),
    ('ZI024_WTNO',None,None),
    ('ZI024_WUR','ZI024_WUR',None),
    ('ZI024_WUR2','ZI024_WUR2',None),
    ('ZI024_WUR3','ZI024_WUR3',None),
    ('ZI024_WUR4','ZI024_WUR4',None),
    ('ZI026_CTUC','ZI026_CTUC',None),
    ('ZI026_CTUL','ZI026_CTUL',None),
    ('ZI026_CTUU','ZI026_CTUU',None),
    ('ZI031S_URI',None,None),
    ('ZI039S_UFI',None,None),
    ('ZVH','ZVH',None),
    ('UFI','UFI','transform_set_UFI') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# StoragePnt field translations
StoragePntFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Pnt_fields) + [ \
    ('ADR','ADR',None),
    ('AOO','AOO',None),
    ('ARA','ARA',None),
    ('AWP','AWP',None),
    ('BEN','BEN',None),
    ('CAA','CAA',None),
    ('CBP','CBP',None),
    ('CNCP',None,None),
    ('COS','COS',None),
    ('F_CODE','F_CODE',None),
    ('FFN','FFN',None),
    ('FFN2','FFN2',None),
    ('FFN3','FFN3',None),
    ('FUFI','FUFI',None),
    ('FURL','FURL','transform_combine_FURL'),
    ('GDBV',None,None),
    ('HEI','HEI',None),
    ('HGT','HGT',None),
    ('LMC','LMC',None),
    ('LUN','LUN',None),
    ('LZN','LZN',None),
    ('PCF','PCF',None),
    ('PMPR','PMPR',None),
    ('PPO','PPO',None),
    ('PPO2','PPO2',None),
    ('PPO3','PPO3',None),
    ('SHT','SHT',None),
    ('SPT','SPT',None),
    ('SSC','SSC',None),
    ('SSR','SSR',None),
    ('SSR2','SSR2',None),
    ('SSR3','SSR3',None),
    ('VCM','VCM',None),
    ('VCM2','VCM2',None),
    ('VCM3','VCM3',None),
    ('VLM','VLM',None),
    ('VOI','VOI',None),
    ('WDST',None,None),
    ('WID','WID',None),
    ('YWQ','YWQ',None),
    ('ZI002_UFI','ZI002_UFI',None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_FNA2','ZI005_FNA2',None),
    ('ZI005_GNT','ZI005_GNT',None),
    ('ZI005_GNT2','ZI005_GNT2',None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZI005_NFN2','ZI005_NFN2',None),
    ('ZI020_GE4','ZI020_GE4',None),
    ('ZI024_ASE','ZI024_ASE',None),
    ('ZI024_CFR','ZI024_CFR',None),
    ('ZI024_CLO','ZI024_CLO',None),
    ('ZI024_CYN','ZI024_CYN',None),
    ('ZI024_FMR',None,None),
    ('ZI024_FRR',None,None),
    ('ZI024_HAR','ZI024_HAR',None),
    ('ZI024_MGN','ZI024_MGN',None),
    ('ZI024_PHW','ZI024_PHW',None),
    ('ZI024_SCC','ZI024_SCC',None),
    ('ZI024_SUL','ZI024_SUL',None),
    ('ZI024_TDS','ZI024_TDS',None),
    ('ZI024_TEP','ZI024_TEP',None),
    ('ZI024_TUR','ZI024_TUR',None),
    ('ZI024_WAC','ZI024_WAC',None),
    ('ZI024_WTNO',None,None),
    ('ZI024_WUR','ZI024_WUR',None),
    ('ZI024_WUR2','ZI024_WUR2',None),
    ('ZI024_WUR3','ZI024_WUR3',None),
    ('ZI024_WUR4','ZI024_WUR4',None),
    ('ZI026_CTUC','ZI026_CTUC',None),
    ('ZI026_CTUL','ZI026_CTUL',None),
    ('ZI026_CTUU','ZI026_CTUU',None),
    ('ZI031S_URI',None,None),
    ('ZI039S_UFI',None,None),
    ('ZVH','ZVH',None),
    ('LOC','LOC','transform_LOC'),
    ('UFI','UFI','transform_set_UFI'),
    ('ZI024_HYP','ZI024_HYP','transform_ZI024_HYP') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# StorageSrf field translations
StorageSrfFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Srf_fields) + [ \
    ('ADR','ADR',None),
    ('AOO','AOO',None),
    ('ARA','ARA',None),
    ('AWP','AWP',None),
    ('BEN','BEN',None),
    ('CAA','CAA',None),
    ('CBP','CBP',None),
    ('CNCP',None,None),
    ('COS','COS',None),
    ('F_CODE','F_CODE',None),
    ('FFN','FFN',None),
    ('FFN2','FFN2',None),
    ('FFN3','FFN3',None),
    ('FUFI','FUFI',None),
    ('FURL','FURL','transform_combine_FURL'),
    ('GDBV',None,None),
    ('HEI','HEI',None),
    ('HGT','HGT',None),
    ('LMC','LMC',None),
    ('LUN','LUN',None),
    ('LZN','LZN',None),
    ('PCF','PCF',None),
    ('PMPR','PMPR',None),
    ('PPO','PPO',None),
    ('PPO2','PPO2',None),
    ('PPO3','PPO3',None),
    ('SHT','SHT',None),
    ('SPT','SPT',None),
    ('SSC','SSC',None),
    ('SSR','SSR',None),
    ('SSR2','SSR2',None),
    ('SSR3','SSR3',None),
    ('VCM','VCM',None),
    ('VCM2','VCM2',None),
    ('VCM3','VCM3',None),
    ('VLM','VLM',None),
    ('VOI','VOI',None),
    ('WDST',None,None),
    ('WID','WID',None),
    ('YWQ','YWQ',None),
    ('ZI002_UFI','ZI002_UFI',None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_FNA2','ZI005_FNA2',None),
    ('ZI005_GNT','ZI005_GNT',None),
    ('ZI005_GNT2','ZI005_GNT2',None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZI005_NFN2','ZI005_NFN2',None),
    ('ZI020_GE4','ZI020_GE4',None),
    ('ZI024_ASE','ZI024_ASE',None),
    ('ZI024_CFR','ZI024_CFR',None),
    ('ZI024_CLO','ZI024_CLO',None),
    ('ZI024_CYN','ZI024_CYN',None),
    ('ZI024_FMR',None,None),
    ('ZI024_FRR',None,None),
    ('ZI024_HAR','ZI024_HAR',None),
    ('ZI024_MGN','ZI024_MGN',None),
    ('ZI024_PHW','ZI024_PHW',None),
    ('ZI024_SCC','ZI024_SCC',None),
    ('ZI024_SUL','ZI024_SUL',None),
    ('ZI024_TDS','ZI024_TDS',None),
    ('ZI024_TEP','ZI024_TEP',None),
    ('ZI024_TUR','ZI024_TUR',None),
    ('ZI024_WAC','ZI024_WAC',None),
    ('ZI024_WTNO',None,None),
    ('ZI024_WUR','ZI024_WUR',None),
    ('ZI024_WUR2','ZI024_WUR2',None),
    ('ZI024_WUR3','ZI024_WUR3',None),
    ('ZI024_WUR4','ZI024_WUR4',None),
    ('ZI026_CTUC','ZI026_CTUC',None),
    ('ZI026_CTUL','ZI026_CTUL',None),
    ('ZI026_CTUU','ZI026_CTUU',None),
    ('ZI031S_URI',None,None),
    ('ZI039S_UFI',None,None),
    ('ZVH','ZVH',None),
    ('LOC','LOC','transform_LOC'),
    ('UFI','UFI','transform_set_UFI'),
    ('ZI024_HYP','ZI024_HYP','transform_ZI024_HYP') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# StructureCrv field translations
StructureCrvFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Crv_fields) + [ \
    ('AOO','AOO',None),
    ('ARA','ARA',None),
    ('AWP','AWP',None),
    ('BAT','BAT',None),
    ('BEN','BEN',None),
    ('BSU','BSU',None),
    ('CAA','CAA',None),
    ('CNCP',None,None),
    ('COS','COS',None),
    ('CRM','CRM',None),
    ('F_CODE','F_CODE',None),
    ('FEF',None,None),
    ('FFN','FFN',None),
    ('FFN2','FFN2',None),
    ('FFN3','FFN3',None),
    ('FTI','FTI',None),
    ('FUFI','FUFI',None),
    ('FURL','FURL','transform_combine_FURL'),
    ('GDBV',None,None),
    ('HEI','HEI',None),
    ('HGT','HGT',None),
    ('LMC','LMC',None),
    ('LZN','LZN',None),
    ('MCC','MCC',None),
    ('MCC2','MCC2',None),
    ('MCC3','MCC3',None),
    ('PCF','PCF',None),
    ('PFHC','PFHC',None),
    ('PFHL','PFHL',None),
    ('PFHU','PFHU',None),
    ('THI','THI',None),
    ('VCM','VCM',None),
    ('VCM2','VCM2',None),
    ('VCM3','VCM3',None),
    ('VOI','VOI',None),
    ('WID','WID',None),
    ('WTI','WTI',None),
    ('ZI002_UFI','ZI002_UFI',None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_GNT','ZI005_GNT',None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZI018_WIT','ZI018_WIT',None),
    ('ZI020_GE4','ZI020_GE4',None),
    ('ZI026_CTUC','ZI026_CTUC',None),
    ('ZI026_CTUL','ZI026_CTUL',None),
    ('ZI026_CTUU','ZI026_CTUU',None),
    ('ZI031S_URI',None,None),
    ('ZI039S_UFI',None,None),
    ('ZVH','ZVH',None),
    ('UFI','UFI','transform_set_UFI') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# StructurePnt field translations
StructurePntFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Pnt_fields) + [ \
    ('ADR','ADR',None),
    ('AOO','AOO',None),
    ('ARA','ARA',None),
    ('ATB','ATB',None),
    ('AWP','AWP',None),
    ('BEN','BEN',None),
    ('BNF','BNF',None),
    ('BSU','BSU',None),
    ('CAA','CAA',None),
    ('CNCP',None,None),
    ('COS','COS',None),
    ('CRM','CRM',None),
    ('DZP','DZP',None),
    ('ETY','ETY',None),
    ('F_CODE','F_CODE',None),
    ('FFN','FFN',None),
    ('FFN2','FFN2',None),
    ('FFN3','FFN3',None),
    ('FUFI','FUFI',None),
    ('FURL','FURL','transform_combine_FURL'),
    ('GDBV',None,None),
    ('GUG','GUG',None),
    ('HEI','HEI',None),
    ('HGT','HGT',None),
    ('HSC','HSC',None),
    ('HST','HST',None),
    ('HST2','HST2',None),
    ('HST3','HST3',None),
    ('LEA','LEA',None),
    ('LMC','LMC',None),
    ('LZN','LZN',None),
    ('MEL','MDSP',None),
    ('MFB','MFB',None),
    ('MFY','MDFC',None),
    ('MKSZ','MKSZ',None),
    ('MUB','MUB',None),
    ('NOR','ROOM',None),
    ('PCF','PCF',None),
    ('PYC','PYC',None),
    ('PYM','PYM',None),
    ('RLE','RLE',None),
    ('SPT','SPT',None),
    ('SRL','SRL',None),
    ('SSR','SSR',None),
    ('SSR2','SSR2',None),
    ('SSR3','SSR3',None),
    ('STAF','STAF',None),
    ('TEL','TEL',None),
    ('TOS','TOS',None),
    ('TTC','TTC',None),
    ('TTC2','TTC2',None),
    ('TTC3','TTC3',None),
    ('VCM','VCM',None),
    ('VCM2','VCM2',None),
    ('VCM3','VCM3',None),
    ('VEC','VEC',None),
    ('VOI','VOI',None),
    ('WID','WID',None),
    ('WPST','WPST',None),
    ('WTYP','WTYP',None),
    ('ZI002_UFI','ZI002_UFI',None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_FNA2','ZI005_FNA2',None),
    ('ZI005_FNA3','ZI005_FNA3',None),
    ('ZI005_GNT','ZI005_GNT',None),
    ('ZI005_GNT2','ZI005_GNT2',None),
    ('ZI005_GNT3','ZI005_GNT3',None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZI005_NFN2','ZI005_NFN2',None),
    ('ZI005_NFN3','ZI005_NFN3',None),
    ('ZI014_PBY','ZI014_PBY',None),
    ('ZI014_PBY2','ZI014_PBY2',None),
    ('ZI014_PBY3','ZI014_PBY3',None),
    ('ZI014_PPO','ZI014_PPO',None),
    ('ZI014_PPO2','ZI014_PPO2',None),
    ('ZI014_PPO3','ZI014_PPO3',None),
    ('ZI014_PRW','ZI014_PRW',None),
    ('ZI014_PRW2','ZI014_PRW2',None),
    ('ZI014_PRW3','ZI014_PRW3',None),
    ('ZI018_WIT','ZI018_WIT',None),
    ('ZI020_GE4','ZI020_GE4',None),
    ('ZI026_CTUC','ZI026_CTUC',None),
    ('ZI026_CTUL','ZI026_CTUL',None),
    ('ZI026_CTUU','ZI026_CTUU',None),
    ('ZI031S_URI',None,None),
    ('ZI037_REL','ZI037_REL',None),
    ('ZI037_RFA','ZI037_RFA',None),
    ('ZI039S_UFI',None,None),
    ('ZVH','ZVH',None),
    ('UFI','UFI','transform_set_UFI') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# StructurePntExt field translations
StructurePntExtFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Pnt_fields) + [ \
    ('ARA','ARA',None),
    ('BEN','BEN',None),
    ('CNCP',None,None),
    ('COS','COS',None),
    ('F_CODE','F_CODE',None),
    ('FUFI','FUFI',None),
    ('FURL','FURL','transform_combine_FURL'),
    ('GDBV',None,None),
    ('LMC','LMC',None),
    ('LZN','LZN',None),
    ('PCF','PCF',None),
    ('WID','WID',None),
    ('ZI002_UFI','ZI002_UFI',None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_GNT','ZI005_GNT',None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZI020_GE4','ZI020_GE4',None),
    ('ZI026_CTUC','ZI026_CTUC',None),
    ('ZI026_CTUL','ZI026_CTUL',None),
    ('ZI026_CTUU','ZI026_CTUU',None),
    ('ZI031S_URI',None,None),
    ('ZI039S_UFI',None,None),
    ('UFI','UFI','transform_set_UFI') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# StructureSrf field translations
StructureSrfFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Srf_fields) + [ \
    ('ADR','ADR',None),
    ('AOO','AOO',None),
    ('ARA','ARA',None),
    ('ATB','ATB',None),
    ('AWP','AWP',None),
    ('BEN','BEN',None),
    ('BNF','BNF',None),
    ('BSU','BSU',None),
    ('CAA','CAA',None),
    ('CNCP',None,None),
    ('COS','COS',None),
    ('ETY','ETY',None),
    ('F_CODE','F_CODE',None),
    ('FFN','FFN',None),
    ('FFN2','FFN2',None),
    ('FFN3','FFN3',None),
    ('FUFI','FUFI',None),
    ('FURL','FURL','transform_combine_FURL'),
    ('GDBV',None,None),
    ('GUG','GUG',None),
    ('HEI','HEI',None),
    ('HGT','HGT',None),
    ('HSC','HSC',None),
    ('HST','HST',None),
    ('HST2','HST2',None),
    ('HST3','HST3',None),
    ('LMC','LMC',None),
    ('LZN','LZN',None),
    ('MEL','MDSP',None),
    ('MFB','MFB',None),
    ('MFY','MDFC',None),
    ('MKSZ','MKSZ',None),
    ('MUB','MUB',None),
    ('NOR','ROOM',None),
    ('PCF','PCF',None),
    ('PYC','PYC',None),
    ('PYM','PYM',None),
    ('RLE','RLE',None),
    ('SPT','SPT',None),
    ('SRL','SRL',None),
    ('SSR','SSR',None),
    ('SSR2','SSR2',None),
    ('SSR3','SSR3',None),
    ('STAF','STAF',None),
    ('TEL','TEL',None),
    ('TOS','TOS',None),
    ('TTC','TTC',None),
    ('TTC2','TTC2',None),
    ('TTC3','TTC3',None),
    ('VCM','VCM',None),
    ('VCM2','VCM2',None),
    ('VCM3','VCM3',None),
    ('VEC','VEC',None),
    ('VOI','VOI',None),
    ('WID','WID',None),
    ('WPST','WPST',None),
    ('WTYP','WTYP',None),
    ('ZI002_UFI','ZI002_UFI',None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_FNA2','ZI005_FNA2',None),
    ('ZI005_FNA3','ZI005_FNA3',None),
    ('ZI005_GNT','ZI005_GNT',None),
    ('ZI005_GNT2','ZI005_GNT2',None),
    ('ZI005_GNT3','ZI005_GNT3',None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZI005_NFN2','ZI005_NFN2',None),
    ('ZI005_NFN3','ZI005_NFN3',None),
    ('ZI014_PBY','ZI014_PBY',None),
    ('ZI014_PBY2','ZI014_PBY2',None),
    ('ZI014_PBY3','ZI014_PBY3',None),
    ('ZI014_PPO','ZI014_PPO',None),
    ('ZI014_PPO2','ZI014_PPO2',None),
    ('ZI014_PPO3','ZI014_PPO3',None),
    ('ZI014_PRW','ZI014_PRW',None),
    ('ZI014_PRW2','ZI014_PRW2',None),
    ('ZI014_PRW3','ZI014_PRW3',None),
    ('ZI018_WIT','ZI018_WIT',None),
    ('ZI020_GE4','ZI020_GE4',None),
    ('ZI026_CTUC','ZI026_CTUC',None),
    ('ZI026_CTUL','ZI026_CTUL',None),
    ('ZI026_CTUU','ZI026_CTUU',None),
    ('ZI031S_URI',None,None),
    ('ZI037_REL','ZI037_REL',None),
    ('ZI037_RFA','ZI037_RFA',None),
    ('ZI039S_UFI',None,None),
    ('ZVH','ZVH',None),
    ('UFI','UFI','transform_set_UFI') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# SubterraneanSrf field translations
SubterraneanSrfFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Srf_fields) + [ \
    ('AQN','AQN',None),
    ('AQO','AQO',None),
    ('AQO2','AQO2',None),
    ('AQO3','AQO3',None),
    ('AQP','AQP',None),
    ('AQP2','AQP2',None),
    ('AQP3','AQP3',None),
    ('AQTC','AQTC',None),
    ('AQTL','AQTL',None),
    ('AQTU','AQTU',None),
    ('ARA','ARA',None),
    ('AYRC','AYRC',None),
    ('AYRL','AYRL',None),
    ('AYRU','AYRU',None),
    ('BEN','BEN',None),
    ('CAA','CAA',None),
    ('CNCP',None,None),
    ('CNF','CNF',None),
    ('COS','COS',None),
    ('DPAC','DPAC',None),
    ('DPAL','DPAL',None),
    ('DPAU','DPAU',None),
    ('DZP','DZP',None),
    ('F_CODE','F_CODE',None),
    ('FUFI','FUFI',None),
    ('FURL','FURL','transform_combine_FURL'),
    ('GDBV',None,None),
    ('GWTR',None,None),
    ('HYCD',None,None),
    ('LEA','LEA',None),
    ('LZN','LZN',None),
    ('PCF','PCF',None),
    ('SWCP',None,None),
    ('WID','WID',None),
    ('WRCC','WARRC',None),
    ('WRCL','WARRL',None),
    ('WRCU','WARRU',None),
    ('WWRC','WWRTC',None),
    ('WWRL','WWRTL',None),
    ('WWRU','WWRTU',None),
    ('ZI002_UFI','ZI002_UFI',None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_FNA2','ZI005_FNA2',None),
    ('ZI005_FNA3','ZI005_FNA3',None),
    ('ZI005_GNT','ZI005_GNT',None),
    ('ZI005_GNT2','ZI005_GNT2',None),
    ('ZI005_GNT3','ZI005_GNT3',None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZI005_NFN2','ZI005_NFN2',None),
    ('ZI005_NFN3','ZI005_NFN3',None),
    ('ZI020_GE4','ZI020_GE4',None),
    ('ZI024_ASE','ZI024_ASE',None),
    ('ZI024_CFR','ZI024_CFR',None),
    ('ZI024_CLO','ZI024_CLO',None),
    ('ZI024_CYN','ZI024_CYN',None),
    ('ZI024_FMR',None,None),
    ('ZI024_FRR',None,None),
    ('ZI024_HAR','ZI024_HAR',None),
    ('ZI024_MGN','ZI024_MGN',None),
    ('ZI024_PHW','ZI024_PHW',None),
    ('ZI024_SCC','ZI024_SCC',None),
    ('ZI024_SUL','ZI024_SUL',None),
    ('ZI024_TDS','ZI024_TDS',None),
    ('ZI024_TEP','ZI024_TEP',None),
    ('ZI024_TUR','ZI024_TUR',None),
    ('ZI024_WAC','ZI024_WAC',None),
    ('ZI024_WTNO',None,None),
    ('ZI024_WUR','ZI024_WUR',None),
    ('ZI024_WUR2','ZI024_WUR2',None),
    ('ZI024_WUR3','ZI024_WUR3',None),
    ('ZI024_WUR4','ZI024_WUR4',None),
    ('ZI024_YWQ','ZI024_YWQ',None),
    ('ZI026_CTUC','ZI026_CTUC',None),
    ('ZI026_CTUL','ZI026_CTUL',None),
    ('ZI026_CTUU','ZI026_CTUU',None),
    ('ZI031S_URI',None,None),
    ('ZI039S_UFI',None,None),
    ('ZI071_CTX','ZI071_CTX',None),
    ('ZI071_FFN','ZI071_FFN',None),
    ('ZI071_FFN2','ZI071_FFN2',None),
    ('ZI071_FFN3','ZI071_FFN3',None),
    ('ZI071_UAO','ZI071_UAO',None),
    ('GWS','GWS','transform_GWS'),
    ('UFI','UFI','transform_set_UFI') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# TransportationGroundCrv field translations
TransportationGroundCrvFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Crv_fields) + [ \
    ('AOO','AOO',None),
    ('ARA','ARA',None),
    ('AWP','AWP',None),
    ('BCC','BCC',None),
    ('BEN','BEN',None),
    ('BMC','BMC',None),
    ('BMC2','BMC2',None),
    ('BMC3','BMC3',None),
    ('BOT','BOT',None),
    ('BRN','BRN',None),
    ('BSC','BSC',None),
    ('BSC2','BSC2',None),
    ('BSC3','BSC3',None),
    ('BSM','BSM',None),
    ('CAA','CAA',None),
    ('CAT','CAT',None),
    ('CIW',None,None),
    ('CNCP',None,None),
    ('CON','CON',None),
    ('COS','COS',None),
    ('CTC','CTC',None),
    ('CTL','CTL',None),
    ('CWT','CWT',None),
    ('DEV','DEV',None),
    ('DZC','DZC',None),
    ('DZP','DZP',None),
    ('EXP','EXP',None),
    ('F_CODE','F_CODE',None),
    ('FCO','FCO',None),
    ('FFN','FFN',None),
    ('FFN2','FFN2',None),
    ('FFN3','FFN3',None),
    ('FSC','FSC',None),
    ('FUFI','FUFI',None),
    ('FURL','FURL','transform_combine_FURL'),
    ('GDBV',None,None),
    ('GTC','GTC',None),
    ('HCA','HCA',None),
    ('HEI','HEI',None),
    ('HGT','HGT',None),
    ('HST','HST',None),
    ('HST2','HST2',None),
    ('HST3','HST3',None),
    ('LC1','LC1',None),
    ('LC2','LC2',None),
    ('LC3','LC3',None),
    ('LC4','LC4',None),
    ('LEA','LEA',None),
    ('LMC','LMC',None),
    ('LOG','LOG',None),
    ('LTN','LTN',None),
    ('LZN','LZN',None),
    ('MCC','MCC',None),
    ('MCC2','MCC2',None),
    ('MCC3','MCC3',None),
    ('MES','MES',None),
    ('MWG','MWG',None),
    ('NOS','NOS',None),
    ('OHC','OHC',None),
    ('ONE','ONE',None),
    ('OOC','OOC',None),
    ('OWO','OWO',None),
    ('PCF','PCF',None),
    ('PFH','PFH',None),
    ('PSN','SINU',None),
    ('PTG',None,None),
    ('RFD','RFD',None),
    ('RIN_ROI','RIN_ROI',None),
    ('RIN_ROI2','RIN_ROI2',None),
    ('RIN_ROI3','RIN_ROI3',None),
    ('RIN_RTN','RIN_RTN',None),
    ('RIN_RTN2','RIN_RTN2',None),
    ('RIN_RTN3','RIN_RTN3',None),
    ('RLE','RLE',None),
    ('RMWC','RMWC',None),
    ('RMWL','RMWL',None),
    ('RMWU','RMWU',None),
    ('ROR','ROR',None),
    ('RRC','RRC',None),
    ('RRC2','RRC2',None),
    ('RRC3','RRC3',None),
    ('RSA','RSA',None),
    ('RTA','RTA',None),
    ('RTN','RTN',None),
    ('RTN2','RTN2',None),
    ('RTN3','RTN3',None),
    ('RTY','RTY',None),
    ('RWC','RWC',None),
    ('SBB','SBB',None),
    ('SEP','SEP',None),
    ('SGCC','SGCC',None),
    ('SGCL','SGCL',None),
    ('SGCU','SGCU',None),
    ('SHC','SHC',None),
    ('SPD','SPD',None),
    ('SPM','SPM',None),
    ('SRE','SRE',None),
    ('TCS','TCS',None),
    ('THI','THI',None),
    ('THR','THR',None),
    ('TRA','TRA',None),
    ('TRP','TRP',None),
    ('TST','TST',None),
    ('UBC','UBC',None),
    ('VCM','VCM',None),
    ('VCM2','VCM2',None),
    ('VCM3','VCM3',None),
    ('VCO',None,None),
    ('VCS','VCS',None),
    ('VCS_VCD','VCS_VCD',None),
    ('VCS_VCR','VCS_VCR',None),
    ('VOI','VOI',None),
    ('WBD','WBD',None),
    ('WD1','WD1',None),
    ('WD2','WD2',None),
    ('WID','WID',None),
    ('WLE','WLE',None),
    ('WT2','WT2',None),
    ('WVA','WVA',None),
    ('ZI002_UFI','ZI002_UFI',None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_GNT','ZI005_GNT',None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZI016_ROC','ZI016_ROC',None),
    ('ZI016_WD1','ZI016_WD1',None),
    ('ZI017_GAW','ZI017_GAW',None),
    ('ZI017_RGC','ZI017_RGC',None),
    ('ZI017_RIR','ZI017_RIR',None),
    ('ZI017_RRA','ZI017_RRA',None),
    ('ZI017_TRT','ZI017_TRT',None),
    ('ZI020_GE4','ZI020_GE4',None),
    ('ZI025_HDP','ZI025_HDP',None),
    ('ZI026_CTUC','ZI026_CTUC',None),
    ('ZI026_CTUL','ZI026_CTUL',None),
    ('ZI026_CTUU','ZI026_CTUU',None),
    ('ZI026_SUR','ZI026_SUR',None),
    ('ZI031S_URI',None,None),
    ('ZI039S_UFI',None,None),
    ('ZVH','ZVH',None),
    ('LOC','LOC','transform_LOC'),
    ('TRS','TRS','transform_TRS'),
    ('TRS2','TRS2','transform_TRS'),
    ('TRS3','TRS3','transform_TRS'),
    ('UFI','UFI','transform_set_UFI'),
    ('ZI016_WTC','ZI016_WTC','transform_CIW_to_ZI016_WTC') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# TransportationGroundPnt field translations
TransportationGroundPntFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Pnt_fields) + [ \
    ('ADI','ADI',None),
    ('ADR','ADR',None),
    ('AOO','AOO',None),
    ('ARA','ARA',None),
    ('ATB','ATB',None),
    ('AWP','AWP',None),
    ('BCC','BCC',None),
    ('BEN','BEN',None),
    ('BMC','BMC',None),
    ('BMC2','BMC2',None),
    ('BMC3','BMC3',None),
    ('BNF','BNF',None),
    ('BOT','BOT',None),
    ('BRN','BRN',None),
    ('BSC','BSC',None),
    ('BSC2','BSC2',None),
    ('BSC3','BSC3',None),
    ('BSM','BSM',None),
    ('CAA','CAA',None),
    ('CIW',None,None),
    ('CNCP',None,None),
    ('CON','CON',None),
    ('COS','COS',None),
    ('CSC','CSC',None),
    ('CSC2','CSC2',None),
    ('CSC3','CSC3',None),
    ('CTC','CTC',None),
    ('CWT','CWT',None),
    ('DEV','DEV',None),
    ('DGC','DGC',None),
    ('DZC','DZC',None),
    ('EXP','EXP',None),
    ('F_CODE','F_CODE',None),
    ('FFN','FFN',None),
    ('FFN2','FFN2',None),
    ('FFN3','FFN3',None),
    ('FUFI','FUFI',None),
    ('FURL','FURL','transform_combine_FURL'),
    ('GDBV',None,None),
    ('GTC','GTC',None),
    ('HCA','HCA',None),
    ('HEI','HEI',None),
    ('HGT','HGT',None),
    ('HST','HST',None),
    ('HST2','HST2',None),
    ('HST3','HST3',None),
    ('LC1','LC1',None),
    ('LC2','LC2',None),
    ('LC3','LC3',None),
    ('LC4','LC4',None),
    ('LMC','LMC',None),
    ('LUN','LUN',None),
    ('LZN','LZN',None),
    ('MCC','MCC',None),
    ('MCC2','MCC2',None),
    ('MCC3','MCC3',None),
    ('MES','MES',None),
    ('MUB','MUB',None),
    ('NOS','NOS',None),
    ('OHC','OHC',None),
    ('OOC','OOC',None),
    ('PCF','PCF',None),
    ('PYM','PYM',None),
    ('RAD','RAD',None),
    ('RFD','RFD',None),
    ('RIN_ROI','RIN_ROI',None),
    ('RIN_ROI2','RIN_ROI2',None),
    ('RIN_ROI3','RIN_ROI3',None),
    ('RIN_RTN','RIN_RTN',None),
    ('RIN_RTN2','RIN_RTN2',None),
    ('RIN_RTN3','RIN_RTN3',None),
    ('RIT','RIT',None),
    ('SHC','SHC',None),
    ('SPT','SPT',None),
    ('SRE','SRE',None),
    ('SSG','SSG',None),
    ('SSR','SSR',None),
    ('SSR2','SSR2',None),
    ('SSR3','SSR3',None),
    ('TCS','TCS',None),
    ('THI','THI',None),
    ('TRP','TRP',None),
    ('UBC','UBC',None),
    ('VCM','VCM',None),
    ('VCM2','VCM2',None),
    ('VCM3','VCM3',None),
    ('VCO',None,None),
    ('VCS','VCS',None),
    ('VCS_VCD','VCS_VCD',None),
    ('VCS_VCR','VCS_VCR',None),
    ('VOI','VOI',None),
    ('WBD','WBD',None),
    ('WD1','WD1',None),
    ('WD2','WD2',None),
    ('WID','WID',None),
    ('WVA','WVA',None),
    ('ZI002_UFI','ZI002_UFI',None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_GNT','ZI005_GNT',None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZI016_ROC','ZI016_ROC',None),
    ('ZI017_GAW','ZI017_GAW',None),
    ('ZI017_RGC','ZI017_RGC',None),
    ('ZI017_RRA','ZI017_RRA',None),
    ('ZI017_TRT','ZI017_TRT',None),
    ('ZI020_GE4','ZI020_GE4',None),
    ('ZI026_CTUC','ZI026_CTUC',None),
    ('ZI026_CTUL','ZI026_CTUL',None),
    ('ZI026_CTUU','ZI026_CTUU',None),
    ('ZI031S_URI',None,None),
    ('ZI039S_UFI',None,None),
    ('ZVH','ZVH',None),
    ('TRS','TRS','transform_TRS'),
    ('TRS2','TRS2','transform_TRS'),
    ('TRS3','TRS3','transform_TRS'),
    ('UFI','UFI','transform_set_UFI'),
    ('ZI016_WTC','ZI016_WTC','transform_CIW_to_ZI016_WTC') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# TransportationGroundPntExt field translations
TransportationGroundPntExtFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Pnt_fields) + [ \
    ('ADR','ADR',None),
    ('AOO','AOO',None),
    ('ARA','ARA',None),
    ('BEN','BEN',None),
    ('CAA','CAA',None),
    ('CNCP',None,None),
    ('COS','COS',None),
    ('CTL','CTL',None),
    ('F_CODE','F_CODE',None),
    ('FFN','FFN',None),
    ('FFN2','FFN2',None),
    ('FFN3','FFN3',None),
    ('FUFI','FUFI',None),
    ('FURL','FURL','transform_combine_FURL'),
    ('GDBV',None,None),
    ('HGT','HGT',None),
    ('LMC','LMC',None),
    ('LTN','LTN',None),
    ('LZN','LZN',None),
    ('MAN','MAN',None),
    ('PCF','PCF',None),
    ('WID','WID',None),
    ('ZI002_UFI','ZI002_UFI',None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_GNT','ZI005_GNT',None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZI017_GAW','ZI017_GAW',None),
    ('ZI017_RGC','ZI017_RGC',None),
    ('ZI017_RRA','ZI017_RRA',None),
    ('ZI017_TRT','ZI017_TRT',None),
    ('ZI020_GE4','ZI020_GE4',None),
    ('ZI026_CTUC','ZI026_CTUC',None),
    ('ZI026_CTUL','ZI026_CTUL',None),
    ('ZI026_CTUU','ZI026_CTUU',None),
    ('ZI031S_URI',None,None),
    ('ZI039S_UFI',None,None),
    ('ZVH','ZVH',None),
    ('TRS','TRS','transform_TRS'),
    ('TRS2','TRS2','transform_TRS'),
    ('TRS3','TRS3','transform_TRS'),
    ('UFI','UFI','transform_set_UFI') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# TransportationGroundSrf field translations
TransportationGroundSrfFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Srf_fields) + [ \
    ('ADR','ADR',None),
    ('AOO','AOO',None),
    ('ARA','ARA',None),
    ('ATB','ATB',None),
    ('AWP','AWP',None),
    ('BCC','BCC',None),
    ('BEN','BEN',None),
    ('BMC','BMC',None),
    ('BMC2','BMC2',None),
    ('BMC3','BMC3',None),
    ('BNF','BNF',None),
    ('BOT','BOT',None),
    ('BRN','BRN',None),
    ('BSC','BSC',None),
    ('BSC2','BSC2',None),
    ('BSC3','BSC3',None),
    ('BSM','BSM',None),
    ('CAA','CAA',None),
    ('CIW',None,None),
    ('CNCP',None,None),
    ('COS','COS',None),
    ('CSC','CSC',None),
    ('CSC2','CSC2',None),
    ('CSC3','CSC3',None),
    ('CTL','CTL',None),
    ('CWT','CWT',None),
    ('DEV','DEV',None),
    ('DGC','DGC',None),
    ('DZC','DZC',None),
    ('DZP','DZP',None),
    ('F_CODE','F_CODE',None),
    ('FCO','FCO',None),
    ('FFN','FFN',None),
    ('FFN2','FFN2',None),
    ('FFN3','FFN3',None),
    ('FSC','FSC',None),
    ('FUFI','FUFI',None),
    ('FURL','FURL','transform_combine_FURL'),
    ('GDBV',None,None),
    ('HCA','HCA',None),
    ('HEI','HEI',None),
    ('HGT','HGT',None),
    ('HST','HST',None),
    ('HST2','HST2',None),
    ('HST3','HST3',None),
    ('LC1','LC1',None),
    ('LC2','LC2',None),
    ('LC3','LC3',None),
    ('LC4','LC4',None),
    ('LEA','LEA',None),
    ('LMC','LMC',None),
    ('LTN','LTN',None),
    ('LUN','LUN',None),
    ('LZN','LZN',None),
    ('MCC','MCC',None),
    ('MCC2','MCC2',None),
    ('MCC3','MCC3',None),
    ('MES','MES',None),
    ('MUB','MUB',None),
    ('MWG','MWG',None),
    ('NOS','NOS',None),
    ('OHC','OHC',None),
    ('ONE','ONE',None),
    ('PCF','PCF',None),
    ('PSN','SINU',None),
    ('PTG',None,None),
    ('RFD','RFD',None),
    ('RIN_ROI','RIN_ROI',None),
    ('RIN_ROI2','RIN_ROI2',None),
    ('RIN_ROI3','RIN_ROI3',None),
    ('RIN_RTN','RIN_RTN',None),
    ('RIN_RTN2','RIN_RTN2',None),
    ('RIN_RTN3','RIN_RTN3',None),
    ('RLE','RLE',None),
    ('RMWC','RMWC',None),
    ('RMWL','RMWL',None),
    ('RMWU','RMWU',None),
    ('ROR','ROR',None),
    ('RTN','RTN',None),
    ('RTN2','RTN2',None),
    ('RTN3','RTN3',None),
    ('RTY','RTY',None),
    ('SBB','SBB',None),
    ('SEP','SEP',None),
    ('SGCC','SGCC',None),
    ('SGCL','SGCL',None),
    ('SGCU','SGCU',None),
    ('SPD','SPD',None),
    ('SPM','SPM',None),
    ('SPT','SPT',None),
    ('SSR','SSR',None),
    ('SSR2','SSR2',None),
    ('SSR3','SSR3',None),
    ('THR','THR',None),
    ('TRA','TRA',None),
    ('TRP','TRP',None),
    ('UBC','UBC',None),
    ('VCM','VCM',None),
    ('VCM2','VCM2',None),
    ('VCM3','VCM3',None),
    ('VCO',None,None),
    ('VCS','VCS',None),
    ('VCS_VCD','VCS_VCD',None),
    ('VCS_VCR','VCS_VCR',None),
    ('VET','VET',None),
    ('VOI','VOI',None),
    ('WBD','WBD',None),
    ('WD2','WD2',None),
    ('WID','WID',None),
    ('WLE','WLE',None),
    ('WT2','WT2',None),
    ('WVA','WVA',None),
    ('ZI002_UFI','ZI002_UFI',None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_GNT','ZI005_GNT',None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZI016_ROC','ZI016_ROC',None),
    ('ZI016_WD1','ZI016_WD1',None),
    ('ZI017_GAW','ZI017_GAW',None),
    ('ZI017_RGC','ZI017_RGC',None),
    ('ZI017_RRA','ZI017_RRA',None),
    ('ZI017_TRT','ZI017_TRT',None),
    ('ZI020_GE4','ZI020_GE4',None),
    ('ZI025_HDP','ZI025_HDP',None),
    ('ZI026_CTUC','ZI026_CTUC',None),
    ('ZI026_CTUL','ZI026_CTUL',None),
    ('ZI026_CTUU','ZI026_CTUU',None),
    ('ZI026_SUR','ZI026_SUR',None),
    ('ZI031S_URI',None,None),
    ('ZI039S_UFI',None,None),
    ('ZVH','ZVH',None),
    ('LOC','LOC','transform_LOC'),
    ('TRS','TRS','transform_TRS'),
    ('TRS2','TRS2','transform_TRS'),
    ('TRS3','TRS3','transform_TRS'),
    ('UFI','UFI','transform_set_UFI'),
    ('ZI016_WTC','ZI016_WTC','transform_CIW_to_ZI016_WTC') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# TransportationWaterAONExt field translations
TransportationWaterAONExtFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Srf_fields) + [ \
    ('ARA','ARA',None),
    ('BBMCA','BBMCA',None),
    ('BBMCA2','BBMCA2',None),
    ('BBMCA3','BBMCA3',None),
    ('BBMCB','BBMCB',None),
    ('BBMCB2','BBMCB2',None),
    ('BBMCB3','BBMCB3',None),
    ('BEN','BEN',None),
    ('BH141_AWBA','BH141_AWBA',None),
    ('BH141_AWBB','BH141_AWBB',None),
    ('BH141_IBOA','BH141_IBOA',None),
    ('BH141_IBOB','BH141_IBOB',None),
    ('BH141_SHDA','BH141_SHDA',None),
    ('BH141_SHDB','BH141_SHDB',None),
    ('BH141_SLTA','BH141_SLTA',None),
    ('BH141_SLTB','BH141_SLTB',None),
    ('BH141_WBHA','BH141_WBHA',None),
    ('BH141_WBHB','BH141_WBHB',None),
    ('BMC','BMC',None),
    ('BMC2','BMC2',None),
    ('BMC3','BMC3',None),
    ('BPWHAC','BPWHAC',None),
    ('BPWHAL','BPWHAL',None),
    ('BPWHAU','BPWHAU',None),
    ('BPWHBC','BPWHBC',None),
    ('BPWHBL','BPWHBL',None),
    ('BPWHBU','BPWHBU',None),
    ('BPWSAC','BPWSAC',None),
    ('BPWSAL','BPWSAL',None),
    ('BPWSAU','BPWSAU',None),
    ('BPWSBC','BPWSBC',None),
    ('BPWSBL','BPWSBL',None),
    ('BPWSBU','BPWSBU',None),
    ('BWVCAC','BWVCAC',None),
    ('BWVCAL','BWVCAL',None),
    ('BWVCAU','BWVCAU',None),
    ('BWVCBC','BWVCBC',None),
    ('BWVCBL','BWVCBL',None),
    ('BWVCBU','BWVCBU',None),
    ('CAA','CAA',None),
    ('CDA','CDA',None),
    ('CDL','CDL',None),
    ('CNCP',None,None),
    ('COS','COS',None),
    ('CWT','CWT',None),
    ('DEV','DEV',None),
    ('DMF','DMF',None),
    ('DOXY',None,None),
    ('DZP','DZP',None),
    ('F_CODE','F_CODE',None),
    ('FRZ',None,None),
    ('FUFI','FUFI',None),
    ('FURL','FURL','transform_combine_FURL'),
    ('GDBV',None,None),
    ('HDP','HDP',None),
    ('HGT','HGT',None),
    ('LEA','LEA',None),
    ('LMC','LMC',None),
    ('LZN','LZN',None),
    ('MWD','MWD',None),
    ('NVS','NVS',None),
    ('PCF','PCF',None),
    ('PWA','PWA',None),
    ('RLE','RLE',None),
    ('SBB','SBB',None),
    ('WD3','WD3',None),
    ('WDAC','WDAC',None),
    ('WDAL','WDAL',None),
    ('WDAU','WDAU',None),
    ('WDH','WDH',None),
    ('WDL','WDL',None),
    ('WID','WID',None),
    ('WVA','WVA',None),
    ('WVH','WVH',None),
    ('WVL','WVL',None),
    ('ZI002_UFI','ZI002_UFI',None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_FNA2','ZI005_FNA2',None),
    ('ZI005_FNA3','ZI005_FNA3',None),
    ('ZI005_GNT','ZI005_GNT',None),
    ('ZI005_GNT2','ZI005_GNT2',None),
    ('ZI005_GNT3','ZI005_GNT3',None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZI005_NFN2','ZI005_NFN2',None),
    ('ZI005_NFN3','ZI005_NFN3',None),
    ('ZI020_GE4','ZI020_GE4',None),
    ('ZI024_ASE','ZI024_ASE',None),
    ('ZI024_AWO','ZI024_AWO',None),
    ('ZI024_AWOI',None,None),
    ('ZI024_AWOX',None,None),
    ('ZI024_CFR','ZI024_CFR',None),
    ('ZI024_CLO','ZI024_CLO',None),
    ('ZI024_CYN','ZI024_CYN',None),
    ('ZI024_FMR',None,None),
    ('ZI024_FRR',None,None),
    ('ZI024_HAR','ZI024_HAR',None),
    ('ZI024_MGN','ZI024_MGN',None),
    ('ZI024_PHW','ZI024_PHW',None),
    ('ZI024_SCC','ZI024_SCC',None),
    ('ZI024_SQN','ZI024_SQN',None),
    ('ZI024_SUL','ZI024_SUL',None),
    ('ZI024_TDS','ZI024_TDS',None),
    ('ZI024_TEP','ZI024_TEP',None),
    ('ZI024_TUR','ZI024_TUR',None),
    ('ZI024_WAC','ZI024_WAC',None),
    ('ZI024_WPAC','ZI024_PAC',None),
    ('ZI024_WSG','ZI024_WSG',None),
    ('ZI024_WTNO',None,None),
    ('ZI024_WUR','ZI024_WUR',None),
    ('ZI024_WUR2','ZI024_WUR2',None),
    ('ZI024_WUR3','ZI024_WUR3',None),
    ('ZI024_WUR4','ZI024_WUR4',None),
    ('ZI024_YWQ','ZI024_YWQ',None),
    ('ZI026_CTUC','ZI026_CTUC',None),
    ('ZI026_CTUL','ZI026_CTUL',None),
    ('ZI026_CTUU','ZI026_CTUU',None),
    ('ZI031S_URI',None,None),
    ('ZI039S_UFI',None,None),
    ('ZVH','ZVH',None),
    ('LOC','LOC','transform_LOC'),
    ('UFI','UFI','transform_set_UFI'),
    ('ZI024_HYP','ZI024_HYP','transform_ZI024_HYP') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# TransportationWaterCrv field translations
TransportationWaterCrvFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Crv_fields) + [ \
    ('AOO','AOO',None),
    ('ARA','ARA',None),
    ('AWP','AWP',None),
    ('BBMCA','BBMCA',None),
    ('BBMCA2','BBMCA2',None),
    ('BBMCA3','BBMCA3',None),
    ('BBMCB','BBMCB',None),
    ('BBMCB2','BBMCB2',None),
    ('BBMCB3','BBMCB3',None),
    ('BEN','BEN',None),
    ('BGT','BGT',None),
    ('BH141_AWBA','BH141_AWBA',None),
    ('BH141_AWBB','BH141_AWBB',None),
    ('BH141_IBOA','BH141_IBOA',None),
    ('BH141_IBOB','BH141_IBOB',None),
    ('BH141_SHDA','BH141_SHDA',None),
    ('BH141_SHDB','BH141_SHDB',None),
    ('BH141_SLTA','BH141_SLTA',None),
    ('BH141_SLTB','BH141_SLTB',None),
    ('BH141_WBHA','BH141_WBHA',None),
    ('BH141_WBHB','BH141_WBHB',None),
    ('BMC','BMC',None),
    ('BMC2','BMC2',None),
    ('BMC3','BMC3',None),
    ('BPWHAC','BPWHAC',None),
    ('BPWHAL','BPWHAL',None),
    ('BPWHAU','BPWHAU',None),
    ('BPWHBC','BPWHBC',None),
    ('BPWHBL','BPWHBL',None),
    ('BPWHBU','BPWHBU',None),
    ('BPWSAC','BPWSAC',None),
    ('BPWSAL','BPWSAL',None),
    ('BPWSAU','BPWSAU',None),
    ('BPWSBC','BPWSBC',None),
    ('BPWSBL','BPWSBL',None),
    ('BPWSBU','BPWSBU',None),
    ('BWVCAC','BWVCAC',None),
    ('BWVCAL','BWVCAL',None),
    ('BWVCAU','BWVCAU',None),
    ('BWVCBC','BWVCBC',None),
    ('BWVCBL','BWVCBL',None),
    ('BWVCBU','BWVCBU',None),
    ('CAA','CAA',None),
    ('CDA','CDA',None),
    ('CDL','CDL',None),
    ('CNCP',None,None),
    ('COS','COS',None),
    ('CWT','CWT',None),
    ('DEV','DEV',None),
    ('DOXY',None,None),
    ('DZP','DZP',None),
    ('F_CODE','F_CODE',None),
    ('FCL','FCL',None),
    ('FER','FER',None),
    ('FRZ',None,None),
    ('FUFI','FUFI',None),
    ('FURL','FURL','transform_combine_FURL'),
    ('GDBV',None,None),
    ('HDP','HDP',None),
    ('HEI','HEI',None),
    ('HGT','HGT',None),
    ('LEA','LEA',None),
    ('LMC','LMC',None),
    ('LNU','LNU',None),
    ('LZN','LZN',None),
    ('MCC','MCC',None),
    ('MCC2','MCC2',None),
    ('MCC3','MCC3',None),
    ('MCX','MCX',None),
    ('MWD','MWD',None),
    ('NVS','NVS',None),
    ('OPT','OPT',None),
    ('PCF','PCF',None),
    ('PSN','SINU',None),
    ('PWA','PWA',None),
    ('RIN_ROI','RIN_ROI',None),
    ('RIN_ROI2','RIN_ROI2',None),
    ('RIN_ROI3','RIN_ROI3',None),
    ('RIN_RTN','RIN_RTN',None),
    ('RIN_RTN2','RIN_RTN2',None),
    ('RIN_RTN3','RIN_RTN3',None),
    ('RLE','RLE',None),
    ('SBB','SBB',None),
    ('SPD','SPD',None),
    ('SPM','SPM',None),
    ('THI','THI',None),
    ('TID',None,None),
    ('VOI','VOI',None),
    ('WD3','WD3',None),
    ('WDAC','WDAC',None),
    ('WDAL','WDAL',None),
    ('WDAU','WDAU',None),
    ('WDH','WDH',None),
    ('WDL','WDL',None),
    ('WDU','WDU',None),
    ('WID','WID',None),
    ('WVA','WVA',None),
    ('WVH','WVH',None),
    ('WVL','WVL',None),
    ('ZI002_UFI','ZI002_UFI',None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_FNA2','ZI005_FNA2',None),
    ('ZI005_FNA3','ZI005_FNA3',None),
    ('ZI005_GNT','ZI005_GNT',None),
    ('ZI005_GNT2','ZI005_GNT2',None),
    ('ZI005_GNT3','ZI005_GNT3',None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZI005_NFN2','ZI005_NFN2',None),
    ('ZI005_NFN3','ZI005_NFN3',None),
    ('ZI020_GE4','ZI020_GE4',None),
    ('ZI024_ASE','ZI024_ASE',None),
    ('ZI024_AWO','ZI024_AWO',None),
    ('ZI024_AWOI',None,None),
    ('ZI024_AWOX',None,None),
    ('ZI024_CFR','ZI024_CFR',None),
    ('ZI024_CLO','ZI024_CLO',None),
    ('ZI024_CYN','ZI024_CYN',None),
    ('ZI024_FMR',None,None),
    ('ZI024_FRR',None,None),
    ('ZI024_HAR','ZI024_HAR',None),
    ('ZI024_MGN','ZI024_MGN',None),
    ('ZI024_PHW','ZI024_PHW',None),
    ('ZI024_SCC','ZI024_SCC',None),
    ('ZI024_SQN','ZI024_SQN',None),
    ('ZI024_SUL','ZI024_SUL',None),
    ('ZI024_TDS','ZI024_TDS',None),
    ('ZI024_TEP','ZI024_TEP',None),
    ('ZI024_TUR','ZI024_TUR',None),
    ('ZI024_WAC','ZI024_WAC',None),
    ('ZI024_WPAC','ZI024_PAC',None),
    ('ZI024_WSG','ZI024_WSG',None),
    ('ZI024_WTNO',None,None),
    ('ZI024_WUR','ZI024_WUR',None),
    ('ZI024_WUR2','ZI024_WUR2',None),
    ('ZI024_WUR3','ZI024_WUR3',None),
    ('ZI024_WUR4','ZI024_WUR4',None),
    ('ZI024_YWQ','ZI024_YWQ',None),
    ('ZI026_CTUC','ZI026_CTUC',None),
    ('ZI026_CTUL','ZI026_CTUL',None),
    ('ZI026_CTUU','ZI026_CTUU',None),
    ('ZI031S_URI',None,None),
    ('ZI039S_UFI',None,None),
    ('ZVH','ZVH',None),
    ('LOC','LOC','transform_LOC'),
    ('TRS','TRS','transform_TRS'),
    ('TRS2','TRS2','transform_TRS'),
    ('TRS3','TRS3','transform_TRS'),
    ('UFI','UFI','transform_set_UFI'),
    ('ZI024_HYP','ZI024_HYP','transform_ZI024_HYP') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# TransportationWaterPnt field translations
TransportationWaterPntFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Pnt_fields) + [ \
    ('ADR','ADR',None),
    ('AOO','AOO',None),
    ('ARA','ARA',None),
    ('ATB','ATB',None),
    ('AWP','AWP',None),
    ('BEN','BEN',None),
    ('BGT','BGT',None),
    ('CAA','CAA',None),
    ('CNCP',None,None),
    ('COS','COS',None),
    ('DZP','DZP',None),
    ('F_CODE','F_CODE',None),
    ('FFN','FFN',None),
    ('FFN2','FFN2',None),
    ('FFN3','FFN3',None),
    ('FUFI','FUFI',None),
    ('FURL','FURL','transform_combine_FURL'),
    ('GDBV',None,None),
    ('HDP','HDP',None),
    ('HEI','HEI',None),
    ('HGT','HGT',None),
    ('HST','HST',None),
    ('HST2','HST2',None),
    ('HST3','HST3',None),
    ('LMC','LMC',None),
    ('LNU','LNU',None),
    ('LZN','LZN',None),
    ('MCC','MCC',None),
    ('MCC2','MCC2',None),
    ('MCC3','MCC3',None),
    ('MUB','MUB',None),
    ('MWD','MWD',None),
    ('PCF','PCF',None),
    ('SSR','SSR',None),
    ('SSR2','SSR2',None),
    ('SSR3','SSR3',None),
    ('THI','THI',None),
    ('VOI','VOI',None),
    ('WDU','WDU',None),
    ('WID','WID',None),
    ('ZI002_UFI','ZI002_UFI',None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_GNT','ZI005_GNT',None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZI020_GE4','ZI020_GE4',None),
    ('ZI026_CTUC','ZI026_CTUC',None),
    ('ZI026_CTUL','ZI026_CTUL',None),
    ('ZI026_CTUU','ZI026_CTUU',None),
    ('ZI031S_URI',None,None),
    ('ZI039S_UFI',None,None),
    ('ZVH','ZVH',None),
    ('TRS','TRS','transform_TRS'),
    ('TRS2','TRS2','transform_TRS'),
    ('TRS3','TRS3','transform_TRS'),
    ('UFI','UFI','transform_set_UFI') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# TransportationWaterPntExt field translations
TransportationWaterPntExtFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Pnt_fields) + [ \
    ('AOO','AOO',None),
    ('BEN','BEN',None),
    ('CAA','CAA',None),
    ('CNCP',None,None),
    ('COS','COS',None),
    ('F_CODE','F_CODE',None),
    ('FCL','FCL',None),
    ('FER','FER',None),
    ('FUFI','FUFI',None),
    ('FURL','FURL','transform_combine_FURL'),
    ('GDBV',None,None),
    ('LMC','LMC',None),
    ('LZN','LZN',None),
    ('MCX','MCX',None),
    ('OPT','OPT',None),
    ('PSN','SINU',None),
    ('RIN_ROI','RIN_ROI',None),
    ('RIN_ROI2','RIN_ROI2',None),
    ('RIN_ROI3','RIN_ROI3',None),
    ('RIN_RTN','RIN_RTN',None),
    ('RIN_RTN2','RIN_RTN2',None),
    ('RIN_RTN3','RIN_RTN3',None),
    ('SPD','SPD',None),
    ('SPM','SPM',None),
    ('ZI002_UFI','ZI002_UFI',None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_GNT','ZI005_GNT',None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZI020_GE4','ZI020_GE4',None),
    ('ZI026_CTUC','ZI026_CTUC',None),
    ('ZI026_CTUL','ZI026_CTUL',None),
    ('ZI026_CTUU','ZI026_CTUU',None),
    ('ZI031S_URI',None,None),
    ('ZI039S_UFI',None,None),
    ('TRS','TRS','transform_TRS'),
    ('TRS2','TRS2','transform_TRS'),
    ('TRS3','TRS3','transform_TRS'),
    ('UFI','UFI','transform_set_UFI') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# TransportationWaterSrf field translations
TransportationWaterSrfFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Srf_fields) + [ \
    ('ADR','ADR',None),
    ('AOO','AOO',None),
    ('ARA','ARA',None),
    ('ATB','ATB',None),
    ('AWP','AWP',None),
    ('BBMCA','BBMCA',None),
    ('BBMCA2','BBMCA2',None),
    ('BBMCA3','BBMCA3',None),
    ('BBMCB','BBMCB',None),
    ('BBMCB2','BBMCB2',None),
    ('BBMCB3','BBMCB3',None),
    ('BEN','BEN',None),
    ('BH141_AWBA','BH141_AWBA',None),
    ('BH141_AWBB','BH141_AWBB',None),
    ('BH141_IBOA','BH141_IBOA',None),
    ('BH141_IBOB','BH141_IBOB',None),
    ('BH141_SHDA','BH141_SHDA',None),
    ('BH141_SHDB','BH141_SHDB',None),
    ('BH141_SLTA','BH141_SLTA',None),
    ('BH141_SLTB','BH141_SLTB',None),
    ('BH141_WBHA','BH141_WBHA',None),
    ('BH141_WBHB','BH141_WBHB',None),
    ('BMC','BMC',None),
    ('BMC2','BMC2',None),
    ('BMC3','BMC3',None),
    ('BPWHAC','BPWHAC',None),
    ('BPWHAL','BPWHAL',None),
    ('BPWHAU','BPWHAU',None),
    ('BPWHBC','BPWHBC',None),
    ('BPWHBL','BPWHBL',None),
    ('BPWHBU','BPWHBU',None),
    ('BPWSAC','BPWSAC',None),
    ('BPWSAL','BPWSAL',None),
    ('BPWSAU','BPWSAU',None),
    ('BPWSBC','BPWSBC',None),
    ('BPWSBL','BPWSBL',None),
    ('BPWSBU','BPWSBU',None),
    ('BWVCAC','BWVCAC',None),
    ('BWVCAL','BWVCAL',None),
    ('BWVCAU','BWVCAU',None),
    ('BWVCBC','BWVCBC',None),
    ('BWVCBL','BWVCBL',None),
    ('BWVCBU','BWVCBU',None),
    ('CAA','CAA',None),
    ('CDA','CDA',None),
    ('CDL','CDL',None),
    ('CNCP',None,None),
    ('COS','COS',None),
    ('CWT','CWT',None),
    ('DEV','DEV',None),
    ('DOXY',None,None),
    ('DZP','DZP',None),
    ('F_CODE','F_CODE',None),
    ('FFN','FFN',None),
    ('FFN2','FFN2',None),
    ('FFN3','FFN3',None),
    ('FRZ',None,None),
    ('FUFI','FUFI',None),
    ('FURL','FURL','transform_combine_FURL'),
    ('GDBV',None,None),
    ('HDP','HDP',None),
    ('HGT','HGT',None),
    ('HST','HST',None),
    ('HST2','HST2',None),
    ('HST3','HST3',None),
    ('LEA','LEA',None),
    ('LMC','LMC',None),
    ('LNU','LNU',None),
    ('LZN','LZN',None),
    ('MCC','MCC',None),
    ('MCC2','MCC2',None),
    ('MCC3','MCC3',None),
    ('MUB','MUB',None),
    ('MWD','MWD',None),
    ('NVS','NVS',None),
    ('PCF','PCF',None),
    ('PWA','PWA',None),
    ('RLE','RLE',None),
    ('SBB','SBB',None),
    ('SSR','SSR',None),
    ('SSR2','SSR2',None),
    ('SSR3','SSR3',None),
    ('TID',None,None),
    ('VOI','VOI',None),
    ('WD3','WD3',None),
    ('WDAC','WDAC',None),
    ('WDAL','WDAL',None),
    ('WDAU','WDAU',None),
    ('WDH','WDH',None),
    ('WDL','WDL',None),
    ('WDU','WDU',None),
    ('WID','WID',None),
    ('WVA','WVA',None),
    ('WVH','WVH',None),
    ('WVL','WVL',None),
    ('ZI002_UFI','ZI002_UFI',None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_FNA2','ZI005_FNA2',None),
    ('ZI005_FNA3','ZI005_FNA3',None),
    ('ZI005_GNT','ZI005_GNT',None),
    ('ZI005_GNT2','ZI005_GNT2',None),
    ('ZI005_GNT3','ZI005_GNT3',None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZI005_NFN2','ZI005_NFN2',None),
    ('ZI005_NFN3','ZI005_NFN3',None),
    ('ZI020_GE4','ZI020_GE4',None),
    ('ZI024_ASE','ZI024_ASE',None),
    ('ZI024_AWO','ZI024_AWO',None),
    ('ZI024_AWOI',None,None),
    ('ZI024_AWOX',None,None),
    ('ZI024_CFR','ZI024_CFR',None),
    ('ZI024_CLO','ZI024_CLO',None),
    ('ZI024_CYN','ZI024_CYN',None),
    ('ZI024_FMR',None,None),
    ('ZI024_FRR',None,None),
    ('ZI024_HAR','ZI024_HAR',None),
    ('ZI024_MGN','ZI024_MGN',None),
    ('ZI024_PHW','ZI024_PHW',None),
    ('ZI024_SCC','ZI024_SCC',None),
    ('ZI024_SQN','ZI024_SQN',None),
    ('ZI024_SUL','ZI024_SUL',None),
    ('ZI024_TDS','ZI024_TDS',None),
    ('ZI024_TEP','ZI024_TEP',None),
    ('ZI024_TUR','ZI024_TUR',None),
    ('ZI024_WAC','ZI024_WAC',None),
    ('ZI024_WPAC','ZI024_PAC',None),
    ('ZI024_WSG','ZI024_WSG',None),
    ('ZI024_WTNO',None,None),
    ('ZI024_WUR','ZI024_WUR',None),
    ('ZI024_WUR2','ZI024_WUR2',None),
    ('ZI024_WUR3','ZI024_WUR3',None),
    ('ZI024_WUR4','ZI024_WUR4',None),
    ('ZI024_YWQ','ZI024_YWQ',None),
    ('ZI026_CTUC','ZI026_CTUC',None),
    ('ZI026_CTUL','ZI026_CTUL',None),
    ('ZI026_CTUU','ZI026_CTUU',None),
    ('ZI031S_URI',None,None),
    ('ZI039S_UFI',None,None),
    ('ZVH','ZVH',None),
    ('LOC','LOC','transform_LOC'),
    ('TRS','TRS','transform_TRS'),
    ('TRS2','TRS2','transform_TRS'),
    ('TRS3','TRS3','transform_TRS'),
    ('UFI','UFI','transform_set_UFI'),
    ('ZI024_HYP','ZI024_HYP','transform_ZI024_HYP') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# UtilityInfrastructureAONExt field translations
UtilityInfrastructureAONExtFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Srf_fields) + [ \
    ('ARA','ARA',None),
    ('BEN','BEN',None),
    ('CAA','CAA',None),
    ('CNCP',None,None),
    ('COS','COS',None),
    ('CWT','CWT',None),
    ('DEV','DEV',None),
    ('DIM','DIM',None),
    ('DMF','DMF',None),
    ('DZP','DZP',None),
    ('F_CODE','F_CODE',None),
    ('FFN','FFN',None),
    ('FFN2','FFN2',None),
    ('FFN3','FFN3',None),
    ('FLO','FLO',None),
    ('FUFI','FUFI',None),
    ('FURL','FURL','transform_combine_FURL'),
    ('GDBV',None,None),
    ('HGT','HGT',None),
    ('LEA','LEA',None),
    ('LMC','LMC',None),
    ('LUN','LUN',None),
    ('LZN','LZN',None),
    ('MCC','MCC',None),
    ('MCC2','MCC2',None),
    ('MCC3','MCC3',None),
    ('NPL','NPL',None),
    ('OWO','OWO',None),
    ('PCF','PCF',None),
    ('PLT','PLT',None),
    ('PLT2','PLT2',None),
    ('PLT3','PLT3',None),
    ('PMPR','PMPR',None),
    ('PPO','PPO',None),
    ('PPO2','PPO2',None),
    ('PPO3','PPO3',None),
    ('RLE','RLE',None),
    ('RTA','RTA',None),
    ('SBB','SBB',None),
    ('SPT','SPT',None),
    ('VCM','VCM',None),
    ('VCM2','VCM2',None),
    ('VCM3','VCM3',None),
    ('WDAC','WDAC',None),
    ('WDAL','WDAL',None),
    ('WDAU','WDAU',None),
    ('WDH','WDH',None),
    ('WDL','WDL',None),
    ('WID','WID',None),
    ('WVA','WVA',None),
    ('ZI002_UFI','ZI002_UFI',None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_FNA2','ZI005_FNA2',None),
    ('ZI005_FNA3','ZI005_FNA3',None),
    ('ZI005_GNT','ZI005_GNT',None),
    ('ZI005_GNT2','ZI005_GNT2',None),
    ('ZI005_GNT3','ZI005_GNT3',None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZI005_NFN2','ZI005_NFN2',None),
    ('ZI005_NFN3','ZI005_NFN3',None),
    ('ZI020_GE4','ZI020_GE4',None),
    ('ZI024_ASE','ZI024_ASE',None),
    ('ZI024_AWO','ZI024_AWO',None),
    ('ZI024_AWOI',None,None),
    ('ZI024_AWOX',None,None),
    ('ZI024_CFR','ZI024_CFR',None),
    ('ZI024_CLO','ZI024_CLO',None),
    ('ZI024_CYN','ZI024_CYN',None),
    ('ZI024_DRL','ZI024_DRL',None),
    ('ZI024_DVPT','ZI024_DVT',None),
    ('ZI024_FMR',None,None),
    ('ZI024_FRR',None,None),
    ('ZI024_HAR','ZI024_HAR',None),
    ('ZI024_MGN','ZI024_MGN',None),
    ('ZI024_PHW','ZI024_PHW',None),
    ('ZI024_PMP','ZI024_PMP',None),
    ('ZI024_SCC','ZI024_SCC',None),
    ('ZI024_SUL','ZI024_SUL',None),
    ('ZI024_TDS','ZI024_TDS',None),
    ('ZI024_TEP','ZI024_TEP',None),
    ('ZI024_TUR','ZI024_TUR',None),
    ('ZI024_WAC','ZI024_WAC',None),
    ('ZI024_WTNO',None,None),
    ('ZI024_WUR','ZI024_WUR',None),
    ('ZI024_WUR2','ZI024_WUR2',None),
    ('ZI024_WUR3','ZI024_WUR3',None),
    ('ZI024_WUR4','ZI024_WUR4',None),
    ('ZI024_YWQ','ZI024_YWQ',None),
    ('ZI025_HDP','ZI025_HDP',None),
    ('ZI026_CTUC','ZI026_CTUC',None),
    ('ZI026_CTUL','ZI026_CTUL',None),
    ('ZI026_CTUU','ZI026_CTUU',None),
    ('ZI031S_URI',None,None),
    ('ZI039S_UFI',None,None),
    ('ZVH','ZVH',None),
    ('LOC','LOC','transform_LOC'),
    ('UFI','UFI','transform_set_UFI') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# UtilityInfrastructureCrv field translations
UtilityInfrastructureCrvFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Crv_fields) + [ \
    ('AWP','AWP',None),
    ('BEN','BEN',None),
    ('CAA','CAA',None),
    ('CAB','CAB',None),
    ('CAB2','CAB2',None),
    ('CAB3','CAB3',None),
    ('CNCP',None,None),
    ('COS','COS',None),
    ('CST','CST',None),
    ('CWT','CWT',None),
    ('DEV','DEV',None),
    ('DIM','DIM',None),
    ('DZP','DZP',None),
    ('F_CODE','F_CODE',None),
    ('FLO','FLO',None),
    ('FUFI','FUFI',None),
    ('FURL','FURL','transform_combine_FURL'),
    ('GDBV',None,None),
    ('HGT','HGT',None),
    ('KVA','KVA',None),
    ('LEA','LEA',None),
    ('LMC','LMC',None),
    ('LZN','LZN',None),
    ('MCC','MCC',None),
    ('MCC2','MCC2',None),
    ('MCC3','MCC3',None),
    ('NPL','NPL',None),
    ('OHC','OHC',None),
    ('OWO','OWO',None),
    ('PCF','PCF',None),
    ('PFH','PFH',None),
    ('PLT','PLT',None),
    ('PLT2','PLT2',None),
    ('PLT3','PLT3',None),
    ('PMPR','PMPR',None),
    ('PPO','PPO',None),
    ('PPO2','PPO2',None),
    ('PPO3','PPO3',None),
    ('RLE','RLE',None),
    ('RTA','RTA',None),
    ('SBB','SBB',None),
    ('SPT','SPT',None),
    ('TST','TST',None),
    ('VCO',None,None),
    ('VOI','VOI',None),
    ('WVA','WVA',None),
    ('ZI002_UFI','ZI002_UFI',None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_FNA2','ZI005_FNA2',None),
    ('ZI005_FNA3','ZI005_FNA3',None),
    ('ZI005_GNT','ZI005_GNT',None),
    ('ZI005_GNT2','ZI005_GNT2',None),
    ('ZI005_GNT3','ZI005_GNT3',None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZI005_NFN2','ZI005_NFN2',None),
    ('ZI005_NFN3','ZI005_NFN3',None),
    ('ZI020_GE4','ZI020_GE4',None),
    ('ZI024_ASE','ZI024_ASE',None),
    ('ZI024_AWO','ZI024_AWO',None),
    ('ZI024_AWOI',None,None),
    ('ZI024_AWOX',None,None),
    ('ZI024_CFR','ZI024_CFR',None),
    ('ZI024_CLO','ZI024_CLO',None),
    ('ZI024_CYN','ZI024_CYN',None),
    ('ZI024_FMR',None,None),
    ('ZI024_FRR',None,None),
    ('ZI024_HAR','ZI024_HAR',None),
    ('ZI024_MGN','ZI024_MGN',None),
    ('ZI024_PHW','ZI024_PHW',None),
    ('ZI024_SCC','ZI024_SCC',None),
    ('ZI024_SUL','ZI024_SUL',None),
    ('ZI024_TDS','ZI024_TDS',None),
    ('ZI024_TEP','ZI024_TEP',None),
    ('ZI024_TUR','ZI024_TUR',None),
    ('ZI024_WAC','ZI024_WAC',None),
    ('ZI024_WTNO',None,None),
    ('ZI024_WUR','ZI024_WUR',None),
    ('ZI024_WUR2','ZI024_WUR2',None),
    ('ZI024_WUR3','ZI024_WUR3',None),
    ('ZI024_WUR4','ZI024_WUR4',None),
    ('ZI024_YWQ','ZI024_YWQ',None),
    ('ZI025_HDP','ZI025_HDP',None),
    ('ZI025_WLE','ZI025_WLE',None),
    ('ZI026_CTUC','ZI026_CTUC',None),
    ('ZI026_CTUL','ZI026_CTUL',None),
    ('ZI026_CTUU','ZI026_CTUU',None),
    ('ZI031S_URI',None,None),
    ('ZI039S_UFI',None,None),
    ('ZVH','ZVH',None),
    ('LOC','LOC','transform_LOC'),
    ('UFI','UFI','transform_set_UFI') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# UtilityInfrastructurePnt field translations
UtilityInfrastructurePntFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Pnt_fields) + [ \
    ('ADR','ADR',None),
    ('ADUR',None,None),
    ('ANFL','ANFL',None),
    ('AOO','AOO',None),
    ('ARA','ARA',None),
    ('AT005_CAB','AT005_CAB',None),
    ('AT005_CAB2','AT005_CAB2',None),
    ('AT005_CAB3','AT005_CAB3',None),
    ('AWP','AWP',None),
    ('BEN','BEN',None),
    ('CAA','CAA',None),
    ('CNCP',None,None),
    ('COS','COS',None),
    ('DCAP','DCAP',None),
    ('DIM','DIM',None),
    ('DINF',None,None),
    ('DZP','DZP',None),
    ('EPW','EPW',None),
    ('F_CODE','F_CODE',None),
    ('FFN','FFN',None),
    ('FFN2','FFN2',None),
    ('FFN3','FFN3',None),
    ('FUFI','FUFI',None),
    ('FURL','FURL','transform_combine_FURL'),
    ('GDBV',None,None),
    ('GRD',None,None),
    ('GUG','GUG',None),
    ('HEI','HEI',None),
    ('HGT','HGT',None),
    ('LEA','LEA',None),
    ('LMC','LMC',None),
    ('LUN','LUN',None),
    ('LZN','LZN',None),
    ('MCC','MCC',None),
    ('MCC2','MCC2',None),
    ('MCC3','MCC3',None),
    ('PCF','PCF',None),
    ('POS','POS',None),
    ('POS2','POS2',None),
    ('POS3','POS3',None),
    ('PPO','PPO',None),
    ('PPO2','PPO2',None),
    ('PPO3','PPO3',None),
    ('RAC','RAC',None),
    ('SBT','SBT',None),
    ('SBT2','SBT2',None),
    ('SBT3','SBT3',None),
    ('SPT','SPT',None),
    ('SRL','SRL',None),
    ('SSR','SSR',None),
    ('SSR2','SSR2',None),
    ('SSR3','SSR3',None),
    ('TOS','TOS',None),
    ('UTY','UTY',None),
    ('UTY2','UTY2',None),
    ('UTY3','UTY3',None),
    ('VCM','VCM',None),
    ('VCM2','VCM2',None),
    ('VCM3','VCM3',None),
    ('VOI','VOI',None),
    ('WDAC','WDAC',None),
    ('WDAL','WDAL',None),
    ('WDAU','WDAU',None),
    ('WDH','WDH',None),
    ('WDL','WDL',None),
    ('WDST',None,None),
    ('WID','WID',None),
    ('WLSS',None,None),
    ('ZI002_UFI','ZI002_UFI',None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_FNA2','ZI005_FNA2',None),
    ('ZI005_FNA3','ZI005_FNA3',None),
    ('ZI005_GNT','ZI005_GNT',None),
    ('ZI005_GNT2','ZI005_GNT2',None),
    ('ZI005_GNT3','ZI005_GNT3',None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZI005_NFN2','ZI005_NFN2',None),
    ('ZI005_NFN3','ZI005_NFN3',None),
    ('ZI014_PBY','ZI014_PBY',None),
    ('ZI014_PBY2','ZI014_PBY2',None),
    ('ZI014_PBY3','ZI014_PBY3',None),
    ('ZI018_WIT','ZI018_WIT',None),
    ('ZI020_GE4','ZI020_GE4',None),
    ('ZI024_ASE','ZI024_ASE',None),
    ('ZI024_AWO','ZI024_AWO',None),
    ('ZI024_AWOI',None,None),
    ('ZI024_AWOX',None,None),
    ('ZI024_CFR','ZI024_CFR',None),
    ('ZI024_CLO','ZI024_CLO',None),
    ('ZI024_CYN','ZI024_CYN',None),
    ('ZI024_DRL','ZI024_DRL',None),
    ('ZI024_DVPT','ZI024_DVT',None),
    ('ZI024_FMR',None,None),
    ('ZI024_FRR',None,None),
    ('ZI024_HAR','ZI024_HAR',None),
    ('ZI024_MGN','ZI024_MGN',None),
    ('ZI024_PHW','ZI024_PHW',None),
    ('ZI024_PMP','ZI024_PMP',None),
    ('ZI024_PUR','ZI024_PUR',None),
    ('ZI024_PUR2','ZI024_PUR2',None),
    ('ZI024_PUR3','ZI024_PUR3',None),
    ('ZI024_PUR4','ZI024_PUR4',None),
    ('ZI024_PUR5','ZI024_PUR5',None),
    ('ZI024_SCC','ZI024_SCC',None),
    ('ZI024_SUL','ZI024_SUL',None),
    ('ZI024_TDS','ZI024_TDS',None),
    ('ZI024_TEP','ZI024_TEP',None),
    ('ZI024_TUR','ZI024_TUR',None),
    ('ZI024_WAC','ZI024_WAC',None),
    ('ZI024_WTNO',None,None),
    ('ZI024_WUR','ZI024_WUR',None),
    ('ZI024_WUR2','ZI024_WUR2',None),
    ('ZI024_WUR3','ZI024_WUR3',None),
    ('ZI024_WUR4','ZI024_WUR4',None),
    ('ZI024_YWQ','ZI024_YWQ',None),
    ('ZI026_CTUC','ZI026_CTUC',None),
    ('ZI026_CTUL','ZI026_CTUL',None),
    ('ZI026_CTUU','ZI026_CTUU',None),
    ('ZI031S_URI',None,None),
    ('ZI032_GUG','ZI032_GUG',None),
    ('ZI032_PYC','ZI032_PYC',None),
    ('ZI032_PYM','ZI032_PYM',None),
    ('ZI032_TOS','ZI032_TOS',None),
    ('ZI039S_UFI',None,None),
    ('ZVH','ZVH',None),
    ('UFI','UFI','transform_set_UFI') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# UtilityInfrastructurePntExt field translations
UtilityInfrastructurePntExtFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Pnt_fields) + [ \
    ('BEN','BEN',None),
    ('CAA','CAA',None),
    ('CNCP',None,None),
    ('COS','COS',None),
    ('DZP','DZP',None),
    ('F_CODE','F_CODE',None),
    ('FUFI','FUFI',None),
    ('FURL','FURL','transform_combine_FURL'),
    ('GDBV',None,None),
    ('HGT','HGT',None),
    ('HSCD',None,None),
    ('LMC',None,None),
    ('LUN','LUN',None),
    ('LZN',None,None),
    ('PCF','PCF',None),
    ('SPT','SPT',None),
    ('ZI002_UFI','ZI002_UFI',None),
    ('ZI005_FNA',None,None),
    ('ZI005_GNT',None,None),
    ('ZI005_NFN',None,None),
    ('ZI020_GE4','ZI020_GE4',None),
    ('ZI024_ASE',None,None),
    ('ZI024_CFR',None,None),
    ('ZI024_CLO',None,None),
    ('ZI024_CYN',None,None),
    ('ZI024_DRL','ZI024_DRL',None),
    ('ZI024_DVPT','ZI024_DVT',None),
    ('ZI024_FMR',None,None),
    ('ZI024_FRR',None,None),
    ('ZI024_HAR',None,None),
    ('ZI024_MGN',None,None),
    ('ZI024_PHW',None,None),
    ('ZI024_PMP','ZI024_PMP',None),
    ('ZI024_SCC',None,None),
    ('ZI024_SUL',None,None),
    ('ZI024_TDS',None,None),
    ('ZI024_TEP',None,None),
    ('ZI024_TUR',None,None),
    ('ZI024_WAC',None,None),
    ('ZI024_WTNO',None,None),
    ('ZI024_WUR',None,None),
    ('ZI024_YWQ',None,None),
    ('ZI026_CTUC','ZI026_CTUC',None),
    ('ZI026_CTUL','ZI026_CTUL',None),
    ('ZI026_CTUU','ZI026_CTUU',None),
    ('ZI031S_URI',None,None),
    ('ZI039S_UFI',None,None),
    ('ZVH',None,None),
    ('UFI','UFI','transform_set_UFI') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# UtilityInfrastructureSrf field translations
UtilityInfrastructureSrfFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Srf_fields) + [ \
    ('ADR','ADR',None),
    ('ADUR',None,None),
    ('ANFL','ANFL',None),
    ('AOO','AOO',None),
    ('ARA','ARA',None),
    ('AWP','AWP',None),
    ('BEN','BEN',None),
    ('CAA','CAA',None),
    ('CNCP',None,None),
    ('COS','COS',None),
    ('DCAP','DCAP',None),
    ('DINF',None,None),
    ('DZP','DZP',None),
    ('EPW','EPW',None),
    ('F_CODE','F_CODE',None),
    ('FFN','FFN',None),
    ('FFN2','FFN2',None),
    ('FFN3','FFN3',None),
    ('FUFI','FUFI',None),
    ('FURL','FURL','transform_combine_FURL'),
    ('GDBV',None,None),
    ('GRD',None,None),
    ('HGT','HGT',None),
    ('LEA','LEA',None),
    ('LMC','LMC',None),
    ('LUN','LUN',None),
    ('LZN','LZN',None),
    ('PCF','PCF',None),
    ('POS','POS',None),
    ('POS2','POS2',None),
    ('POS3','POS3',None),
    ('PPO','PPO',None),
    ('PPO2','PPO2',None),
    ('PPO3','PPO3',None),
    ('SBT','SBT',None),
    ('SBT2','SBT2',None),
    ('SBT3','SBT3',None),
    ('SSR','SSR',None),
    ('SSR2','SSR2',None),
    ('SSR3','SSR3',None),
    ('VCM','VCM',None),
    ('VCM2','VCM2',None),
    ('VCM3','VCM3',None),
    ('VOI','VOI',None),
    ('WDAC','WDAC',None),
    ('WDAL','WDAL',None),
    ('WDAU','WDAU',None),
    ('WDH','WDH',None),
    ('WDL','WDL',None),
    ('WDST',None,None),
    ('WID','WID',None),
    ('WLSS',None,None),
    ('ZI002_UFI','ZI002_UFI',None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_FNA2','ZI005_FNA2',None),
    ('ZI005_FNA3','ZI005_FNA3',None),
    ('ZI005_GNT','ZI005_GNT',None),
    ('ZI005_GNT2','ZI005_GNT2',None),
    ('ZI005_GNT3','ZI005_GNT3',None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZI005_NFN2','ZI005_NFN2',None),
    ('ZI005_NFN3','ZI005_NFN3',None),
    ('ZI014_PBY','ZI014_PBY',None),
    ('ZI014_PBY2','ZI014_PBY2',None),
    ('ZI014_PBY3','ZI014_PBY3',None),
    ('ZI020_GE4','ZI020_GE4',None),
    ('ZI024_ASE','ZI024_ASE',None),
    ('ZI024_AWO','ZI024_AWO',None),
    ('ZI024_AWOI',None,None),
    ('ZI024_AWOX',None,None),
    ('ZI024_CFR','ZI024_CFR',None),
    ('ZI024_CLO','ZI024_CLO',None),
    ('ZI024_CYN','ZI024_CYN',None),
    ('ZI024_DRL','ZI024_DRL',None),
    ('ZI024_DVPT','ZI024_DVT',None),
    ('ZI024_FMR',None,None),
    ('ZI024_FRR',None,None),
    ('ZI024_HAR','ZI024_HAR',None),
    ('ZI024_MGN','ZI024_MGN',None),
    ('ZI024_PHW','ZI024_PHW',None),
    ('ZI024_PMP','ZI024_PMP',None),
    ('ZI024_PUR','ZI024_PUR',None),
    ('ZI024_PUR2','ZI024_PUR2',None),
    ('ZI024_PUR3','ZI024_PUR3',None),
    ('ZI024_PUR4','ZI024_PUR4',None),
    ('ZI024_PUR5','ZI024_PUR5',None),
    ('ZI024_SCC','ZI024_SCC',None),
    ('ZI024_SUL','ZI024_SUL',None),
    ('ZI024_TDS','ZI024_TDS',None),
    ('ZI024_TEP','ZI024_TEP',None),
    ('ZI024_TUR','ZI024_TUR',None),
    ('ZI024_WAC','ZI024_WAC',None),
    ('ZI024_WTNO',None,None),
    ('ZI024_WUR','ZI024_WUR',None),
    ('ZI024_WUR2','ZI024_WUR2',None),
    ('ZI024_WUR3','ZI024_WUR3',None),
    ('ZI024_WUR4','ZI024_WUR4',None),
    ('ZI024_YWQ','ZI024_YWQ',None),
    ('ZI026_CTUC','ZI026_CTUC',None),
    ('ZI026_CTUL','ZI026_CTUL',None),
    ('ZI026_CTUU','ZI026_CTUU',None),
    ('ZI031S_URI',None,None),
    ('ZI039S_UFI',None,None),
    ('ZVH','ZVH',None),
    ('UFI','UFI','transform_set_UFI') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# VegetationCrv field translations
VegetationCrvFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Crv_fields) + [ \
    ('AOO','AOO',None),
    ('ARA','ARA',None),
    ('BEN','BEN',None),
    ('DMBC','DMBC',None),
    ('DMBL','DMBL',None),
    ('DMBU','DMBU',None),
    ('DMT','DMT',None),
    ('F_CODE','F_CODE',None),
    ('FUFI','FUFI',None),
    ('FURL','FURL','transform_combine_FURL'),
    ('GDBV',None,None),
    ('HGT','HGT',None),
    ('LMC','LMC',None),
    ('LZN','LZN',None),
    ('PVH','PVH',None),
    ('SBC','SBC',None),
    ('SDSC','SDSC',None),
    ('TRE','TRE',None),
    ('TSCC','TSCC',None),
    ('TSCL','TSCL',None),
    ('TSCU','TSCU',None),
    ('VSP','VSP',None),
    ('VSP2','VSP2',None),
    ('VSP3','VSP3',None),
    ('VTI','VTI',None),
    ('WID','WID',None),
    ('ZI002_UFI','ZI002_UFI',None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_GNT','ZI005_GNT',None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZI020_GE4','ZI020_GE4',None),
    ('ZI026_CTUC','ZI026_CTUC',None),
    ('ZI026_CTUL','ZI026_CTUL',None),
    ('ZI026_CTUU','ZI026_CTUU',None),
    ('ZI031S_URI',None,None),
    ('ZI039S_UFI',None,None),
    ('ZVH','ZVH',None),
    ('SDSL','SDSL','transform_decimetre_to_metre'),
    ('SDSU','SDSU','transform_decimetre_to_metre'),
    ('UFI','UFI','transform_set_UFI') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# VegetationPnt field translations
VegetationPntFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Pnt_fields) + [ \
    ('BEN','BEN',None),
    ('F_CODE','F_CODE',None),
    ('FUFI','FUFI',None),
    ('FURL','FURL','transform_combine_FURL'),
    ('GDBV',None,None),
    ('HGT','HGT',None),
    ('LMC','LMC',None),
    ('SDSC','SDSC',None),
    ('TRE','TRE',None),
    ('VSP','VSP',None),
    ('ZI002_UFI','ZI002_UFI',None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_GNT','ZI005_GNT',None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZI020_GE4','ZI020_GE4',None),
    ('ZI026_CTUC','ZI026_CTUC',None),
    ('ZI026_CTUL','ZI026_CTUL',None),
    ('ZI026_CTUU','ZI026_CTUU',None),
    ('ZI031S_URI',None,None),
    ('ZI039S_UFI',None,None),
    ('ZVH','ZVH',None),
    ('SDSL','SDSL','transform_decimetre_to_metre'),
    ('SDSU','SDSU','transform_decimetre_to_metre'),
    ('UFI','UFI','transform_set_UFI') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# VegetationPntExt field translations
VegetationPntExtFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Pnt_fields) + [ \
    ('ARA','ARA',None),
    ('BEN','BEN',None),
    ('COA','COA',None),
    ('COC','COC',None),
    ('COG','COG',None),
    ('DMBC','DMBC',None),
    ('DMBL','DMBL',None),
    ('DMBU','DMBU',None),
    ('DMT','DMT',None),
    ('F_CODE','F_CODE',None),
    ('FEO','FEO',None),
    ('FUFI','FUFI',None),
    ('FURL','FURL','transform_combine_FURL'),
    ('GDBV',None,None),
    ('HGT','HGT',None),
    ('LMC','LMC',None),
    ('LZN','LZN',None),
    ('PVH','PVH',None),
    ('SBC','SBC',None),
    ('SDSC','SDSC',None),
    ('STR','STR',None),
    ('TRE','TRE',None),
    ('TSCC','TSCC',None),
    ('TSCL','TSCL',None),
    ('TSCU','TSCU',None),
    ('VSP','VSP',None),
    ('VSP2','VSP2',None),
    ('VSP3','VSP3',None),
    ('VTI','VTI',None),
    ('WCL','WCL',None),
    ('WID','WID',None),
    ('ZI002_UFI','ZI002_UFI',None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_GNT','ZI005_GNT',None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZI020_GE4','ZI020_GE4',None),
    ('ZI026_CTUC','ZI026_CTUC',None),
    ('ZI026_CTUL','ZI026_CTUL',None),
    ('ZI026_CTUU','ZI026_CTUU',None),
    ('ZI031S_URI',None,None),
    ('ZI039S_UFI',None,None),
    ('ZVH','ZVH',None),
    ('SDSL','SDSL','transform_decimetre_to_metre'),
    ('SDSU','SDSU','transform_decimetre_to_metre'),
    ('UFI','UFI','transform_set_UFI') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# VegetationSrf field translations
VegetationSrfFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Srf_fields) + [ \
    ('AOO','AOO',None),
    ('ARA','ARA',None),
    ('BEN','BEN',None),
    ('BMC','BMC',None),
    ('BMC2','BMC2',None),
    ('BMC3','BMC3',None),
    ('BOC','BOC',None),
    ('CAA','CAA',None),
    ('DMBC','DMBC',None),
    ('DMBL','DMBL',None),
    ('DMBU','DMBU',None),
    ('DMT','DMT',None),
    ('DZP','DZP',None),
    ('F_CODE','F_CODE',None),
    ('FFN','FFN',None),
    ('FFN2','FFN2',None),
    ('FFN3','FFN3',None),
    ('FUFI','FUFI',None),
    ('FURL','FURL','transform_combine_FURL'),
    ('GDBV',None,None),
    ('HDP','HDP',None),
    ('HGT','HGT',None),
    ('LMC','LMC',None),
    ('LZN','LZN',None),
    ('PVH','PVH',None),
    ('SBC','SBC',None),
    ('SDSC','SDSC',None),
    ('SNDC','SNDC',None),
    ('SNDL','SNDL',None),
    ('SNDU','SNDU',None),
    ('TID','TID',None),
    ('TRE','TRE',None),
    ('TSCC','TSCC',None),
    ('TSCL','TSCL',None),
    ('TSCU','TSCU',None),
    ('TWS',None,None),
    ('VSP','VSP',None),
    ('VSP2','VSP2',None),
    ('VSP3','VSP3',None),
    ('VTI','VTI',None),
    ('WDAC','WDAC',None),
    ('WDAL','WDAL',None),
    ('WDAU','WDAU',None),
    ('WID','WID',None),
    ('ZI002_UFI','ZI002_UFI',None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_GNT','ZI005_GNT',None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZI020_GE4','ZI020_GE4',None),
    ('ZI024_ASE','ZI024_ASE',None),
    ('ZI024_CFR','ZI024_CFR',None),
    ('ZI024_CLO','ZI024_CLO',None),
    ('ZI024_CYN','ZI024_CYN',None),
    ('ZI024_FMR',None,None),
    ('ZI024_FRR',None,None),
    ('ZI024_HAR','ZI024_HAR',None),
    ('ZI024_MGN','ZI024_MGN',None),
    ('ZI024_PHW','ZI024_PHW',None),
    ('ZI024_SCC','ZI024_SCC',None),
    ('ZI024_SUL','ZI024_SUL',None),
    ('ZI024_TDS','ZI024_TDS',None),
    ('ZI024_TEP','ZI024_TEP',None),
    ('ZI024_TUR','ZI024_TUR',None),
    ('ZI024_WAC','ZI024_WAC',None),
    ('ZI024_WTNO',None,None),
    ('ZI024_WUR','ZI024_WUR',None),
    ('ZI024_YWQ','ZI024_YWQ',None),
    ('ZI026_CTUC','ZI026_CTUC',None),
    ('ZI026_CTUL','ZI026_CTUL',None),
    ('ZI026_CTUU','ZI026_CTUU',None),
    ('ZI031S_URI',None,None),
    ('ZI039S_UFI',None,None),
    ('ZVH','ZVH',None),
    ('SDSL','SDSL','transform_decimetre_to_metre'),
    ('SDSU','SDSU','transform_decimetre_to_metre'),
    ('UFI','UFI','transform_set_UFI'),
    ('VEG','VEG','transform_VEG'),
    ('ZI024_HYP','ZI024_HYP','transform_ZI024_HYP') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# VegetationSrfExt field translations
VegetationSrfExtFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Srf_fields) + [ \
    ('ARA','ARA',None),
    ('BEN','BEN',None),
    ('COA','COA',None),
    ('COC','COC',None),
    ('COG','COG',None),
    ('DMBC','DMBC',None),
    ('DMBL','DMBL',None),
    ('DMBU','DMBU',None),
    ('DMT','DMT',None),
    ('F_CODE','F_CODE',None),
    ('FEO','FEO',None),
    ('FUFI','FUFI',None),
    ('FURL','FURL','transform_combine_FURL'),
    ('GDBV',None,None),
    ('HGT','HGT',None),
    ('LMC','LMC',None),
    ('LZN','LZN',None),
    ('PVH','PVH',None),
    ('SBC','SBC',None),
    ('SDSC','SDSC',None),
    ('STR','STR',None),
    ('TRE','TRE',None),
    ('TSCC','TSCC',None),
    ('TSCL','TSCL',None),
    ('TSCU','TSCU',None),
    ('VSP','VSP',None),
    ('VSP2','VSP2',None),
    ('VSP3','VSP3',None),
    ('VTI','VTI',None),
    ('WCL','WCL',None),
    ('WID','WID',None),
    ('ZI002_UFI','ZI002_UFI',None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_GNT','ZI005_GNT',None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZI020_GE4','ZI020_GE4',None),
    ('ZI026_CTUC','ZI026_CTUC',None),
    ('ZI026_CTUL','ZI026_CTUL',None),
    ('ZI026_CTUU','ZI026_CTUU',None),
    ('ZI031S_URI',None,None),
    ('ZI039S_UFI',None,None),
    ('ZVH','ZVH',None),
    ('SDSL','SDSL','transform_decimetre_to_metre'),
    ('SDSU','SDSU','transform_decimetre_to_metre'),
    ('UFI','UFI','transform_set_UFI') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)
