﻿
""" 
 ************************************************************************************************
 **                                                                                            **
 **  File: GGDM30_2_TDS71_TranslateFeaturesandFields.py                                      **
 **  Copyright (c) March 2020 by Leidos                                                        **
 **  Produced under U.S. Government contract W5J9CQ-12-D-0004  Task Order: 053.                **
 **  As per DFARS, the U.S. Government is granted unlimited rights to use this work            **
 **  in any manner and for any purpose.                                                        **
 **                                                                                            **
 **  Summary:   This file provides the feature class / feature / and field specific            **
 **             mappings and where a translation is involved, that is listed as well.          **
 **             The information in this file is specific to translations from:                 **
 **                 GGDM 3.0 to TDS 7.1                             **
 **             Notes:                                                                         **
 **                 Be sure MEM and OTH transforms are done last in each feature class.        **
 **                                                                                            **
 **  Developed by Leidos, Inc., High Resolution ISR Systems Division, Geospatial Programs                                   **
 **                                                                                            **
 **  Development History:                                                                      **
 **  March 2016 / Annette Janett Filer (Annette.J.Filer@leidos.com) Original version
      Translation mapping added for RTL**               **
 **                                                                                            **
 **                                                                                            **
 ************************************************************************************************
"""

import sys
import os
import copy


current_include_source = "GGDM 3.0"
current_include_target = "TDS 7.1"



# Change 'None' to None, change AON to Srf remove entity coll and restrict from metadataSrf
## The following transforms could have been used, but we
## will rely on the transformer utility to notice that not
## all of the values from the source are allowed in the destination.
##transform_CAA_2_CAA'
##transform_ZI014_PPO'
##transform_MCC'
##transform_ZI014_PBY'
##transform_PRW'
##transform_BC101_SST'
##transform_BH141_SLT'
##transform_LOC'
##transform_ZI024_SCC'
##'transform_PPO'
##'transform_FFN'


common_fields = [
    ('FCSubtype', 'FCSubtype', 'transform_FCSubtype'),
    ('ObjectID', None, None), 
    ('GLOBALID', None, None)  
]

common_geom_fields =  [
    ('FCSubtype', 'FCSubtype', 'transform_FCSubtype'),
    ('ObjectID', None, None), 
    ('GLOBALID', None, None), 
    ('SHAPE@', 'SHAPE@', None)
    ]

common_Pnt_fields = []

common_Crv_fields = [
    ('SHAPE@Length', 'SHAPE@Length', None)
    ]

common_Srf_fields = [
    ('SHAPE@Length', 'SHAPE@Length', None),
    ('SHAPE@Area', 'SHAPE@Area', None)
    ]

# when doing field compares, field move, and lookup of field data type
# we do NOT want to be looking any of that up on this list of fields.
# ('GLOBALID', 'GLOBALID', None)
common_fields_ignore = ['SHAPE@', 'SHAPE@Length', 'SHAPE@Area', 'FCSubtype']


common_Ext_fields = []

RestrictionInfoTblFields = [
    ('CCN','CCN',None),
    ('CDR','CDR',None),
    ('SAX_RS1','SAX_RS1',None),
    ('SAX_RS2','SAX_RS2',None),
    ('SAX_RS4','SAX_RS4',None),
    ('SAX_RS5','SAX_RS5',None),
    ('SAX_RS6','SAX_RS6',None),
    ('SAX_RS8','SAX_RS8',None),
    ('SAX_RS9','SAX_RS9',None),
    ('SAX_RX1','SAX_RX1',None),
    ('SAX_RX2','SAX_RX2',None),
    ('SAX_RX5','SAX_RX5',None),
    ('SAX_RX6','SAX_RX6',None),
    ('SAX_RX7','SAX_RX7',None),
    ('SAX_RX9','SAX_RX9',None),
    ('SAX_RY0','SAX_RY0',None),
    ('SAX_RY1','SAX_RY1',None),
    ('SAX_RY2','SAX_RY2',None),
    ('UFI','UFI','transform_placeholder_return_None'),
    ('F_CODE','F_CODE','transform_placeholder_return_None'),
    ('SAX_RX8',None,'transform_set_to_default'),
    ('SAX_RS3',None,'transform_set_to_default')
]

# A dictionary of fields and values for default restriction information item
RestrictionInfoTargetDefaultFieldValues = {
    'CCN':'No Information',
    'CDR':'No Information',
    'F_CODE':'ZI002',
    'SAX_RY2':'noInformation',
    'SAX_RS1':'No Information',
    'SAX_RS2':'No Information',
    'SAX_RX9':'No Information',
    'SAX_RS4':'noInformation',
    'SAX_RS5':'No Information',
    'SAX_RS6':'noInformation',
    'SAX_RS8':'No Information',
    'SAX_RS9':'No Information',
    'SAX_RY0':'No Information',
    'SAX_RX1':'noInformation',
    'SAX_RX2':'noInformation',
    'SAX_RY1':'noInformation',
    'SAX_RX5':'noInformation',
    'SAX_RX7':'noInformation',
    'SAX_RX6':'noInformation',
    'UFI':'A9593791-4AE9-4180-8E1E-9CB3D239DEE5'
}

EntityCollectionFields = [
    ('AHA','AHA', 'transform_set_EntityCollection_field_to_default'),
    ('AVA','AVA','transform_set_EntityCollection_field_to_default'),
    ('DQS','DQS','transform_set_EntityCollection_field_to_default'),
    ('EQS','EQS','transform_set_EntityCollection_field_to_default'),
    ('EVA','EVA','transform_set_EntityCollection_field_to_default'),
    ('F_CODE','F_CODE',None),
    ('HVA','HVA','transform_set_EntityCollection_field_to_default'),
    ('MDE','MDE',None),
    ('RCG','RCG',None),
    ('SCVN','SCVN','transform_set_schemaversion'),
    ('UFI','UFI',None),
    ('ZI001_SDP','ZI001_SDP',None),
    #('ZI001_SDV','ZI001_SDV',None),
    #('ZI001_SRT','ZI001_SRT','transformZI001_SRTfromcodelisttoenum'),
    ('ZI001_SPS','ZI001_SPS',None),
    ('ZI001_VSC','ZI001_VSC','transformZI001_VSCfromenumtocodelist'),
    ('ZI001_VSD','ZI001_VSD',None),
    ('ZI001_VSN','ZI001_VSN',None),
    ('ZI004_PRE','ZI004_PRE',None),
    ('OTH','OTH','transformMoveOTHOnlyIfMetaAttribute')
    ]

EntityCollectionTargetDefaultFieldValues = {
    'FCSubType':132721,
    'AHA':-999999,
    'AVA':-999999,
    'DQS':'No Information',
    'EQS':-999999,
    'EVA':-999999,
    'F_CODE':'ZI039',
    'HVA':-999999,
    'MDE':'noInformation',
    'OTH':'noInformation',
    'RCG':-999999,
    'SCVN':'No Information',
    'UFI':'noInformation',
    'ZI001_SDP':'No Information',
    'ZI001_SPS':-999999,
    'ZI001_VSC':-999999,
    'ZI001_VSD':'noInformation',
    'ZI001_VSN':'No Information',
    'ZI004_PRE':'No Information'
    }


#  group translations - EntityCollectionOnFeature
EntityCollectionFCSubsetFields = [ 
    ('ZI001_SDV','ZI001_SDV',None), 
    ('ZI001_SRT','ZI001_SRT',None)
]

#  group translations - RestrictionInfoSubset
RestrictionInfoFCSubsetFields = [ 
    ('ZSAX_RS0','ZSAX_RS0',None), 
    ('ZSAX_RX0','ZSAX_RX0',None), 
    ('ZSAX_RX3','ZSAX_RX3',None), 
    ('ZSAX_RX4','ZSAX_RX4',None)
]


#  group translations - EntityCollectionTDS
EntityCollectionTDS = [
    (None, 'AHA', 'transform_get_from_entity_collection_table'),
    (None,'ZI001_SDP','transform_get_from_entity_collection_table'), 
    (None,'ZI001_SPS','transform_get_from_entity_collection_table'), 
    (None,'ZI001_VSC','transform_get_from_entity_collection_table'), 
    (None,'ZI001_VSD','transform_get_from_entity_collection_table'), 
    (None,'ZI001_VSN','transform_get_from_entity_collection_table'),
    ('ZI004_RCG','ZI004_RCG',None),
    ('ZI031S_URI',None, None),
    ('ZI039S_UFI',None, None)
]



#  group translations - RestrictionInfoTDSGroup
RestrictionInfoTDSGroup = [ 
    (None,'CCN','transform_get_from_restriction_info_table'), 
    (None,'CDR','transform_get_from_restriction_info_table'), 
    (None,'SAX_RS1','transform_get_from_restriction_info_table'), 
    (None,'SAX_RS2','transform_get_from_restriction_info_table'), 
    (None,'SAX_RS3','transform_set_to_default'), 
    (None,'SAX_RS4','transform_get_from_restriction_info_table'), 
    (None,'SAX_RS5','transform_get_from_restriction_info_table'), 
    (None,'SAX_RS6','transform_get_from_restriction_info_table'), 
    (None,'SAX_RS8','transform_get_from_restriction_info_table'), 
    (None,'SAX_RS9','transform_get_from_restriction_info_table'), 
    (None,'SAX_RX1','transform_get_from_restriction_info_table'), 
    (None,'SAX_RX2','transform_get_from_restriction_info_table'), 
    (None,'SAX_RX5','transform_get_from_restriction_info_table'), 
    (None,'SAX_RX6','transform_get_from_restriction_info_table'), 
    (None,'SAX_RX7','transform_get_from_restriction_info_table'), 
    (None,'SAX_RX8','transform_set_to_default'), 
    (None,'SAX_RX9','transform_get_from_restriction_info_table'), 
    (None,'SAX_RY0','transform_get_from_restriction_info_table'), 
    (None,'SAX_RY1','transform_get_from_restriction_info_table'), 
    (None,'SAX_RY2','transform_get_from_restriction_info_table'),
    ('ZI002_UFI',None, None)
]


#  group translations - CommonTranslationGroup
common_metadata_translate_fields = copy.deepcopy(RestrictionInfoTDSGroup) + copy.deepcopy(EntityCollectionTDS) +  [ \
    ('ZI006_MEM','ZI006_MEM','transform_MEM'),
    ('OTH','OTH','transform_OTH')
]





# MetadataSrf field translations
MetadataSrfFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Srf_fields) + [ \
    ('AHA','AHA',None),
    ('AVA','AVA',None),
    ('DQS','DQS',None),
    ('EQS',None,None),
    ('EVA','EVA',None),
    ('F_CODE','F_CODE',None),
    ('HVA','HVA',None),
    ('RCG','RCG',None),
    ('SCVN',None,None),
    ('UFI','UFI',None),
    ('MDE', 'MDE', None),
    ('RTL', 'RTL', None),
    ('ZI001_SDP','ZI001_SDP',None),
    (None,'ZI001_SDV','transform_set_to_default'), # Removed from GGDM 3 on every feature
    (None,'ZI001_SRT','transform_set_to_default'), # Removed from GGDM 3 on every feature
    ('ZI001_SPS','ZI001_SPS',None),
    ('ZI001_VSD','ZI001_VSD',None),
    ('ZI001_VSN','ZI001_VSN',None),
    ('ZI004_PRE','ZI004_PRE',None),
    ('ZI001_VSC','ZI001_VSC','transformZI001_VSCenumvalue2ZI001_VSCcodelist'),
    ('VDT','VDT',None),
    ('OTH','OTH','transform_OTH')
     ]


# ResourceSrf field translations
ResourceSrfFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Srf_fields) + [ \
    ('AHA','AHA',None),
    ('AVA','AVA',None),
    ('CID','CID',None),
    ('DQS','DQS',None),
    ('ETZ','ETZ',None),
    ('EVA','EVA',None),
    ('F_CODE','F_CODE',None),
    ('FURL',None,None),
    ('HVA','HVA',None),
    ('MDE','MDE',None),
    ('RTL','RTL',None),
    ('SCVN',None,None),
    ('URI','URI',None),
    ('ZI002_UFI',None,None),
    ('ZI020_GE4','ZI020_GE4',None),
    ('ZI020_GE42','ZI020_GE42',None),
    ('ZI020_GE43','ZI020_GE43',None),
    ('ZI020_GE44','ZI020_GE44',None),
    ('CPS','CPS',None),
    ('EQS','EQC','transformEQSinteger2EQCcodelist'),
    ('ETS','ETS',None),
    ('HZD','HZD',None),
    ('RCG','RCG',None),
    ('VDT','VDT',None),
    ('MEM','MEM','transform_MEM'),
    ('OTH','OTH','transform_OTH')
     ] + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(RestrictionInfoTDSGroup)



#-----------------------------------------------------------------
# AeronauticCrv field translations
AeronauticCrvFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Crv_fields) + [ \
    ('ARA','ARA',None),
    ('AXS','AXS',None),
    ('BEN','BEN',None),
    ('CNCP',None,None),
    ('COS',None,None),
    ('DEV','DEV',None),
    ('F_CODE','F_CODE',None),
    ('FUFI',None,None),
    ('FURL',None,None),
    ('GDBV',None,None),
    ('LZN','LZN',None),
    ('PCF','PCF',None),
    ('SBB','SBB',None),
    ('TXP','TXP',None),
    ('UFI','UFI',None),
    ('WID','WID',None),
    ('ZI002_UFI',None,None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_GNT',None,None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZI019_ASP','ZI019_ASP',None),
    ('ZI019_ASP2','ZI019_ASP2',None),
    ('ZI019_ASP3','ZI019_ASP3',None),
    ('ZI019_ASU','ZI019_ASU',None),
    ('ZI019_ASU2','ZI019_ASU2',None),
    ('ZI019_ASU3','ZI019_ASU3',None),
    ('ZI019_ASX','ZI019_ASX',None),
    ('ZI019_SFS','ZI019_SFS',None),
    ('ZI020_GE4','ZI020_GE4',None),
    ('ZI026_CTUC','ZI026_CTUC',None),
    ('ZI026_CTUL','ZI026_CTUL',None),
    ('ZI026_CTUU','ZI026_CTUU',None),
    ('ZI031S_URI',None,None),
    ('ZVH','ZVH',None)
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# AeronauticPnt field translations
AeronauticPntFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Pnt_fields) + [ \
    ('ADR','ADR',None),
    ('AOO','AOO',None),
    ('APT','APT',None),
    ('APT2','APT2',None),
    ('APT3','APT3',None),
    ('ARA','ARA',None),
    ('ASY','ASY',None),
    ('ATB','ATB',None),
    ('AWP','AWP',None),
    ('AXS','AXS',None),
    ('BEN','BEN',None),
    ('CAA','CAA',None),
    ('CNCP',None,None),
    ('COS','COS',None),
    ('F_CODE','F_CODE',None),
    ('FFN','FFN',None),
    ('FFN2','FFN2',None),
    ('FFN3','FFN3',None),
    ('FPT','FPT',None),
    ('FUFI',None,None),
    ('FURL',None,None),
    ('GDBV',None,None),
    ('GUG','GUG',None),
    ('HAF','HAF',None),
    ('HGT','HGT',None),
    ('HST','HST',None),
    ('HST2','HST2',None),
    ('HST3','HST3',None),
    ('HTP','HTP',None),
    ('IKO','IKO',None),
    ('LASZ',None,None),
    ('LMC','LMC',None),
    ('LZN','LZN',None),
    ('MAG','MAG',None),
    ('MCC','MCC',None),
    ('MCC2','MCC2',None),
    ('MCC3','MCC3',None),
    ('MUB','MUB',None),
    ('NA8','NA8',None),
    ('NAO','NAO',None),
    ('PCF','PCF',None),
    ('PEC','PEC',None),
    ('PYM','PYM',None),
    ('SSR','SSR',None),
    ('SSR2','SSR2',None),
    ('SSR3','SSR3',None),
    ('TOS','TOS',None),
    ('UFI','UFI',None),
    ('VCM','VCM',None),
    ('VCM2','VCM2',None),
    ('VCM3','VCM3',None),
    ('VOI','VOI',None),
    ('WID','WID',None),
    ('ZI002_UFI',None,None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_GNT',None,None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZI019_ASP','ZI019_ASP',None),
    ('ZI019_ASP2','ZI019_ASP2',None),
    ('ZI019_ASP3','ZI019_ASP3',None),
    ('ZI019_ASU','ZI019_ASU',None),
    ('ZI019_ASU2','ZI019_ASU2',None),
    ('ZI019_ASU3','ZI019_ASU3',None),
    ('ZI019_ASX','ZI019_ASX',None),
    ('ZI019_SFS','ZI019_SFS',None),
    ('ZI020_GE4','ZI020_GE4',None),
    ('ZI026_CTUC','ZI026_CTUC',None),
    ('ZI026_CTUL','ZI026_CTUL',None),
    ('ZI026_CTUU','ZI026_CTUU',None),
    ('ZI031S_URI',None,None),
    ('ZI103_MVD',None,None),
    ('ZVA','ZVA',None),
    ('ZVH','ZVH',None),
    ('TRS','TRS','transform_TRS'),
    ('TRS2','TRS2','transform_TRS'),
    ('TRS3','TRS3','transform_TRS') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# AeronauticPntExt field translations
AeronauticPntExtFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Pnt_fields) + [ \
    ('ARA',None,None),
    ('ART',None,None),
    ('ASO',None,None),
    ('AWP',None,None),
    ('BEN',None,None),
    ('CAA',None,None),
    ('CHA',None,None),
    ('CMS',None,None),
    ('CNCP',None,None),
    ('COC',None,None),
    ('COL',None,None),
    ('COS',None,None),
    ('DIA',None,None),
    ('DIR',None,None),
    ('F_CODE',None,None),
    ('FUFI',None,None),
    ('FURL',None,None),
    ('GA032_NSX',None,None),
    ('GB001_AID',None,None),
    ('GDBV',None,None),
    ('HGT',None,None),
    ('LCN',None,None),
    ('LOC',None,None),
    ('LZN',None,None),
    ('MCA',None,None),
    ('MCC',None,None),
    ('MCC2',None,None),
    ('MCC3',None,None),
    ('PCF',None,None),
    ('PER',None,None),
    ('PRM',None,None),
    ('PWR',None,None),
    ('RAC',None,None),
    ('RSI',None,None),
    ('SPT',None,None),
    ('SRL',None,None),
    ('UFI',None,None),
    ('VIS',None,None),
    ('VIS2',None,None),
    ('VIS3',None,None),
    ('VOI',None,None),
    ('WID',None,None),
    ('ZI002_UFI',None,None),
    ('ZI005_FNA',None,None),
    ('ZI005_GNT',None,None),
    ('ZI005_NFN',None,None),
    ('ZI020_GE4',None,None),
    ('ZI026_CTUC',None,None),
    ('ZI026_CTUL',None,None),
    ('ZI026_CTUU',None,None),
    ('ZI031S_URI',None,None),
    ('ZVH',None,None)
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# AeronauticSrf field translations
AeronauticSrfFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Srf_fields) + [ \
    ('ADR','ADR',None),
    ('AOO','AOO',None),
    ('APT','APT',None),
    ('APT2','APT2',None),
    ('APT3','APT3',None),
    ('APU','APU',None),
    ('APU2','APU2',None),
    ('APU3','APU3',None),
    ('APY','APY',None),
    ('ARA','ARA',None),
    ('ASU','ASU',None),
    ('ASU2','ASU2',None),
    ('ASU3','ASU3',None),
    ('ASY','ASY',None),
    ('ATB','ATB',None),
    ('AWP','AWP',None),
    ('AXS','AXS',None),
    ('BEN','BEN',None),
    ('CAA','CAA',None),
    ('CNCP',None,None),
    ('COS','COS',None),
    ('DEV','DEV',None),
    ('F_CODE','F_CODE',None),
    ('FFN','FFN',None),
    ('FFN2','FFN2',None),
    ('FFN3','FFN3',None),
    ('FPT','FPT',None),
    ('FUFI',None,None),
    ('FURL',None,None),
    ('GB052_RIDH','GB052_RIDH',None),
    ('GB052_RIDL','GB052_RIDL',None),
    ('GB052_TRHH',None,None),
    ('GB052_TRHL',None,None),
    ('GDBV',None,None),
    ('GSGCHC','GSGCHC',None),
    ('GSGCHL','GSGCHL',None),
    ('GSGCHU','GSGCHU',None),
    ('GSGCLC','GSGCLC',None),
    ('GSGCLL','GSGCLL',None),
    ('GSGCLU','GSGCLU',None),
    ('HAF','HAF',None),
    ('HGT','HGT',None),
    ('HST','HST',None),
    ('HST2','HST2',None),
    ('HST3','HST3',None),
    ('HTP','HTP',None),
    ('IKO','IKO',None),
    ('LASZ',None,None),
    ('LMC','LMC',None),
    ('LZN','LZN',None),
    ('MAG','MAG',None),
    ('MCC','MCC',None),
    ('MCC2','MCC2',None),
    ('MCC3','MCC3',None),
    ('MUB','MUB',None),
    ('NA8','NA8',None),
    ('NAO','NAO',None),
    ('PCF','PCF',None),
    ('PEC','PEC',None),
    ('SBB','SBB',None),
    ('SERP',None,None),
    ('SSR','SSR',None),
    ('SSR2','SSR2',None),
    ('SSR3','SSR3',None),
    ('TXP','TXP',None),
    ('UFI','UFI',None),
    ('VCM','VCM',None),
    ('VCM2','VCM2',None),
    ('VCM3','VCM3',None),
    ('VOI','VOI',None),
    ('WID','WID',None),
    ('ZI002_UFI',None,None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_GNT',None,None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZI019_ASP','ZI019_ASP',None),
    ('ZI019_ASP2','ZI019_ASP2',None),
    ('ZI019_ASP3','ZI019_ASP3',None),
    ('ZI019_ASU','ZI019_ASU',None),
    ('ZI019_ASU2','ZI019_ASU2',None),
    ('ZI019_ASU3','ZI019_ASU3',None),
    ('ZI019_ASX','ZI019_ASX',None),
    ('ZI019_SFS','ZI019_SFS',None),
    ('ZI020_GE4','ZI020_GE4',None),
    ('ZI026_CTUC','ZI026_CTUC',None),
    ('ZI026_CTUL','ZI026_CTUL',None),
    ('ZI026_CTUU','ZI026_CTUU',None),
    ('ZI031S_URI',None,None),
    ('ZI103_MVD',None,None),
    ('ZVA','ZVA',None),
    ('ZVH','ZVH',None),
    ('TRS','TRS','transform_TRS'),
    ('TRS2','TRS2','transform_TRS'),
    ('TRS3','TRS3','transform_TRS') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# AeronauticSrfExt field translations
AeronauticSrfExtFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Srf_fields) + [ \
    ('BEN',None,None),
    ('F_CODE',None,None),
    ('FUFI',None,None),
    ('FURL',None,None),
    ('GDBV',None,None),
    ('UFI',None,None),
    ('ZI002_UFI',None,None),
    ('ZI020_GE4',None,None),
    ('ZI026_CTUC',None,None),
    ('ZI026_CTUL',None,None),
    ('ZI026_CTUU',None,None),
    ('ZI031S_URI',None,None)
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# AgriculturePnt field translations
AgriculturePntFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Pnt_fields) + [ \
    ('ADR','ADR',None),
    ('AOO','AOO',None),
    ('ARA','ARA',None),
    ('ATB','ATB',None),
    ('AWP','AWP',None),
    ('BEN','BEN',None),
    ('BNF',None,None),
    ('CAA','CAA',None),
    ('CNCP',None,None),
    ('COS',None,None),
    ('DMBC','DMBC',None),
    ('DMBL','DMBL',None),
    ('DMBU','DMBU',None),
    ('DMT','DMT',None),
    ('F_CODE','F_CODE',None),
    ('FFN','FFN',None),
    ('FFN2','FFN2',None),
    ('FFN3','FFN3',None),
    ('FUFI',None,None),
    ('FURL',None,None),
    ('GDBV',None,None),
    ('HGT','HGT',None),
    ('LMC','LMC',None),
    ('LUN',None,None),
    ('LZN','LZN',None),
    ('PCF','PCF',None),
    ('PPO','PPO',None),
    ('PPO2','PPO2',None),
    ('PPO3','PPO3',None),
    ('PVH',None,None),
    ('SDSC','SDSC',None),
    ('SSR','SSR',None),
    ('SSR2','SSR2',None),
    ('SSR3','SSR3',None),
    ('TOS','TOS',None),
    ('TRE','TRE',None),
    ('TSCC','TSCC',None),
    ('TSCL','TSCL',None),
    ('TSCU','TSCU',None),
    ('UFI','UFI',None),
    ('VCM','VCM',None),
    ('VCM2','VCM2',None),
    ('VCM3','VCM3',None),
    ('VLM','VLM',None),
    ('VOI','VOI',None),
    ('VSP','VSP',None),
    ('VSP2','VSP2',None),
    ('VSP3','VSP3',None),
    ('VTI','VTI',None),
    ('WID','WID',None),
    ('ZI002_UFI',None,None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_GNT',None,None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZI013_CSP','ZI013_CSP',None),
    ('ZI013_CSP2','ZI013_CSP2',None),
    ('ZI013_CSP3','ZI013_CSP3',None),
    ('ZI013_FFP','ZI013_FFP',None),
    ('ZI013_FFP2','ZI013_FFP2',None),
    ('ZI013_FFP3','ZI013_FFP3',None),
    ('ZI013_FMM','ZI013_FMM',None),
    ('ZI013_FMM2','ZI013_FMM2',None),
    ('ZI013_FMM3','ZI013_FMM3',None),
    ('ZI013_PIG','ZI013_PIG',None),
    ('ZI014_PPO','ZI014_PPO',None),
    ('ZI014_PPO2','ZI014_PPO2',None),
    ('ZI014_PPO3','ZI014_PPO3',None),
    ('ZI020_GE4','ZI020_GE4',None),
    ('ZI024_ASE',None,None),
    ('ZI024_CFR',None,None),
    ('ZI024_CLO',None,None),
    ('ZI024_CYN',None,None),
    ('ZI024_FMR',None,None),
    ('ZI024_FRR',None,None),
    ('ZI024_HAR',None,None),
    ('ZI024_HYP',None,None),
    ('ZI024_MGN',None,None),
    ('ZI024_PHW',None,None),
    ('ZI024_SCC',None,None),
    ('ZI024_SUL',None,None),
    ('ZI024_TDS',None,None),
    ('ZI024_TEP',None,None),
    ('ZI024_TUR',None,None),
    ('ZI024_WAC',None,None),
    ('ZI024_WTNO',None,None),
    ('ZI024_WUR',None,None),
    ('ZI024_WUR2',None,None),
    ('ZI024_WUR3',None,None),
    ('ZI024_WUR4',None,None),
    ('ZI024_YWQ',None,None),
    ('ZI026_CTUC','ZI026_CTUC',None),
    ('ZI026_CTUL','ZI026_CTUL',None),
    ('ZI026_CTUU','ZI026_CTUU',None),
    ('ZI031S_URI',None,None),
    ('ZVH','ZVH',None),
    ('SDSL','SDSL','transform_decimetre_to_metre'),
    ('SDSU','SDSU','transform_decimetre_to_metre') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# AgriculturePntExt field translations
AgriculturePntExtFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Pnt_fields) + [ \
    ('ARA',None,None),
    ('BEN',None,None),
    ('DMBC',None,None),
    ('DMBL',None,None),
    ('DMBU',None,None),
    ('DMT',None,None),
    ('F_CODE',None,None),
    ('FUFI',None,None),
    ('FURL',None,None),
    ('GDBV',None,None),
    ('HGT',None,None),
    ('LMC',None,None),
    ('LZN',None,None),
    ('PVH',None,None),
    ('SDSC',None,None),
    ('SDSL',None,None),
    ('SDSU',None,None),
    ('TRE',None,None),
    ('TSCC',None,None),
    ('TSCL',None,None),
    ('TSCU',None,None),
    ('UFI',None,None),
    ('VTI',None,None),
    ('WID',None,None),
    ('ZI002_UFI',None,None),
    ('ZI005_FNA',None,None),
    ('ZI005_GNT',None,None),
    ('ZI005_NFN',None,None),
    ('ZI013_CSP',None,None),
    ('ZI013_CSP2',None,None),
    ('ZI013_CSP3',None,None),
    ('ZI013_FFP',None,None),
    ('ZI013_FFP2',None,None),
    ('ZI013_FFP3',None,None),
    ('ZI013_IRG',None,None),
    ('ZI020_GE4',None,None),
    ('ZI026_CTUC',None,None),
    ('ZI026_CTUL',None,None),
    ('ZI026_CTUU',None,None),
    ('ZI031S_URI',None,None),
    ('ZVH',None,None)
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# AgricultureSrf field translations
AgricultureSrfFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Srf_fields) + [ \
    ('ADR','ADR',None),
    ('AOO','AOO',None),
    ('ARA','ARA',None),
    ('ATB','ATB',None),
    ('AWP','AWP',None),
    ('BEN','BEN',None),
    ('BNF',None,None),
    ('CAA','CAA',None),
    ('CNCP',None,None),
    ('COS',None,None),
    ('DMBC','DMBC',None),
    ('DMBL','DMBL',None),
    ('DMBU','DMBU',None),
    ('DMT','DMT',None),
    ('DZP',None,None),
    ('F_CODE','F_CODE',None),
    ('FFN','FFN',None),
    ('FFN2','FFN2',None),
    ('FFN3','FFN3',None),
    ('FUFI',None,None),
    ('FURL',None,None),
    ('GDBV',None,None),
    ('HGT','HGT',None),
    ('LMC','LMC',None),
    ('LUN',None,None),
    ('LZN','LZN',None),
    ('PCF','PCF',None),
    ('PPO','PPO',None),
    ('PPO2','PPO2',None),
    ('PPO3','PPO3',None),
    ('PVH','PVH',None),
    ('SDSC','SDSC',None),
    ('SSR','SSR',None),
    ('SSR2','SSR2',None),
    ('SSR3','SSR3',None),
    ('TOS','TOS',None),
    ('TRE','TRE',None),
    ('TSCC','TSCC',None),
    ('TSCL','TSCL',None),
    ('TSCU','TSCU',None),
    ('UFI','UFI',None),
    ('VCM','VCM',None),
    ('VCM2','VCM2',None),
    ('VCM3','VCM3',None),
    ('VLM','VLM',None),
    ('VOI','VOI',None),
    ('VSP','VSP',None),
    ('VSP2','VSP2',None),
    ('VSP3','VSP3',None),
    ('VTI','VTI',None),
    ('WDAC',None,None),
    ('WDAL',None,None),
    ('WDAU',None,None),
    ('WID','WID',None),
    ('ZI002_UFI',None,None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_GNT',None,None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZI013_CSP','ZI013_CSP',None),
    ('ZI013_CSP2','ZI013_CSP2',None),
    ('ZI013_CSP3','ZI013_CSP3',None),
    ('ZI013_FFP','ZI013_FFP',None),
    ('ZI013_FFP2','ZI013_FFP2',None),
    ('ZI013_FFP3','ZI013_FFP3',None),
    ('ZI013_FMM','ZI013_FMM',None),
    ('ZI013_FMM2','ZI013_FMM2',None),
    ('ZI013_FMM3','ZI013_FMM3',None),
    ('ZI013_IRG','ZI013_IRG',None),
    ('ZI013_PIG','ZI013_PIG',None),
    ('ZI014_PPO','ZI014_PPO',None),
    ('ZI014_PPO2','ZI014_PPO2',None),
    ('ZI014_PPO3','ZI014_PPO3',None),
    ('ZI020_GE4','ZI020_GE4',None),
    ('ZI024_ASE',None,None),
    ('ZI024_CFR',None,None),
    ('ZI024_CLO',None,None),
    ('ZI024_CYN',None,None),
    ('ZI024_FMR',None,None),
    ('ZI024_FRR',None,None),
    ('ZI024_HAR',None,None),
    ('ZI024_HYP',None,None),
    ('ZI024_MGN',None,None),
    ('ZI024_PHW',None,None),
    ('ZI024_SCC',None,None),
    ('ZI024_SUL',None,None),
    ('ZI024_TDS',None,None),
    ('ZI024_TEP',None,None),
    ('ZI024_TUR',None,None),
    ('ZI024_WAC',None,None),
    ('ZI024_WTNO',None,None),
    ('ZI024_WUR',None,None),
    ('ZI024_WUR2',None,None),
    ('ZI024_WUR3',None,None),
    ('ZI024_WUR4',None,None),
    ('ZI024_YWQ',None,None),
    ('ZI026_CTUC','ZI026_CTUC',None),
    ('ZI026_CTUL','ZI026_CTUL',None),
    ('ZI026_CTUU','ZI026_CTUU',None),
    ('ZI031S_URI',None,None),
    ('ZVH','ZVH',None),
    ('SDSL','SDSL','transform_decimetre_to_metre'),
    ('SDSU','SDSU','transform_decimetre_to_metre') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# BoundaryCrvExt field translations
BoundaryCrvExtFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Crv_fields) + [ \
    ('BEN',None,None),
    ('BST',None,None),
    ('CAA',None,None),
    ('DSP',None,None),
    ('F_CODE',None,None),
    ('FA003_BAL',None,None),
    ('FUFI',None,None),
    ('FURL',None,None),
    ('GDBV',None,None),
    ('LSP',None,None),
    ('LZN',None,None),
    ('MGL',None,None),
    ('MGL2',None,None),
    ('MGL3',None,None),
    ('RPC',None,None),
    ('UFI',None,None),
    ('ZI002_UFI',None,None),
    ('ZI005_FNAA',None,None),
    ('ZI005_FNAB',None,None),
    ('ZI005_GNTA',None,None),
    ('ZI005_GNTB',None,None),
    ('ZI005_NFNA',None,None),
    ('ZI005_NFNB',None,None),
    ('ZI020_FI2A',None,None),
    ('ZI020_FI2B',None,None),
    ('ZI020_GE4',None,None),
    ('ZI020_GE4A',None,None),
    ('ZI020_GE4B',None,None),
    ('ZI026_CTUC',None,None),
    ('ZI026_CTUL',None,None),
    ('ZI026_CTUU',None,None),
    ('ZI031S_URI',None,None)
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# BoundaryPnt field translations
BoundaryPntFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Pnt_fields) + [ \
    ('BEN',None,None),
    ('CNCP',None,None),
    ('COS',None,None),
    ('F_CODE','F_CODE',None),
    ('FUFI',None,None),
    ('FURL',None,None),
    ('GDBV',None,None),
    ('LZN','LZN',None),
    ('MCC','MCC',None),
    ('MCC2','MCC2',None),
    ('MCC3','MCC3',None),
    ('PCF','PCF',None),
    ('UFI','UFI',None),
    ('WID','WID',None),
    ('ZI002_UFI',None,None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_GNT',None,None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZI020_GE4','ZI020_GE4',None),
    ('ZI026_CTUC','ZI026_CTUC',None),
    ('ZI026_CTUL','ZI026_CTUL',None),
    ('ZI026_CTUU','ZI026_CTUU',None),
    ('ZI031S_URI',None,None),
    ('ZVH',None,None)
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# BoundarySrf field translations
BoundarySrfFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Srf_fields) + [ \
    ('ARA','ARA',None),
    ('BEN',None,None),
    ('CAA','CAA',None),
    ('CDM','CDM',None),
    ('CDY','CDY',None),
    ('CSI','CSI',None),
    ('CSY','CSY',None),
    ('F_CODE','F_CODE',None),
    ('FUFI',None,None),
    ('FURL',None,None),
    ('GDBV',None,None),
    ('UFI','UFI',None),
    ('ZI002_UFI',None,None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_GNT',None,None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZI020_GE4','ZI020_GE4',None),
    ('ZI026_CTUC','ZI026_CTUC',None),
    ('ZI026_CTUL','ZI026_CTUL',None),
    ('ZI026_CTUU','ZI026_CTUU',None),
    ('ZI031S_URI',None,None)
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# BoundarySrfExt field translations
BoundarySrfExtFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Srf_fields) + [ \
    ('ARA',None,None),
    ('BEN',None,None),
    ('CAA',None,None),
    ('F_CODE',None,None),
    ('FUFI',None,None),
    ('FURL',None,None),
    ('GDBV',None,None),
    ('GEC',None,None),
    ('PPL',None,None),
    ('UFI',None,None),
    ('ZI002_UFI',None,None),
    ('ZI005_FNA',None,None),
    ('ZI005_GNT',None,None),
    ('ZI005_NFN',None,None),
    ('ZI020_GE4',None,None),
    ('ZI020_IC4',None,None),
    ('ZI026_CTUC',None,None),
    ('ZI026_CTUL',None,None),
    ('ZI026_CTUU',None,None),
    ('ZI031S_URI',None,None)
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

### ConstraintTbl field translations
##ConstraintTblFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Tbl_fields) + [ \
##    ('CCN',None,None),
##    ('CDR',None,None),
##    ('F_CODE',None,None),
##    ('UFI',None,None)
##     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# CultureCrv field translations
CultureCrvFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Crv_fields) + [ \
    ('AOO','AOO',None),
    ('ARA','ARA',None),
    ('AWP','AWP',None),
    ('BEN','BEN',None),
    ('CAA','CAA',None),
    ('CNCP',None,None),
    ('COS',None,None),
    ('F_CODE','F_CODE',None),
    ('FUFI',None,None),
    ('FURL',None,None),
    ('GDBV',None,None),
    ('HEI','HEI',None),
    ('HGT','HGT',None),
    ('LMC','LMC',None),
    ('LZN','LZN',None),
    ('PCF','PCF',None),
    ('SSC','SSC',None),
    ('SSR','SSR',None),
    ('SSR2','SSR2',None),
    ('SSR3','SSR3',None),
    ('TOS','TOS',None),
    ('UFI','UFI',None),
    ('VOI','VOI',None),
    ('WID','WID',None),
    ('ZI002_UFI',None,None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_GNT',None,None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZI020_GE4','ZI020_GE4',None),
    ('ZI026_CTUC','ZI026_CTUC',None),
    ('ZI026_CTUL','ZI026_CTUL',None),
    ('ZI026_CTUU','ZI026_CTUU',None),
    ('ZI031S_URI',None,None),
    ('ZVH','ZVH',None)
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# CulturePnt field translations
CulturePntFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Pnt_fields) + [ \
    ('ADR','ADR',None),
    ('AOO','AOO',None),
    ('ARA','ARA',None),
    ('AWP','AWP',None),
    ('BEN','BEN',None),
    ('CAA','CAA',None),
    ('CCG','CCG',None),
    ('CNCP',None,None),
    ('COS',None,None),
    ('CSO','CSO',None),
    ('DZP',None,None),
    ('F_CODE','F_CODE',None),
    ('FUFI',None,None),
    ('FURL',None,None),
    ('GDBV',None,None),
    ('HEI','HEI',None),
    ('HGT','HGT',None),
    ('HSS','HSS',None),
    ('LEA',None,None),
    ('LMC','LMC',None),
    ('LZN','LZN',None),
    ('PCF','PCF',None),
    ('SDQ','SDQ',None),
    ('SRL','SRL',None),
    ('SSC','SSC',None),
    ('SSR','SSR',None),
    ('SSR2','SSR2',None),
    ('SSR3','SSR3',None),
    ('TOS','TOS',None),
    ('TTY','TTY',None),
    ('UFI','UFI',None),
    ('VLM','VLM',None),
    ('VOI','VOI',None),
    ('WID','WID',None),
    ('ZI002_UFI',None,None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_GNT',None,None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZI020_GE4','ZI020_GE4',None),
    ('ZI024_ASE',None,None),
    ('ZI024_CFR',None,None),
    ('ZI024_CLO',None,None),
    ('ZI024_CYN',None,None),
    ('ZI024_FMR',None,None),
    ('ZI024_FRR',None,None),
    ('ZI024_HAR',None,None),
    ('ZI024_MGN',None,None),
    ('ZI024_PHW',None,None),
    ('ZI024_SCC',None,None),
    ('ZI024_SUL',None,None),
    ('ZI024_TDS',None,None),
    ('ZI024_TEP',None,None),
    ('ZI024_TUR',None,None),
    ('ZI024_WAC',None,None),
    ('ZI024_WTNO',None,None),
    ('ZI024_WUR',None,None),
    ('ZI024_WUR2',None,None),
    ('ZI024_WUR3',None,None),
    ('ZI024_WUR4',None,None),
    ('ZI024_YWQ','ZI024_YWQ',None),
    ('ZI025_HDP',None,None),
    ('ZI026_CTUC','ZI026_CTUC',None),
    ('ZI026_CTUL','ZI026_CTUL',None),
    ('ZI026_CTUU','ZI026_CTUU',None),
    ('ZI031S_URI',None,None),
    ('ZI037_REL','ZI037_REL',None),
    ('ZI037_RFA','ZI037_RFA',None),
    ('ZVH','ZVH',None)
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# CulturePntExt field translations
CulturePntExtFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Pnt_fields) + [ \
    ('ARA',None,None),
    ('BEN',None,None),
    ('CUL',None,None),
    ('F_CODE',None,None),
    ('FUFI',None,None),
    ('FURL',None,None),
    ('GDBV',None,None),
    ('LZN',None,None),
    ('UFI',None,None),
    ('WID',None,None),
    ('ZI002_UFI',None,None),
    ('ZI005_FNA',None,None),
    ('ZI005_GNT',None,None),
    ('ZI005_NFN',None,None),
    ('ZI020_GE4',None,None),
    ('ZI026_CTUC',None,None),
    ('ZI026_CTUL',None,None),
    ('ZI026_CTUU',None,None),
    ('ZI031S_URI',None,None),
    ('ZI037_REL',None,None)
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# CultureSrf field translations
CultureSrfFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Srf_fields) + [ \
    ('ADI','ADI',None),
    ('ADR','ADR',None),
    ('AOO','AOO',None),
    ('ARA','ARA',None),
    ('AWP','AWP',None),
    ('BEN','BEN',None),
    ('CAA','CAA',None),
    ('CAM','CAM',None),
    ('CCG','CCG',None),
    ('CNCP',None,None),
    ('COS',None,None),
    ('CSO','CSO',None),
    ('DZP',None,None),
    ('F_CODE','F_CODE',None),
    ('FFN','FFN',None),
    ('FFN2','FFN2',None),
    ('FFN3','FFN3',None),
    ('FUFI',None,None),
    ('FURL',None,None),
    ('GDBV',None,None),
    ('HEI','HEI',None),
    ('HGT','HGT',None),
    ('HSS','HSS',None),
    ('LEA',None,None),
    ('LMC','LMC',None),
    ('LZN','LZN',None),
    ('MCC','MCC',None),
    ('MCC2','MCC2',None),
    ('MCC3','MCC3',None),
    ('PCF','PCF',None),
    ('SDQ','SDQ',None),
    ('SRL','SRL',None),
    ('SSC','SSC',None),
    ('SSR','SSR',None),
    ('SSR2','SSR2',None),
    ('SSR3','SSR3',None),
    ('TOS','TOS',None),
    ('TRE',None,None),
    ('TTY','TTY',None),
    ('UFI','UFI',None),
    ('VLM','VLM',None),
    ('VOI','VOI',None),
    ('WID','WID',None),
    ('ZI002_UFI',None,None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_GNT',None,None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZI020_GE4','ZI020_GE4',None),
    ('ZI024_ASE',None,None),
    ('ZI024_CFR',None,None),
    ('ZI024_CLO',None,None),
    ('ZI024_CYN',None,None),
    ('ZI024_FMR',None,None),
    ('ZI024_FRR',None,None),
    ('ZI024_HAR',None,None),
    ('ZI024_MGN',None,None),
    ('ZI024_PHW',None,None),
    ('ZI024_SCC',None,None),
    ('ZI024_SUL',None,None),
    ('ZI024_TDS',None,None),
    ('ZI024_TEP',None,None),
    ('ZI024_TUR',None,None),
    ('ZI024_WAC',None,None),
    ('ZI024_WTNO',None,None),
    ('ZI024_WUR',None,None),
    ('ZI024_WUR2',None,None),
    ('ZI024_WUR3',None,None),
    ('ZI024_WUR4',None,None),
    ('ZI024_YWQ','ZI024_YWQ',None),
    ('ZI025_HDP',None,None),
    ('ZI026_CTUC','ZI026_CTUC',None),
    ('ZI026_CTUL','ZI026_CTUL',None),
    ('ZI026_CTUU','ZI026_CTUU',None),
    ('ZI031S_URI',None,None),
    ('ZI037_REL','ZI037_REL',None),
    ('ZI037_RFA','ZI037_RFA',None),
    ('ZVH','ZVH',None)
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# CultureSrfExt field translations
CultureSrfExtFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Srf_fields) + [ \
    ('ARA',None,None),
    ('BEN',None,None),
    ('CUL',None,None),
    ('F_CODE',None,None),
    ('FUFI',None,None),
    ('FURL',None,None),
    ('GDBV',None,None),
    ('LZN',None,None),
    ('UFI',None,None),
    ('WID',None,None),
    ('ZI002_UFI',None,None),
    ('ZI005_FNA',None,None),
    ('ZI005_GNT',None,None),
    ('ZI005_NFN',None,None),
    ('ZI020_GE4',None,None),
    ('ZI026_CTUC',None,None),
    ('ZI026_CTUL',None,None),
    ('ZI026_CTUU',None,None),
    ('ZI031S_URI',None,None),
    ('ZI037_REL',None,None)
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# FacilityPnt field translations
FacilityPntFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Pnt_fields) + [ \
    ('ADR','ADR',None),
    ('ADUR',None,None),
    ('AOO','AOO',None),
    ('ARA','ARA',None),
    ('BEN','BEN',None),
    ('CAA','CAA',None),
    ('CNCP',None,None),
    ('COS',None,None),
    ('F_CODE','F_CODE',None),
    ('FFN','FFN',None),
    ('FFN2','FFN2',None),
    ('FFN3','FFN3',None),
    ('FUFI',None,None),
    ('FURL',None,None),
    ('GDBV',None,None),
    ('HGT','HGT',None),
    ('LMC','LMC',None),
    ('LZN','LZN',None),
    ('PCF','PCF',None),
    ('PRM','PRM',None),
    ('RAS','RAS',None),
    ('UFI','UFI',None),
    ('VCM','VCM',None),
    ('VCM2','VCM2',None),
    ('VCM3','VCM3',None),
    ('WID','WID',None),
    ('WLSS',None,None),
    ('WSRC',None,None),
    ('YSU','YSU',None),
    ('ZI002_UFI',None,None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_FNA2',None,None),
    ('ZI005_FNA3',None,None),
    ('ZI005_GNT',None,None),
    ('ZI005_GNT2',None,None),
    ('ZI005_GNT3',None,None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZI005_NFN2',None,None),
    ('ZI005_NFN3',None,None),
    ('ZI014_PBY','ZI014_PBY',None),
    ('ZI014_PBY2','ZI014_PBY2',None),
    ('ZI014_PBY3','ZI014_PBY3',None),
    ('ZI014_PPO','ZI014_PPO',None),
    ('ZI014_PPO2','ZI014_PPO2',None),
    ('ZI014_PPO3','ZI014_PPO3',None),
    ('ZI014_PRW','ZI014_PRW',None),
    ('ZI014_PRW2','ZI014_PRW2',None),
    ('ZI014_PRW3','ZI014_PRW3',None),
    ('ZI018_WIT','ZI018_WIT',None),
    ('ZI020_GE4','ZI020_GE4',None),
    ('ZI026_CTUC','ZI026_CTUC',None),
    ('ZI026_CTUL','ZI026_CTUL',None),
    ('ZI026_CTUU','ZI026_CTUU',None),
    ('ZI031S_URI',None,None),
    ('ZI037_REL','ZI037_REL',None),
    ('ZI037_RFA','ZI037_RFA',None),
    ('ZVH','ZVH',None)
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# FacilitySrf field translations
FacilitySrfFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Srf_fields) + [ \
    ('ADR','ADR',None),
    ('ADUR',None,None),
    ('AOO','AOO',None),
    ('ARA','ARA',None),
    ('BEN','BEN',None),
    ('CAA','CAA',None),
    ('CNCP',None,None),
    ('COS',None,None),
    ('F_CODE','F_CODE',None),
    ('FFN','FFN',None),
    ('FFN2','FFN2',None),
    ('FFN3','FFN3',None),
    ('FUFI',None,None),
    ('FURL',None,None),
    ('GDBV',None,None),
    ('HGT','HGT',None),
    ('LMC','LMC',None),
    ('LZN','LZN',None),
    ('PCF','PCF',None),
    ('PRM','PRM',None),
    ('RAS','RAS',None),
    ('UFI','UFI',None),
    ('VCM','VCM',None),
    ('VCM2','VCM2',None),
    ('VCM3','VCM3',None),
    ('WID','WID',None),
    ('WLSS',None,None),
    ('WSRC',None,None),
    ('YSU','YSU',None),
    ('ZI002_UFI',None,None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_FNA2',None,None),
    ('ZI005_FNA3',None,None),
    ('ZI005_GNT',None,None),
    ('ZI005_GNT2',None,None),
    ('ZI005_GNT3',None,None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZI005_NFN2',None,None),
    ('ZI005_NFN3',None,None),
    ('ZI014_PBY','ZI014_PBY',None),
    ('ZI014_PBY2','ZI014_PBY2',None),
    ('ZI014_PBY3','ZI014_PBY3',None),
    ('ZI014_PPO','ZI014_PPO',None),
    ('ZI014_PPO2','ZI014_PPO2',None),
    ('ZI014_PPO3','ZI014_PPO3',None),
    ('ZI014_PRW','ZI014_PRW',None),
    ('ZI014_PRW2','ZI014_PRW2',None),
    ('ZI014_PRW3','ZI014_PRW3',None),
    ('ZI018_WIT','ZI018_WIT',None),
    ('ZI020_GE4','ZI020_GE4',None),
    ('ZI026_CTUC','ZI026_CTUC',None),
    ('ZI026_CTUL','ZI026_CTUL',None),
    ('ZI026_CTUU','ZI026_CTUU',None),
    ('ZI031S_URI',None,None),
    ('ZI037_REL','ZI037_REL',None),
    ('ZI037_RFA','ZI037_RFA',None),
    ('ZVH','ZVH',None)
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# HydroAidNavigationCrvExt field translations
HydroAidNavigationCrvExtFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Crv_fields) + [ \
    ('BEN',None,None),
    ('BRR',None,None),
    ('F_CODE',None,None),
    ('FUFI',None,None),
    ('FURL',None,None),
    ('GDBV',None,None),
    ('UFI',None,None),
    ('ZI002_UFI',None,None),
    ('ZI005_FNA',None,None),
    ('ZI005_GNT',None,None),
    ('ZI005_NFN',None,None),
    ('ZI020_GE4',None,None),
    ('ZI026_CTUC',None,None),
    ('ZI026_CTUL',None,None),
    ('ZI026_CTUU',None,None),
    ('ZI031S_URI',None,None)
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# HydroAidNavigationPnt field translations
HydroAidNavigationPntFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Pnt_fields) + [ \
    ('ADR','ADR',None),
    ('AOO','AOO',None),
    ('ARA','ARA',None),
    ('ATB','ATB',None),
    ('AWP','AWP',None),
    ('BC034_BRF',None,None),
    ('BC034_BRF2',None,None),
    ('BC034_MRT','BC034_MRT',None),
    ('BC034_MRT2',None,None),
    ('BC034_MRT3',None,None),
    ('BC040_COL',None,None),
    ('BC040_EOL','BC040_EOL',None),
    ('BC040_LCN','BC040_LCN',None),
    ('BC040_LVN','BC040_LVN',None),
    ('BC040_MLR',None,None),
    ('BC040_PER','BC040_PER',None),
    ('BC101_SST','BC101_SST',None),
    ('BEN','BEN',None),
    ('CAA','CAA',None),
    ('CNCP',None,None),
    ('COS','COS',None),
    ('F_CODE','F_CODE',None),
    ('FFN','FFN',None),
    ('FFN2','FFN2',None),
    ('FFN3','FFN3',None),
    ('FUFI',None,None),
    ('FURL',None,None),
    ('GDBV',None,None),
    ('HGT','HGT',None),
    ('LMC','LMC',None),
    ('LZN','LZN',None),
    ('MAN','MAN',None),
    ('PCF','PCF',None),
    ('REF',None,None),
    ('SSR','SSR',None),
    ('SSR2','SSR2',None),
    ('SSR3','SSR3',None),
    ('UFI','UFI',None),
    ('VCM','VCM',None),
    ('VCM2','VCM2',None),
    ('VCM3','VCM3',None),
    ('VOI','VOI',None),
    ('WID','WID',None),
    ('ZI002_UFI',None,None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_GNT',None,None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZI020_GE4','ZI020_GE4',None),
    ('ZI026_CTUC','ZI026_CTUC',None),
    ('ZI026_CTUL','ZI026_CTUL',None),
    ('ZI026_CTUU','ZI026_CTUU',None),
    ('ZI031S_URI',None,None),
    ('ZVH','ZVH',None)
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# HydroAidNavigationPntExt field translations
HydroAidNavigationPntExtFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Pnt_fields) + [ \
    ('ARA',None,None),
    ('BC010_REF',None,None),
    ('BC010_TZP',None,None),
    ('BC034_BRF',None,None),
    ('BC034_BRF2',None,None),
    ('BC034_MRT',None,None),
    ('BC034_MRT2',None,None),
    ('BC034_MRT3',None,None),
    ('BC040_CAA',None,None),
    ('BC040_COL',None,None),
    ('BC040_EOL',None,None),
    ('BC040_LVN',None,None),
    ('BC040_MLR',None,None),
    ('BC040_ZVH',None,None),
    ('BC101_SST',None,None),
    ('BEN',None,None),
    ('BET',None,None),
    ('BRF',None,None),
    ('BRF2',None,None),
    ('BUS',None,None),
    ('BUT',None,None),
    ('CAA',None,None),
    ('CCR',None,None),
    ('CNCP',None,None),
    ('COC',None,None),
    ('COL',None,None),
    ('COS',None,None),
    ('CPT',None,None),
    ('CSS',None,None),
    ('DKS',None,None),
    ('EOL',None,None),
    ('F_CODE',None,None),
    ('FLT',None,None),
    ('FUFI',None,None),
    ('FURL',None,None),
    ('GDBV',None,None),
    ('GUG',None,None),
    ('HBH',None,None),
    ('HGT',None,None),
    ('IAA',None,None),
    ('IAS',None,None),
    ('LFC',None,None),
    ('LFC2',None,None),
    ('LFC3',None,None),
    ('LMC',None,None),
    ('LOC',None,None),
    ('LSA',None,None),
    ('LSI',None,None),
    ('LST',None,None),
    ('LVN',None,None),
    ('LZN',None,None),
    ('MCC',None,None),
    ('MCC2',None,None),
    ('MCC3',None,None),
    ('MLR',None,None),
    ('MRP',None,None),
    ('MRT',None,None),
    ('NMC',None,None),
    ('NMC2',None,None),
    ('NMC3',None,None),
    ('NSC',None,None),
    ('ORC',None,None),
    ('PCF',None,None),
    ('PRM',None,None),
    ('REF',None,None),
    ('SPT',None,None),
    ('SRL',None,None),
    ('STA',None,None),
    ('STA2',None,None),
    ('STA3',None,None),
    ('TOS',None,None),
    ('TZP',None,None),
    ('UFI',None,None),
    ('VOI',None,None),
    ('WID',None,None),
    ('ZHBH_DCR',None,None),
    ('ZHBH_DKC',None,None),
    ('ZHBH_DKC2',None,None),
    ('ZHBH_DKC3',None,None),
    ('ZHBH_SVC',None,None),
    ('ZHBH_TEC',None,None),
    ('ZHBH_TEC2',None,None),
    ('ZHBH_TEC3',None,None),
    ('ZHBH_VDC',None,None),
    ('ZHBH_VDR',None,None),
    ('ZI002_UFI',None,None),
    ('ZI005_FNA',None,None),
    ('ZI005_GNT',None,None),
    ('ZI005_NFN',None,None),
    ('ZI018_BRF',None,None),
    ('ZI018_WIT',None,None),
    ('ZI020_GE4',None,None),
    ('ZI026_CTUC',None,None),
    ('ZI026_CTUL',None,None),
    ('ZI026_CTUU',None,None),
    ('ZI031S_URI',None,None),
    ('ZVH',None,None)
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# HydroAidNavigationSrf field translations
HydroAidNavigationSrfFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Srf_fields) + [ \
    ('ADR','ADR',None),
    ('AOO','AOO',None),
    ('ARA','ARA',None),
    ('ATB','ATB',None),
    ('AWP','AWP',None),
    ('BC040_LCN','BC040_LCN',None),
    ('BC040_PER','BC040_PER',None),
    ('BEN','BEN',None),
    ('CAA','CAA',None),
    ('CNCP',None,None),
    ('COS','COS',None),
    ('F_CODE','F_CODE',None),
    ('FFN','FFN',None),
    ('FFN2','FFN2',None),
    ('FFN3','FFN3',None),
    ('FUFI',None,None),
    ('FURL',None,None),
    ('GDBV',None,None),
    ('HGT','HGT',None),
    ('LMC','LMC',None),
    ('LZN','LZN',None),
    ('MAN','MAN',None),
    ('PCF','PCF',None),
    ('SSR','SSR',None),
    ('SSR2','SSR2',None),
    ('SSR3','SSR3',None),
    ('UFI','UFI',None),
    ('VCM','VCM',None),
    ('VCM2','VCM2',None),
    ('VCM3','VCM3',None),
    ('VOI','VOI',None),
    ('WID','WID',None),
    ('ZI002_UFI',None,None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_GNT',None,None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZI020_GE4','ZI020_GE4',None),
    ('ZI026_CTUC','ZI026_CTUC',None),
    ('ZI026_CTUL','ZI026_CTUL',None),
    ('ZI026_CTUU','ZI026_CTUU',None),
    ('ZI031S_URI',None,None),
    ('ZVH','ZVH',None)
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# HydrographyAONExt field translations
HydrographyAONExtFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Srf_fields) + [ \
    ('AQN',None,None),
    ('ARA',None,None),
    ('ATC',None,None),
    ('AZC',None,None),
    ('BBMCA',None,None),
    ('BBMCA2',None,None),
    ('BBMCA3',None,None),
    ('BBMCB',None,None),
    ('BBMCB2',None,None),
    ('BBMCB3',None,None),
    ('BEN',None,None),
    ('BH141_AWBA',None,None),
    ('BH141_AWBB',None,None),
    ('BH141_IBOA',None,None),
    ('BH141_IBOB',None,None),
    ('BH141_SHDA',None,None),
    ('BH141_SHDB',None,None),
    ('BH141_SLTA',None,None),
    ('BH141_SLTB',None,None),
    ('BH141_WBHA',None,None),
    ('BH141_WBHB',None,None),
    ('BMC',None,None),
    ('BMC2',None,None),
    ('BMC3',None,None),
    ('BPWHAC',None,None),
    ('BPWHAL',None,None),
    ('BPWHAU',None,None),
    ('BPWHBC',None,None),
    ('BPWHBL',None,None),
    ('BPWHBU',None,None),
    ('BPWSAC',None,None),
    ('BPWSAL',None,None),
    ('BPWSAU',None,None),
    ('BPWSBC',None,None),
    ('BPWSBL',None,None),
    ('BPWSBU',None,None),
    ('BWVCAC',None,None),
    ('BWVCAL',None,None),
    ('BWVCAU',None,None),
    ('BWVCBC',None,None),
    ('BWVCBL',None,None),
    ('BWVCBU',None,None),
    ('CAA',None,None),
    ('CDA',None,None),
    ('CDL',None,None),
    ('CNCP',None,None),
    ('COS',None,None),
    ('CWT',None,None),
    ('DEV',None,None),
    ('DIT',None,None),
    ('DMD',None,None),
    ('DMF',None,None),
    ('DOF',None,None),
    ('DOXY',None,None),
    ('DZP',None,None),
    ('F_CODE',None,None),
    ('FFN',None,None),
    ('FFN2',None,None),
    ('FFN3',None,None),
    ('FRZ',None,None),
    ('FUFI',None,None),
    ('FURL',None,None),
    ('GDBV',None,None),
    ('HGT',None,None),
    ('IWT',None,None),
    ('LMC',None,None),
    ('LOC',None,None),
    ('LUN',None,None),
    ('LZN',None,None),
    ('MNS',None,None),
    ('MWD',None,None),
    ('NVS',None,None),
    ('PCF',None,None),
    ('PMPR',None,None),
    ('PWA',None,None),
    ('PWAC',None,None),
    ('PWAL',None,None),
    ('PWAU',None,None),
    ('RLE',None,None),
    ('SBB',None,None),
    ('SWT',None,None),
    ('SWW',None,None),
    ('TID',None,None),
    ('TSSM',None,None),
    ('TSSM2',None,None),
    ('TSSM3',None,None),
    ('UFI',None,None),
    ('VCM',None,None),
    ('VCM2',None,None),
    ('VCM3',None,None),
    ('VLM',None,None),
    ('WAD',None,None),
    ('WCC',None,None),
    ('WD3',None,None),
    ('WDAC',None,None),
    ('WDAL',None,None),
    ('WDAU',None,None),
    ('WDH',None,None),
    ('WDL',None,None),
    ('WDST',None,None),
    ('WFT',None,None),
    ('WID',None,None),
    ('WMT',None,None),
    ('WVA',None,None),
    ('WVH',None,None),
    ('WVL',None,None),
    ('WWM',None,None),
    ('WWM2',None,None),
    ('WWM3',None,None),
    ('ZI002_UFI',None,None),
    ('ZI005_FNA',None,None),
    ('ZI005_FNA2',None,None),
    ('ZI005_FNA3',None,None),
    ('ZI005_GNT',None,None),
    ('ZI005_GNT2',None,None),
    ('ZI005_GNT3',None,None),
    ('ZI005_NFN',None,None),
    ('ZI005_NFN2',None,None),
    ('ZI005_NFN3',None,None),
    ('ZI020_GE4',None,None),
    ('ZI024_ASE',None,None),
    ('ZI024_AWO',None,None),
    ('ZI024_AWOI',None,None),
    ('ZI024_AWOX',None,None),
    ('ZI024_CFR',None,None),
    ('ZI024_CLO',None,None),
    ('ZI024_CYN',None,None),
    ('ZI024_DRL',None,None),
    ('ZI024_FMR',None,None),
    ('ZI024_FRR',None,None),
    ('ZI024_HAR',None,None),
    ('ZI024_HYP',None,None),
    ('ZI024_MGN',None,None),
    ('ZI024_PHW',None,None),
    ('ZI024_PMP',None,None),
    ('ZI024_RTP',None,None),
    ('ZI024_SCC',None,None),
    ('ZI024_SQN',None,None),
    ('ZI024_SUL',None,None),
    ('ZI024_TDS',None,None),
    ('ZI024_TEP',None,None),
    ('ZI024_TUR',None,None),
    ('ZI024_WAC',None,None),
    ('ZI024_WPAC',None,None),
    ('ZI024_WSG',None,None),
    ('ZI024_WTNO',None,None),
    ('ZI024_WUR',None,None),
    ('ZI024_WUR2',None,None),
    ('ZI024_WUR3',None,None),
    ('ZI024_WUR4',None,None),
    ('ZI024_YWQ',None,None),
    ('ZI025_HDP',None,None),
    ('ZI026_CTUC',None,None),
    ('ZI026_CTUL',None,None),
    ('ZI026_CTUU',None,None),
    ('ZI031S_URI',None,None),
    ('ZVH',None,None)
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# HydrographyCrv field translations
HydrographyCrvFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Crv_fields) + [ \
    ('AOO','AOO',None),
    ('ARA','ARA',None),
    ('ATC','ATC',None),
    ('AWP','AWP',None),
    ('BBMCA',None,None),
    ('BBMCA2',None,None),
    ('BBMCA3',None,None),
    ('BBMCB',None,None),
    ('BBMCB2',None,None),
    ('BBMCB3',None,None),
    ('BEN','BEN',None),
    ('BH141_AWBA','BH141_AWBA',None),
    ('BH141_AWBB','BH141_AWBB',None),
    ('BH141_IBOA','BH141_IBOA',None),
    ('BH141_IBOB','BH141_IBOB',None),
    ('BH141_SHDA','BH141_SHDA',None),
    ('BH141_SHDB','BH141_SHDB',None),
    ('BH141_SLTA','BH141_SLTA',None),
    ('BH141_SLTB','BH141_SLTB',None),
    ('BH141_WBHA','BH141_WBHA',None),
    ('BH141_WBHB','BH141_WBHB',None),
    ('BMC','BMC',None),
    ('BMC2','BMC2',None),
    ('BMC3','BMC3',None),
    ('BPWHAC','BPWHAC',None),
    ('BPWHAL','BPWHAL',None),
    ('BPWHAU','BPWHAU',None),
    ('BPWHBC','BPWHBC',None),
    ('BPWHBL','BPWHBL',None),
    ('BPWHBU','BPWHBU',None),
    ('BPWSAC','BPWSAC',None),
    ('BPWSAL','BPWSAL',None),
    ('BPWSAU','BPWSAU',None),
    ('BPWSBC','BPWSBC',None),
    ('BPWSBL','BPWSBL',None),
    ('BPWSBU','BPWSBU',None),
    ('BWVCAC','BWVCAC',None),
    ('BWVCAL','BWVCAL',None),
    ('BWVCAU','BWVCAU',None),
    ('BWVCBC','BWVCBC',None),
    ('BWVCBL','BWVCBL',None),
    ('BWVCBU','BWVCBU',None),
    ('CAA','CAA',None),
    ('CDA','CDA',None),
    ('CDL','CDL',None),
    ('CNCP',None,None),
    ('COS',None,None),
    ('CWT','CWT',None),
    ('DEV','DEV',None),
    ('DFT','DFT',None),
    ('DFU2',None,None),
    ('DFU3',None,None),
    ('DIM','DIM',None),
    ('DIT',None,None),
    ('DOXY',None,None),
    ('DSD',None,None),
    ('DZP',None,None),
    ('F_CODE','F_CODE',None),
    ('FCS','FCS',None),
    ('FRZ',None,None),
    ('FUFI',None,None),
    ('FURL',None,None),
    ('GDBV',None,None),
    ('HDP',None,None),
    ('HGS','HGS',None),
    ('HGT','HGT',None),
    ('LDC','LDC',None),
    ('LEA',None,None),
    ('LMC','LMC',None),
    ('LOC','LOC',None),
    ('LUN',None,None),
    ('LZN','LZN',None),
    ('MCC','MCC',None),
    ('MCC2','MCC2',None),
    ('MCC3','MCC3',None),
    ('MWD','MWD',None),
    ('NVS','NVS',None),
    ('PCF','PCF',None),
    ('PWA','PWA',None),
    ('PWAC',None,None),
    ('PWAL',None,None),
    ('PWAU',None,None),
    ('RLE','RLE',None),
    ('SBB','SBB',None),
    ('SPT','SPT',None),
    ('STNB',None,None),
    ('THI','THI',None),
    ('TID','TID',None),
    ('UFI','UFI',None),
    ('VLM','VLM',None),
    ('VOI','VOI',None),
    ('WCC','WCC',None),
    ('WD3','WD3',None),
    ('WDAC',None,None),
    ('WDAL',None,None),
    ('WDAU',None,None),
    ('WDH','WDH',None),
    ('WDL','WDL',None),
    ('WID','WID',None),
    ('WMT','WMT',None),
    ('WOC','WOC',None),
    ('WRT','WRT',None),
    ('WVA','WVA',None),
    ('WVH','WVH',None),
    ('WVL','WVL',None),
    ('ZI002_UFI',None,None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_FNA2',None,None),
    ('ZI005_FNA3',None,None),
    ('ZI005_GNT',None,None),
    ('ZI005_GNT2',None,None),
    ('ZI005_GNT3',None,None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZI005_NFN2',None,None),
    ('ZI005_NFN3',None,None),
    ('ZI020_GE4','ZI020_GE4',None),
    ('ZI024_ASE',None,None),
    ('ZI024_AWO',None,None),
    ('ZI024_AWOI',None,None),
    ('ZI024_AWOX',None,None),
    ('ZI024_CFR',None,None),
    ('ZI024_CLO',None,None),
    ('ZI024_CYN',None,None),
    ('ZI024_FMR',None,None),
    ('ZI024_FRR',None,None),
    ('ZI024_HAR',None,None),
    ('ZI024_HYP','ZI024_HYP',None),
    ('ZI024_MGN',None,None),
    ('ZI024_PHW',None,None),
    ('ZI024_SCC','ZI024_SCC',None),
    ('ZI024_SQN',None,None),
    ('ZI024_SUL',None,None),
    ('ZI024_TDS',None,None),
    ('ZI024_TEP',None,None),
    ('ZI024_TUR',None,None),
    ('ZI024_WAC',None,None),
    ('ZI024_WPAC',None,None),
    ('ZI024_WSG',None,None),
    ('ZI024_WTNO',None,None),
    ('ZI024_WUR',None,None),
    ('ZI024_WUR2',None,None),
    ('ZI024_WUR3',None,None),
    ('ZI024_WUR4',None,None),
    ('ZI024_YWQ','ZI024_YWQ',None),
    ('ZI025_HDP',None,None),
    ('ZI026_CTUC','ZI026_CTUC',None),
    ('ZI026_CTUL','ZI026_CTUL',None),
    ('ZI026_CTUU','ZI026_CTUU',None),
    ('ZI031S_URI',None,None),
    ('ZVH','ZVH',None),
    ('DFU','DWT','transformDFU_to_DWT'),
    ('TRS','TRS','transform_TRS'),
    ('TRS2','TRS2','transform_TRS'),
    ('TRS3','TRS3','transform_TRS') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# HydrographyCrvExt field translations
HydrographyCrvExtFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Crv_fields) + [ \
    ('ARA',None,None),
    ('BDS',None,None),
    ('BEN',None,None),
    ('BRG',None,None),
    ('BRR',None,None),
    ('BRS',None,None),
    ('CAA',None,None),
    ('CFT',None,None),
    ('CRV',None,None),
    ('DAN',None,None),
    ('DMC',None,None),
    ('DOF',None,None),
    ('DPG',None,None),
    ('DPG2',None,None),
    ('DPG3',None,None),
    ('DRP',None,None),
    ('DSP',None,None),
    ('F_CODE',None,None),
    ('FUFI',None,None),
    ('FURL',None,None),
    ('GDBV',None,None),
    ('HDP',None,None),
    ('HGT',None,None),
    ('IAS',None,None),
    ('LAF',None,None),
    ('LOR',None,None),
    ('LZN',None,None),
    ('MAN',None,None),
    ('MAS',None,None),
    ('MCC',None,None),
    ('MCC2',None,None),
    ('MCC3',None,None),
    ('MCY',None,None),
    ('MCY2',None,None),
    ('MCY3',None,None),
    ('MLO',None,None),
    ('MNR',None,None),
    ('MNR2',None,None),
    ('MNR3',None,None),
    ('MRR',None,None),
    ('MRR2',None,None),
    ('MRR3',None,None),
    ('NFP',None,None),
    ('NFP2',None,None),
    ('NFP3',None,None),
    ('NOA',None,None),
    ('NOA2',None,None),
    ('NOA3',None,None),
    ('PCF',None,None),
    ('RTT',None,None),
    ('TAN',None,None),
    ('TSP',None,None),
    ('UFI',None,None),
    ('WID',None,None),
    ('WTT',None,None),
    ('ZHDP_DCR',None,None),
    ('ZHDP_DKC',None,None),
    ('ZHDP_DKC2',None,None),
    ('ZHDP_DKC3',None,None),
    ('ZHDP_SVC',None,None),
    ('ZHDP_TEC',None,None),
    ('ZHDP_TEC2',None,None),
    ('ZHDP_TEC3',None,None),
    ('ZHDP_VDC',None,None),
    ('ZHDP_VDR',None,None),
    ('ZI002_UFI',None,None),
    ('ZI005_FNA',None,None),
    ('ZI005_GNT',None,None),
    ('ZI005_NFN',None,None),
    ('ZI012_DCR',None,None),
    ('ZI012_DKC',None,None),
    ('ZI012_DKC2',None,None),
    ('ZI012_DKC3',None,None),
    ('ZI012_SVC',None,None),
    ('ZI012_TEC',None,None),
    ('ZI012_TEC2',None,None),
    ('ZI012_TEC3',None,None),
    ('ZI012_VDC',None,None),
    ('ZI012_VDR',None,None),
    ('ZI020_GE4',None,None),
    ('ZI025_HDP',None,None),
    ('ZI025_WLE',None,None),
    ('ZI026_CTUC',None,None),
    ('ZI026_CTUL',None,None),
    ('ZI026_CTUU',None,None),
    ('ZI031S_URI',None,None)
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# HydrographyPnt field translations
HydrographyPntFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Pnt_fields) + [ \
    ('AOO','AOO',None),
    ('AQN','AQN',None),
    ('ARA','ARA',None),
    ('AWP','AWP',None),
    ('AZC','AZC',None),
    ('BC034_MRT','BC034_MRT',None),
    ('BC034_MRT2',None,None),
    ('BC034_MRT3',None,None),
    ('BC101_SST','BC101_SST',None),
    ('BEN','BEN',None),
    ('BH010_CAA',None,None),
    ('BH141_AWBA','BH141_AWBA',None),
    ('BH141_AWBB','BH141_AWBB',None),
    ('BH141_IBOA','BH141_IBOA',None),
    ('BH141_IBOB','BH141_IBOB',None),
    ('BH141_SHDA','BH141_SHDA',None),
    ('BH141_SHDB','BH141_SHDB',None),
    ('BH141_SLTA','BH141_SLTA',None),
    ('BH141_SLTB','BH141_SLTB',None),
    ('BH141_WBHA','BH141_WBHA',None),
    ('BH141_WBHB','BH141_WBHB',None),
    ('BPWHAC','BPWHAC',None),
    ('BPWHAL','BPWHAL',None),
    ('BPWHAU','BPWHAU',None),
    ('BPWHBC','BPWHBC',None),
    ('BPWHBL','BPWHBL',None),
    ('BPWHBU','BPWHBU',None),
    ('BPWSAC','BPWSAC',None),
    ('BPWSAL','BPWSAL',None),
    ('BPWSAU','BPWSAU',None),
    ('BPWSBC','BPWSBC',None),
    ('BPWSBL','BPWSBL',None),
    ('BPWSBU','BPWSBU',None),
    ('BWVCAC','BWVCAC',None),
    ('BWVCAL','BWVCAL',None),
    ('BWVCAU','BWVCAU',None),
    ('BWVCBC','BWVCBC',None),
    ('BWVCBL','BWVCBL',None),
    ('BWVCBU','BWVCBU',None),
    ('CAA','CAA',None),
    ('CDI',None,None),
    ('CNCP',None,None),
    ('COS',None,None),
    ('DFT','DFT',None),
    ('DFU2',None,None),
    ('DFU3',None,None),
    ('DMD','DMD',None),
    ('DOF','DOF',None),
    ('DOXY',None,None),
    ('DSD',None,None),
    ('DWL',None,None),
    ('DZP',None,None),
    ('F_CODE','F_CODE',None),
    ('FCS','FCS',None),
    ('FFN','FFN',None),
    ('FFN2','FFN2',None),
    ('FFN3','FFN3',None),
    ('FRZ',None,None),
    ('FUFI',None,None),
    ('FURL',None,None),
    ('GDBV',None,None),
    ('HDP',None,None),
    ('HGS','HGS',None),
    ('HGT','HGT',None),
    ('IWT','IWT',None),
    ('LDC','LDC',None),
    ('LEA','LEA',None),
    ('LMC','LMC',None),
    ('LUN',None,None),
    ('LZN','LZN',None),
    ('MCC','MCC',None),
    ('MCC2','MCC2',None),
    ('MCC3','MCC3',None),
    ('MNS','MNS',None),
    ('OCS','OCS',None),
    ('PCF','PCF',None),
    ('PMPR',None,None),
    ('PSE','PSE',None),
    ('PUD',None,None),
    ('PWAC','PWAC',None),
    ('PWAL','PWAL',None),
    ('PWAU','PWAU',None),
    ('SCOG',None,None),
    ('SWT','SWT',None),
    ('SWW','SWW',None),
    ('THI','THI',None),
    ('TID','TID',None),
    ('TSSM',None,None),
    ('TSSM2',None,None),
    ('TSSM3',None,None),
    ('TSTE',None,None),
    ('UFI','UFI',None),
    ('VCM','VCM',None),
    ('VCM2','VCM2',None),
    ('VCM3','VCM3',None),
    ('VLM','VLM',None),
    ('VOI','VOI',None),
    ('WAD','WAD',None),
    ('WCAC',None,None),
    ('WDAC','WDAC',None),
    ('WDAL','WDAL',None),
    ('WDAU','WDAU',None),
    ('WDH','WDH',None),
    ('WDL','WDL',None),
    ('WDST',None,None),
    ('WFT','WFT',None),
    ('WHCO',None,None),
    ('WID','WID',None),
    ('WOC','WOC',None),
    ('WODR',None,None),
    ('WST','WST',None),
    ('WTBB',None,None),
    ('WTCA',None,None),
    ('WTCL',None,None),
    ('WTFE',None,None),
    ('WTKK',None,None),
    ('WTMN',None,None),
    ('WTNA',None,None),
    ('WTNO',None,None),
    ('WTPO',None,None),
    ('WTSI',None,None),
    ('WTST',None,None),
    ('WVA','WVA',None),
    ('WVH','WVH',None),
    ('WVL','WVL',None),
    ('WWM',None,None),
    ('WWM2',None,None),
    ('WWM3',None,None),
    ('ZI002_UFI',None,None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_FNA2','ZI005_FNA2',None),
    ('ZI005_FNA3','ZI005_FNA3',None),
    ('ZI005_GNT',None,None),
    ('ZI005_GNT2',None,None),
    ('ZI005_GNT3',None,None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZI005_NFN2','ZI005_NFN2',None),
    ('ZI005_NFN3','ZI005_NFN3',None),
    ('ZI020_GE4','ZI020_GE4',None),
    ('ZI024_AWO',None,None),
    ('ZI024_AWOI',None,None),
    ('ZI024_AWOX',None,None),
    ('ZI024_CFR','ZI024_CFR',None),
    ('ZI024_DRL',None,None),
    ('ZI024_DVPT',None,None),
    ('ZI024_FMR',None,None),
    ('ZI024_FRR',None,None),
    ('ZI024_HYP','ZI024_HYP',None),
    ('ZI024_PHW','ZI024_PHW',None),
    ('ZI024_PMP',None,None),
    ('ZI024_RTP',None,None),
    ('ZI024_SCC','ZI024_SCC',None),
    ('ZI024_TEP','ZI024_TEP',None),
    ('ZI024_TUR','ZI024_TUR',None),
    ('ZI024_WAC','ZI024_WAC',None),
    ('ZI024_WPAC',None,None),
    ('ZI024_WTBB',None,None),
    ('ZI024_WTCA',None,None),
    ('ZI024_WTFE',None,None),
    ('ZI024_WTKK',None,None),
    ('ZI024_WTMN',None,None),
    ('ZI024_WTNA',None,None),
    ('ZI024_WTNO',None,None),
    ('ZI024_WTPO',None,None),
    ('ZI024_WTSI',None,None),
    ('ZI024_WUR',None,None),
    ('ZI024_WUR2',None,None),
    ('ZI024_WUR3',None,None),
    ('ZI024_WUR4',None,None),
    ('ZI024_YWQ','ZI024_YWQ',None),
    ('ZI025_HDP',None,None),
    ('ZI025_MAN','ZI025_MAN',None),
    ('ZI026_CTUC','ZI026_CTUC',None),
    ('ZI026_CTUL','ZI026_CTUL',None),
    ('ZI026_CTUU','ZI026_CTUU',None),
    ('ZI031S_URI',None,None),
    ('ZVH','ZVH',None),
    ('DFU','DWT','transformDFU_to_DWT'),
    ('TRS','TRS','transform_TRS'),
    ('TRS2','TRS2','transform_TRS'),
    ('TRS3','TRS3','transform_TRS'),
    ('ZI024_ASE','ZI024_ASE','transform_mgperlitre_to_gramspercm'),
    ('ZI024_CLO','ZI024_CLO','transform_mgperlitre_to_gramspercm'),
    ('ZI024_CYN','ZI024_CYN','transform_mgperlitre_to_gramspercm'),
    ('ZI024_HAR','ZI024_HAR','transform_mgperlitre_to_gramspercm'),
    ('ZI024_MGN','ZI024_MGN','transform_mgperlitre_to_gramspercm'),
    ('ZI024_SUL','ZI024_SUL','transform_mgperlitre_to_gramspercm'),
    ('ZI024_TDS','ZI024_TDS','transform_mgperlitre_to_gramspercm') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# HydrographyPntExt field translations
HydrographyPntExtFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Pnt_fields) + [ \
    ('ARA',None,None),
    ('BEN',None,None),
    ('C35',None,None),
    ('C36',None,None),
    ('C37',None,None),
    ('C38',None,None),
    ('C39',None,None),
    ('C40',None,None),
    ('C41',None,None),
    ('C42',None,None),
    ('C43',None,None),
    ('C44',None,None),
    ('C45',None,None),
    ('C46',None,None),
    ('CAA',None,None),
    ('CNCP',None,None),
    ('COS',None,None),
    ('CRN',None,None),
    ('CRS',None,None),
    ('CRX',None,None),
    ('CUR',None,None),
    ('D35',None,None),
    ('D36',None,None),
    ('D37',None,None),
    ('D38',None,None),
    ('D39',None,None),
    ('D40',None,None),
    ('D41',None,None),
    ('D42',None,None),
    ('D43',None,None),
    ('D44',None,None),
    ('D45',None,None),
    ('D46',None,None),
    ('DKC',None,None),
    ('DKC2',None,None),
    ('DKC3',None,None),
    ('DOF',None,None),
    ('DTN',None,None),
    ('DZP',None,None),
    ('F_CODE',None,None),
    ('FLO',None,None),
    ('FUFI',None,None),
    ('FURL',None,None),
    ('GDBV',None,None),
    ('HDH',None,None),
    ('HDP',None,None),
    ('HSE',None,None),
    ('IAS',None,None),
    ('LZN',None,None),
    ('MAN',None,None),
    ('MBC_MCC1',None,None),
    ('MBC_MCC2',None,None),
    ('MBC_PSC1',None,None),
    ('MBC_PSC2',None,None),
    ('MBC_SCO1',None,None),
    ('MBC_SCO2',None,None),
    ('MCC',None,None),
    ('MCC2',None,None),
    ('MCC3',None,None),
    ('PCF',None,None),
    ('REW',None,None),
    ('TAN',None,None),
    ('TSP',None,None),
    ('UFI',None,None),
    ('VEG',None,None),
    ('VSP',None,None),
    ('VSP2',None,None),
    ('VSP3',None,None),
    ('WID',None,None),
    ('WLO',None,None),
    ('WTT',None,None),
    ('ZHBH_TEC',None,None),
    ('ZHBH_TEC2',None,None),
    ('ZHBH_TEC3',None,None),
    ('ZHDP_DCR',None,None),
    ('ZHDP_DKC',None,None),
    ('ZHDP_DKC2',None,None),
    ('ZHDP_DKC3',None,None),
    ('ZHDP_SVC',None,None),
    ('ZHDP_TEC',None,None),
    ('ZHDP_TEC2',None,None),
    ('ZHDP_TEC3',None,None),
    ('ZHDP_VDC',None,None),
    ('ZHDP_VDR',None,None),
    ('ZI002_UFI',None,None),
    ('ZI005_FNA',None,None),
    ('ZI005_GNT',None,None),
    ('ZI005_NFN',None,None),
    ('ZI020_GE4',None,None),
    ('ZI025_HDP',None,None),
    ('ZI025_UHS',None,None),
    ('ZI025_WLE',None,None),
    ('ZI026_CTUC',None,None),
    ('ZI026_CTUL',None,None),
    ('ZI026_CTUU',None,None),
    ('ZI031S_URI',None,None)
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# HydrographySrf field translations
HydrographySrfFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Srf_fields) + [ \
    ('AOO','AOO',None),
    ('AQN','AQN',None),
    ('ARA','ARA',None),
    ('ATC','ATC',None),
    ('AWP','AWP',None),
    ('AZC','AZC',None),
    ('BBMCA',None,None),
    ('BBMCA2',None,None),
    ('BBMCA3',None,None),
    ('BBMCB',None,None),
    ('BBMCB2',None,None),
    ('BBMCB3',None,None),
    ('BC034_MRT','BC034_MRT',None),
    ('BC034_MRT2',None,None),
    ('BC034_MRT3',None,None),
    ('BC101_SST','BC101_SST',None),
    ('BEN','BEN',None),
    ('BH141_AWBA','BH141_AWBA',None),
    ('BH141_AWBB','BH141_AWBB',None),
    ('BH141_IBOA','BH141_IBOA',None),
    ('BH141_IBOB','BH141_IBOB',None),
    ('BH141_SHDA','BH141_SHDA',None),
    ('BH141_SHDB','BH141_SHDB',None),
    ('BH141_SLTA','BH141_SLTA',None),
    ('BH141_SLTB','BH141_SLTB',None),
    ('BH141_WBHA','BH141_WBHA',None),
    ('BH141_WBHB','BH141_WBHB',None),
    ('BMC','BMC',None),
    ('BMC2','BMC2',None),
    ('BMC3','BMC3',None),
    ('BPWHAC','BPWHAC',None),
    ('BPWHAL','BPWHAL',None),
    ('BPWHAU','BPWHAU',None),
    ('BPWHBC','BPWHBC',None),
    ('BPWHBL','BPWHBL',None),
    ('BPWHBU','BPWHBU',None),
    ('BPWSAC','BPWSAC',None),
    ('BPWSAL','BPWSAL',None),
    ('BPWSAU','BPWSAU',None),
    ('BPWSBC','BPWSBC',None),
    ('BPWSBL','BPWSBL',None),
    ('BPWSBU','BPWSBU',None),
    ('BWVCAC','BWVCAC',None),
    ('BWVCAL','BWVCAL',None),
    ('BWVCAU','BWVCAU',None),
    ('BWVCBC','BWVCBC',None),
    ('BWVCBL','BWVCBL',None),
    ('BWVCBU','BWVCBU',None),
    ('CAA','CAA',None),
    ('CDA','CDA',None),
    ('CDI',None,None),
    ('CDL','CDL',None),
    ('CNCP',None,None),
    ('COS',None,None),
    ('CWT','CWT',None),
    ('DEV','DEV',None),
    ('DFT','DFT',None),
    ('DFU2',None,None),
    ('DFU3',None,None),
    ('DIT',None,None),
    ('DMD','DMD',None),
    ('DOF','DOF',None),
    ('DOXY',None,None),
    ('DSD',None,None),
    ('DWL',None,None),
    ('DZP',None,None),
    ('F_CODE','F_CODE',None),
    ('FCS','FCS',None),
    ('FFN','FFN',None),
    ('FFN2','FFN2',None),
    ('FFN3','FFN3',None),
    ('FRZ',None,None),
    ('FUFI',None,None),
    ('FURL',None,None),
    ('GDBV',None,None),
    ('HDP',None,None),
    ('HGS','HGS',None),
    ('HGT','HGT',None),
    ('INU','INU',None),
    ('IWT','IWT',None),
    ('LDC','LDC',None),
    ('LEA','LEA',None),
    ('LMC','LMC',None),
    ('LOC','LOC',None),
    ('LUN',None,None),
    ('LZN','LZN',None),
    ('MCC','MCC',None),
    ('MCC2','MCC2',None),
    ('MCC3','MCC3',None),
    ('MNS','MNS',None),
    ('MWD','MWD',None),
    ('NVS','NVS',None),
    ('OCS','OCS',None),
    ('PCF','PCF',None),
    ('PSE','PSE',None),
    ('PUD',None,None),
    ('PWA','PWA',None),
    ('PWAC','PWAC',None),
    ('PWAL','PWAL',None),
    ('PWAU','PWAU',None),
    ('RLE','RLE',None),
    ('SBB','SBB',None),
    ('SCOG',None,None),
    ('STNB',None,None),
    ('SWT','SWT',None),
    ('SWW','SWW',None),
    ('TID','TID',None),
    ('TSSM',None,None),
    ('TSSM2',None,None),
    ('TSSM3',None,None),
    ('TSTE',None,None),
    ('UFI','UFI',None),
    ('VCM','VCM',None),
    ('VCM2','VCM2',None),
    ('VCM3','VCM3',None),
    ('VLM','VLM',None),
    ('VOI','VOI',None),
    ('WAD','WAD',None),
    ('WCAC',None,None),
    ('WCC','WCC',None),
    ('WD3','WD3',None),
    ('WDAC','WDAC',None),
    ('WDAL','WDAL',None),
    ('WDAU','WDAU',None),
    ('WDH','WDH',None),
    ('WDL','WDL',None),
    ('WDST',None,None),
    ('WFT','WFT',None),
    ('WHCO',None,None),
    ('WID','WID',None),
    ('WMT','WMT',None),
    ('WOC','WOC',None),
    ('WODR',None,None),
    ('WTBB',None,None),
    ('WTCA',None,None),
    ('WTCL',None,None),
    ('WTFE',None,None),
    ('WTKK',None,None),
    ('WTMN',None,None),
    ('WTNA',None,None),
    ('WTNO',None,None),
    ('WTPO',None,None),
    ('WTSI',None,None),
    ('WTST',None,None),
    ('WVA','WVA',None),
    ('WVH','WVH',None),
    ('WVL','WVL',None),
    ('WWM',None,None),
    ('WWM2',None,None),
    ('WWM3',None,None),
    ('ZI002_UFI',None,None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_FNA2','ZI005_FNA2',None),
    ('ZI005_FNA3','ZI005_FNA3',None),
    ('ZI005_GNT',None,None),
    ('ZI005_GNT2',None,None),
    ('ZI005_GNT3',None,None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZI005_NFN2','ZI005_NFN2',None),
    ('ZI005_NFN3','ZI005_NFN3',None),
    ('ZI020_GE4','ZI020_GE4',None),
    ('ZI024_AWO',None,None),
    ('ZI024_AWOI',None,None),
    ('ZI024_AWOX',None,None),
    ('ZI024_CFR','ZI024_CFR',None),
    ('ZI024_DRL',None,None),
    ('ZI024_DVPT',None,None),
    ('ZI024_FMR',None,None),
    ('ZI024_FRR',None,None),
    ('ZI024_HYP','ZI024_HYP',None),
    ('ZI024_PHW','ZI024_PHW',None),
    ('ZI024_PMP',None,None),
    ('ZI024_RTP',None,None),
    ('ZI024_SCC','ZI024_SCC',None),
    ('ZI024_SQN',None,None),
    ('ZI024_TEP','ZI024_TEP',None),
    ('ZI024_TUR','ZI024_TUR',None),
    ('ZI024_WAC','ZI024_WAC',None),
    ('ZI024_WPAC',None,None),
    ('ZI024_WSG',None,None),
    ('ZI024_WTBB',None,None),
    ('ZI024_WTCA',None,None),
    ('ZI024_WTFE',None,None),
    ('ZI024_WTKK',None,None),
    ('ZI024_WTMN',None,None),
    ('ZI024_WTNA',None,None),
    ('ZI024_WTNO',None,None),
    ('ZI024_WTPO',None,None),
    ('ZI024_WTSI',None,None),
    ('ZI024_WUR',None,None),
    ('ZI024_WUR2',None,None),
    ('ZI024_WUR3',None,None),
    ('ZI024_WUR4',None,None),
    ('ZI024_YWQ','ZI024_YWQ',None),
    ('ZI025_HDP',None,None),
    ('ZI025_MAN','ZI025_MAN',None),
    ('ZI026_CTUC','ZI026_CTUC',None),
    ('ZI026_CTUL','ZI026_CTUL',None),
    ('ZI026_CTUU','ZI026_CTUU',None),
    ('ZI031S_URI',None,None),
    ('ZVH','ZVH',None),
    ('DFU','DWT','transformDFU_to_DWT'),
    ('TRS','TRS','transform_TRS'),
    ('TRS2','TRS2','transform_TRS'),
    ('TRS3','TRS3','transform_TRS'),
    ('ZI024_ASE','ZI024_ASE','transform_mgperlitre_to_gramspercm'),
    ('ZI024_CLO','ZI024_CLO','transform_mgperlitre_to_gramspercm'),
    ('ZI024_CYN','ZI024_CYN','transform_mgperlitre_to_gramspercm'),
    ('ZI024_HAR','ZI024_HAR','transform_mgperlitre_to_gramspercm'),
    ('ZI024_MGN','ZI024_MGN','transform_mgperlitre_to_gramspercm'),
    ('ZI024_SUL','ZI024_SUL','transform_mgperlitre_to_gramspercm'),
    ('ZI024_TDS','ZI024_TDS','transform_mgperlitre_to_gramspercm') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# HydrographySrfExt field translations
HydrographySrfExtFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Srf_fields) + [ \
    ('AQF',None,None),
    ('ARA',None,None),
    ('BDS',None,None),
    ('BEN',None,None),
    ('BMC',None,None),
    ('BMC2',None,None),
    ('BMC3',None,None),
    ('BRR',None,None),
    ('BRS',None,None),
    ('CAA',None,None),
    ('CAB',None,None),
    ('CNCP',None,None),
    ('COA',None,None),
    ('COC',None,None),
    ('COG',None,None),
    ('COS',None,None),
    ('DAN',None,None),
    ('DKC',None,None),
    ('DKC2',None,None),
    ('DKC3',None,None),
    ('DOF',None,None),
    ('DOXY',None,None),
    ('DRP',None,None),
    ('DTN',None,None),
    ('F_CODE',None,None),
    ('FLO',None,None),
    ('FUFI',None,None),
    ('FURL',None,None),
    ('GDBV',None,None),
    ('HDP',None,None),
    ('IAS',None,None),
    ('LMC',None,None),
    ('LZN',None,None),
    ('MAN',None,None),
    ('MAS',None,None),
    ('MBC_MCC1',None,None),
    ('MBC_MCC2',None,None),
    ('MBC_PSC1',None,None),
    ('MBC_PSC2',None,None),
    ('MBC_SCO1',None,None),
    ('MBC_SCO2',None,None),
    ('MCC',None,None),
    ('MCC2',None,None),
    ('MCC3',None,None),
    ('MCY',None,None),
    ('MCY2',None,None),
    ('MCY3',None,None),
    ('MFE',None,None),
    ('MLO',None,None),
    ('MNR',None,None),
    ('MNR2',None,None),
    ('MNR3',None,None),
    ('MRR',None,None),
    ('MRR2',None,None),
    ('MRR3',None,None),
    ('OPT',None,None),
    ('ORS',None,None),
    ('ORS2',None,None),
    ('ORS3',None,None),
    ('PCF',None,None),
    ('PPO',None,None),
    ('PPO2',None,None),
    ('PPO3',None,None),
    ('PWAC',None,None),
    ('PWAL',None,None),
    ('PWAU',None,None),
    ('RTT',None,None),
    ('TAN',None,None),
    ('TSP',None,None),
    ('UFI',None,None),
    ('VEG',None,None),
    ('VSP',None,None),
    ('VSP2',None,None),
    ('VSP3',None,None),
    ('WDAC',None,None),
    ('WDAL',None,None),
    ('WDAU',None,None),
    ('WDH',None,None),
    ('WDL',None,None),
    ('WID',None,None),
    ('WLO',None,None),
    ('WPC',None,None),
    ('WPC2',None,None),
    ('WPC3',None,None),
    ('WTT',None,None),
    ('ZHBH_TEC',None,None),
    ('ZHBH_TEC2',None,None),
    ('ZHBH_TEC3',None,None),
    ('ZHDP_DCR',None,None),
    ('ZHDP_DKC',None,None),
    ('ZHDP_DKC2',None,None),
    ('ZHDP_DKC3',None,None),
    ('ZHDP_SVC',None,None),
    ('ZHDP_TEC',None,None),
    ('ZHDP_TEC2',None,None),
    ('ZHDP_TEC3',None,None),
    ('ZHDP_VDC',None,None),
    ('ZHDP_VDR',None,None),
    ('ZI002_UFI',None,None),
    ('ZI005_FNA',None,None),
    ('ZI005_FNA2',None,None),
    ('ZI005_FNA3',None,None),
    ('ZI005_GNT',None,None),
    ('ZI005_GNT2',None,None),
    ('ZI005_GNT3',None,None),
    ('ZI005_NFN',None,None),
    ('ZI005_NFN2',None,None),
    ('ZI005_NFN3',None,None),
    ('ZI020_GE4',None,None),
    ('ZI024_ASE',None,None),
    ('ZI024_CFR',None,None),
    ('ZI024_CLO',None,None),
    ('ZI024_CYN',None,None),
    ('ZI024_FMR',None,None),
    ('ZI024_FRR',None,None),
    ('ZI024_HAR',None,None),
    ('ZI024_HYP',None,None),
    ('ZI024_MGN',None,None),
    ('ZI024_PHW',None,None),
    ('ZI024_SCC',None,None),
    ('ZI024_SUL',None,None),
    ('ZI024_TDS',None,None),
    ('ZI024_TEP',None,None),
    ('ZI024_TUR',None,None),
    ('ZI024_WAC',None,None),
    ('ZI024_WTNO',None,None),
    ('ZI025_HDP',None,None),
    ('ZI025_WLE',None,None),
    ('ZI026_CTUC',None,None),
    ('ZI026_CTUL',None,None),
    ('ZI026_CTUU',None,None),
    ('ZI031S_URI',None,None)
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# HypsographyCrv field translations
HypsographyCrvFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Crv_fields) + [ \
    ('BEN',None,None),
    ('ESC','ESC',None),
    ('F_CODE','F_CODE',None),
    ('FUFI',None,None),
    ('FURL',None,None),
    ('GDBV',None,None),
    ('HQC','HQC',None),
    ('UFI','UFI',None),
    ('ZI002_UFI',None,None),
    ('ZI020_GE4','ZI020_GE4',None),
    ('ZI026_CTUC','ZI026_CTUC',None),
    ('ZI026_CTUL','ZI026_CTUL',None),
    ('ZI026_CTUU','ZI026_CTUU',None),
    ('ZI031S_URI',None,None),
    ('ZVH','ZVH',None)
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# HypsographyPnt field translations
HypsographyPntFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Pnt_fields) + [ \
    ('BEL','BEL',None),
    ('BEN',None,None),
    ('CAA',None,None),
    ('ESC','ESC',None),
    ('F_CODE','F_CODE',None),
    ('FUFI',None,None),
    ('FURL',None,None),
    ('GDBV',None,None),
    ('PCF','PCF',None),
    ('SUY','SUY',None),
    ('UFI','UFI',None),
    ('ZI002_UFI',None,None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_GNT',None,None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZI020_GE4','ZI020_GE4',None),
    ('ZI026_CTUC','ZI026_CTUC',None),
    ('ZI026_CTUL','ZI026_CTUL',None),
    ('ZI026_CTUU','ZI026_CTUU',None),
    ('ZI031S_URI',None,None),
    ('ZVH','ZVH',None),
    ('ZVH_AVA','ZVH_AVA',None),
    ('ZVH_VDT','ZVH_VDT',None) \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# HypsographyPntExt field translations
HypsographyPntExtFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Pnt_fields) + [ \
    ('BEN',None,None),
    ('CPA',None,None),
    ('F_CODE',None,None),
    ('FUFI',None,None),
    ('FURL',None,None),
    ('GDBV',None,None),
    ('PCF',None,None),
    ('UFI',None,None),
    ('ZI002_UFI',None,None),
    ('ZI005_FNA',None,None),
    ('ZI005_GNT',None,None),
    ('ZI005_NFN',None,None),
    ('ZI020_GE4',None,None),
    ('ZI026_CTUC',None,None),
    ('ZI026_CTUL',None,None),
    ('ZI026_CTUU',None,None),
    ('ZI031S_URI',None,None),
    ('ZVH',None,None)
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# IndustryCrv field translations
IndustryCrvFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Crv_fields) + [ \
    ('AOO','AOO',None),
    ('ARA','ARA',None),
    ('AWP','AWP',None),
    ('BEN','BEN',None),
    ('CAA','CAA',None),
    ('CNCP',None,None),
    ('COS',None,None),
    ('CVT','CVT',None),
    ('CVT2','CVT2',None),
    ('CVT3','CVT3',None),
    ('DZP',None,None),
    ('F_CODE','F_CODE',None),
    ('FUFI',None,None),
    ('FURL',None,None),
    ('GDBV',None,None),
    ('HGT','HGT',None),
    ('LMC','LMC',None),
    ('LZN','LZN',None),
    ('PCF','PCF',None),
    ('PFH','PFH',None),
    ('UFI','UFI',None),
    ('VCM','VCM',None),
    ('VCM2','VCM2',None),
    ('VCM3','VCM3',None),
    ('VOI','VOI',None),
    ('WID','WID',None),
    ('ZI002_UFI',None,None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_GNT',None,None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZI020_GE4','ZI020_GE4',None),
    ('ZI026_CTUC','ZI026_CTUC',None),
    ('ZI026_CTUL','ZI026_CTUL',None),
    ('ZI026_CTUU','ZI026_CTUU',None),
    ('ZI031S_URI',None,None),
    ('ZVH','ZVH',None)
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# IndustryPnt field translations
IndustryPntFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Pnt_fields) + [ \
    ('ADR','ADR',None),
    ('AOO','AOO',None),
    ('ARA','ARA',None),
    ('AWP','AWP',None),
    ('AZC','AZC',None),
    ('BEN','BEN',None),
    ('BNF',None,None),
    ('CAA','CAA',None),
    ('CNCP',None,None),
    ('COS',None,None),
    ('CRA','CRA',None),
    ('CRM','CRM',None),
    ('CVT','CVT',None),
    ('CVT2','CVT2',None),
    ('CVT3','CVT3',None),
    ('DZP','DZP',None),
    ('F_CODE','F_CODE',None),
    ('FFN','FFN',None),
    ('FFN2','FFN2',None),
    ('FFN3','FFN3',None),
    ('FUFI',None,None),
    ('FURL',None,None),
    ('GDBV',None,None),
    ('GUG','GUG',None),
    ('HGT','HGT',None),
    ('HST','HST',None),
    ('HST2','HST2',None),
    ('HST3','HST3',None),
    ('LCA','LCA',None),
    ('LEA','LEA',None),
    ('LMC','LMC',None),
    ('LOC','LOC',None),
    ('LZN','LZN',None),
    ('MZN','MZN',None),
    ('PBY','PBY',None),
    ('PBY2','PBY2',None),
    ('PBY3','PBY3',None),
    ('PCF','PCF',None),
    ('PPO','PPO',None),
    ('PPO2','PPO2',None),
    ('PPO3','PPO3',None),
    ('PRW','PRW',None),
    ('PRW2','PRW2',None),
    ('PRW3','PRW3',None),
    ('RIP','RIP',None),
    ('SRL','SRL',None),
    ('UFI','UFI',None),
    ('UMA','UMA',None),
    ('VCM','VCM',None),
    ('VCM2','VCM2',None),
    ('VCM3','VCM3',None),
    ('VOI','VOI',None),
    ('WEQ','WEQ',None),
    ('WEQ2','WEQ2',None),
    ('WEQ3','WEQ3',None),
    ('WID','WID',None),
    ('ZI002_UFI',None,None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_GNT',None,None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZI014_PPO','ZI014_PPO',None),
    ('ZI014_PPO2','ZI014_PPO2',None),
    ('ZI014_PPO3','ZI014_PPO3',None),
    ('ZI020_GE4','ZI020_GE4',None),
    ('ZI025_HDP',None,None),
    ('ZI026_CTUC','ZI026_CTUC',None),
    ('ZI026_CTUL','ZI026_CTUL',None),
    ('ZI026_CTUU','ZI026_CTUU',None),
    ('ZI031S_URI',None,None),
    ('ZVH','ZVH',None),
    ('TRS','TRS','transform_TRS'),
    ('TRS2','TRS2','transform_TRS'),
    ('TRS3','TRS3','transform_TRS') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# IndustryPntExt field translations
IndustryPntExtFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Pnt_fields) + [ \
    ('ARA',None,None),
    ('BEN',None,None),
    ('F_CODE',None,None),
    ('FUFI',None,None),
    ('FURL',None,None),
    ('GDBV',None,None),
    ('LZN',None,None),
    ('PPO',None,None),
    ('PPO2',None,None),
    ('PPO3',None,None),
    ('UFI',None,None),
    ('WID',None,None),
    ('ZI002_UFI',None,None),
    ('ZI005_FNA',None,None),
    ('ZI005_GNT',None,None),
    ('ZI005_NFN',None,None),
    ('ZI020_GE4',None,None),
    ('ZI026_CTUC',None,None),
    ('ZI026_CTUL',None,None),
    ('ZI026_CTUU',None,None),
    ('ZI031S_URI',None,None)
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# IndustrySrf field translations
IndustrySrfFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Srf_fields) + [ \
    ('ADR','ADR',None),
    ('AOO','AOO',None),
    ('ARA','ARA',None),
    ('AWP','AWP',None),
    ('AZC','AZC',None),
    ('BEN','BEN',None),
    ('BNF',None,None),
    ('CAA','CAA',None),
    ('CNCP',None,None),
    ('COS',None,None),
    ('CRA','CRA',None),
    ('CRM','CRM',None),
    ('DZP','DZP',None),
    ('F_CODE','F_CODE',None),
    ('FFN','FFN',None),
    ('FFN2','FFN2',None),
    ('FFN3','FFN3',None),
    ('FUFI',None,None),
    ('FURL',None,None),
    ('GDBV',None,None),
    ('HGT','HGT',None),
    ('HST','HST',None),
    ('HST2','HST2',None),
    ('HST3','HST3',None),
    ('LCA','LCA',None),
    ('LEA','LEA',None),
    ('LMC','LMC',None),
    ('LOC','LOC',None),
    ('LZN','LZN',None),
    ('MZN','MZN',None),
    ('PBY','PBY',None),
    ('PBY2','PBY2',None),
    ('PBY3','PBY3',None),
    ('PCF','PCF',None),
    ('PPO','PPO',None),
    ('PPO2','PPO2',None),
    ('PPO3','PPO3',None),
    ('PRW','PRW',None),
    ('PRW2','PRW2',None),
    ('PRW3','PRW3',None),
    ('SRL','SRL',None),
    ('UFI','UFI',None),
    ('UMA','UMA',None),
    ('VCM','VCM',None),
    ('VCM2','VCM2',None),
    ('VCM3','VCM3',None),
    ('VLM','VLM',None),
    ('VOI','VOI',None),
    ('WDAC',None,None),
    ('WDAL',None,None),
    ('WDAU',None,None),
    ('WID','WID',None),
    ('ZI002_UFI',None,None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_GNT',None,None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZI014_PPO','ZI014_PPO',None),
    ('ZI014_PPO2','ZI014_PPO2',None),
    ('ZI014_PPO3','ZI014_PPO3',None),
    ('ZI020_GE4','ZI020_GE4',None),
    ('ZI024_ASE',None,None),
    ('ZI024_CFR',None,None),
    ('ZI024_CLO',None,None),
    ('ZI024_CYN',None,None),
    ('ZI024_FMR',None,None),
    ('ZI024_FRR',None,None),
    ('ZI024_HAR',None,None),
    ('ZI024_MGN',None,None),
    ('ZI024_PHW',None,None),
    ('ZI024_SCC',None,None),
    ('ZI024_SUL',None,None),
    ('ZI024_TDS',None,None),
    ('ZI024_TEP',None,None),
    ('ZI024_TUR',None,None),
    ('ZI024_WAC',None,None),
    ('ZI024_WTNO',None,None),
    ('ZI026_CTUC','ZI026_CTUC',None),
    ('ZI026_CTUL','ZI026_CTUL',None),
    ('ZI026_CTUU','ZI026_CTUU',None),
    ('ZI031S_URI',None,None),
    ('ZVH','ZVH',None),
    ('TRS','TRS','transform_TRS'),
    ('TRS2','TRS2','transform_TRS'),
    ('TRS3','TRS3','transform_TRS') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# InformationCrv field translations
InformationCrvFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Crv_fields) + [ \
    ('BEN',None,None),
    ('F_CODE','F_CODE',None),
    ('FUFI',None,None),
    ('FURL',None,None),
    ('GDBV',None,None),
    ('UFI','UFI',None),
    ('ZI002_UFI',None,None),
    ('ZI005_FNA',None,None),
    ('ZI005_FNA2',None,None),
    ('ZI005_FNA3',None,None),
    ('ZI005_GNR',None,None),
    ('ZI005_GNR2',None,None),
    ('ZI005_GNR3',None,None),
    ('ZI005_GNT',None,None),
    ('ZI005_GNT2',None,None),
    ('ZI005_GNT3',None,None),
    ('ZI005_NFN',None,None),
    ('ZI005_NFN2',None,None),
    ('ZI005_NFN3',None,None),
    ('ZI015_GCUC',None,None),
    ('ZI015_GCUL',None,None),
    ('ZI015_GCUU',None,None),
    ('ZI020_GE4','ZI020_GE4',None),
    ('ZI026_CTUC','ZI026_CTUC',None),
    ('ZI026_CTUL','ZI026_CTUL',None),
    ('ZI026_CTUU','ZI026_CTUU',None),
    ('ZI031S_URI',None,None)
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# InformationCrvExt field translations
InformationCrvExtFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Crv_fields) + [ \
    ('BEN',None,None),
    ('F_CODE',None,None),
    ('FUFI',None,None),
    ('FURL',None,None),
    ('GDBV',None,None),
    ('NLT',None,None),
    ('UFI',None,None),
    ('ZI002_UFI',None,None),
    ('ZI005_FNA',None,None),
    ('ZI005_FNA2',None,None),
    ('ZI005_FNA3',None,None),
    ('ZI005_GNR',None,None),
    ('ZI005_GNR2',None,None),
    ('ZI005_GNR3',None,None),
    ('ZI005_GNT',None,None),
    ('ZI005_GNT2',None,None),
    ('ZI005_GNT3',None,None),
    ('ZI005_NFN',None,None),
    ('ZI005_NFN2',None,None),
    ('ZI005_NFN3',None,None),
    ('ZI015_GCUC',None,None),
    ('ZI015_GCUL',None,None),
    ('ZI015_GCUU',None,None),
    ('ZI020_GE4',None,None),
    ('ZI026_CTUC',None,None),
    ('ZI026_CTUL',None,None),
    ('ZI026_CTUU',None,None),
    ('ZI031S_URI',None,None)
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# InformationPnt field translations
InformationPntFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Pnt_fields) + [ \
    ('BEN',None,None),
    ('F_CODE','F_CODE',None),
    ('FUFI',None,None),
    ('FURL',None,None),
    ('GDBV',None,None),
    ('NLT','NLT',None),
    ('UFI','UFI',None),
    ('ZI002_UFI',None,None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_FNA2',None,None),
    ('ZI005_FNA3',None,None),
    ('ZI005_GNR',None,None),
    ('ZI005_GNR2',None,None),
    ('ZI005_GNR3',None,None),
    ('ZI005_GNT',None,None),
    ('ZI005_GNT2',None,None),
    ('ZI005_GNT3',None,None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZI005_NFN2',None,None),
    ('ZI005_NFN3',None,None),
    ('ZI015_GCUC',None,None),
    ('ZI015_GCUL',None,None),
    ('ZI015_GCUU',None,None),
    ('ZI020_GE4','ZI020_GE4',None),
    ('ZI026_CTUC','ZI026_CTUC',None),
    ('ZI026_CTUL','ZI026_CTUL',None),
    ('ZI026_CTUU','ZI026_CTUU',None),
    ('ZI031S_URI',None,None)
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# InformationSrf field translations
InformationSrfFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Srf_fields) + [ \
    ('ARA','ARA',None),
    ('BEN',None,None),
    ('F_CODE','F_CODE',None),
    ('FUFI',None,None),
    ('FURL',None,None),
    ('GDBV',None,None),
    ('LZN','LZN',None),
    ('UFI','UFI',None),
    ('VCA','VCA',None),
    ('VCA2','VCA2',None),
    ('VCA3','VCA3',None),
    ('VCT','VCT',None),
    ('VCT2','VCT2',None),
    ('VCT3','VCT3',None),
    ('WID','WID',None),
    ('ZI002_UFI',None,None),
    ('ZI005_FNA',None,None),
    ('ZI005_FNA2',None,None),
    ('ZI005_FNA3',None,None),
    ('ZI005_GNR',None,None),
    ('ZI005_GNR2',None,None),
    ('ZI005_GNR3',None,None),
    ('ZI005_GNT',None,None),
    ('ZI005_GNT2',None,None),
    ('ZI005_GNT3',None,None),
    ('ZI005_NFN',None,None),
    ('ZI005_NFN2',None,None),
    ('ZI005_NFN3',None,None),
    ('ZI015_GCUC',None,None),
    ('ZI015_GCUL',None,None),
    ('ZI015_GCUU',None,None),
    ('ZI020_GE4','ZI020_GE4',None),
    ('ZI026_CTUC','ZI026_CTUC',None),
    ('ZI026_CTUL','ZI026_CTUL',None),
    ('ZI026_CTUU','ZI026_CTUU',None),
    ('ZI031S_URI',None,None)
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# InformationSrfExt field translations
InformationSrfExtFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Srf_fields) + [ \
    ('BEN',None,None),
    ('F_CODE',None,None),
    ('FUFI',None,None),
    ('FURL',None,None),
    ('GDBV',None,None),
    ('NLT',None,None),
    ('UFI',None,None),
    ('VAVC',None,None),
    ('VAVL',None,None),
    ('VAVU',None,None),
    ('ZI002_UFI',None,None),
    ('ZI005_FNA',None,None),
    ('ZI005_FNA2',None,None),
    ('ZI005_FNA3',None,None),
    ('ZI005_GNR',None,None),
    ('ZI005_GNR2',None,None),
    ('ZI005_GNR3',None,None),
    ('ZI005_GNT',None,None),
    ('ZI005_GNT2',None,None),
    ('ZI005_GNT3',None,None),
    ('ZI005_NFN',None,None),
    ('ZI005_NFN2',None,None),
    ('ZI005_NFN3',None,None),
    ('ZI015_GCUC',None,None),
    ('ZI015_GCUL',None,None),
    ('ZI015_GCUU',None,None),
    ('ZI020_GE4',None,None),
    ('ZI026_CTUC',None,None),
    ('ZI026_CTUL',None,None),
    ('ZI026_CTUU',None,None),
    ('ZI031S_URI',None,None)
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

### MetadataSrf field translations
##MetadataSrfFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Srf_fields) + [ \
##    ('AHA',None,None),
##    ('AVA',None,None),
##    ('DQS',None,None),
##    ('EQS',None,None),
##    ('EVA',None,None),
##    ('F_CODE','F_CODE',None),
##    ('HVA',None,None),
##    ('MDE',None,None),
##    ('RCG',None,None),
##    ('SCVN',None,None),
##    ('UFI','UFI',None),
##    ('ZI001_SDP','ZI001_SDP',None),
##    ('ZI001_SPS','ZI001_SPS',None),
##    ('ZI001_VSD','ZI001_VSD',None),
##    ('ZI001_VSN','ZI001_VSN',None),
##    ('ZI004_PRE','ZI004_PRE',None),
##    ('ZI001_VSC','ZI001_VSC','transformZI001_VSCenumvalue2ZI001_VSCcodelist'),
##    ('OTH','OTH','transform_OTH')
##     ]

### MetadataTbl field translations
##MetadataTblFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Tbl_fields) + [ \
##    ('AHA',None,None),
##    ('AVA',None,None),
##    ('DQS',None,None),
##    ('EQS',None,None),
##    ('EVA',None,None),
##    ('F_CODE','F_CODE',None),
##    ('HVA',None,None),
##    ('MDE',None,None),
##    ('RCG',None,None),
##    ('SCVN',None,None),
##    ('UFI','UFI',None),
##    ('ZI001_SDP','ZI001_SDP',None),
##    ('ZI001_SPS','ZI001_SPS',None),
##    ('ZI001_VSD','ZI001_VSD',None),
##    ('ZI001_VSN','ZI001_VSN',None),
##    ('ZI004_PRE','ZI004_PRE',None),
##    ('ZI001_VSC','ZI001_VSC','transformZI001_VSCenumvalue2ZI001_VSCcodelist') \
##     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# MilitaryCrv field translations
MilitaryCrvFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Crv_fields) + [ \
    ('ARA','ARA',None),
    ('BEN','BEN',None),
    ('CNCP',None,None),
    ('COS',None,None),
    ('DZP',None,None),
    ('EET','EET',None),
    ('F_CODE','F_CODE',None),
    ('FUFI',None,None),
    ('FURL',None,None),
    ('GDBV',None,None),
    ('HGT','HGT',None),
    ('HST','HST',None),
    ('HST2','HST2',None),
    ('HST3','HST3',None),
    ('LMC','LMC',None),
    ('LNU','LNU',None),
    ('LZN','LZN',None),
    ('MCC','MCC',None),
    ('MCC2','MCC2',None),
    ('MCC3','MCC3',None),
    ('PCF','PCF',None),
    ('PFHC',None,None),
    ('PFHL',None,None),
    ('PFHU',None,None),
    ('UFI','UFI',None),
    ('VOI','VOI',None),
    ('WD3','WD3',None),
    ('WID','WID',None),
    ('YSU',None,None),
    ('ZI002_UFI',None,None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_GNT',None,None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZI020_GE4','ZI020_GE4',None),
    ('ZI026_CTUC','ZI026_CTUC',None),
    ('ZI026_CTUL','ZI026_CTUL',None),
    ('ZI026_CTUU','ZI026_CTUU',None),
    ('ZI031S_URI',None,None),
    ('ZVH','ZVH',None)
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# MilitaryCrvExt field translations
MilitaryCrvExtFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Crv_fields) + [ \
    ('BEN',None,None),
    ('CAA',None,None),
    ('DSP',None,None),
    ('F_CODE',None,None),
    ('FUFI',None,None),
    ('FURL',None,None),
    ('GDBV',None,None),
    ('LZN',None,None),
    ('MLUS',None,None),
    ('UFI',None,None),
    ('ZI002_UFI',None,None),
    ('ZI005_FNAA',None,None),
    ('ZI005_FNAB',None,None),
    ('ZI005_GNTA',None,None),
    ('ZI005_GNTB',None,None),
    ('ZI005_NFNA',None,None),
    ('ZI005_NFNB',None,None),
    ('ZI020_FI2A',None,None),
    ('ZI020_FI2B',None,None),
    ('ZI020_GE4',None,None),
    ('ZI020_GE4A',None,None),
    ('ZI020_GE4B',None,None),
    ('ZI026_CTUC',None,None),
    ('ZI026_CTUL',None,None),
    ('ZI026_CTUU',None,None),
    ('ZI031S_URI',None,None)
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# MilitaryPnt field translations
MilitaryPntFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Pnt_fields) + [ \
    ('ADR','ADR',None),
    ('AOO','AOO',None),
    ('ARA','ARA',None),
    ('ATB','ATB',None),
    ('AWP','AWP',None),
    ('BEN','BEN',None),
    ('BNF','BNF',None),
    ('CAA','CAA',None),
    ('CNCP',None,None),
    ('COS',None,None),
    ('DZP','DZP',None),
    ('F_CODE','F_CODE',None),
    ('FFN','FFN',None),
    ('FFN2','FFN2',None),
    ('FFN3','FFN3',None),
    ('FRT','FRT',None),
    ('FRT2','FRT2',None),
    ('FRT3','FRT3',None),
    ('FUFI',None,None),
    ('FURL',None,None),
    ('FZR','FZR',None),
    ('GDBV',None,None),
    ('HGT','HGT',None),
    ('HST','HST',None),
    ('HST2','HST2',None),
    ('HST3','HST3',None),
    ('LEA','LEA',None),
    ('LMC','LMC',None),
    ('LUN','LUN',None),
    ('LZN','LZN',None),
    ('MCC','MCC',None),
    ('MCC2','MCC2',None),
    ('MCC3','MCC3',None),
    ('MLOP',None,None),
    ('MLUS',None,None),
    ('MST','MST',None),
    ('MST2','MST2',None),
    ('MST3','MST3',None),
    ('MUB','MUB',None),
    ('PCF','PCF',None),
    ('PPO','PPO',None),
    ('PPO2','PPO2',None),
    ('PPO3','PPO3',None),
    ('PRM','PRM',None),
    ('RLE','RLE',None),
    ('SSR','SSR',None),
    ('SSR2','SSR2',None),
    ('SSR3','SSR3',None),
    ('UFI','UFI',None),
    ('VCM','VCM',None),
    ('VCM2','VCM2',None),
    ('VCM3','VCM3',None),
    ('VOI','VOI',None),
    ('WID','WID',None),
    ('WPST',None,None),
    ('WTYP',None,None),
    ('YSU','YSU',None),
    ('ZI002_UFI',None,None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_GNT',None,None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZI014_PBY','ZI014_PBY',None),
    ('ZI014_PBY2','ZI014_PBY2',None),
    ('ZI014_PBY3','ZI014_PBY3',None),
    ('ZI014_PPO','ZI014_PPO',None),
    ('ZI014_PPO2','ZI014_PPO2',None),
    ('ZI014_PPO3','ZI014_PPO3',None),
    ('ZI014_PRW','ZI014_PRW',None),
    ('ZI014_PRW2','ZI014_PRW2',None),
    ('ZI014_PRW3','ZI014_PRW3',None),
    ('ZI018_WIT','ZI018_WIT',None),
    ('ZI020_GE4','ZI020_GE4',None),
    ('ZI025_HDP',None,None),
    ('ZI026_CTUC','ZI026_CTUC',None),
    ('ZI026_CTUL','ZI026_CTUL',None),
    ('ZI026_CTUU','ZI026_CTUU',None),
    ('ZI031S_URI',None,None),
    ('ZVH','ZVH',None)
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# MilitaryPntExt field translations
MilitaryPntExtFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Pnt_fields) + [ \
    ('ARA',None,None),
    ('AZC',None,None),
    ('BEN',None,None),
    ('CAA',None,None),
    ('CNCP',None,None),
    ('COS',None,None),
    ('F_CODE',None,None),
    ('FUFI',None,None),
    ('FURL',None,None),
    ('GDBV',None,None),
    ('HGT',None,None),
    ('LMC',None,None),
    ('LZN',None,None),
    ('PCF',None,None),
    ('UFI',None,None),
    ('VCM',None,None),
    ('VCM2',None,None),
    ('VCM3',None,None),
    ('WID',None,None),
    ('YSU',None,None),
    ('ZI002_UFI',None,None),
    ('ZI005_FNA',None,None),
    ('ZI005_GNT',None,None),
    ('ZI005_NFN',None,None),
    ('ZI020_GE4',None,None),
    ('ZI026_CTUC',None,None),
    ('ZI026_CTUL',None,None),
    ('ZI026_CTUU',None,None),
    ('ZI031S_URI',None,None)
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# MilitarySrf field translations
MilitarySrfFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Srf_fields) + [ \
    ('ADR','ADR',None),
    ('AOO','AOO',None),
    ('ARA','ARA',None),
    ('ATB','ATB',None),
    ('AWP','AWP',None),
    ('BEN','BEN',None),
    ('BNF','BNF',None),
    ('CAA','CAA',None),
    ('CNCP',None,None),
    ('COS',None,None),
    ('DZP','DZP',None),
    ('EET','EET',None),
    ('F_CODE','F_CODE',None),
    ('FFN','FFN',None),
    ('FFN2','FFN2',None),
    ('FFN3','FFN3',None),
    ('FRT','FRT',None),
    ('FRT2','FRT2',None),
    ('FRT3','FRT3',None),
    ('FUFI',None,None),
    ('FURL',None,None),
    ('FZR','FZR',None),
    ('GDBV',None,None),
    ('HGT','HGT',None),
    ('HST','HST',None),
    ('HST2','HST2',None),
    ('HST3','HST3',None),
    ('LEA','LEA',None),
    ('LMC','LMC',None),
    ('LUN','LUN',None),
    ('LZN','LZN',None),
    ('MCC','MCC',None),
    ('MCC2','MCC2',None),
    ('MCC3','MCC3',None),
    ('MLOP',None,None),
    ('MLUS',None,None),
    ('MST','MST',None),
    ('MST2','MST2',None),
    ('MST3','MST3',None),
    ('MUB','MUB',None),
    ('PCF','PCF',None),
    ('PFHC',None,None),
    ('PFHL',None,None),
    ('PFHU',None,None),
    ('PPO','PPO',None),
    ('PPO2','PPO2',None),
    ('PPO3','PPO3',None),
    ('PRM','PRM',None),
    ('RLE','RLE',None),
    ('SSR','SSR',None),
    ('SSR2','SSR2',None),
    ('SSR3','SSR3',None),
    ('UFI','UFI',None),
    ('VCM','VCM',None),
    ('VCM2','VCM2',None),
    ('VCM3','VCM3',None),
    ('VOI','VOI',None),
    ('WD3','WD3',None),
    ('WID','WID',None),
    ('WPST',None,None),
    ('WTYP',None,None),
    ('YSU','YSU',None),
    ('ZI002_UFI',None,None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_GNT',None,None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZI014_PBY','ZI014_PBY',None),
    ('ZI014_PBY2','ZI014_PBY2',None),
    ('ZI014_PBY3','ZI014_PBY3',None),
    ('ZI014_PPO','ZI014_PPO',None),
    ('ZI014_PPO2','ZI014_PPO2',None),
    ('ZI014_PPO3','ZI014_PPO3',None),
    ('ZI014_PRW','ZI014_PRW',None),
    ('ZI014_PRW2','ZI014_PRW2',None),
    ('ZI014_PRW3','ZI014_PRW3',None),
    ('ZI018_WIT','ZI018_WIT',None),
    ('ZI020_GE4','ZI020_GE4',None),
    ('ZI025_HDP',None,None),
    ('ZI026_CTUC','ZI026_CTUC',None),
    ('ZI026_CTUL','ZI026_CTUL',None),
    ('ZI026_CTUU','ZI026_CTUU',None),
    ('ZI031S_URI',None,None),
    ('ZVH','ZVH',None)
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# MilitarySrfExt field translations
MilitarySrfExtFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Srf_fields) + [ \
    ('ARA',None,None),
    ('AZC',None,None),
    ('BEN',None,None),
    ('CAA',None,None),
    ('CNCP',None,None),
    ('COS',None,None),
    ('F_CODE',None,None),
    ('FUFI',None,None),
    ('FURL',None,None),
    ('GDBV',None,None),
    ('HGT',None,None),
    ('LMC',None,None),
    ('LZN',None,None),
    ('PCF',None,None),
    ('UFI',None,None),
    ('VCM',None,None),
    ('VCM2',None,None),
    ('VCM3',None,None),
    ('WID',None,None),
    ('YSU',None,None),
    ('ZI002_UFI',None,None),
    ('ZI005_FNA',None,None),
    ('ZI005_GNT',None,None),
    ('ZI005_NFN',None,None),
    ('ZI020_GE4',None,None),
    ('ZI026_CTUC',None,None),
    ('ZI026_CTUL',None,None),
    ('ZI026_CTUU',None,None),
    ('ZI031S_URI',None,None)
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# PhysiographyAONExt field translations
PhysiographyAONExtFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Srf_fields) + [ \
    ('ARA',None,None),
    ('BEN',None,None),
    ('DMF',None,None),
    ('F_CODE',None,None),
    ('FUFI',None,None),
    ('FURL',None,None),
    ('GDBV',None,None),
    ('LMC',None,None),
    ('LZN',None,None),
    ('UFI',None,None),
    ('WID',None,None),
    ('ZI002_UFI',None,None),
    ('ZI005_FNA',None,None),
    ('ZI005_GNT',None,None),
    ('ZI005_NFN',None,None),
    ('ZI020_GE4',None,None),
    ('ZI026_CTUC',None,None),
    ('ZI026_CTUL',None,None),
    ('ZI026_CTUU',None,None),
    ('ZI031S_URI',None,None)
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# PhysiographyCrv field translations
PhysiographyCrvFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Crv_fields) + [ \
    ('ARA','ARA',None),
    ('AZC','AZC',None),
    ('BA000_VDC','BA000_VDC',None),
    ('BA000_VDR','BA000_VDR',None),
    ('BEN',None,None),
    ('CAA','CAA',None),
    ('CET','CET',None),
    ('CNCP',None,None),
    ('COS',None,None),
    ('DZP',None,None),
    ('F_CODE','F_CODE',None),
    ('FDI',None,None),
    ('FIC','FIC',None),
    ('FUFI',None,None),
    ('FURL',None,None),
    ('GDBV',None,None),
    ('GFT','GFT',None),
    ('GFY',None,None),
    ('HDP',None,None),
    ('HGT','HGT',None),
    ('LMC','LMC',None),
    ('LZN','LZN',None),
    ('MCC','MCC',None),
    ('MCC2','MCC2',None),
    ('MCC3','MCC3',None),
    ('PCF','PCF',None),
    ('PFD','PFD',None),
    ('PFH','PFH',None),
    ('SDI',None,None),
    ('SGCC','SGCC',None),
    ('SGCL','SGCL',None),
    ('SGCU','SGCU',None),
    ('SHD','SHD',None),
    ('SHO',None,None),
    ('SLT','SLT',None),
    ('SNDC',None,None),
    ('SNDL',None,None),
    ('SNDU',None,None),
    ('UFI','UFI',None),
    ('WID','WID',None),
    ('WLE','WLE',None),
    ('ZI002_UFI',None,None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_GNT',None,None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZI020_GE4','ZI020_GE4',None),
    ('ZI026_CTUC','ZI026_CTUC',None),
    ('ZI026_CTUL','ZI026_CTUL',None),
    ('ZI026_CTUU','ZI026_CTUU',None),
    ('ZI031S_URI',None,None),
    ('ZVH','ZVH',None),
    ('TRS','TRS','transform_TRS'),
    ('TRS2','TRS2','transform_TRS'),
    ('TRS3','TRS3','transform_TRS') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# PhysiographyCrvExt field translations
PhysiographyCrvExtFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Crv_fields) + [ \
    ('AZC',None,None),
    ('BEN',None,None),
    ('F_CODE',None,None),
    ('FUFI',None,None),
    ('FURL',None,None),
    ('GDBV',None,None),
    ('SLT',None,None),
    ('SSE',None,None),
    ('UFI',None,None),
    ('ZI002_UFI',None,None),
    ('ZI005_FNA',None,None),
    ('ZI005_GNT',None,None),
    ('ZI005_NFN',None,None),
    ('ZI020_GE4',None,None),
    ('ZI026_CTUC',None,None),
    ('ZI026_CTUL',None,None),
    ('ZI026_CTUU',None,None),
    ('ZI031S_URI',None,None)
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# PhysiographyPnt field translations
PhysiographyPntFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Pnt_fields) + [ \
    ('AOO','AOO',None),
    ('AQN','AQN',None),
    ('ARA','ARA',None),
    ('BA000_VDC','BA000_VDC',None),
    ('BA000_VDR','BA000_VDR',None),
    ('BEN','BEN',None),
    ('CAA','CAA',None),
    ('DOF','DOF',None),
    ('F_CODE','F_CODE',None),
    ('FUFI',None,None),
    ('FURL',None,None),
    ('GDBV',None,None),
    ('GOT','GOT',None),
    ('HGT','HGT',None),
    ('LMC','LMC',None),
    ('LZN','LZN',None),
    ('MCC','MCC',None),
    ('MCC2','MCC2',None),
    ('MCC3','MCC3',None),
    ('OHC','OHC',None),
    ('PCF','PCF',None),
    ('PFH','PFH',None),
    ('RKF','RKF',None),
    ('SHD','SHD',None),
    ('SLT','SLT',None),
    ('SNDC',None,None),
    ('SNDL',None,None),
    ('SNDU',None,None),
    ('UFI','UFI',None),
    ('VGT','VGT',None),
    ('VOA','VOA',None),
    ('VTI','VTI',None),
    ('WID','WID',None),
    ('ZI002_UFI',None,None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_FNA2',None,None),
    ('ZI005_FNA3',None,None),
    ('ZI005_GNT',None,None),
    ('ZI005_GNT2',None,None),
    ('ZI005_GNT3',None,None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZI005_NFN2',None,None),
    ('ZI005_NFN3',None,None),
    ('ZI020_GE4','ZI020_GE4',None),
    ('ZI024_ASE',None,None),
    ('ZI024_AWO',None,None),
    ('ZI024_AWOI',None,None),
    ('ZI024_AWOX',None,None),
    ('ZI024_CFR',None,None),
    ('ZI024_CLO',None,None),
    ('ZI024_CYN',None,None),
    ('ZI024_FMR',None,None),
    ('ZI024_FRR',None,None),
    ('ZI024_HAR',None,None),
    ('ZI024_HYP',None,None),
    ('ZI024_MGN',None,None),
    ('ZI024_PHW',None,None),
    ('ZI024_SCC',None,None),
    ('ZI024_SUL',None,None),
    ('ZI024_TDS',None,None),
    ('ZI024_TEP',None,None),
    ('ZI024_TUR',None,None),
    ('ZI024_WAC',None,None),
    ('ZI024_WTNO',None,None),
    ('ZI024_WUR',None,None),
    ('ZI024_WUR2',None,None),
    ('ZI024_WUR3',None,None),
    ('ZI024_WUR4',None,None),
    ('ZI024_YWQ',None,None),
    ('ZI025_HDP',None,None),
    ('ZI026_CTUC','ZI026_CTUC',None),
    ('ZI026_CTUL','ZI026_CTUL',None),
    ('ZI026_CTUU','ZI026_CTUU',None),
    ('ZI031S_URI',None,None),
    ('ZI071_CTX','ZI071_CTX',None),
    ('ZI071_FFN','ZI071_FFN',None),
    ('ZI071_FFN2','ZI071_FFN2',None),
    ('ZI071_FFN3','ZI071_FFN3',None),
    ('ZI071_UAO','ZI071_UAO',None),
    ('ZVH','ZVH',None)
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# PhysiographyPntExt field translations
PhysiographyPntExtFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Pnt_fields) + [ \
    ('ARA',None,None),
    ('BEN',None,None),
    ('DZP',None,None),
    ('F_CODE',None,None),
    ('FUFI',None,None),
    ('FURL',None,None),
    ('GDBV',None,None),
    ('LMC',None,None),
    ('LZN',None,None),
    ('PFD',None,None),
    ('SGCC',None,None),
    ('SGCL',None,None),
    ('SGCU',None,None),
    ('UFI',None,None),
    ('WID',None,None),
    ('ZI002_UFI',None,None),
    ('ZI005_FNA',None,None),
    ('ZI005_GNT',None,None),
    ('ZI005_NFN',None,None),
    ('ZI020_GE4',None,None),
    ('ZI026_CTUC',None,None),
    ('ZI026_CTUL',None,None),
    ('ZI026_CTUU',None,None),
    ('ZI031S_URI',None,None)
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# PhysiographySrf field translations
PhysiographySrfFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Srf_fields) + [ \
    ('AOO','AOO',None),
    ('AQN','AQN',None),
    ('ARA','ARA',None),
    ('BA000_VDC','BA000_VDC',None),
    ('BA000_VDR','BA000_VDR',None),
    ('BEN',None,None),
    ('CAA','CAA',None),
    ('CET','CET',None),
    ('CNCP',None,None),
    ('COS',None,None),
    ('DOF','DOF',None),
    ('DZP',None,None),
    ('F_CODE','F_CODE',None),
    ('FIC','FIC',None),
    ('FUFI',None,None),
    ('FURL',None,None),
    ('GDBV',None,None),
    ('GOT','GOT',None),
    ('HGT','HGT',None),
    ('LMC','LMC',None),
    ('LND','LND',None),
    ('LZN','LZN',None),
    ('MCC','MCC',None),
    ('MCC2','MCC2',None),
    ('MCC3','MCC3',None),
    ('PCF','PCF',None),
    ('PFD','PFD',None),
    ('PFH','PFH',None),
    ('RKF','RKF',None),
    ('SAD','SAD',None),
    ('SDCC','SDCC',None),
    ('SDCL','SDCL',None),
    ('SDCU','SDCU',None),
    ('SDO','SDO',None),
    ('SDT','SDT',None),
    ('SGCC','SGCC',None),
    ('SGCL','SGCL',None),
    ('SGCU','SGCU',None),
    ('SHD','SHD',None),
    ('SIC','SIC',None),
    ('SLT','SLT',None),
    ('SNDC',None,None),
    ('SNDL',None,None),
    ('SNDU',None,None),
    ('SRD','SRD',None),
    ('SSE','SSE',None),
    ('STP','STP',None),
    ('SWC','SWC',None),
    ('TSM','TSM',None),
    ('TSM2','TSM2',None),
    ('TSM3','TSM3',None),
    ('UFI','UFI',None),
    ('VGT','VGT',None),
    ('VOA','VOA',None),
    ('VTI','VTI',None),
    ('WID','WID',None),
    ('WLE','WLE',None),
    ('ZI002_UFI',None,None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_FNA2',None,None),
    ('ZI005_FNA3',None,None),
    ('ZI005_GNT',None,None),
    ('ZI005_GNT2',None,None),
    ('ZI005_GNT3',None,None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZI005_NFN2',None,None),
    ('ZI005_NFN3',None,None),
    ('ZI020_GE4','ZI020_GE4',None),
    ('ZI024_ASE',None,None),
    ('ZI024_AWO',None,None),
    ('ZI024_AWOI',None,None),
    ('ZI024_AWOX',None,None),
    ('ZI024_CFR',None,None),
    ('ZI024_CLO',None,None),
    ('ZI024_CYN',None,None),
    ('ZI024_FMR',None,None),
    ('ZI024_FRR',None,None),
    ('ZI024_HAR',None,None),
    ('ZI024_HYP',None,None),
    ('ZI024_MGN',None,None),
    ('ZI024_PHW',None,None),
    ('ZI024_SCC',None,None),
    ('ZI024_SUL',None,None),
    ('ZI024_TDS',None,None),
    ('ZI024_TEP',None,None),
    ('ZI024_TUR',None,None),
    ('ZI024_WAC',None,None),
    ('ZI024_WTNO',None,None),
    ('ZI024_WUR',None,None),
    ('ZI024_WUR2',None,None),
    ('ZI024_WUR3',None,None),
    ('ZI024_WUR4',None,None),
    ('ZI024_YWQ',None,None),
    ('ZI025_HDP',None,None),
    ('ZI026_CTUC','ZI026_CTUC',None),
    ('ZI026_CTUL','ZI026_CTUL',None),
    ('ZI026_CTUU','ZI026_CTUU',None),
    ('ZI031S_URI',None,None),
    ('ZVH','ZVH',None),
    ('TRS','TRS','transform_TRS'),
    ('TRS2','TRS2','transform_TRS'),
    ('TRS3','TRS3','transform_TRS') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# PhysiographySrfExt field translations
PhysiographySrfExtFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Srf_fields) + [ \
    ('ARA',None,None),
    ('BEN',None,None),
    ('DZP',None,None),
    ('F_CODE',None,None),
    ('FUFI',None,None),
    ('FURL',None,None),
    ('GDBV',None,None),
    ('LMC',None,None),
    ('LZN',None,None),
    ('MBC_MCC1',None,None),
    ('MBC_MCC2',None,None),
    ('MBC_PSC1',None,None),
    ('MBC_PSC2',None,None),
    ('MBC_SCO1',None,None),
    ('MBC_SCO2',None,None),
    ('PCF',None,None),
    ('PRVR',None,None),
    ('SGCC',None,None),
    ('SGCL',None,None),
    ('SGCU',None,None),
    ('SSE',None,None),
    ('STP',None,None),
    ('SWC',None,None),
    ('UFI',None,None),
    ('VTI',None,None),
    ('WID',None,None),
    ('ZI002_UFI',None,None),
    ('ZI005_FNA',None,None),
    ('ZI005_GNT',None,None),
    ('ZI005_NFN',None,None),
    ('ZI020_GE4',None,None),
    ('ZI026_CTUC',None,None),
    ('ZI026_CTUL',None,None),
    ('ZI026_CTUU',None,None),
    ('ZI031S_URI',None,None)
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# PortHarbourCrv field translations
PortHarbourCrvFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Crv_fields) + [ \
    ('AOO','AOO',None),
    ('ARA','ARA',None),
    ('BEN','BEN',None),
    ('CAA','CAA',None),
    ('CNCP',None,None),
    ('COS',None,None),
    ('F_CODE','F_CODE',None),
    ('FAC','FAC',None),
    ('FFN','FFN',None),
    ('FFN2','FFN2',None),
    ('FFN3','FFN3',None),
    ('FLO','FLO',None),
    ('FUFI',None,None),
    ('FURL',None,None),
    ('GDBV',None,None),
    ('HGT','HGT',None),
    ('LMC','LMC',None),
    ('LZN','LZN',None),
    ('MCC','MCC',None),
    ('MCC2','MCC2',None),
    ('MCC3','MCC3',None),
    ('PCF','PCF',None),
    ('PWC','PWC',None),
    ('SGCC','SGCC',None),
    ('SGCL','SGCL',None),
    ('SGCU','SGCU',None),
    ('SLR','SLR',None),
    ('UFI','UFI',None),
    ('WID','WID',None),
    ('WLE','WLE',None),
    ('ZI002_UFI',None,None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_GNT',None,None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZI020_GE4','ZI020_GE4',None),
    ('ZI026_CTUC','ZI026_CTUC',None),
    ('ZI026_CTUL','ZI026_CTUL',None),
    ('ZI026_CTUU','ZI026_CTUU',None),
    ('ZI031S_URI',None,None),
    ('ZVH','ZVH',None)
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# PortHarbourPnt field translations
PortHarbourPntFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Pnt_fields) + [ \
    ('ADR','ADR',None),
    ('AOO','AOO',None),
    ('ARA','ARA',None),
    ('BEN','BEN',None),
    ('CAA','CAA',None),
    ('CNCP',None,None),
    ('COS',None,None),
    ('F_CODE','F_CODE',None),
    ('FFN','FFN',None),
    ('FFN2','FFN2',None),
    ('FFN3','FFN3',None),
    ('FUFI',None,None),
    ('FURL',None,None),
    ('GDBV',None,None),
    ('HGT','HGT',None),
    ('LMC','LMC',None),
    ('LZN','LZN',None),
    ('MCC','MCC',None),
    ('MCC2','MCC2',None),
    ('MCC3','MCC3',None),
    ('PCF','PCF',None),
    ('PLC',None,None),
    ('TID','TID',None),
    ('UFI','UFI',None),
    ('WID','WID',None),
    ('WPI','WPI',None),
    ('YSU','YSU',None),
    ('ZI002_UFI',None,None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_GNT',None,None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZI014_PBY','ZI014_PBY',None),
    ('ZI014_PBY2','ZI014_PBY2',None),
    ('ZI014_PBY3','ZI014_PBY3',None),
    ('ZI014_PPO','ZI014_PPO',None),
    ('ZI014_PPO2','ZI014_PPO2',None),
    ('ZI014_PPO3','ZI014_PPO3',None),
    ('ZI014_PRW','ZI014_PRW',None),
    ('ZI014_PRW2','ZI014_PRW2',None),
    ('ZI014_PRW3','ZI014_PRW3',None),
    ('ZI020_GE4','ZI020_GE4',None),
    ('ZI025_HDP',None,None),
    ('ZI025_WLE','ZI025_WLE',None),
    ('ZI026_CTUC','ZI026_CTUC',None),
    ('ZI026_CTUL','ZI026_CTUL',None),
    ('ZI026_CTUU','ZI026_CTUU',None),
    ('ZI031S_URI',None,None),
    ('ZVH','ZVH',None)
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# PortHarbourPntExt field translations
PortHarbourPntExtFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Pnt_fields) + [ \
    ('ACH',None,None),
    ('ARA',None,None),
    ('BEN',None,None),
    ('BER',None,None),
    ('CNCP',None,None),
    ('COS',None,None),
    ('DF1',None,None),
    ('DF2',None,None),
    ('DF3',None,None),
    ('DF4',None,None),
    ('F_CODE',None,None),
    ('FUFI',None,None),
    ('FURL',None,None),
    ('GDBV',None,None),
    ('HDP',None,None),
    ('LZN',None,None),
    ('PCF',None,None),
    ('UFI',None,None),
    ('ZI002_UFI',None,None),
    ('ZI005_FNA',None,None),
    ('ZI005_GNT',None,None),
    ('ZI005_NFN',None,None),
    ('ZI020_GE4',None,None),
    ('ZI026_CTUC',None,None),
    ('ZI026_CTUL',None,None),
    ('ZI026_CTUU',None,None),
    ('ZI031S_URI',None,None)
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# PortHarbourSrf field translations
PortHarbourSrfFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Srf_fields) + [ \
    ('ADR','ADR',None),
    ('AOO','AOO',None),
    ('ARA','ARA',None),
    ('BEN','BEN',None),
    ('CAA','CAA',None),
    ('CNCP',None,None),
    ('COS',None,None),
    ('DZP',None,None),
    ('F_CODE','F_CODE',None),
    ('FAC','FAC',None),
    ('FFN','FFN',None),
    ('FFN2','FFN2',None),
    ('FFN3','FFN3',None),
    ('FHC','FHC',None),
    ('FHC2','FHC2',None),
    ('FHC3','FHC3',None),
    ('FLO','FLO',None),
    ('FUFI',None,None),
    ('FURL',None,None),
    ('GDBV',None,None),
    ('HGT','HGT',None),
    ('LCA','LCA',None),
    ('LMC','LMC',None),
    ('LNU','LNU',None),
    ('LZN','LZN',None),
    ('MCC','MCC',None),
    ('MCC2','MCC2',None),
    ('MCC3','MCC3',None),
    ('MWD','MWD',None),
    ('PCF','PCF',None),
    ('PLC',None,None),
    ('PWC','PWC',None),
    ('SGCC','SGCC',None),
    ('SGCL','SGCL',None),
    ('SGCU','SGCU',None),
    ('SLR','SLR',None),
    ('TID','TID',None),
    ('UFI','UFI',None),
    ('WDU','WDU',None),
    ('WID','WID',None),
    ('WLE','WLE',None),
    ('WPI','WPI',None),
    ('YSU','YSU',None),
    ('ZI002_UFI',None,None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_FNA2',None,None),
    ('ZI005_GNT',None,None),
    ('ZI005_GNT2',None,None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZI005_NFN2',None,None),
    ('ZI014_PBY','ZI014_PBY',None),
    ('ZI014_PBY2','ZI014_PBY2',None),
    ('ZI014_PBY3','ZI014_PBY3',None),
    ('ZI014_PPO','ZI014_PPO',None),
    ('ZI014_PPO2','ZI014_PPO2',None),
    ('ZI014_PPO3','ZI014_PPO3',None),
    ('ZI014_PRW','ZI014_PRW',None),
    ('ZI014_PRW2','ZI014_PRW2',None),
    ('ZI014_PRW3','ZI014_PRW3',None),
    ('ZI020_GE4','ZI020_GE4',None),
    ('ZI025_HDP',None,None),
    ('ZI025_WLE','ZI025_WLE',None),
    ('ZI026_CTUC','ZI026_CTUC',None),
    ('ZI026_CTUL','ZI026_CTUL',None),
    ('ZI026_CTUU','ZI026_CTUU',None),
    ('ZI031S_URI',None,None),
    ('ZVH','ZVH',None)
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# PortHarbourSrfExt field translations
PortHarbourSrfExtFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Srf_fields) + [ \
    ('ACH',None,None),
    ('ARA',None,None),
    ('BEN',None,None),
    ('CNCP',None,None),
    ('COS',None,None),
    ('F_CODE',None,None),
    ('FUFI',None,None),
    ('FURL',None,None),
    ('GDBV',None,None),
    ('HDP',None,None),
    ('LZN',None,None),
    ('MCC',None,None),
    ('MCC2',None,None),
    ('MCC3',None,None),
    ('PCF',None,None),
    ('UFI',None,None),
    ('WID',None,None),
    ('WLE',None,None),
    ('ZI002_UFI',None,None),
    ('ZI005_FNA',None,None),
    ('ZI005_GNT',None,None),
    ('ZI005_NFN',None,None),
    ('ZI020_GE4',None,None),
    ('ZI026_CTUC',None,None),
    ('ZI026_CTUL',None,None),
    ('ZI026_CTUU',None,None),
    ('ZI031S_URI',None,None)
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# RecreationAONExt field translations
RecreationAONExtFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Srf_fields) + [ \
    ('ARA',None,None),
    ('BEN',None,None),
    ('CAA',None,None),
    ('CNCP',None,None),
    ('COS',None,None),
    ('DMF',None,None),
    ('DZP',None,None),
    ('F_CODE',None,None),
    ('FUFI',None,None),
    ('FURL',None,None),
    ('GDBV',None,None),
    ('HGT',None,None),
    ('LMC',None,None),
    ('LOC',None,None),
    ('LZN',None,None),
    ('PCF',None,None),
    ('UFI',None,None),
    ('VLM',None,None),
    ('WID',None,None),
    ('ZI002_UFI',None,None),
    ('ZI005_FNA',None,None),
    ('ZI005_GNT',None,None),
    ('ZI005_NFN',None,None),
    ('ZI020_GE4',None,None),
    ('ZI024_ASE',None,None),
    ('ZI024_CFR',None,None),
    ('ZI024_CLO',None,None),
    ('ZI024_CYN',None,None),
    ('ZI024_FMR',None,None),
    ('ZI024_FRR',None,None),
    ('ZI024_HAR',None,None),
    ('ZI024_HYP',None,None),
    ('ZI024_MGN',None,None),
    ('ZI024_PHW',None,None),
    ('ZI024_SCC',None,None),
    ('ZI024_SUL',None,None),
    ('ZI024_TDS',None,None),
    ('ZI024_TEP',None,None),
    ('ZI024_TUR',None,None),
    ('ZI024_WAC',None,None),
    ('ZI024_WTNO',None,None),
    ('ZI024_WUR',None,None),
    ('ZI024_WUR2',None,None),
    ('ZI024_WUR3',None,None),
    ('ZI024_WUR4',None,None),
    ('ZI026_CTUC',None,None),
    ('ZI026_CTUL',None,None),
    ('ZI026_CTUU',None,None),
    ('ZI031S_URI',None,None)
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# RecreationCrv field translations
RecreationCrvFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Crv_fields) + [ \
    ('ADR','ADR',None),
    ('AMA','AMA',None),
    ('AOO','AOO',None),
    ('ARA','ARA',None),
    ('AWP','AWP',None),
    ('BEN','BEN',None),
    ('CAA','CAA',None),
    ('CNCP',None,None),
    ('COS',None,None),
    ('F_CODE','F_CODE',None),
    ('FUFI',None,None),
    ('FURL',None,None),
    ('GDBV',None,None),
    ('HEI','HEI',None),
    ('HGT','HGT',None),
    ('LMC','LMC',None),
    ('LZN','LZN',None),
    ('PCF','PCF',None),
    ('RAY',None,None),
    ('THI','THI',None),
    ('UFI','UFI',None),
    ('VOI','VOI',None),
    ('WID','WID',None),
    ('ZI002_UFI',None,None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_GNT',None,None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZI020_GE4','ZI020_GE4',None),
    ('ZI026_CTUC','ZI026_CTUC',None),
    ('ZI026_CTUL','ZI026_CTUL',None),
    ('ZI026_CTUU','ZI026_CTUU',None),
    ('ZI031S_URI',None,None),
    ('ZVH','ZVH',None)
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# RecreationPnt field translations
RecreationPntFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Pnt_fields) + [ \
    ('ADR','ADR',None),
    ('AMA','AMA',None),
    ('AOO','AOO',None),
    ('ARA','ARA',None),
    ('AWP','AWP',None),
    ('BEN','BEN',None),
    ('CAA','CAA',None),
    ('CCT','CCT',None),
    ('CNCP',None,None),
    ('COS',None,None),
    ('DZP',None,None),
    ('F_CODE','F_CODE',None),
    ('FFN','FFN',None),
    ('FFN2','FFN2',None),
    ('FFN3','FFN3',None),
    ('FUFI',None,None),
    ('FURL',None,None),
    ('GDBV',None,None),
    ('HEI','HEI',None),
    ('HGT','HGT',None),
    ('LMC','LMC',None),
    ('LOC',None,None),
    ('LZN','LZN',None),
    ('PCF','PCF',None),
    ('SSR','SSR',None),
    ('SSR2','SSR2',None),
    ('SSR3','SSR3',None),
    ('THI','THI',None),
    ('UFI','UFI',None),
    ('VLM','VLM',None),
    ('VOI','VOI',None),
    ('WID','WID',None),
    ('ZI002_UFI',None,None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_GNT',None,None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZI020_GE4','ZI020_GE4',None),
    ('ZI024_ASE',None,None),
    ('ZI024_CFR',None,None),
    ('ZI024_CLO',None,None),
    ('ZI024_CYN',None,None),
    ('ZI024_FMR',None,None),
    ('ZI024_FRR',None,None),
    ('ZI024_HAR',None,None),
    ('ZI024_HYP',None,None),
    ('ZI024_MGN',None,None),
    ('ZI024_PHW',None,None),
    ('ZI024_SCC',None,None),
    ('ZI024_SUL',None,None),
    ('ZI024_TDS',None,None),
    ('ZI024_TEP',None,None),
    ('ZI024_TUR',None,None),
    ('ZI024_WAC',None,None),
    ('ZI024_WTNO',None,None),
    ('ZI024_WUR',None,None),
    ('ZI024_WUR2',None,None),
    ('ZI024_WUR3',None,None),
    ('ZI024_WUR4',None,None),
    ('ZI026_CTUC','ZI026_CTUC',None),
    ('ZI026_CTUL','ZI026_CTUL',None),
    ('ZI026_CTUU','ZI026_CTUU',None),
    ('ZI031S_URI',None,None),
    ('ZVH','ZVH',None)
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# RecreationSrf field translations
RecreationSrfFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Srf_fields) + [ \
    ('ADR','ADR',None),
    ('AMA','AMA',None),
    ('AOO','AOO',None),
    ('ARA','ARA',None),
    ('AWP','AWP',None),
    ('BEN','BEN',None),
    ('CAA','CAA',None),
    ('CCT','CCT',None),
    ('CNCP',None,None),
    ('COS',None,None),
    ('DZP',None,None),
    ('F_CODE','F_CODE',None),
    ('FFN','FFN',None),
    ('FFN2','FFN2',None),
    ('FFN3','FFN3',None),
    ('FUFI',None,None),
    ('FURL',None,None),
    ('GDBV',None,None),
    ('HGT','HGT',None),
    ('LMC','LMC',None),
    ('LOC',None,None),
    ('LZN','LZN',None),
    ('PCF','PCF',None),
    ('RAY',None,None),
    ('SSR','SSR',None),
    ('SSR2','SSR2',None),
    ('SSR3','SSR3',None),
    ('UFI','UFI',None),
    ('VLM','VLM',None),
    ('VOI','VOI',None),
    ('WID','WID',None),
    ('ZI002_UFI',None,None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_GNT',None,None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZI020_GE4','ZI020_GE4',None),
    ('ZI024_ASE',None,None),
    ('ZI024_CFR',None,None),
    ('ZI024_CLO',None,None),
    ('ZI024_CYN',None,None),
    ('ZI024_FMR',None,None),
    ('ZI024_FRR',None,None),
    ('ZI024_HAR',None,None),
    ('ZI024_HYP',None,None),
    ('ZI024_MGN',None,None),
    ('ZI024_PHW',None,None),
    ('ZI024_SCC',None,None),
    ('ZI024_SUL',None,None),
    ('ZI024_TDS',None,None),
    ('ZI024_TEP',None,None),
    ('ZI024_TUR',None,None),
    ('ZI024_WAC',None,None),
    ('ZI024_WTNO',None,None),
    ('ZI024_WUR',None,None),
    ('ZI024_WUR2',None,None),
    ('ZI024_WUR3',None,None),
    ('ZI024_WUR4',None,None),
    ('ZI026_CTUC','ZI026_CTUC',None),
    ('ZI026_CTUL','ZI026_CTUL',None),
    ('ZI026_CTUU','ZI026_CTUU',None),
    ('ZI031S_URI',None,None),
    ('ZVH','ZVH',None)
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

### ReferenceTblExt field translations
##ReferenceTblExtFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Tbl_fields) + [ \
##    ('RS6',None,None),
##    ('RX0',None,None),
##    ('RX1',None,None),
##    ('RX2',None,None),
##    ('RX3',None,None),
##    ('RX4',None,None),
##    ('RX5',None,None),
##    ('RX6',None,None),
##    ('RX7',None,None),
##    ('RY1',None,None),
##    ('RY2',None,None)
##     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

### ResourceSrf field translations
##ResourceSrfFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Srf_fields) + [ \
##    ('AHA','AHA',None),
##    ('AVA','AVA',None),
##    ('CID','CID',None),
##    ('DQS','DQS',None),
##    ('ETZ','ETZ',None),
##    ('EVA','EVA',None),
##    ('F_CODE','F_CODE',None),
##    ('FURL',None,None),
##    ('HVA','HVA',None),
##    ('MDE','MDE',None),
##    ('MEM','MEM',None),
##    ('RTL',None,None),
##    ('SCVN',None,None),
##    ('URI','URI',None),
##    ('ZI002_UFI',None,None),
##    ('ZI020_GE4','ZI020_GE4',None),
##    ('ZI020_GE42','ZI020_GE42',None),
##    ('ZI020_GE43','ZI020_GE43',None),
##    ('ZI020_GE44','ZI020_GE44',None),
##    ('CPS','CPS','transformCPSEnumeration2CPSCodeList'),
##    ('EQS','EQC','transformEQSinteger2EQCcodelist'),
##    ('ETS','ETS','transformETSEnumeration2ETSCodeList'),
##    ('HZD','HZD','transformHZDEnumeration2HZDCodeList'),
##    ('RCG','RCG','transformRCGEnumeration2RCGCodeList'),
##    ('VDT','VDT','transformVDTenumeration2VDTcodelist'),
##    ('MEM','MEM','transform_MEM'),
##    ('OTH','OTH','transform_OTH')
##     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoTDSGroup)

# ResourceTbl field translations
##ResourceTblFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Tbl_fields) + [ \
##    ('AHA','AHA',None),
##    ('AVA','AVA',None),
##    ('CID','CID',None),
##    ('DQS','DQS',None),
##    ('EQS',None,None),
##    ('ETZ','ETZ',None),
##    ('EVA','EVA',None),
##    ('F_CODE','F_CODE',None),
##    ('FURL',None,None),
##    ('HVA','HVA',None),
##    ('MDE','MDE',None),
##    ('MEM','MEM',None),
##    ('RTL',None,None),
##    ('SCVN',None,None),
##    ('URI','URI',None),
##    ('ZI002_UFI',None,None),
##    ('ZI020_GE4','ZI020_GE4',None),
##    ('ZI020_GE42','ZI020_GE42',None),
##    ('ZI020_GE43','ZI020_GE43',None),
##    ('ZI020_GE44','ZI020_GE44',None),
##    ('CPS','CPS','transformCPSEnumeration2CPSCodeList'),
##    ('ETS','ETS','transformETSEnumeration2ETSCodeList'),
##    ('HZD','HZD','transformHZDEnumeration2HZDCodeList'),
##    ('RCG','RCG','transformRCGEnumeration2RCGCodeList'),
##    ('VDT','VDT','transformVDTEnumeration2VDTCodeList') \
##     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# SettlementPnt field translations
SettlementPntFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Pnt_fields) + [ \
    ('ADR','ADR',None),
    ('AOO','AOO',None),
    ('ARA','ARA',None),
    ('BAC','BAC',None),
    ('BEN','BEN',None),
    ('BNF',None,None),
    ('CAA','CAA',None),
    ('CNCP',None,None),
    ('COS',None,None),
    ('DNE',None,None),
    ('F_CODE','F_CODE',None),
    ('FFN','FFN',None),
    ('FFN2','FFN2',None),
    ('FFN3','FFN3',None),
    ('FUFI',None,None),
    ('FURL',None,None),
    ('GDBV',None,None),
    ('HGT','HGT',None),
    ('HHD','HHD',None),
    ('LMC','LMC',None),
    ('LZN','LZN',None),
    ('PCF','PCF',None),
    ('STL','STL',None),
    ('STL2','STL2',None),
    ('STL3','STL3',None),
    ('UFI','UFI',None),
    ('WID','WID',None),
    ('WPI','WPI',None),
    ('ZI002_UFI',None,None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_FNA2','ZI005_FNA2',None),
    ('ZI005_GNT',None,None),
    ('ZI005_GNT2',None,None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZI005_NFN2','ZI005_NFN2',None),
    ('ZI020_GE4','ZI020_GE4',None),
    ('ZI026_CTUC','ZI026_CTUC',None),
    ('ZI026_CTUL','ZI026_CTUL',None),
    ('ZI026_CTUU','ZI026_CTUU',None),
    ('ZI031S_URI',None,None),
    ('ZVH','ZVH',None)
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# SettlementSrf field translations
SettlementSrfFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Srf_fields) + [ \
    ('ADR','ADR',None),
    ('AOO','AOO',None),
    ('ARA','ARA',None),
    ('BAC','BAC',None),
    ('BEN','BEN',None),
    ('BNF',None,None),
    ('CAA','CAA',None),
    ('CNCP',None,None),
    ('COS',None,None),
    ('DNE',None,None),
    ('F_CODE','F_CODE',None),
    ('FFN','FFN',None),
    ('FFN2','FFN2',None),
    ('FFN3','FFN3',None),
    ('FUFI',None,None),
    ('FURL',None,None),
    ('GDBV',None,None),
    ('HGT','HGT',None),
    ('HHD','HHD',None),
    ('LMC','LMC',None),
    ('LZN','LZN',None),
    ('PCF','PCF',None),
    ('STL','STL',None),
    ('STL2','STL2',None),
    ('STL3','STL3',None),
    ('UFI','UFI',None),
    ('WID','WID',None),
    ('WPI','WPI',None),
    ('ZI002_UFI',None,None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_FNA2','ZI005_FNA2',None),
    ('ZI005_GNT',None,None),
    ('ZI005_GNT2',None,None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZI005_NFN2','ZI005_NFN2',None),
    ('ZI020_GE4','ZI020_GE4',None),
    ('ZI026_CTUC','ZI026_CTUC',None),
    ('ZI026_CTUL','ZI026_CTUL',None),
    ('ZI026_CTUU','ZI026_CTUU',None),
    ('ZI031S_URI',None,None),
    ('ZVH','ZVH',None)
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# SettlementSrfExt field translations
SettlementSrfExtFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Srf_fields) + [ \
    ('ARA',None,None),
    ('BEN',None,None),
    ('F_CODE',None,None),
    ('FUFI',None,None),
    ('FURL',None,None),
    ('GDBV',None,None),
    ('NDX',None,None),
    ('NDX2',None,None),
    ('NDX3',None,None),
    ('UFI',None,None),
    ('ZI002_UFI',None,None),
    ('ZI005_FNA',None,None),
    ('ZI005_GNT',None,None),
    ('ZI005_NFN',None,None),
    ('ZI020_GE4',None,None),
    ('ZI026_CTUC',None,None),
    ('ZI026_CTUL',None,None),
    ('ZI026_CTUU',None,None),
    ('ZI031S_URI',None,None)
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# StorageAONExt field translations
StorageAONExtFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Srf_fields) + [ \
    ('ARA',None,None),
    ('AWP',None,None),
    ('BEN',None,None),
    ('CAA',None,None),
    ('CBP',None,None),
    ('CNCP',None,None),
    ('COS',None,None),
    ('DMF',None,None),
    ('F_CODE',None,None),
    ('FUFI',None,None),
    ('FURL',None,None),
    ('GDBV',None,None),
    ('HEI',None,None),
    ('HGT',None,None),
    ('LMC',None,None),
    ('LUN',None,None),
    ('LZN',None,None),
    ('PCF',None,None),
    ('PPO',None,None),
    ('PPO2',None,None),
    ('PPO3',None,None),
    ('SPT',None,None),
    ('SSC',None,None),
    ('UFI',None,None),
    ('VCM',None,None),
    ('VCM2',None,None),
    ('VCM3',None,None),
    ('VLM',None,None),
    ('VOI',None,None),
    ('WID',None,None),
    ('YWQ',None,None),
    ('ZI002_UFI',None,None),
    ('ZI005_FNA',None,None),
    ('ZI005_FNA2',None,None),
    ('ZI005_GNT',None,None),
    ('ZI005_GNT2',None,None),
    ('ZI005_NFN',None,None),
    ('ZI005_NFN2',None,None),
    ('ZI020_GE4',None,None),
    ('ZI024_ASE',None,None),
    ('ZI024_CFR',None,None),
    ('ZI024_CLO',None,None),
    ('ZI024_CYN',None,None),
    ('ZI024_FMR',None,None),
    ('ZI024_FRR',None,None),
    ('ZI024_HAR',None,None),
    ('ZI024_MGN',None,None),
    ('ZI024_PHW',None,None),
    ('ZI024_SCC',None,None),
    ('ZI024_SUL',None,None),
    ('ZI024_TDS',None,None),
    ('ZI024_TEP',None,None),
    ('ZI024_TUR',None,None),
    ('ZI024_WAC',None,None),
    ('ZI024_WTNO',None,None),
    ('ZI024_WUR',None,None),
    ('ZI024_WUR2',None,None),
    ('ZI024_WUR3',None,None),
    ('ZI024_WUR4',None,None),
    ('ZI026_CTUC',None,None),
    ('ZI026_CTUL',None,None),
    ('ZI026_CTUU',None,None),
    ('ZI031S_URI',None,None),
    ('ZVH',None,None)
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# StoragePnt field translations
StoragePntFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Pnt_fields) + [ \
    ('ADR','ADR',None),
    ('AOO','AOO',None),
    ('ARA','ARA',None),
    ('AWP','AWP',None),
    ('BEN','BEN',None),
    ('CAA','CAA',None),
    ('CBP','CBP',None),
    ('CNCP',None,None),
    ('COS',None,None),
    ('F_CODE','F_CODE',None),
    ('FFN','FFN',None),
    ('FFN2','FFN2',None),
    ('FFN3','FFN3',None),
    ('FUFI',None,None),
    ('FURL',None,None),
    ('GDBV',None,None),
    ('HEI','HEI',None),
    ('HGT','HGT',None),
    ('LMC','LMC',None),
    ('LOC',None,None),
    ('LUN','LUN',None),
    ('LZN','LZN',None),
    ('PCF','PCF',None),
    ('PMPR',None,None),
    ('PPO','PPO',None),
    ('PPO2','PPO2',None),
    ('PPO3','PPO3',None),
    ('SHT','SHT',None),
    ('SPT','SPT',None),
    ('SSC','SSC',None),
    ('SSR','SSR',None),
    ('SSR2','SSR2',None),
    ('SSR3','SSR3',None),
    ('UFI','UFI',None),
    ('VCM','VCM',None),
    ('VCM2','VCM2',None),
    ('VCM3','VCM3',None),
    ('VLM','VLM',None),
    ('VOI','VOI',None),
    ('WDST',None,None),
    ('WID','WID',None),
    ('YWQ','YWQ',None),
    ('ZI002_UFI',None,None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_FNA2',None,None),
    ('ZI005_GNT',None,None),
    ('ZI005_GNT2',None,None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZI005_NFN2',None,None),
    ('ZI020_GE4','ZI020_GE4',None),
    ('ZI024_ASE',None,None),
    ('ZI024_CFR',None,None),
    ('ZI024_CLO',None,None),
    ('ZI024_CYN',None,None),
    ('ZI024_FMR',None,None),
    ('ZI024_FRR',None,None),
    ('ZI024_HAR',None,None),
    ('ZI024_HYP',None,None),
    ('ZI024_MGN',None,None),
    ('ZI024_PHW',None,None),
    ('ZI024_SCC',None,None),
    ('ZI024_SUL',None,None),
    ('ZI024_TDS',None,None),
    ('ZI024_TEP',None,None),
    ('ZI024_TUR',None,None),
    ('ZI024_WAC',None,None),
    ('ZI024_WTNO',None,None),
    ('ZI024_WUR',None,None),
    ('ZI024_WUR2',None,None),
    ('ZI024_WUR3',None,None),
    ('ZI024_WUR4',None,None),
    ('ZI026_CTUC','ZI026_CTUC',None),
    ('ZI026_CTUL','ZI026_CTUL',None),
    ('ZI026_CTUU','ZI026_CTUU',None),
    ('ZI031S_URI',None,None),
    ('ZVH','ZVH',None)
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# StorageSrf field translations
StorageSrfFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Srf_fields) + [ \
    ('ADR','ADR',None),
    ('AOO','AOO',None),
    ('ARA','ARA',None),
    ('AWP','AWP',None),
    ('BEN','BEN',None),
    ('CAA','CAA',None),
    ('CBP','CBP',None),
    ('CNCP',None,None),
    ('COS',None,None),
    ('F_CODE','F_CODE',None),
    ('FFN','FFN',None),
    ('FFN2','FFN2',None),
    ('FFN3','FFN3',None),
    ('FUFI',None,None),
    ('FURL',None,None),
    ('GDBV',None,None),
    ('HEI','HEI',None),
    ('HGT','HGT',None),
    ('LMC','LMC',None),
    ('LOC',None,None),
    ('LUN','LUN',None),
    ('LZN','LZN',None),
    ('PCF','PCF',None),
    ('PMPR',None,None),
    ('PPO','PPO',None),
    ('PPO2','PPO2',None),
    ('PPO3','PPO3',None),
    ('SHT','SHT',None),
    ('SPT','SPT',None),
    ('SSC','SSC',None),
    ('SSR','SSR',None),
    ('SSR2','SSR2',None),
    ('SSR3','SSR3',None),
    ('UFI','UFI',None),
    ('VCM','VCM',None),
    ('VCM2','VCM2',None),
    ('VCM3','VCM3',None),
    ('VLM','VLM',None),
    ('VOI','VOI',None),
    ('WDST',None,None),
    ('WID','WID',None),
    ('YWQ','YWQ',None),
    ('ZI002_UFI',None,None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_FNA2',None,None),
    ('ZI005_GNT',None,None),
    ('ZI005_GNT2',None,None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZI005_NFN2',None,None),
    ('ZI020_GE4','ZI020_GE4',None),
    ('ZI024_ASE',None,None),
    ('ZI024_CFR',None,None),
    ('ZI024_CLO',None,None),
    ('ZI024_CYN',None,None),
    ('ZI024_FMR',None,None),
    ('ZI024_FRR',None,None),
    ('ZI024_HAR',None,None),
    ('ZI024_HYP',None,None),
    ('ZI024_MGN',None,None),
    ('ZI024_PHW',None,None),
    ('ZI024_SCC',None,None),
    ('ZI024_SUL',None,None),
    ('ZI024_TDS',None,None),
    ('ZI024_TEP',None,None),
    ('ZI024_TUR',None,None),
    ('ZI024_WAC',None,None),
    ('ZI024_WTNO',None,None),
    ('ZI024_WUR',None,None),
    ('ZI024_WUR2',None,None),
    ('ZI024_WUR3',None,None),
    ('ZI024_WUR4',None,None),
    ('ZI026_CTUC','ZI026_CTUC',None),
    ('ZI026_CTUL','ZI026_CTUL',None),
    ('ZI026_CTUU','ZI026_CTUU',None),
    ('ZI031S_URI',None,None),
    ('ZVH','ZVH',None)
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# StructureCrv field translations
StructureCrvFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Crv_fields) + [ \
    ('AOO','AOO',None),
    ('ARA','ARA',None),
    ('AWP','AWP',None),
    ('BAT','BAT',None),
    ('BEN','BEN',None),
    ('BSU','BSU',None),
    ('CAA','CAA',None),
    ('CNCP',None,None),
    ('COS',None,None),
    ('CRM','CRM',None),
    ('F_CODE','F_CODE',None),
    ('FEF',None,None),
    ('FFN','FFN',None),
    ('FFN2','FFN2',None),
    ('FFN3','FFN3',None),
    ('FTI','FTI',None),
    ('FUFI',None,None),
    ('FURL',None,None),
    ('GDBV',None,None),
    ('HEI','HEI',None),
    ('HGT','HGT',None),
    ('LMC','LMC',None),
    ('LZN','LZN',None),
    ('MCC','MCC',None),
    ('MCC2','MCC2',None),
    ('MCC3','MCC3',None),
    ('PCF','PCF',None),
    ('PFHC',None,None),
    ('PFHL',None,None),
    ('PFHU',None,None),
    ('THI','THI',None),
    ('UFI','UFI',None),
    ('VCM','VCM',None),
    ('VCM2','VCM2',None),
    ('VCM3','VCM3',None),
    ('VOI','VOI',None),
    ('WID','WID',None),
    ('WTI','WTI',None),
    ('ZI002_UFI',None,None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_GNT',None,None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZI018_WIT','ZI018_WIT',None),
    ('ZI020_GE4','ZI020_GE4',None),
    ('ZI026_CTUC','ZI026_CTUC',None),
    ('ZI026_CTUL','ZI026_CTUL',None),
    ('ZI026_CTUU','ZI026_CTUU',None),
    ('ZI031S_URI',None,None),
    ('ZVH','ZVH',None)
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# StructurePnt field translations
StructurePntFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Pnt_fields) + [ \
    ('ADR','ADR',None),
    ('AOO','AOO',None),
    ('ARA','ARA',None),
    ('ATB','ATB',None),
    ('AWP','AWP',None),
    ('BEN','BEN',None),
    ('BNF','BNF',None),
    ('BSU','BSU',None),
    ('CAA','CAA',None),
    ('CNCP',None,None),
    ('COS','COS',None),
    ('CRM','CRM',None),
    ('DZP',None,None),
    ('ETY','ETY',None),
    ('F_CODE','F_CODE',None),
    ('FFN','FFN',None),
    ('FFN2','FFN2',None),
    ('FFN3','FFN3',None),
    ('FUFI',None,None),
    ('FURL',None,None),
    ('GDBV',None,None),
    ('GUG','GUG',None),
    ('HEI','HEI',None),
    ('HGT','HGT',None),
    ('HSC',None,None),
    ('HST','HST',None),
    ('HST2','HST2',None),
    ('HST3','HST3',None),
    ('LEA',None,None),
    ('LMC','LMC',None),
    ('LZN','LZN',None),
    ('MEL',None,None),
    ('MFB','MFB',None),
    ('MFY',None,None),
    ('MKSZ',None,None),
    ('MUB','MUB',None),
    ('NOR',None,None),
    ('PCF','PCF',None),
    ('PYC','PYC',None),
    ('PYM','PYM',None),
    ('RLE','RLE',None),
    ('SPT','SPT',None),
    ('SRL','SRL',None),
    ('SSR','SSR',None),
    ('SSR2','SSR2',None),
    ('SSR3','SSR3',None),
    ('STAF',None,None),
    ('TEL','TEL',None),
    ('TOS','TOS',None),
    ('TTC','TTC',None),
    ('TTC2','TTC2',None),
    ('TTC3','TTC3',None),
    ('UFI','UFI',None),
    ('VCM','VCM',None),
    ('VCM2','VCM2',None),
    ('VCM3','VCM3',None),
    ('VEC',None,None),
    ('VOI','VOI',None),
    ('WID','WID',None),
    ('WPST',None,None),
    ('WTYP',None,None),
    ('ZI002_UFI',None,None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_FNA2',None,None),
    ('ZI005_FNA3',None,None),
    ('ZI005_GNT',None,None),
    ('ZI005_GNT2',None,None),
    ('ZI005_GNT3',None,None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZI005_NFN2',None,None),
    ('ZI005_NFN3',None,None),
    ('ZI014_PBY','ZI014_PBY',None),
    ('ZI014_PBY2','ZI014_PBY2',None),
    ('ZI014_PBY3','ZI014_PBY3',None),
    ('ZI014_PPO','ZI014_PPO',None),
    ('ZI014_PPO2','ZI014_PPO2',None),
    ('ZI014_PPO3','ZI014_PPO3',None),
    ('ZI014_PRW','ZI014_PRW',None),
    ('ZI014_PRW2','ZI014_PRW2',None),
    ('ZI014_PRW3','ZI014_PRW3',None),
    ('ZI018_WIT','ZI018_WIT',None),
    ('ZI020_GE4','ZI020_GE4',None),
    ('ZI026_CTUC','ZI026_CTUC',None),
    ('ZI026_CTUL','ZI026_CTUL',None),
    ('ZI026_CTUU','ZI026_CTUU',None),
    ('ZI031S_URI',None,None),
    ('ZI037_REL','ZI037_REL',None),
    ('ZI037_RFA','ZI037_RFA',None),
    ('ZVH','ZVH',None)
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# StructurePntExt field translations
StructurePntExtFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Pnt_fields) + [ \
    ('ARA',None,None),
    ('BEN',None,None),
    ('CNCP',None,None),
    ('COS',None,None),
    ('F_CODE',None,None),
    ('FUFI',None,None),
    ('FURL',None,None),
    ('GDBV',None,None),
    ('LMC',None,None),
    ('LZN',None,None),
    ('PCF',None,None),
    ('UFI',None,None),
    ('WID',None,None),
    ('ZI002_UFI',None,None),
    ('ZI005_FNA',None,None),
    ('ZI005_GNT',None,None),
    ('ZI005_NFN',None,None),
    ('ZI020_GE4',None,None),
    ('ZI026_CTUC',None,None),
    ('ZI026_CTUL',None,None),
    ('ZI026_CTUU',None,None),
    ('ZI031S_URI',None,None)
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# StructureSrf field translations
StructureSrfFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Srf_fields) + [ \
    ('ADR','ADR',None),
    ('AOO','AOO',None),
    ('ARA','ARA',None),
    ('ATB','ATB',None),
    ('AWP','AWP',None),
    ('BEN','BEN',None),
    ('BNF','BNF',None),
    ('BSU','BSU',None),
    ('CAA','CAA',None),
    ('CNCP',None,None),
    ('COS','COS',None),
    ('ETY','ETY',None),
    ('F_CODE','F_CODE',None),
    ('FFN','FFN',None),
    ('FFN2','FFN2',None),
    ('FFN3','FFN3',None),
    ('FUFI',None,None),
    ('FURL',None,None),
    ('GDBV',None,None),
    ('GUG','GUG',None),
    ('HEI','HEI',None),
    ('HGT','HGT',None),
    ('HSC',None,None),
    ('HST','HST',None),
    ('HST2','HST2',None),
    ('HST3','HST3',None),
    ('LMC','LMC',None),
    ('LZN','LZN',None),
    ('MEL',None,None),
    ('MFB','MFB',None),
    ('MFY',None,None),
    ('MKSZ',None,None),
    ('MUB','MUB',None),
    ('NOR',None,None),
    ('PCF','PCF',None),
    ('PYC','PYC',None),
    ('PYM','PYM',None),
    ('RLE','RLE',None),
    ('SPT','SPT',None),
    ('SRL','SRL',None),
    ('SSR','SSR',None),
    ('SSR2','SSR2',None),
    ('SSR3','SSR3',None),
    ('STAF',None,None),
    ('TEL','TEL',None),
    ('TOS','TOS',None),
    ('TTC','TTC',None),
    ('TTC2','TTC2',None),
    ('TTC3','TTC3',None),
    ('UFI','UFI',None),
    ('VCM','VCM',None),
    ('VCM2','VCM2',None),
    ('VCM3','VCM3',None),
    ('VEC',None,None),
    ('VOI','VOI',None),
    ('WID','WID',None),
    ('WPST',None,None),
    ('WTYP',None,None),
    ('ZI002_UFI',None,None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_FNA2',None,None),
    ('ZI005_FNA3',None,None),
    ('ZI005_GNT',None,None),
    ('ZI005_GNT2',None,None),
    ('ZI005_GNT3',None,None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZI005_NFN2',None,None),
    ('ZI005_NFN3',None,None),
    ('ZI014_PBY','ZI014_PBY',None),
    ('ZI014_PBY2','ZI014_PBY2',None),
    ('ZI014_PBY3','ZI014_PBY3',None),
    ('ZI014_PPO','ZI014_PPO',None),
    ('ZI014_PPO2','ZI014_PPO2',None),
    ('ZI014_PPO3','ZI014_PPO3',None),
    ('ZI014_PRW','ZI014_PRW',None),
    ('ZI014_PRW2','ZI014_PRW2',None),
    ('ZI014_PRW3','ZI014_PRW3',None),
    ('ZI018_WIT','ZI018_WIT',None),
    ('ZI020_GE4','ZI020_GE4',None),
    ('ZI026_CTUC','ZI026_CTUC',None),
    ('ZI026_CTUL','ZI026_CTUL',None),
    ('ZI026_CTUU','ZI026_CTUU',None),
    ('ZI031S_URI',None,None),
    ('ZI037_REL','ZI037_REL',None),
    ('ZI037_RFA','ZI037_RFA',None),
    ('ZVH','ZVH',None)
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# SubterraneanSrf field translations
SubterraneanSrfFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Srf_fields) + [ \
    ('AQN','AQN',None),
    ('AQO','AQO',None),
    ('AQO2','AQO2',None),
    ('AQO3','AQO3',None),
    ('AQP','AQP',None),
    ('AQP2','AQP2',None),
    ('AQP3','AQP3',None),
    ('AQTC','AQTC',None),
    ('AQTL','AQTL',None),
    ('AQTU','AQTU',None),
    ('ARA','ARA',None),
    ('AYRC','AYRC',None),
    ('AYRL','AYRL',None),
    ('AYRU','AYRU',None),
    ('BEN','BEN',None),
    ('CAA','CAA',None),
    ('CNCP',None,None),
    ('CNF','CNF',None),
    ('COS','COS',None),
    ('DPAC','DPAC',None),
    ('DPAL','DPAL',None),
    ('DPAU','DPAU',None),
    ('DZP','DZP',None),
    ('F_CODE','F_CODE',None),
    ('FUFI',None,None),
    ('FURL',None,None),
    ('GDBV',None,None),
    ('GWS',None,None),
    ('GWTR',None,None),
    ('HYCD',None,None),
    ('LEA','LEA',None),
    ('LZN','LZN',None),
    ('PCF','PCF',None),
    ('SWCP',None,None),
    ('UFI','UFI',None),
    ('WID','WID',None),
    ('WRCC',None,None),
    ('WRCL',None,None),
    ('WRCU',None,None),
    ('WWRC',None,None),
    ('WWRL',None,None),
    ('WWRU',None,None),
    ('ZI002_UFI',None,None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_FNA2',None,None),
    ('ZI005_FNA3',None,None),
    ('ZI005_GNT',None,None),
    ('ZI005_GNT2',None,None),
    ('ZI005_GNT3',None,None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZI005_NFN2',None,None),
    ('ZI005_NFN3',None,None),
    ('ZI020_GE4','ZI020_GE4',None),
    ('ZI024_ASE',None,None),
    ('ZI024_CFR',None,None),
    ('ZI024_CLO',None,None),
    ('ZI024_CYN',None,None),
    ('ZI024_FMR',None,None),
    ('ZI024_FRR',None,None),
    ('ZI024_HAR',None,None),
    ('ZI024_MGN',None,None),
    ('ZI024_PHW',None,None),
    ('ZI024_SCC','ZI024_SCC',None),
    ('ZI024_SUL',None,None),
    ('ZI024_TDS',None,None),
    ('ZI024_TEP',None,None),
    ('ZI024_TUR',None,None),
    ('ZI024_WAC',None,None),
    ('ZI024_WTNO',None,None),
    ('ZI024_WUR',None,None),
    ('ZI024_WUR2',None,None),
    ('ZI024_WUR3',None,None),
    ('ZI024_WUR4',None,None),
    ('ZI024_YWQ','ZI024_YWQ',None),
    ('ZI026_CTUC','ZI026_CTUC',None),
    ('ZI026_CTUL','ZI026_CTUL',None),
    ('ZI026_CTUU','ZI026_CTUU',None),
    ('ZI031S_URI',None,None),
    ('ZI071_CTX','ZI071_CTX',None),
    ('ZI071_FFN','ZI071_FFN',None),
    ('ZI071_FFN2','ZI071_FFN2',None),
    ('ZI071_FFN3','ZI071_FFN3',None),
    ('ZI071_UAO','ZI071_UAO',None)
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# TransportationGroundCrv field translations
TransportationGroundCrvFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Crv_fields) + [ \
    ('AOO','AOO',None),
    ('ARA','ARA',None),
    ('AWP','AWP',None),
    ('BCC','BCC',None),
    ('BEN','BEN',None),
    ('BMC',None,None),
    ('BMC2',None,None),
    ('BMC3',None,None),
    ('BOT','BOT',None),
    ('BRN','BRN',None),
    ('BSM','BSM',None),
    ('CAA','CAA',None),
    ('CAT','CAT',None),
    ('CIW','CIW',None),
    ('CNCP',None,None),
    ('CON','CON',None),
    ('COS','COS',None),
    ('CTC','CTC',None),
    ('CTL','CTL',None),
    ('CWT','CWT',None),
    ('DEV','DEV',None),
    ('DZC','DZC',None),
    ('DZP',None,None),
    ('EXP','EXP',None),
    ('F_CODE','F_CODE',None),
    ('FCO','FCO',None),
    ('FFN','FFN',None),
    ('FFN2','FFN2',None),
    ('FFN3','FFN3',None),
    ('FSC','FSC',None),
    ('FUFI',None,None),
    ('FURL',None,None),
    ('GDBV',None,None),
    ('GTC','GTC',None),
    ('HCA','HCA',None),
    ('HEI','HEI',None),
    ('HGT','HGT',None),
    ('HST','HST',None),
    ('HST2','HST2',None),
    ('HST3','HST3',None),
    ('LC1','LC1',None),
    ('LC2','LC2',None),
    ('LC3','LC3',None),
    ('LC4','LC4',None),
    ('LEA',None,None),
    ('LMC','LMC',None),
    ('LOC','LOC',None),
    ('LOG','LOG',None),
    ('LTN','LTN',None),
    ('LZN','LZN',None),
    ('MCC','MCC',None),
    ('MCC2','MCC2',None),
    ('MCC3','MCC3',None),
    ('MES','MES',None),
    ('MWG','MWG',None),
    ('NOS','NOS',None),
    ('OHC','OHC',None),
    ('ONE','ONE',None),
    ('OOC','OOC',None),
    ('OWO','OWO',None),
    ('PCF','PCF',None),
    ('PFH','PFH',None),
    ('PSN',None,None),
    ('PTG',None,None),
    ('RFD','RFD',None),
    ('RIN_ROI','RIN_ROI',None),
    ('RIN_ROI2','RIN_ROI2',None),
    ('RIN_ROI3','RIN_ROI3',None),
    ('RIN_RTN','RIN_RTN',None),
    ('RIN_RTN2','RIN_RTN2',None),
    ('RIN_RTN3','RIN_RTN3',None),
    ('RLE','RLE',None),
    ('RMWC','RMWC',None),
    ('RMWL','RMWL',None),
    ('RMWU','RMWU',None),
    ('ROR','ROR',None),
    ('RRC','RRC',None),
    ('RRC2','RRC2',None),
    ('RRC3','RRC3',None),
    ('RSA','RSA',None),
    ('RTA','RTA',None),
    ('RTN','RTN',None),
    ('RTN2','RTN2',None),
    ('RTN3','RTN3',None),
    ('RTY','RTY',None),
    ('RWC','RWC',None),
    ('SBB','SBB',None),
    ('SEP','SEP',None),
    ('SGCC','SGCC',None),
    ('SGCL','SGCL',None),
    ('SGCU','SGCU',None),
    ('SHC','SHC',None),
    ('SPD',None,None),
    ('SPM','SPM',None),
    ('SRE','SRE',None),
    ('TCS','TCS',None),
    ('THI','THI',None),
    ('THR','THR',None),
    ('TRA','TRA',None),
    ('TRP','TRP',None),
    ('TST','TST',None),
    ('UBC','UBC',None),
    ('UFI','UFI',None),
    ('VCM','VCM',None),
    ('VCM2','VCM2',None),
    ('VCM3','VCM3',None),
    ('VCO',None,None),
    ('VCS','VCS',None),
    ('VCS_VCD','VCS_VCD',None),
    ('VCS_VCR','VCS_VCR',None),
    ('VOI','VOI',None),
    ('WBD','WBD',None),
    ('WD1','WD1',None),
    ('WD2','WD2',None),
    ('WID','WID',None),
    ('WLE','WLE',None),
    ('WT2','WT2',None),
    ('WVA',None,None),
    ('ZI002_UFI',None,None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_GNT',None,None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZI016_ROC','ZI016_ROC',None),
    ('ZI016_WD1','ZI016_WD1',None),
    ('ZI017_GAW','ZI017_GAW',None),
    ('ZI017_RGC','ZI017_RGC',None),
    ('ZI017_RIR','ZI017_RIR',None),
    ('ZI017_RRA','ZI017_RRA',None),
    ('ZI017_TRT','ZI017_TRT',None),
    ('ZI020_GE4','ZI020_GE4',None),
    ('ZI025_HDP',None,None),
    ('ZI026_CTUC','ZI026_CTUC',None),
    ('ZI026_CTUL','ZI026_CTUL',None),
    ('ZI026_CTUU','ZI026_CTUU',None),
    ('ZI026_SUR','ZI026_SUR',None),
    ('ZI031S_URI',None,None),
    ('ZVH','ZVH',None),
    ('BSC','BSC','transform_BSC'),
    ('BSC2','BSC2','transform_BSC'),
    ('BSC3','BSC3','transform_BSC'),
    ('TRS','TRS','transform_TRS'),
    ('TRS2','TRS2','transform_TRS'),
    ('TRS3','TRS3','transform_TRS'),
    ('ZI016_WTC','ZI016_WTC','transform_CIW_to_ZI016_WTC') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# TransportationGroundPnt field translations
TransportationGroundPntFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Pnt_fields) + [ \
    ('ADI','ADI',None),
    ('ADR','ADR',None),
    ('AOO','AOO',None),
    ('ARA','ARA',None),
    ('ATB','ATB',None),
    ('AWP','AWP',None),
    ('BCC','BCC',None),
    ('BEN','BEN',None),
    ('BMC',None,None),
    ('BMC2',None,None),
    ('BMC3',None,None),
    ('BNF',None,None),
    ('BOT','BOT',None),
    ('BRN','BRN',None),
    ('BSM','BSM',None),
    ('CAA','CAA',None),
    ('CIW','CIW',None),
    ('CNCP',None,None),
    ('CON','CON',None),
    ('COS',None,None),
    ('CSC','CSC',None),
    ('CSC2','CSC2',None),
    ('CSC3','CSC3',None),
    ('CTC','CTC',None),
    ('CWT','CWT',None),
    ('DEV','DEV',None),
    ('DGC','DGC',None),
    ('DZC','DZC',None),
    ('EXP','EXP',None),
    ('F_CODE','F_CODE',None),
    ('FFN','FFN',None),
    ('FFN2','FFN2',None),
    ('FFN3','FFN3',None),
    ('FUFI',None,None),
    ('FURL',None,None),
    ('GDBV',None,None),
    ('GTC','GTC',None),
    ('HCA','HCA',None),
    ('HEI','HEI',None),
    ('HGT','HGT',None),
    ('HST','HST',None),
    ('HST2','HST2',None),
    ('HST3','HST3',None),
    ('LC1','LC1',None),
    ('LC2','LC2',None),
    ('LC3','LC3',None),
    ('LC4','LC4',None),
    ('LMC','LMC',None),
    ('LUN','LUN',None),
    ('LZN','LZN',None),
    ('MCC','MCC',None),
    ('MCC2','MCC2',None),
    ('MCC3','MCC3',None),
    ('MES','MES',None),
    ('MUB','MUB',None),
    ('NOS','NOS',None),
    ('OHC','OHC',None),
    ('OOC','OOC',None),
    ('PCF','PCF',None),
    ('PYM','PYM',None),
    ('RAD','RAD',None),
    ('RFD','RFD',None),
    ('RIN_ROI','RIN_ROI',None),
    ('RIN_ROI2','RIN_ROI2',None),
    ('RIN_ROI3','RIN_ROI3',None),
    ('RIN_RTN','RIN_RTN',None),
    ('RIN_RTN2','RIN_RTN2',None),
    ('RIN_RTN3','RIN_RTN3',None),
    ('RIT','RIT',None),
    ('SHC','SHC',None),
    ('SPT','SPT',None),
    ('SRE','SRE',None),
    ('SSG','SSG',None),
    ('SSR','SSR',None),
    ('SSR2','SSR2',None),
    ('SSR3','SSR3',None),
    ('TCS','TCS',None),
    ('THI','THI',None),
    ('TRP','TRP',None),
    ('UBC','UBC',None),
    ('UFI','UFI',None),
    ('VCM','VCM',None),
    ('VCM2','VCM2',None),
    ('VCM3','VCM3',None),
    ('VCO',None,None),
    ('VCS','VCS',None),
    ('VCS_VCD','VCS_VCD',None),
    ('VCS_VCR','VCS_VCR',None),
    ('VOI','VOI',None),
    ('WBD','WBD',None),
    ('WD1','WD1',None),
    ('WD2','WD2',None),
    ('WID','WID',None),
    ('WVA',None,None),
    ('ZI002_UFI',None,None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_GNT',None,None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZI016_ROC','ZI016_ROC',None),
    ('ZI017_GAW','ZI017_GAW',None),
    ('ZI017_RGC','ZI017_RGC',None),
    ('ZI017_RRA','ZI017_RRA',None),
    ('ZI017_TRT','ZI017_TRT',None),
    ('ZI020_GE4','ZI020_GE4',None),
    ('ZI026_CTUC','ZI026_CTUC',None),
    ('ZI026_CTUL','ZI026_CTUL',None),
    ('ZI026_CTUU','ZI026_CTUU',None),
    ('ZI031S_URI',None,None),
    ('ZVH','ZVH',None),
    ('BSC','BSC','transform_BSC'),
    ('BSC2','BSC2','transform_BSC'),
    ('BSC3','BSC3','transform_BSC'),
    ('TRS','TRS','transform_TRS'),
    ('TRS2','TRS2','transform_TRS'),
    ('TRS3','TRS3','transform_TRS'),
    ('ZI016_WTC','ZI016_WTC','transform_CIW_to_ZI016_WTC') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# TransportationGroundPntExt field translations
TransportationGroundPntExtFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Pnt_fields) + [ \
    ('ADR',None,None),
    ('AOO',None,None),
    ('ARA',None,None),
    ('BEN',None,None),
    ('CAA',None,None),
    ('CNCP',None,None),
    ('COS',None,None),
    ('CTL',None,None),
    ('F_CODE',None,None),
    ('FFN',None,None),
    ('FFN2',None,None),
    ('FFN3',None,None),
    ('FUFI',None,None),
    ('FURL',None,None),
    ('GDBV',None,None),
    ('HGT',None,None),
    ('LMC',None,None),
    ('LTN',None,None),
    ('LZN',None,None),
    ('MAN',None,None),
    ('PCF',None,None),
    ('TRS',None,None),
    ('TRS2',None,None),
    ('TRS3',None,None),
    ('UFI',None,None),
    ('WID',None,None),
    ('ZI002_UFI',None,None),
    ('ZI005_FNA',None,None),
    ('ZI005_GNT',None,None),
    ('ZI005_NFN',None,None),
    ('ZI017_GAW',None,None),
    ('ZI017_RGC',None,None),
    ('ZI017_RRA',None,None),
    ('ZI017_TRT',None,None),
    ('ZI020_GE4',None,None),
    ('ZI026_CTUC',None,None),
    ('ZI026_CTUL',None,None),
    ('ZI026_CTUU',None,None),
    ('ZI031S_URI',None,None),
    ('ZVH',None,None)
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# TransportationGroundSrf field translations
TransportationGroundSrfFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Srf_fields) + [ \
    ('ADR','ADR',None),
    ('AOO','AOO',None),
    ('ARA','ARA',None),
    ('ATB','ATB',None),
    ('AWP','AWP',None),
    ('BCC','BCC',None),
    ('BEN','BEN',None),
    ('BMC',None,None),
    ('BMC2',None,None),
    ('BMC3',None,None),
    ('BNF',None,None),
    ('BOT','BOT',None),
    ('BRN','BRN',None),
    ('BSM','BSM',None),
    ('CAA','CAA',None),
    ('CIW','CIW',None),
    ('CNCP',None,None),
    ('COS','COS',None),
    ('CSC','CSC',None),
    ('CSC2','CSC2',None),
    ('CSC3','CSC3',None),
    ('CTL','CTL',None),
    ('CWT','CWT',None),
    ('DEV','DEV',None),
    ('DGC','DGC',None),
    ('DZC','DZC',None),
    ('DZP',None,None),
    ('F_CODE','F_CODE',None),
    ('FCO','FCO',None),
    ('FFN','FFN',None),
    ('FFN2','FFN2',None),
    ('FFN3','FFN3',None),
    ('FSC','FSC',None),
    ('FUFI',None,None),
    ('FURL',None,None),
    ('GDBV',None,None),
    ('HCA','HCA',None),
    ('HEI','HEI',None),
    ('HGT','HGT',None),
    ('HST','HST',None),
    ('HST2','HST2',None),
    ('HST3','HST3',None),
    ('LC1','LC1',None),
    ('LC2','LC2',None),
    ('LC3','LC3',None),
    ('LC4','LC4',None),
    ('LEA',None,None),
    ('LMC','LMC',None),
    ('LOC','LOC',None),
    ('LTN','LTN',None),
    ('LUN','LUN',None),
    ('LZN','LZN',None),
    ('MCC','MCC',None),
    ('MCC2','MCC2',None),
    ('MCC3','MCC3',None),
    ('MES','MES',None),
    ('MUB','MUB',None),
    ('MWG','MWG',None),
    ('NOS','NOS',None),
    ('OHC','OHC',None),
    ('ONE','ONE',None),
    ('PCF','PCF',None),
    ('PSN',None,None),
    ('PTG',None,None),
    ('RFD','RFD',None),
    ('RIN_ROI','RIN_ROI',None),
    ('RIN_ROI2','RIN_ROI2',None),
    ('RIN_ROI3','RIN_ROI3',None),
    ('RIN_RTN','RIN_RTN',None),
    ('RIN_RTN2','RIN_RTN2',None),
    ('RIN_RTN3','RIN_RTN3',None),
    ('RLE','RLE',None),
    ('RMWC','RMWC',None),
    ('RMWL','RMWL',None),
    ('RMWU','RMWU',None),
    ('ROR','ROR',None),
    ('RTN','RTN',None),
    ('RTN2','RTN2',None),
    ('RTN3','RTN3',None),
    ('RTY','RTY',None),
    ('SBB','SBB',None),
    ('SEP','SEP',None),
    ('SGCC','SGCC',None),
    ('SGCL','SGCL',None),
    ('SGCU','SGCU',None),
    ('SPD',None,None),
    ('SPM','SPM',None),
    ('SPT','SPT',None),
    ('SSR','SSR',None),
    ('SSR2','SSR2',None),
    ('SSR3','SSR3',None),
    ('THR','THR',None),
    ('TRA','TRA',None),
    ('TRP','TRP',None),
    ('UBC','UBC',None),
    ('UFI','UFI',None),
    ('VCM','VCM',None),
    ('VCM2','VCM2',None),
    ('VCM3','VCM3',None),
    ('VCO',None,None),
    ('VCS','VCS',None),
    ('VCS_VCD','VCS_VCD',None),
    ('VCS_VCR','VCS_VCR',None),
    ('VET','VET',None),
    ('VOI','VOI',None),
    ('WBD','WBD',None),
    ('WD2','WD2',None),
    ('WID','WID',None),
    ('WLE','WLE',None),
    ('WT2','WT2',None),
    ('WVA',None,None),
    ('ZI002_UFI',None,None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_GNT',None,None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZI016_ROC','ZI016_ROC',None),
    ('ZI016_WD1','ZI016_WD1',None),
    ('ZI017_GAW','ZI017_GAW',None),
    ('ZI017_RGC','ZI017_RGC',None),
    ('ZI017_RRA','ZI017_RRA',None),
    ('ZI017_TRT','ZI017_TRT',None),
    ('ZI020_GE4','ZI020_GE4',None),
    ('ZI025_HDP',None,None),
    ('ZI026_CTUC','ZI026_CTUC',None),
    ('ZI026_CTUL','ZI026_CTUL',None),
    ('ZI026_CTUU','ZI026_CTUU',None),
    ('ZI026_SUR','ZI026_SUR',None),
    ('ZI031S_URI',None,None),
    ('ZVH','ZVH',None),
    ('BSC','BSC','transform_BSC'),
    ('BSC2','BSC2','transform_BSC'),
    ('BSC3','BSC3','transform_BSC'),
    ('TRS','TRS','transform_TRS'),
    ('TRS2','TRS2','transform_TRS'),
    ('TRS3','TRS3','transform_TRS'),
    ('ZI016_WTC','ZI016_WTC','transform_CIW_to_ZI016_WTC') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# TransportationWaterAONExt field translations
TransportationWaterAONExtFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Srf_fields) + [ \
    ('ARA',None,None),
    ('BBMCA',None,None),
    ('BBMCA2',None,None),
    ('BBMCA3',None,None),
    ('BBMCB',None,None),
    ('BBMCB2',None,None),
    ('BBMCB3',None,None),
    ('BEN',None,None),
    ('BH141_AWBA',None,None),
    ('BH141_AWBB',None,None),
    ('BH141_IBOA',None,None),
    ('BH141_IBOB',None,None),
    ('BH141_SHDA',None,None),
    ('BH141_SHDB',None,None),
    ('BH141_SLTA',None,None),
    ('BH141_SLTB',None,None),
    ('BH141_WBHA',None,None),
    ('BH141_WBHB',None,None),
    ('BMC',None,None),
    ('BMC2',None,None),
    ('BMC3',None,None),
    ('BPWHAC',None,None),
    ('BPWHAL',None,None),
    ('BPWHAU',None,None),
    ('BPWHBC',None,None),
    ('BPWHBL',None,None),
    ('BPWHBU',None,None),
    ('BPWSAC',None,None),
    ('BPWSAL',None,None),
    ('BPWSAU',None,None),
    ('BPWSBC',None,None),
    ('BPWSBL',None,None),
    ('BPWSBU',None,None),
    ('BWVCAC',None,None),
    ('BWVCAL',None,None),
    ('BWVCAU',None,None),
    ('BWVCBC',None,None),
    ('BWVCBL',None,None),
    ('BWVCBU',None,None),
    ('CAA',None,None),
    ('CDA',None,None),
    ('CDL',None,None),
    ('CNCP',None,None),
    ('COS',None,None),
    ('CWT',None,None),
    ('DEV',None,None),
    ('DMF',None,None),
    ('DOXY',None,None),
    ('DZP',None,None),
    ('F_CODE',None,None),
    ('FRZ',None,None),
    ('FUFI',None,None),
    ('FURL',None,None),
    ('GDBV',None,None),
    ('HDP',None,None),
    ('HGT',None,None),
    ('LEA',None,None),
    ('LMC',None,None),
    ('LOC',None,None),
    ('LZN',None,None),
    ('MWD',None,None),
    ('NVS',None,None),
    ('PCF',None,None),
    ('PWA',None,None),
    ('RLE',None,None),
    ('SBB',None,None),
    ('UFI',None,None),
    ('WD3',None,None),
    ('WDAC',None,None),
    ('WDAL',None,None),
    ('WDAU',None,None),
    ('WDH',None,None),
    ('WDL',None,None),
    ('WID',None,None),
    ('WVA',None,None),
    ('WVH',None,None),
    ('WVL',None,None),
    ('ZI002_UFI',None,None),
    ('ZI005_FNA',None,None),
    ('ZI005_FNA2',None,None),
    ('ZI005_FNA3',None,None),
    ('ZI005_GNT',None,None),
    ('ZI005_GNT2',None,None),
    ('ZI005_GNT3',None,None),
    ('ZI005_NFN',None,None),
    ('ZI005_NFN2',None,None),
    ('ZI005_NFN3',None,None),
    ('ZI020_GE4',None,None),
    ('ZI024_ASE',None,None),
    ('ZI024_AWO',None,None),
    ('ZI024_AWOI',None,None),
    ('ZI024_AWOX',None,None),
    ('ZI024_CFR',None,None),
    ('ZI024_CLO',None,None),
    ('ZI024_CYN',None,None),
    ('ZI024_FMR',None,None),
    ('ZI024_FRR',None,None),
    ('ZI024_HAR',None,None),
    ('ZI024_HYP',None,None),
    ('ZI024_MGN',None,None),
    ('ZI024_PHW',None,None),
    ('ZI024_SCC',None,None),
    ('ZI024_SQN',None,None),
    ('ZI024_SUL',None,None),
    ('ZI024_TDS',None,None),
    ('ZI024_TEP',None,None),
    ('ZI024_TUR',None,None),
    ('ZI024_WAC',None,None),
    ('ZI024_WPAC',None,None),
    ('ZI024_WSG',None,None),
    ('ZI024_WTNO',None,None),
    ('ZI024_WUR',None,None),
    ('ZI024_WUR2',None,None),
    ('ZI024_WUR3',None,None),
    ('ZI024_WUR4',None,None),
    ('ZI024_YWQ',None,None),
    ('ZI026_CTUC',None,None),
    ('ZI026_CTUL',None,None),
    ('ZI026_CTUU',None,None),
    ('ZI031S_URI',None,None),
    ('ZVH',None,None)
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# TransportationWaterCrv field translations
TransportationWaterCrvFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Crv_fields) + [ \
    ('AOO','AOO',None),
    ('ARA','ARA',None),
    ('AWP','AWP',None),
    ('BBMCA',None,None),
    ('BBMCA2',None,None),
    ('BBMCA3',None,None),
    ('BBMCB',None,None),
    ('BBMCB2',None,None),
    ('BBMCB3',None,None),
    ('BEN','BEN',None),
    ('BGT','BGT',None),
    ('BH141_AWBA','BH141_AWBA',None),
    ('BH141_AWBB','BH141_AWBB',None),
    ('BH141_IBOA','BH141_IBOA',None),
    ('BH141_IBOB','BH141_IBOB',None),
    ('BH141_SHDA','BH141_SHDA',None),
    ('BH141_SHDB','BH141_SHDB',None),
    ('BH141_SLTA','BH141_SLTA',None),
    ('BH141_SLTB','BH141_SLTB',None),
    ('BH141_WBHA','BH141_WBHA',None),
    ('BH141_WBHB','BH141_WBHB',None),
    ('BMC','BMC',None),
    ('BMC2','BMC2',None),
    ('BMC3','BMC3',None),
    ('BPWHAC','BPWHAC',None),
    ('BPWHAL','BPWHAL',None),
    ('BPWHAU','BPWHAU',None),
    ('BPWHBC','BPWHBC',None),
    ('BPWHBL','BPWHBL',None),
    ('BPWHBU','BPWHBU',None),
    ('BPWSAC','BPWSAC',None),
    ('BPWSAL','BPWSAL',None),
    ('BPWSAU','BPWSAU',None),
    ('BPWSBC','BPWSBC',None),
    ('BPWSBL','BPWSBL',None),
    ('BPWSBU','BPWSBU',None),
    ('BWVCAC','BWVCAC',None),
    ('BWVCAL','BWVCAL',None),
    ('BWVCAU','BWVCAU',None),
    ('BWVCBC','BWVCBC',None),
    ('BWVCBL','BWVCBL',None),
    ('BWVCBU','BWVCBU',None),
    ('CAA','CAA',None),
    ('CDA','CDA',None),
    ('CDL','CDL',None),
    ('CNCP',None,None),
    ('COS','COS',None),
    ('CWT','CWT',None),
    ('DEV','DEV',None),
    ('DOXY',None,None),
    ('DZP',None,None),
    ('F_CODE','F_CODE',None),
    ('FCL','FCL',None),
    ('FER','FER',None),
    ('FRZ',None,None),
    ('FUFI',None,None),
    ('FURL',None,None),
    ('GDBV',None,None),
    ('HDP',None,None),
    ('HEI','HEI',None),
    ('HGT','HGT',None),
    ('LEA',None,None),
    ('LMC','LMC',None),
    ('LNU','LNU',None),
    ('LOC','LOC',None),
    ('LZN','LZN',None),
    ('MCC','MCC',None),
    ('MCC2','MCC2',None),
    ('MCC3','MCC3',None),
    ('MCX','MCX',None),
    ('MWD','MWD',None),
    ('NVS','NVS',None),
    ('OPT','OPT',None),
    ('PCF','PCF',None),
    ('PSN',None,None),
    ('PWA','PWA',None),
    ('RIN_ROI','RIN_ROI',None),
    ('RIN_ROI2','RIN_ROI2',None),
    ('RIN_ROI3','RIN_ROI3',None),
    ('RIN_RTN','RIN_RTN',None),
    ('RIN_RTN2','RIN_RTN2',None),
    ('RIN_RTN3','RIN_RTN3',None),
    ('RLE','RLE',None),
    ('SBB','SBB',None),
    ('SPD',None,None),
    ('SPM',None,None),
    ('THI','THI',None),
    ('TID',None,None),
    ('UFI','UFI',None),
    ('VOI','VOI',None),
    ('WD3','WD3',None),
    ('WDAC',None,None),
    ('WDAL',None,None),
    ('WDAU',None,None),
    ('WDH','WDH',None),
    ('WDL','WDL',None),
    ('WDU','WDU',None),
    ('WID','WID',None),
    ('WVA','WVA',None),
    ('WVH','WVH',None),
    ('WVL','WVL',None),
    ('ZI002_UFI',None,None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_FNA2',None,None),
    ('ZI005_FNA3',None,None),
    ('ZI005_GNT',None,None),
    ('ZI005_GNT2',None,None),
    ('ZI005_GNT3',None,None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZI005_NFN2',None,None),
    ('ZI005_NFN3',None,None),
    ('ZI020_GE4','ZI020_GE4',None),
    ('ZI024_ASE',None,None),
    ('ZI024_AWO',None,None),
    ('ZI024_AWOI',None,None),
    ('ZI024_AWOX',None,None),
    ('ZI024_CFR',None,None),
    ('ZI024_CLO',None,None),
    ('ZI024_CYN',None,None),
    ('ZI024_FMR',None,None),
    ('ZI024_FRR',None,None),
    ('ZI024_HAR',None,None),
    ('ZI024_HYP','ZI024_HYP',None),
    ('ZI024_MGN',None,None),
    ('ZI024_PHW',None,None),
    ('ZI024_SCC',None,None),
    ('ZI024_SQN',None,None),
    ('ZI024_SUL',None,None),
    ('ZI024_TDS',None,None),
    ('ZI024_TEP',None,None),
    ('ZI024_TUR',None,None),
    ('ZI024_WAC',None,None),
    ('ZI024_WPAC',None,None),
    ('ZI024_WSG',None,None),
    ('ZI024_WTNO',None,None),
    ('ZI024_WUR',None,None),
    ('ZI024_WUR2',None,None),
    ('ZI024_WUR3',None,None),
    ('ZI024_WUR4',None,None),
    ('ZI024_YWQ','ZI024_YWQ',None),
    ('ZI026_CTUC','ZI026_CTUC',None),
    ('ZI026_CTUL','ZI026_CTUL',None),
    ('ZI026_CTUU','ZI026_CTUU',None),
    ('ZI031S_URI',None,None),
    ('ZVH','ZVH',None),
    ('TRS','TRS','transform_TRS'),
    ('TRS2','TRS2','transform_TRS'),
    ('TRS3','TRS3','transform_TRS') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# TransportationWaterPnt field translations
TransportationWaterPntFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Pnt_fields) + [ \
    ('ADR','ADR',None),
    ('AOO','AOO',None),
    ('ARA','ARA',None),
    ('ATB','ATB',None),
    ('AWP','AWP',None),
    ('BEN','BEN',None),
    ('BGT','BGT',None),
    ('CAA','CAA',None),
    ('CNCP',None,None),
    ('COS',None,None),
    ('DZP',None,None),
    ('F_CODE','F_CODE',None),
    ('FFN','FFN',None),
    ('FFN2','FFN2',None),
    ('FFN3','FFN3',None),
    ('FUFI',None,None),
    ('FURL',None,None),
    ('GDBV',None,None),
    ('HDP',None,None),
    ('HEI','HEI',None),
    ('HGT','HGT',None),
    ('HST','HST',None),
    ('HST2','HST2',None),
    ('HST3','HST3',None),
    ('LMC','LMC',None),
    ('LNU','LNU',None),
    ('LZN','LZN',None),
    ('MCC','MCC',None),
    ('MCC2','MCC2',None),
    ('MCC3','MCC3',None),
    ('MUB','MUB',None),
    ('MWD','MWD',None),
    ('PCF','PCF',None),
    ('SSR','SSR',None),
    ('SSR2','SSR2',None),
    ('SSR3','SSR3',None),
    ('THI','THI',None),
    ('UFI','UFI',None),
    ('VOI','VOI',None),
    ('WDU','WDU',None),
    ('WID','WID',None),
    ('ZI002_UFI',None,None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_GNT',None,None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZI020_GE4','ZI020_GE4',None),
    ('ZI026_CTUC','ZI026_CTUC',None),
    ('ZI026_CTUL','ZI026_CTUL',None),
    ('ZI026_CTUU','ZI026_CTUU',None),
    ('ZI031S_URI',None,None),
    ('ZVH','ZVH',None),
    ('TRS','TRS','transform_TRS'),
    ('TRS2','TRS2','transform_TRS'),
    ('TRS3','TRS3','transform_TRS') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# TransportationWaterPntExt field translations
TransportationWaterPntExtFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Pnt_fields) + [ \
    ('AOO',None,None),
    ('BEN',None,None),
    ('CAA',None,None),
    ('CNCP',None,None),
    ('COS',None,None),
    ('F_CODE',None,None),
    ('FCL',None,None),
    ('FER',None,None),
    ('FUFI',None,None),
    ('FURL',None,None),
    ('GDBV',None,None),
    ('LMC',None,None),
    ('LZN',None,None),
    ('MCX',None,None),
    ('OPT',None,None),
    ('PSN',None,None),
    ('RIN_ROI',None,None),
    ('RIN_ROI2',None,None),
    ('RIN_ROI3',None,None),
    ('RIN_RTN',None,None),
    ('RIN_RTN2',None,None),
    ('RIN_RTN3',None,None),
    ('SPD',None,None),
    ('SPM',None,None),
    ('TRS',None,None),
    ('TRS2',None,None),
    ('TRS3',None,None),
    ('UFI',None,None),
    ('ZI002_UFI',None,None),
    ('ZI005_FNA',None,None),
    ('ZI005_GNT',None,None),
    ('ZI005_NFN',None,None),
    ('ZI020_GE4',None,None),
    ('ZI026_CTUC',None,None),
    ('ZI026_CTUL',None,None),
    ('ZI026_CTUU',None,None),
    ('ZI031S_URI',None,None)
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# TransportationWaterSrf field translations
TransportationWaterSrfFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Srf_fields) + [ \
    ('ADR','ADR',None),
    ('AOO','AOO',None),
    ('ARA','ARA',None),
    ('ATB','ATB',None),
    ('AWP','AWP',None),
    ('BBMCA',None,None),
    ('BBMCA2',None,None),
    ('BBMCA3',None,None),
    ('BBMCB',None,None),
    ('BBMCB2',None,None),
    ('BBMCB3',None,None),
    ('BEN','BEN',None),
    ('BH141_AWBA','BH141_AWBA',None),
    ('BH141_AWBB','BH141_AWBB',None),
    ('BH141_IBOA','BH141_IBOA',None),
    ('BH141_IBOB','BH141_IBOB',None),
    ('BH141_SHDA','BH141_SHDA',None),
    ('BH141_SHDB','BH141_SHDB',None),
    ('BH141_SLTA','BH141_SLTA',None),
    ('BH141_SLTB','BH141_SLTB',None),
    ('BH141_WBHA','BH141_WBHA',None),
    ('BH141_WBHB','BH141_WBHB',None),
    ('BMC','BMC',None),
    ('BMC2','BMC2',None),
    ('BMC3','BMC3',None),
    ('BPWHAC','BPWHAC',None),
    ('BPWHAL','BPWHAL',None),
    ('BPWHAU','BPWHAU',None),
    ('BPWHBC','BPWHBC',None),
    ('BPWHBL','BPWHBL',None),
    ('BPWHBU','BPWHBU',None),
    ('BPWSAC','BPWSAC',None),
    ('BPWSAL','BPWSAL',None),
    ('BPWSAU','BPWSAU',None),
    ('BPWSBC','BPWSBC',None),
    ('BPWSBL','BPWSBL',None),
    ('BPWSBU','BPWSBU',None),
    ('BWVCAC','BWVCAC',None),
    ('BWVCAL','BWVCAL',None),
    ('BWVCAU','BWVCAU',None),
    ('BWVCBC','BWVCBC',None),
    ('BWVCBL','BWVCBL',None),
    ('BWVCBU','BWVCBU',None),
    ('CAA','CAA',None),
    ('CDA','CDA',None),
    ('CDL','CDL',None),
    ('CNCP',None,None),
    ('COS','COS',None),
    ('CWT','CWT',None),
    ('DEV','DEV',None),
    ('DOXY',None,None),
    ('DZP',None,None),
    ('F_CODE','F_CODE',None),
    ('FFN','FFN',None),
    ('FFN2','FFN2',None),
    ('FFN3','FFN3',None),
    ('FRZ',None,None),
    ('FUFI',None,None),
    ('FURL',None,None),
    ('GDBV',None,None),
    ('HDP',None,None),
    ('HGT','HGT',None),
    ('HST','HST',None),
    ('HST2','HST2',None),
    ('HST3','HST3',None),
    ('LEA',None,None),
    ('LMC','LMC',None),
    ('LNU','LNU',None),
    ('LOC','LOC',None),
    ('LZN','LZN',None),
    ('MCC','MCC',None),
    ('MCC2','MCC2',None),
    ('MCC3','MCC3',None),
    ('MUB','MUB',None),
    ('MWD','MWD',None),
    ('NVS','NVS',None),
    ('PCF','PCF',None),
    ('PWA','PWA',None),
    ('RLE','RLE',None),
    ('SBB','SBB',None),
    ('SSR','SSR',None),
    ('SSR2','SSR2',None),
    ('SSR3','SSR3',None),
    ('TID',None,None),
    ('UFI','UFI',None),
    ('VOI','VOI',None),
    ('WD3','WD3',None),
    ('WDAC',None,None),
    ('WDAL',None,None),
    ('WDAU',None,None),
    ('WDH','WDH',None),
    ('WDL','WDL',None),
    ('WDU','WDU',None),
    ('WID','WID',None),
    ('WVA','WVA',None),
    ('WVH','WVH',None),
    ('WVL','WVL',None),
    ('ZI002_UFI',None,None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_FNA2',None,None),
    ('ZI005_FNA3',None,None),
    ('ZI005_GNT',None,None),
    ('ZI005_GNT2',None,None),
    ('ZI005_GNT3',None,None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZI005_NFN2',None,None),
    ('ZI005_NFN3',None,None),
    ('ZI020_GE4','ZI020_GE4',None),
    ('ZI024_ASE',None,None),
    ('ZI024_AWO',None,None),
    ('ZI024_AWOI',None,None),
    ('ZI024_AWOX',None,None),
    ('ZI024_CFR',None,None),
    ('ZI024_CLO',None,None),
    ('ZI024_CYN',None,None),
    ('ZI024_FMR',None,None),
    ('ZI024_FRR',None,None),
    ('ZI024_HAR',None,None),
    ('ZI024_HYP','ZI024_HYP',None),
    ('ZI024_MGN',None,None),
    ('ZI024_PHW',None,None),
    ('ZI024_SCC',None,None),
    ('ZI024_SQN',None,None),
    ('ZI024_SUL',None,None),
    ('ZI024_TDS',None,None),
    ('ZI024_TEP',None,None),
    ('ZI024_TUR',None,None),
    ('ZI024_WAC',None,None),
    ('ZI024_WPAC',None,None),
    ('ZI024_WSG',None,None),
    ('ZI024_WTNO',None,None),
    ('ZI024_WUR',None,None),
    ('ZI024_WUR2',None,None),
    ('ZI024_WUR3',None,None),
    ('ZI024_WUR4',None,None),
    ('ZI024_YWQ','ZI024_YWQ',None),
    ('ZI026_CTUC','ZI026_CTUC',None),
    ('ZI026_CTUL','ZI026_CTUL',None),
    ('ZI026_CTUU','ZI026_CTUU',None),
    ('ZI031S_URI',None,None),
    ('ZVH','ZVH',None),
    ('TRS','TRS','transform_TRS'),
    ('TRS2','TRS2','transform_TRS'),
    ('TRS3','TRS3','transform_TRS') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# UtilityInfrastructureAONExt field translations
UtilityInfrastructureAONExtFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Srf_fields) + [ \
    ('ARA',None,None),
    ('BEN',None,None),
    ('CAA',None,None),
    ('CNCP',None,None),
    ('COS',None,None),
    ('CWT',None,None),
    ('DEV',None,None),
    ('DIM',None,None),
    ('DMF',None,None),
    ('DZP',None,None),
    ('F_CODE',None,None),
    ('FFN',None,None),
    ('FFN2',None,None),
    ('FFN3',None,None),
    ('FLO',None,None),
    ('FUFI',None,None),
    ('FURL',None,None),
    ('GDBV',None,None),
    ('HGT',None,None),
    ('LEA',None,None),
    ('LMC',None,None),
    ('LOC',None,None),
    ('LUN',None,None),
    ('LZN',None,None),
    ('MCC',None,None),
    ('MCC2',None,None),
    ('MCC3',None,None),
    ('NPL',None,None),
    ('OWO',None,None),
    ('PCF',None,None),
    ('PLT',None,None),
    ('PLT2',None,None),
    ('PLT3',None,None),
    ('PMPR',None,None),
    ('PPO',None,None),
    ('PPO2',None,None),
    ('PPO3',None,None),
    ('RLE',None,None),
    ('RTA',None,None),
    ('SBB',None,None),
    ('SPT',None,None),
    ('UFI',None,None),
    ('VCM',None,None),
    ('VCM2',None,None),
    ('VCM3',None,None),
    ('WDAC',None,None),
    ('WDAL',None,None),
    ('WDAU',None,None),
    ('WDH',None,None),
    ('WDL',None,None),
    ('WID',None,None),
    ('WVA',None,None),
    ('ZI002_UFI',None,None),
    ('ZI005_FNA',None,None),
    ('ZI005_FNA2',None,None),
    ('ZI005_FNA3',None,None),
    ('ZI005_GNT',None,None),
    ('ZI005_GNT2',None,None),
    ('ZI005_GNT3',None,None),
    ('ZI005_NFN',None,None),
    ('ZI005_NFN2',None,None),
    ('ZI005_NFN3',None,None),
    ('ZI020_GE4',None,None),
    ('ZI024_ASE',None,None),
    ('ZI024_AWO',None,None),
    ('ZI024_AWOI',None,None),
    ('ZI024_AWOX',None,None),
    ('ZI024_CFR',None,None),
    ('ZI024_CLO',None,None),
    ('ZI024_CYN',None,None),
    ('ZI024_DRL',None,None),
    ('ZI024_DVPT',None,None),
    ('ZI024_FMR',None,None),
    ('ZI024_FRR',None,None),
    ('ZI024_HAR',None,None),
    ('ZI024_MGN',None,None),
    ('ZI024_PHW',None,None),
    ('ZI024_PMP',None,None),
    ('ZI024_SCC',None,None),
    ('ZI024_SUL',None,None),
    ('ZI024_TDS',None,None),
    ('ZI024_TEP',None,None),
    ('ZI024_TUR',None,None),
    ('ZI024_WAC',None,None),
    ('ZI024_WTNO',None,None),
    ('ZI024_WUR',None,None),
    ('ZI024_WUR2',None,None),
    ('ZI024_WUR3',None,None),
    ('ZI024_WUR4',None,None),
    ('ZI024_YWQ',None,None),
    ('ZI025_HDP',None,None),
    ('ZI026_CTUC',None,None),
    ('ZI026_CTUL',None,None),
    ('ZI026_CTUU',None,None),
    ('ZI031S_URI',None,None),
    ('ZVH',None,None)
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# UtilityInfrastructureCrv field translations
UtilityInfrastructureCrvFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Crv_fields) + [ \
    ('AWP','AWP',None),
    ('BEN','BEN',None),
    ('CAA','CAA',None),
    ('CAB','CAB',None),
    ('CAB2','CAB2',None),
    ('CAB3','CAB3',None),
    ('CNCP',None,None),
    ('COS',None,None),
    ('CST','CST',None),
    ('CWT','CWT',None),
    ('DEV','DEV',None),
    ('DIM','DIM',None),
    ('DZP',None,None),
    ('F_CODE','F_CODE',None),
    ('FLO','FLO',None),
    ('FUFI',None,None),
    ('FURL',None,None),
    ('GDBV',None,None),
    ('HGT','HGT',None),
    ('KVA','KVA',None),
    ('LEA',None,None),
    ('LMC','LMC',None),
    ('LOC','LOC',None),
    ('LZN','LZN',None),
    ('MCC',None,None),
    ('MCC2',None,None),
    ('MCC3',None,None),
    ('NPL','NPL',None),
    ('OHC','OHC',None),
    ('OWO','OWO',None),
    ('PCF','PCF',None),
    ('PFH','PFH',None),
    ('PLT','PLT',None),
    ('PLT2','PLT2',None),
    ('PLT3','PLT3',None),
    ('PMPR',None,None),
    ('PPO','PPO',None),
    ('PPO2','PPO2',None),
    ('PPO3','PPO3',None),
    ('RLE','RLE',None),
    ('RTA','RTA',None),
    ('SBB','SBB',None),
    ('SPT','SPT',None),
    ('TST','TST',None),
    ('UFI','UFI',None),
    ('VCO',None,None),
    ('VOI','VOI',None),
    ('WVA',None,None),
    ('ZI002_UFI',None,None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_FNA2',None,None),
    ('ZI005_FNA3',None,None),
    ('ZI005_GNT',None,None),
    ('ZI005_GNT2',None,None),
    ('ZI005_GNT3',None,None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZI005_NFN2',None,None),
    ('ZI005_NFN3',None,None),
    ('ZI020_GE4','ZI020_GE4',None),
    ('ZI024_ASE',None,None),
    ('ZI024_AWO',None,None),
    ('ZI024_AWOI',None,None),
    ('ZI024_AWOX',None,None),
    ('ZI024_CFR',None,None),
    ('ZI024_CLO',None,None),
    ('ZI024_CYN',None,None),
    ('ZI024_FMR',None,None),
    ('ZI024_FRR',None,None),
    ('ZI024_HAR',None,None),
    ('ZI024_MGN',None,None),
    ('ZI024_PHW',None,None),
    ('ZI024_SCC',None,None),
    ('ZI024_SUL',None,None),
    ('ZI024_TDS',None,None),
    ('ZI024_TEP',None,None),
    ('ZI024_TUR',None,None),
    ('ZI024_WAC',None,None),
    ('ZI024_WTNO',None,None),
    ('ZI024_WUR',None,None),
    ('ZI024_WUR2',None,None),
    ('ZI024_WUR3',None,None),
    ('ZI024_WUR4',None,None),
    ('ZI024_YWQ',None,None),
    ('ZI025_HDP',None,None),
    ('ZI025_WLE','ZI025_WLE',None),
    ('ZI026_CTUC','ZI026_CTUC',None),
    ('ZI026_CTUL','ZI026_CTUL',None),
    ('ZI026_CTUU','ZI026_CTUU',None),
    ('ZI031S_URI',None,None),
    ('ZVH','ZVH',None)
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# UtilityInfrastructurePnt field translations
UtilityInfrastructurePntFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Pnt_fields) + [ \
    ('ADR','ADR',None),
    ('ADUR',None,None),
    ('ANFL',None,None),
    ('AOO','AOO',None),
    ('ARA','ARA',None),
    ('AT005_CAB','AT005_CAB',None),
    ('AT005_CAB2','AT005_CAB2',None),
    ('AT005_CAB3','AT005_CAB3',None),
    ('AWP','AWP',None),
    ('BEN','BEN',None),
    ('CAA','CAA',None),
    ('CNCP',None,None),
    ('COS',None,None),
    ('DCAP',None,None),
    ('DIM','DIM',None),
    ('DINF',None,None),
    ('DZP',None,None),
    ('EPW','EPW',None),
    ('F_CODE','F_CODE',None),
    ('FFN','FFN',None),
    ('FFN2','FFN2',None),
    ('FFN3','FFN3',None),
    ('FUFI',None,None),
    ('FURL',None,None),
    ('GDBV',None,None),
    ('GRD',None,None),
    ('GUG','GUG',None),
    ('HEI','HEI',None),
    ('HGT','HGT',None),
    ('LEA',None,None),
    ('LMC','LMC',None),
    ('LUN',None,None),
    ('LZN','LZN',None),
    ('MCC','MCC',None),
    ('MCC2','MCC2',None),
    ('MCC3','MCC3',None),
    ('PCF','PCF',None),
    ('POS','POS',None),
    ('POS2','POS2',None),
    ('POS3','POS3',None),
    ('PPO','PPO',None),
    ('PPO2','PPO2',None),
    ('PPO3','PPO3',None),
    ('RAC','RAC',None),
    ('SBT','SBT',None),
    ('SBT2','SBT2',None),
    ('SBT3','SBT3',None),
    ('SPT','SPT',None),
    ('SRL','SRL',None),
    ('SSR','SSR',None),
    ('SSR2','SSR2',None),
    ('SSR3','SSR3',None),
    ('TOS','TOS',None),
    ('UFI','UFI',None),
    ('UTY','UTY',None),
    ('UTY2','UTY2',None),
    ('UTY3','UTY3',None),
    ('VCM','VCM',None),
    ('VCM2','VCM2',None),
    ('VCM3','VCM3',None),
    ('VOI','VOI',None),
    ('WDAC',None,None),
    ('WDAL',None,None),
    ('WDAU',None,None),
    ('WDH',None,None),
    ('WDL',None,None),
    ('WDST',None,None),
    ('WID','WID',None),
    ('WLSS',None,None),
    ('ZI002_UFI',None,None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_FNA2',None,None),
    ('ZI005_FNA3',None,None),
    ('ZI005_GNT',None,None),
    ('ZI005_GNT2',None,None),
    ('ZI005_GNT3',None,None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZI005_NFN2',None,None),
    ('ZI005_NFN3',None,None),
    ('ZI014_PBY',None,None),
    ('ZI014_PBY2',None,None),
    ('ZI014_PBY3',None,None),
    ('ZI018_WIT','ZI018_WIT',None),
    ('ZI020_GE4','ZI020_GE4',None),
    ('ZI024_ASE',None,None),
    ('ZI024_AWO',None,None),
    ('ZI024_AWOI',None,None),
    ('ZI024_AWOX',None,None),
    ('ZI024_CFR',None,None),
    ('ZI024_CLO',None,None),
    ('ZI024_CYN',None,None),
    ('ZI024_DRL',None,None),
    ('ZI024_DVPT',None,None),
    ('ZI024_FMR',None,None),
    ('ZI024_FRR',None,None),
    ('ZI024_HAR',None,None),
    ('ZI024_MGN',None,None),
    ('ZI024_PHW',None,None),
    ('ZI024_PMP',None,None),
    ('ZI024_PUR',None,None),
    ('ZI024_PUR2',None,None),
    ('ZI024_PUR3',None,None),
    ('ZI024_PUR4',None,None),
    ('ZI024_PUR5',None,None),
    ('ZI024_SCC',None,None),
    ('ZI024_SUL',None,None),
    ('ZI024_TDS',None,None),
    ('ZI024_TEP',None,None),
    ('ZI024_TUR',None,None),
    ('ZI024_WAC',None,None),
    ('ZI024_WTNO',None,None),
    ('ZI024_WUR',None,None),
    ('ZI024_WUR2',None,None),
    ('ZI024_WUR3',None,None),
    ('ZI024_WUR4',None,None),
    ('ZI024_YWQ',None,None),
    ('ZI026_CTUC','ZI026_CTUC',None),
    ('ZI026_CTUL','ZI026_CTUL',None),
    ('ZI026_CTUU','ZI026_CTUU',None),
    ('ZI031S_URI',None,None),
    ('ZI032_GUG','ZI032_GUG',None),
    ('ZI032_PYC','ZI032_PYC',None),
    ('ZI032_PYM','ZI032_PYM',None),
    ('ZI032_TOS','ZI032_TOS',None),
    ('ZVH','ZVH',None)
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# UtilityInfrastructurePntExt field translations
UtilityInfrastructurePntExtFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Pnt_fields) + [ \
    ('BEN',None,None),
    ('CAA',None,None),
    ('CNCP',None,None),
    ('COS',None,None),
    ('DZP',None,None),
    ('F_CODE',None,None),
    ('FUFI',None,None),
    ('FURL',None,None),
    ('GDBV',None,None),
    ('HGT',None,None),
    ('HSCD',None,None),
    ('LMC',None,None),
    ('LUN',None,None),
    ('LZN',None,None),
    ('PCF',None,None),
    ('SPT',None,None),
    ('UFI',None,None),
    ('ZI002_UFI',None,None),
    ('ZI005_FNA',None,None),
    ('ZI005_GNT',None,None),
    ('ZI005_NFN',None,None),
    ('ZI020_GE4',None,None),
    ('ZI024_ASE',None,None),
    ('ZI024_CFR',None,None),
    ('ZI024_CLO',None,None),
    ('ZI024_CYN',None,None),
    ('ZI024_DRL',None,None),
    ('ZI024_DVPT',None,None),
    ('ZI024_FMR',None,None),
    ('ZI024_FRR',None,None),
    ('ZI024_HAR',None,None),
    ('ZI024_MGN',None,None),
    ('ZI024_PHW',None,None),
    ('ZI024_PMP',None,None),
    ('ZI024_SCC',None,None),
    ('ZI024_SUL',None,None),
    ('ZI024_TDS',None,None),
    ('ZI024_TEP',None,None),
    ('ZI024_TUR',None,None),
    ('ZI024_WAC',None,None),
    ('ZI024_WTNO',None,None),
    ('ZI024_WUR',None,None),
    ('ZI024_YWQ',None,None),
    ('ZI026_CTUC',None,None),
    ('ZI026_CTUL',None,None),
    ('ZI026_CTUU',None,None),
    ('ZI031S_URI',None,None),
    ('ZVH',None,None)
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# UtilityInfrastructureSrf field translations
UtilityInfrastructureSrfFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Srf_fields) + [ \
    ('ADR','ADR',None),
    ('ADUR',None,None),
    ('ANFL',None,None),
    ('AOO','AOO',None),
    ('ARA','ARA',None),
    ('AWP','AWP',None),
    ('BEN','BEN',None),
    ('CAA','CAA',None),
    ('CNCP',None,None),
    ('COS',None,None),
    ('DCAP',None,None),
    ('DINF',None,None),
    ('DZP',None,None),
    ('EPW','EPW',None),
    ('F_CODE','F_CODE',None),
    ('FFN','FFN',None),
    ('FFN2','FFN2',None),
    ('FFN3','FFN3',None),
    ('FUFI',None,None),
    ('FURL',None,None),
    ('GDBV',None,None),
    ('GRD',None,None),
    ('HGT','HGT',None),
    ('LEA',None,None),
    ('LMC','LMC',None),
    ('LUN',None,None),
    ('LZN','LZN',None),
    ('PCF','PCF',None),
    ('POS','POS',None),
    ('POS2','POS2',None),
    ('POS3','POS3',None),
    ('PPO','PPO',None),
    ('PPO2','PPO2',None),
    ('PPO3','PPO3',None),
    ('SBT','SBT',None),
    ('SBT2','SBT2',None),
    ('SBT3','SBT3',None),
    ('SSR','SSR',None),
    ('SSR2','SSR2',None),
    ('SSR3','SSR3',None),
    ('UFI','UFI',None),
    ('VCM','VCM',None),
    ('VCM2','VCM2',None),
    ('VCM3','VCM3',None),
    ('VOI','VOI',None),
    ('WDAC',None,None),
    ('WDAL',None,None),
    ('WDAU',None,None),
    ('WDH',None,None),
    ('WDL',None,None),
    ('WDST',None,None),
    ('WID','WID',None),
    ('WLSS',None,None),
    ('ZI002_UFI',None,None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_FNA2',None,None),
    ('ZI005_FNA3',None,None),
    ('ZI005_GNT',None,None),
    ('ZI005_GNT2',None,None),
    ('ZI005_GNT3',None,None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZI005_NFN2',None,None),
    ('ZI005_NFN3',None,None),
    ('ZI014_PBY',None,None),
    ('ZI014_PBY2',None,None),
    ('ZI014_PBY3',None,None),
    ('ZI020_GE4','ZI020_GE4',None),
    ('ZI024_ASE',None,None),
    ('ZI024_AWO',None,None),
    ('ZI024_AWOI',None,None),
    ('ZI024_AWOX',None,None),
    ('ZI024_CFR',None,None),
    ('ZI024_CLO',None,None),
    ('ZI024_CYN',None,None),
    ('ZI024_DRL',None,None),
    ('ZI024_DVPT',None,None),
    ('ZI024_FMR',None,None),
    ('ZI024_FRR',None,None),
    ('ZI024_HAR',None,None),
    ('ZI024_MGN',None,None),
    ('ZI024_PHW',None,None),
    ('ZI024_PMP',None,None),
    ('ZI024_PUR',None,None),
    ('ZI024_PUR2',None,None),
    ('ZI024_PUR3',None,None),
    ('ZI024_PUR4',None,None),
    ('ZI024_PUR5',None,None),
    ('ZI024_SCC',None,None),
    ('ZI024_SUL',None,None),
    ('ZI024_TDS',None,None),
    ('ZI024_TEP',None,None),
    ('ZI024_TUR',None,None),
    ('ZI024_WAC',None,None),
    ('ZI024_WTNO',None,None),
    ('ZI024_WUR',None,None),
    ('ZI024_WUR2',None,None),
    ('ZI024_WUR3',None,None),
    ('ZI024_WUR4',None,None),
    ('ZI024_YWQ',None,None),
    ('ZI026_CTUC','ZI026_CTUC',None),
    ('ZI026_CTUL','ZI026_CTUL',None),
    ('ZI026_CTUU','ZI026_CTUU',None),
    ('ZI031S_URI',None,None),
    ('ZVH','ZVH',None)
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# VegetationCrv field translations
VegetationCrvFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Crv_fields) + [ \
    ('AOO','AOO',None),
    ('ARA','ARA',None),
    ('BEN',None,None),
    ('DMBC','DMBC',None),
    ('DMBL','DMBL',None),
    ('DMBU','DMBU',None),
    ('DMT','DMT',None),
    ('F_CODE','F_CODE',None),
    ('FUFI',None,None),
    ('FURL',None,None),
    ('GDBV',None,None),
    ('HGT','HGT',None),
    ('LMC','LMC',None),
    ('LZN','LZN',None),
    ('PVH','PVH',None),
    ('SBC','SBC',None),
    ('SDSC','SDSC',None),
    ('TRE','TRE',None),
    ('TSCC','TSCC',None),
    ('TSCL','TSCL',None),
    ('TSCU','TSCU',None),
    ('UFI','UFI',None),
    ('VSP',None,None),
    ('VSP2',None,None),
    ('VSP3',None,None),
    ('VTI','VTI',None),
    ('WID','WID',None),
    ('ZI002_UFI',None,None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_GNT',None,None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZI020_GE4','ZI020_GE4',None),
    ('ZI026_CTUC','ZI026_CTUC',None),
    ('ZI026_CTUL','ZI026_CTUL',None),
    ('ZI026_CTUU','ZI026_CTUU',None),
    ('ZI031S_URI',None,None),
    ('ZVH','ZVH',None),
    ('SDSL','SDSL','transform_decimetre_to_metre'),
    ('SDSU','SDSU','transform_decimetre_to_metre') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# VegetationPnt field translations
VegetationPntFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Pnt_fields) + [ \
    ('BEN','BEN',None),
    ('F_CODE','F_CODE',None),
    ('FUFI',None,None),
    ('FURL',None,None),
    ('GDBV',None,None),
    ('HGT','HGT',None),
    ('LMC','LMC',None),
    ('SDSC',None,None),
    ('SDSL',None,None),
    ('SDSU',None,None),
    ('TRE','TRE',None),
    ('UFI','UFI',None),
    ('VSP',None,None),
    ('ZI002_UFI',None,None),
    ('ZI005_FNA',None,None),
    ('ZI005_GNT',None,None),
    ('ZI005_NFN',None,None),
    ('ZI020_GE4','ZI020_GE4',None),
    ('ZI026_CTUC','ZI026_CTUC',None),
    ('ZI026_CTUL','ZI026_CTUL',None),
    ('ZI026_CTUU','ZI026_CTUU',None),
    ('ZI031S_URI',None,None),
    ('ZVH','ZVH',None)
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# VegetationPntExt field translations
VegetationPntExtFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Pnt_fields) + [ \
    ('ARA',None,None),
    ('BEN',None,None),
    ('COA',None,None),
    ('COC',None,None),
    ('COG',None,None),
    ('DMBC',None,None),
    ('DMBL',None,None),
    ('DMBU',None,None),
    ('DMT',None,None),
    ('F_CODE',None,None),
    ('FEO',None,None),
    ('FUFI',None,None),
    ('FURL',None,None),
    ('GDBV',None,None),
    ('HGT',None,None),
    ('LMC',None,None),
    ('LZN',None,None),
    ('PVH',None,None),
    ('SBC',None,None),
    ('SDSC',None,None),
    ('SDSL',None,None),
    ('SDSU',None,None),
    ('STR',None,None),
    ('TRE',None,None),
    ('TSCC',None,None),
    ('TSCL',None,None),
    ('TSCU',None,None),
    ('UFI',None,None),
    ('VSP',None,None),
    ('VSP2',None,None),
    ('VSP3',None,None),
    ('VTI',None,None),
    ('WCL',None,None),
    ('WID',None,None),
    ('ZI002_UFI',None,None),
    ('ZI005_FNA',None,None),
    ('ZI005_GNT',None,None),
    ('ZI005_NFN',None,None),
    ('ZI020_GE4',None,None),
    ('ZI026_CTUC',None,None),
    ('ZI026_CTUL',None,None),
    ('ZI026_CTUU',None,None),
    ('ZI031S_URI',None,None),
    ('ZVH',None,None)
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# VegetationSrf field translations
VegetationSrfFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Srf_fields) + [ \
    ('AOO','AOO',None),
    ('ARA','ARA',None),
    ('BEN',None,None),
    ('BMC','BMC',None),
    ('BMC2','BMC2',None),
    ('BMC3','BMC3',None),
    ('BOC','BOC',None),
    ('CAA',None,None),
    ('DMBC','DMBC',None),
    ('DMBL','DMBL',None),
    ('DMBU','DMBU',None),
    ('DMT','DMT',None),
    ('DZP',None,None),
    ('F_CODE','F_CODE',None),
    ('FFN','FFN',None),
    ('FFN2','FFN2',None),
    ('FFN3','FFN3',None),
    ('FUFI',None,None),
    ('FURL',None,None),
    ('GDBV',None,None),
    ('HDP',None,None),
    ('HGT','HGT',None),
    ('LMC','LMC',None),
    ('LZN','LZN',None),
    ('PVH','PVH',None),
    ('SBC','SBC',None),
    ('SDSC','SDSC',None),
    ('SNDC',None,None),
    ('SNDL',None,None),
    ('SNDU',None,None),
    ('TID','TID',None),
    ('TRE','TRE',None),
    ('TSCC','TSCC',None),
    ('TSCL','TSCL',None),
    ('TSCU','TSCU',None),
    ('TWS',None,None),
    ('UFI','UFI',None),
    ('VSP','VSP',None),
    ('VSP2','VSP2',None),
    ('VSP3','VSP3',None),
    ('VTI','VTI',None),
    ('WDAC',None,None),
    ('WDAL',None,None),
    ('WDAU',None,None),
    ('WID','WID',None),
    ('ZI002_UFI',None,None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_GNT',None,None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZI020_GE4','ZI020_GE4',None),
    ('ZI024_ASE',None,None),
    ('ZI024_CFR',None,None),
    ('ZI024_CLO',None,None),
    ('ZI024_CYN',None,None),
    ('ZI024_FMR',None,None),
    ('ZI024_FRR',None,None),
    ('ZI024_HAR',None,None),
    ('ZI024_HYP','ZI024_HYP',None),
    ('ZI024_MGN',None,None),
    ('ZI024_PHW',None,None),
    ('ZI024_SCC',None,None),
    ('ZI024_SUL',None,None),
    ('ZI024_TDS',None,None),
    ('ZI024_TEP',None,None),
    ('ZI024_TUR',None,None),
    ('ZI024_WAC',None,None),
    ('ZI024_WTNO',None,None),
    ('ZI024_WUR',None,None),
    ('ZI024_YWQ',None,None),
    ('ZI026_CTUC','ZI026_CTUC',None),
    ('ZI026_CTUL','ZI026_CTUL',None),
    ('ZI026_CTUU','ZI026_CTUU',None),
    ('ZI031S_URI',None,None),
    ('ZVH','ZVH',None),
    ('SDSL','SDSL','transform_decimetre_to_metre'),
    ('SDSU','SDSU','transform_decimetre_to_metre'),
    ('VEG','VEG','transform_VEG') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# VegetationSrfExt field translations
VegetationSrfExtFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Srf_fields) + [ \
    ('ARA',None,None),
    ('BEN',None,None),
    ('COA',None,None),
    ('COC',None,None),
    ('COG',None,None),
    ('DMBC',None,None),
    ('DMBL',None,None),
    ('DMBU',None,None),
    ('DMT',None,None),
    ('F_CODE',None,None),
    ('FEO',None,None),
    ('FUFI',None,None),
    ('FURL',None,None),
    ('GDBV',None,None),
    ('HGT',None,None),
    ('LMC',None,None),
    ('LZN',None,None),
    ('PVH',None,None),
    ('SBC',None,None),
    ('SDSC',None,None),
    ('SDSL',None,None),
    ('SDSU',None,None),
    ('STR',None,None),
    ('TRE',None,None),
    ('TSCC',None,None),
    ('TSCL',None,None),
    ('TSCU',None,None),
    ('UFI',None,None),
    ('VSP',None,None),
    ('VSP2',None,None),
    ('VSP3',None,None),
    ('VTI',None,None),
    ('WCL',None,None),
    ('WID',None,None),
    ('ZI002_UFI',None,None),
    ('ZI005_FNA',None,None),
    ('ZI005_GNT',None,None),
    ('ZI005_NFN',None,None),
    ('ZI020_GE4',None,None),
    ('ZI026_CTUC',None,None),
    ('ZI026_CTUL',None,None),
    ('ZI026_CTUU',None,None),
    ('ZI031S_URI',None,None),
    ('ZVH',None,None)
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

