﻿
""" 
 ************************************************************************************************
 **                                                                                            **
 **  File: GGDM30_FCFields.py                                        **
 **  Copyright (c) March 2017 by Leidos                                                      **
 **  Produced under U.S. Government contract W5J9CQ-12-D-0004  Task Order: 062.                **
 **  As per DFARS, the U.S. Government is granted unlimited rights to use this work            **
 **  in any manner and for any purpose.                                                        **
 **                                                                                            **
 **  Summary:   This file provides a schema-like definition for the data model:             **
 **                 GGDM 3.0 Composite and GRLS                                   **
 **
 **    A python dictionary structure is used to define the schema fields for this data model
 **    allowing for the look up and retrieval of default value information, assigned feature code
 **    and identification of whether an attribute applies to a feature within a feature class.
 **
 **    This information is specific to the data model listed above.
 **
 **    The information held within this definition consists of:
 **    1) interval_fields: are special case fields that do not have the standard default value
 **    2) feature class lists
 **    3) fields in the feature class, and for each field, the data type and list of feature codes
 **       on which the field is 'allowed'
 **    4) fields that are enumerated values also get a list of the allowed values for that field
 **    5) summary domain values is a listing of the domain value numeric and textual value that may be
 **       useful for lookup or documentation purposes
 **    6) default values
 **    7) allocation of features to levels (GRLS)
 **                                                                                            **
 **  Developed by Leidos, Inc., High Resolution ISR Systems Division, Geospatial Programs                                   **
 **                                                                                            **
 **  Development History:                                                                      **
 **  March 2017 / Annette Janett Filer (Annette.J.Filer@leidos.com) Regenerated this code
 **           using CDMF tools in C114_Translations.mdb
 **                                                                                            **
 **                                                                                            **
 ************************************************************************************************
"""

def GGDM30AddSchemaInfoFeaturesSubtypes(field_information):
    field_information['GGDM 3.0']['interval_fields'] = {'AQTC','AYRC','BPWHAC','BPWHBC','BPWSAC','BPWSBC','BWVCAC','BWVCBC','DMBC','DPAC','GSGCHC','GSGCLC','PFHC','PWAC','RMWC','SDCC','SDSC','SGCC','SNDC','TSCC','VAVC','WDAC','WRCC','WWRC','ZI015_GCUC','ZI026_CTUC'}
    field_information['GGDM 3.0']['AeronauticCrv'] = {}
    field_information['GGDM 3.0']['AeronauticPnt'] = {}
    field_information['GGDM 3.0']['AeronauticPntExt'] = {}
    field_information['GGDM 3.0']['AeronauticSrf'] = {}
    field_information['GGDM 3.0']['AeronauticSrfExt'] = {}
    field_information['GGDM 3.0']['AgriculturePnt'] = {}
    field_information['GGDM 3.0']['AgriculturePntExt'] = {}
    field_information['GGDM 3.0']['AgricultureSrf'] = {}
    field_information['GGDM 3.0']['BoundaryCrvExt'] = {}
    field_information['GGDM 3.0']['BoundaryPnt'] = {}
    field_information['GGDM 3.0']['BoundarySrf'] = {}
    field_information['GGDM 3.0']['BoundarySrfExt'] = {}
    field_information['GGDM 3.0']['RESTRICTION_INFO_T'] = {}
    field_information['GGDM 3.0']['CultureCrv'] = {}
    field_information['GGDM 3.0']['CulturePnt'] = {}
    field_information['GGDM 3.0']['CulturePntExt'] = {}
    field_information['GGDM 3.0']['CultureSrf'] = {}
    field_information['GGDM 3.0']['CultureSrfExt'] = {}
    field_information['GGDM 3.0']['FacilityPnt'] = {}
    field_information['GGDM 3.0']['FacilitySrf'] = {}
    field_information['GGDM 3.0']['HydroAidNavigationCrvExt'] = {}
    field_information['GGDM 3.0']['HydroAidNavigationPnt'] = {}
    field_information['GGDM 3.0']['HydroAidNavigationPntExt'] = {}
    field_information['GGDM 3.0']['HydroAidNavigationSrf'] = {}
    field_information['GGDM 3.0']['HydrographyAONExt'] = {}
    field_information['GGDM 3.0']['HydrographyCrv'] = {}
    field_information['GGDM 3.0']['HydrographyCrvExt'] = {}
    field_information['GGDM 3.0']['HydrographyPnt'] = {}
    field_information['GGDM 3.0']['HydrographyPntExt'] = {}
    field_information['GGDM 3.0']['HydrographySrf'] = {}
    field_information['GGDM 3.0']['HydrographySrfExt'] = {}
    field_information['GGDM 3.0']['HypsographyCrv'] = {}
    field_information['GGDM 3.0']['HypsographyPnt'] = {}
    field_information['GGDM 3.0']['HypsographyPntExt'] = {}
    field_information['GGDM 3.0']['IndustryCrv'] = {}
    field_information['GGDM 3.0']['IndustryPnt'] = {}
    field_information['GGDM 3.0']['IndustryPntExt'] = {}
    field_information['GGDM 3.0']['IndustrySrf'] = {}
    field_information['GGDM 3.0']['InformationCrv'] = {}
    field_information['GGDM 3.0']['InformationCrvExt'] = {}
    field_information['GGDM 3.0']['InformationPnt'] = {}
    field_information['GGDM 3.0']['InformationSrf'] = {}
    field_information['GGDM 3.0']['InformationSrfExt'] = {}
    field_information['GGDM 3.0']['MetadataSrf'] = {}
    field_information['GGDM 3.0']['ENTITY_COLLECTION_METADATA_T'] = {}
    field_information['GGDM 3.0']['MilitaryCrv'] = {}
    field_information['GGDM 3.0']['MilitaryCrvExt'] = {}
    field_information['GGDM 3.0']['MilitaryPnt'] = {}
    field_information['GGDM 3.0']['MilitaryPntExt'] = {}
    field_information['GGDM 3.0']['MilitarySrf'] = {}
    field_information['GGDM 3.0']['MilitarySrfExt'] = {}
    field_information['GGDM 3.0']['PhysiographyAONExt'] = {}
    field_information['GGDM 3.0']['PhysiographyCrv'] = {}
    field_information['GGDM 3.0']['PhysiographyCrvExt'] = {}
    field_information['GGDM 3.0']['PhysiographyPnt'] = {}
    field_information['GGDM 3.0']['PhysiographyPntExt'] = {}
    field_information['GGDM 3.0']['PhysiographySrf'] = {}
    field_information['GGDM 3.0']['PhysiographySrfExt'] = {}
    field_information['GGDM 3.0']['PortHarbourCrv'] = {}
    field_information['GGDM 3.0']['PortHarbourPnt'] = {}
    field_information['GGDM 3.0']['PortHarbourPntExt'] = {}
    field_information['GGDM 3.0']['PortHarbourSrf'] = {}
    field_information['GGDM 3.0']['PortHarbourSrfExt'] = {}
    field_information['GGDM 3.0']['RecreationAONExt'] = {}
    field_information['GGDM 3.0']['RecreationCrv'] = {}
    field_information['GGDM 3.0']['RecreationPnt'] = {}
    field_information['GGDM 3.0']['RecreationSrf'] = {}
    field_information['GGDM 3.0']['ReferenceTblExt'] = {}
    field_information['GGDM 3.0']['ResourceSrf'] = {}
    field_information['GGDM 3.0']['DATASET_T'] = {}
    field_information['GGDM 3.0']['SettlementPnt'] = {}
    field_information['GGDM 3.0']['SettlementSrf'] = {}
    field_information['GGDM 3.0']['SettlementSrfExt'] = {}
    field_information['GGDM 3.0']['StorageAONExt'] = {}
    field_information['GGDM 3.0']['StoragePnt'] = {}
    field_information['GGDM 3.0']['StorageSrf'] = {}
    field_information['GGDM 3.0']['StructureCrv'] = {}
    field_information['GGDM 3.0']['StructurePnt'] = {}
    field_information['GGDM 3.0']['StructurePntExt'] = {}
    field_information['GGDM 3.0']['StructureSrf'] = {}
    field_information['GGDM 3.0']['SubterraneanSrf'] = {}
    field_information['GGDM 3.0']['TransportationGroundCrv'] = {}
    field_information['GGDM 3.0']['TransportationGroundPnt'] = {}
    field_information['GGDM 3.0']['TransportationGroundPntExt'] = {}
    field_information['GGDM 3.0']['TransportationGroundSrf'] = {}
    field_information['GGDM 3.0']['TransportationWaterAONExt'] = {}
    field_information['GGDM 3.0']['TransportationWaterCrv'] = {}
    field_information['GGDM 3.0']['TransportationWaterPnt'] = {}
    field_information['GGDM 3.0']['TransportationWaterPntExt'] = {}
    field_information['GGDM 3.0']['TransportationWaterSrf'] = {}
    field_information['GGDM 3.0']['UtilityInfrastructureAONExt'] = {}
    field_information['GGDM 3.0']['UtilityInfrastructureCrv'] = {}
    field_information['GGDM 3.0']['UtilityInfrastructurePnt'] = {}
    field_information['GGDM 3.0']['UtilityInfrastructurePntExt'] = {}
    field_information['GGDM 3.0']['UtilityInfrastructureSrf'] = {}
    field_information['GGDM 3.0']['VegetationCrv'] = {}
    field_information['GGDM 3.0']['VegetationPnt'] = {}
    field_information['GGDM 3.0']['VegetationPntExt'] = {}
    field_information['GGDM 3.0']['VegetationSrf'] = {}
    field_information['GGDM 3.0']['VegetationSrfExt'] = {}
    field_information['GGDM 3.0']['AeronauticCrv']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['AeronauticPnt']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['AeronauticPntExt']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['AeronauticSrfExt']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['AgriculturePnt']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['AgriculturePntExt']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['BoundaryCrvExt']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['BoundaryPnt']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['BoundarySrf']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['BoundarySrfExt']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['RESTRICTION_INFO_T']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['CultureCrv']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['CulturePnt']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['CulturePntExt']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['CultureSrf']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['CultureSrfExt']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['FacilityPnt']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['FacilitySrf']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['HydroAidNavigationCrvExt']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['HydroAidNavigationPnt']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['HydroAidNavigationSrf']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['HydrographyCrvExt']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['HydrographyPntExt']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['HypsographyCrv']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['HypsographyPnt']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['HypsographyPntExt']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['IndustryCrv']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['IndustryPntExt']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['IndustrySrf']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['InformationCrv']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['InformationCrvExt']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['InformationPnt']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['InformationSrf']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['InformationSrfExt']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['MetadataSrf']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['ENTITY_COLLECTION_METADATA_T']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['MilitaryCrv']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['MilitaryCrvExt']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['MilitaryPnt']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['MilitaryPntExt']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['MilitarySrf']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['MilitarySrfExt']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['PhysiographyAONExt']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['PhysiographyCrv']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['PhysiographyCrvExt']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['PhysiographyPnt']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['PhysiographyPntExt']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['PhysiographySrf']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['PhysiographySrfExt']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['PortHarbourCrv']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['PortHarbourPnt']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['PortHarbourPntExt']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['PortHarbourSrf']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['PortHarbourSrfExt']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['RecreationAONExt']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['RecreationCrv']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['RecreationPnt']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['RecreationSrf']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['ReferenceTblExt']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['ResourceSrf']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['DATASET_T']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['SettlementPnt']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['SettlementSrf']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['SettlementSrfExt']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['StorageAONExt']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['StoragePnt']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['StorageSrf']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['StructureCrv']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['StructurePntExt']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['StructureSrf']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['SubterraneanSrf']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['TransportationGroundPntExt']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['TransportationWaterAONExt']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['TransportationWaterCrv']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['TransportationWaterPnt']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['TransportationWaterPntExt']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['TransportationWaterSrf']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['UtilityInfrastructureAONExt']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['UtilityInfrastructureCrv']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['UtilityInfrastructurePntExt']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['VegetationCrv']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['VegetationPnt']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['VegetationPntExt']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['VegetationSrf']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['VegetationSrfExt']['EnumeratedIndexValues'] = {}


    field_information['GGDM 3.0']['AeronauticCrv']['ARA'] = ('Real',('GB075'))
    field_information['GGDM 3.0']['AeronauticCrv']['AXS'] = ('Enumeration',('GB075'))
    field_information['GGDM 3.0']['AeronauticCrv']['EnumeratedIndexValues']['AXS'] = {}
    field_information['GGDM 3.0']['AeronauticCrv']['EnumeratedIndexValues']['AXS']['GB075']  = (-999999,1,2,3,4)
    field_information['GGDM 3.0']['AeronauticCrv']['BEN'] = ('StructuredText',('GB075'))
    field_information['GGDM 3.0']['AeronauticCrv']['CNCP'] = ('StructuredText',('GB075'))
    field_information['GGDM 3.0']['AeronauticCrv']['COS'] = ('Enumeration',('GB075'))
    field_information['GGDM 3.0']['AeronauticCrv']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['AeronauticCrv']['EnumeratedIndexValues']['COS']['GB075']  = (-999999,4,6,13,14)
    field_information['GGDM 3.0']['AeronauticCrv']['DEV'] = ('Integer',('GB075'))
    field_information['GGDM 3.0']['AeronauticCrv']['F_CODE'] = ('CONSTRAINED_STRING',('GB075'))
    field_information['GGDM 3.0']['AeronauticCrv']['FUFI'] = ('StructuredText',('GB075'))
    field_information['GGDM 3.0']['AeronauticCrv']['FURL'] = ('StructuredText',('GB075'))
    field_information['GGDM 3.0']['AeronauticCrv']['GDBV'] = ('Enumeration',('GB075'))
    field_information['GGDM 3.0']['AeronauticCrv']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['AeronauticCrv']['EnumeratedIndexValues']['GDBV']['GB075']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['AeronauticCrv']['LZN'] = ('Real',('GB075'))
    field_information['GGDM 3.0']['AeronauticCrv']['OTH'] = ('StructuredText',('GB075'))
    field_information['GGDM 3.0']['AeronauticCrv']['PCF'] = ('Enumeration',('GB075'))
    field_information['GGDM 3.0']['AeronauticCrv']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['AeronauticCrv']['EnumeratedIndexValues']['PCF']['GB075']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['AeronauticCrv']['SBB'] = ('Boolean',('GB075'))
    field_information['GGDM 3.0']['AeronauticCrv']['TXP'] = ('Enumeration',('GB075'))
    field_information['GGDM 3.0']['AeronauticCrv']['EnumeratedIndexValues']['TXP'] = {}
    field_information['GGDM 3.0']['AeronauticCrv']['EnumeratedIndexValues']['TXP']['GB075']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,999)
    field_information['GGDM 3.0']['AeronauticCrv']['UFI'] = ('StructuredText',('GB075'))
    field_information['GGDM 3.0']['AeronauticCrv']['WID'] = ('Real',('GB075'))
    field_information['GGDM 3.0']['AeronauticCrv']['ZI001_SDV'] = ('StructuredText',('GB075'))
    field_information['GGDM 3.0']['AeronauticCrv']['ZI001_SRT'] = ('Enumeration',('GB075'))
    field_information['GGDM 3.0']['AeronauticCrv']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['AeronauticCrv']['EnumeratedIndexValues']['ZI001_SRT']['GB075']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['AeronauticCrv']['ZI002_UFI'] = ('StructuredText',('GB075'))
    field_information['GGDM 3.0']['AeronauticCrv']['ZI004_RCG'] = ('Enumeration',('GB075'))
    field_information['GGDM 3.0']['AeronauticCrv']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['AeronauticCrv']['EnumeratedIndexValues']['ZI004_RCG']['GB075']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['AeronauticCrv']['ZI005_FNA'] = ('String',('GB075'))
    field_information['GGDM 3.0']['AeronauticCrv']['ZI005_GNT'] = ('Enumeration',('GB075'))
    field_information['GGDM 3.0']['AeronauticCrv']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['AeronauticCrv']['EnumeratedIndexValues']['ZI005_GNT']['GB075']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['AeronauticCrv']['ZI005_NFN'] = ('String',('GB075'))
    field_information['GGDM 3.0']['AeronauticCrv']['ZI006_MEM'] = ('String',('GB075'))
    field_information['GGDM 3.0']['AeronauticCrv']['ZI019_ASP'] = ('Enumeration',('GB075'))
    field_information['GGDM 3.0']['AeronauticCrv']['EnumeratedIndexValues']['ZI019_ASP'] = {}
    field_information['GGDM 3.0']['AeronauticCrv']['EnumeratedIndexValues']['ZI019_ASP']['GB075']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['GGDM 3.0']['AeronauticCrv']['ZI019_ASP2'] = ('Enumeration',('GB075'))
    field_information['GGDM 3.0']['AeronauticCrv']['EnumeratedIndexValues']['ZI019_ASP2'] = {}
    field_information['GGDM 3.0']['AeronauticCrv']['EnumeratedIndexValues']['ZI019_ASP2']['GB075']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['GGDM 3.0']['AeronauticCrv']['ZI019_ASP3'] = ('Enumeration',('GB075'))
    field_information['GGDM 3.0']['AeronauticCrv']['EnumeratedIndexValues']['ZI019_ASP3'] = {}
    field_information['GGDM 3.0']['AeronauticCrv']['EnumeratedIndexValues']['ZI019_ASP3']['GB075']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['GGDM 3.0']['AeronauticCrv']['ZI019_ASU'] = ('Enumeration',('GB075'))
    field_information['GGDM 3.0']['AeronauticCrv']['EnumeratedIndexValues']['ZI019_ASU'] = {}
    field_information['GGDM 3.0']['AeronauticCrv']['EnumeratedIndexValues']['ZI019_ASU']['GB075']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,20,21,999)
    field_information['GGDM 3.0']['AeronauticCrv']['ZI019_ASU2'] = ('Enumeration',('GB075'))
    field_information['GGDM 3.0']['AeronauticCrv']['EnumeratedIndexValues']['ZI019_ASU2'] = {}
    field_information['GGDM 3.0']['AeronauticCrv']['EnumeratedIndexValues']['ZI019_ASU2']['GB075']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,20,21,999)
    field_information['GGDM 3.0']['AeronauticCrv']['ZI019_ASU3'] = ('Enumeration',('GB075'))
    field_information['GGDM 3.0']['AeronauticCrv']['EnumeratedIndexValues']['ZI019_ASU3'] = {}
    field_information['GGDM 3.0']['AeronauticCrv']['EnumeratedIndexValues']['ZI019_ASU3']['GB075']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,20,21,999)
    field_information['GGDM 3.0']['AeronauticCrv']['ZI019_ASX'] = ('Enumeration',('GB075'))
    field_information['GGDM 3.0']['AeronauticCrv']['EnumeratedIndexValues']['ZI019_ASX'] = {}
    field_information['GGDM 3.0']['AeronauticCrv']['EnumeratedIndexValues']['ZI019_ASX']['GB075']  = (-999999,1,2,3,4,5,999)
    field_information['GGDM 3.0']['AeronauticCrv']['ZI019_SFS'] = ('Enumeration',('GB075'))
    field_information['GGDM 3.0']['AeronauticCrv']['EnumeratedIndexValues']['ZI019_SFS'] = {}
    field_information['GGDM 3.0']['AeronauticCrv']['EnumeratedIndexValues']['ZI019_SFS']['GB075']  = (-999999,1,2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['AeronauticCrv']['ZI020_GE4'] = ('CodeList',('GB075'))
    field_information['GGDM 3.0']['AeronauticCrv']['ZI026_CTUC'] = ('Enumeration',('GB075'))
    field_information['GGDM 3.0']['AeronauticCrv']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['AeronauticCrv']['EnumeratedIndexValues']['ZI026_CTUC']['GB075']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['AeronauticCrv']['ZI026_CTUL'] = ('integer',('GB075'))
    field_information['GGDM 3.0']['AeronauticCrv']['ZI026_CTUU'] = ('integer',('GB075'))
    field_information['GGDM 3.0']['AeronauticCrv']['ZI031S_URI'] = ('StructuredText',('GB075'))
    field_information['GGDM 3.0']['AeronauticCrv']['ZI039S_UFI'] = ('StructuredText',('GB075'))
    field_information['GGDM 3.0']['AeronauticCrv']['ZSAX_RS0'] = ('CodeList',('GB075'))
    field_information['GGDM 3.0']['AeronauticCrv']['ZSAX_RX0'] = ('StructuredText',('GB075'))
    field_information['GGDM 3.0']['AeronauticCrv']['ZSAX_RX3'] = ('StructuredText',('GB075'))
    field_information['GGDM 3.0']['AeronauticCrv']['ZSAX_RX4'] = ('StructuredText',('GB075'))
    field_information['GGDM 3.0']['AeronauticCrv']['ZVH'] = ('Real',('GB075'))
    field_information['GGDM 3.0']['AeronauticPnt']['ADR'] = ('String',('AL351','AQ060','GB230','GB250'))
    field_information['GGDM 3.0']['AeronauticPnt']['AOO'] = ('Real',('AL351','AL510','AQ060','AQ110','GB040','GB230','GB250'))
    field_information['GGDM 3.0']['AeronauticPnt']['APT'] = ('Enumeration',('GB005'))
    field_information['GGDM 3.0']['AeronauticPnt']['EnumeratedIndexValues']['APT'] = {}
    field_information['GGDM 3.0']['AeronauticPnt']['EnumeratedIndexValues']['APT']['GB005']  = (-999999,1,2,3,5,6,7,8,12,13,16,999)
    field_information['GGDM 3.0']['AeronauticPnt']['APT2'] = ('Enumeration',('GB005'))
    field_information['GGDM 3.0']['AeronauticPnt']['EnumeratedIndexValues']['APT2'] = {}
    field_information['GGDM 3.0']['AeronauticPnt']['EnumeratedIndexValues']['APT2']['GB005']  = (-999999,1,2,3,5,6,7,8,12,13,16,999)
    field_information['GGDM 3.0']['AeronauticPnt']['APT3'] = ('Enumeration',('GB005'))
    field_information['GGDM 3.0']['AeronauticPnt']['EnumeratedIndexValues']['APT3'] = {}
    field_information['GGDM 3.0']['AeronauticPnt']['EnumeratedIndexValues']['APT3']['GB005']  = (-999999,1,2,3,5,6,7,8,12,13,16,999)
    field_information['GGDM 3.0']['AeronauticPnt']['ARA'] = ('Real',('AL351','AQ060','GB005','GB030','GB035','GB040','GB065','GB230','GB250'))
    field_information['GGDM 3.0']['AeronauticPnt']['ASY'] = ('Enumeration',('GB005','GB035','GB065'))
    field_information['GGDM 3.0']['AeronauticPnt']['EnumeratedIndexValues']['ASY'] = {}
    field_information['GGDM 3.0']['AeronauticPnt']['EnumeratedIndexValues']['ASY']['GB005']  = (-999999,1,2,3,4,5,6,7,12)
    field_information['GGDM 3.0']['AeronauticPnt']['EnumeratedIndexValues']['ASY']['GB035']  = (-999999,8,9,10,11,12,13)
    field_information['GGDM 3.0']['AeronauticPnt']['EnumeratedIndexValues']['ASY']['GB065']  = (-999999,1,2,3,4,5,7,12)
    field_information['GGDM 3.0']['AeronauticPnt']['ATB'] = ('Boolean',('GB230'))
    field_information['GGDM 3.0']['AeronauticPnt']['AWP'] = ('Boolean',('AL510','AQ060','AQ110','GB230','GB250'))
    field_information['GGDM 3.0']['AeronauticPnt']['AXS'] = ('Enumeration',('GB030'))
    field_information['GGDM 3.0']['AeronauticPnt']['EnumeratedIndexValues']['AXS'] = {}
    field_information['GGDM 3.0']['AeronauticPnt']['EnumeratedIndexValues']['AXS']['GB030']  = (-999999,1,2,3,4)
    field_information['GGDM 3.0']['AeronauticPnt']['BEN'] = ('StructuredText',('AL351','AL510','AQ060','AQ110','GB005','GB030','GB035','GB040','GB065','GB230','GB250'))
    field_information['GGDM 3.0']['AeronauticPnt']['CAA'] = ('Enumeration',('AL351','AQ060','AQ110','GB005','GB030','GB035','GB065','GB230','GB250'))
    field_information['GGDM 3.0']['AeronauticPnt']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['AeronauticPnt']['EnumeratedIndexValues']['CAA']['AL351']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['AeronauticPnt']['EnumeratedIndexValues']['CAA']['AQ060']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['AeronauticPnt']['EnumeratedIndexValues']['CAA']['AQ110']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['AeronauticPnt']['EnumeratedIndexValues']['CAA']['GB005']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['AeronauticPnt']['EnumeratedIndexValues']['CAA']['GB030']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['AeronauticPnt']['EnumeratedIndexValues']['CAA']['GB035']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['AeronauticPnt']['EnumeratedIndexValues']['CAA']['GB065']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['AeronauticPnt']['EnumeratedIndexValues']['CAA']['GB230']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['AeronauticPnt']['EnumeratedIndexValues']['CAA']['GB250']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['AeronauticPnt']['CNCP'] = ('StructuredText',('AL351','AL510','AQ060','AQ110','GB005','GB030','GB035','GB040','GB065','GB230','GB250'))
    field_information['GGDM 3.0']['AeronauticPnt']['COS'] = ('Enumeration',('AL351','AL510','AQ060','AQ110','GB005','GB030','GB035','GB040','GB065','GB230','GB250'))
    field_information['GGDM 3.0']['AeronauticPnt']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['AeronauticPnt']['EnumeratedIndexValues']['COS']['AL351']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['AeronauticPnt']['EnumeratedIndexValues']['COS']['AL510']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['AeronauticPnt']['EnumeratedIndexValues']['COS']['AQ060']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['AeronauticPnt']['EnumeratedIndexValues']['COS']['AQ110']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['AeronauticPnt']['EnumeratedIndexValues']['COS']['GB005']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['AeronauticPnt']['EnumeratedIndexValues']['COS']['GB030']  = (-999999,4,6,8,13,14)
    field_information['GGDM 3.0']['AeronauticPnt']['EnumeratedIndexValues']['COS']['GB035']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['AeronauticPnt']['EnumeratedIndexValues']['COS']['GB040']  = (-999999,4,6,8,9,13,14)
    field_information['GGDM 3.0']['AeronauticPnt']['EnumeratedIndexValues']['COS']['GB065']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['AeronauticPnt']['EnumeratedIndexValues']['COS']['GB230']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['AeronauticPnt']['EnumeratedIndexValues']['COS']['GB250']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['AeronauticPnt']['F_CODE'] = ('CONSTRAINED_STRING',('AL351','AL510','AQ060','AQ110','GB005','GB030','GB035','GB040','GB065','GB230','GB250'))
    field_information['GGDM 3.0']['AeronauticPnt']['FFN'] = ('Enumeration',('AL351','AQ060','GB230','GB250'))
    field_information['GGDM 3.0']['AeronauticPnt']['EnumeratedIndexValues']['FFN'] = {}
    field_information['GGDM 3.0']['AeronauticPnt']['EnumeratedIndexValues']['FFN']['AL351']  = (-999999,331,333,334,341,530,550,835,847,970,999)
    field_information['GGDM 3.0']['AeronauticPnt']['EnumeratedIndexValues']['FFN']['AQ060']  = (-999999,486,490,495,505,507,508,510,511,513,520,525,847,999)
    field_information['GGDM 3.0']['AeronauticPnt']['EnumeratedIndexValues']['FFN']['GB230']  = (-999999,341,520,530,536,847,862,881,999)
    field_information['GGDM 3.0']['AeronauticPnt']['EnumeratedIndexValues']['FFN']['GB250']  = (-999999,341,520,530,536,835,836,847,999)
    field_information['GGDM 3.0']['AeronauticPnt']['FFN2'] = ('Enumeration',('AL351','AQ060','GB230','GB250'))
    field_information['GGDM 3.0']['AeronauticPnt']['EnumeratedIndexValues']['FFN2'] = {}
    field_information['GGDM 3.0']['AeronauticPnt']['EnumeratedIndexValues']['FFN2']['AL351']  = (-999999,331,333,334,341,530,550,835,847,970,999)
    field_information['GGDM 3.0']['AeronauticPnt']['EnumeratedIndexValues']['FFN2']['AQ060']  = (-999999,486,490,495,505,507,508,510,511,513,520,525,847,999)
    field_information['GGDM 3.0']['AeronauticPnt']['EnumeratedIndexValues']['FFN2']['GB230']  = (-999999,341,520,530,536,847,862,881,999)
    field_information['GGDM 3.0']['AeronauticPnt']['EnumeratedIndexValues']['FFN2']['GB250']  = (-999999,341,520,530,536,835,836,847,999)
    field_information['GGDM 3.0']['AeronauticPnt']['FFN3'] = ('Enumeration',('AL351','AQ060','GB230','GB250'))
    field_information['GGDM 3.0']['AeronauticPnt']['EnumeratedIndexValues']['FFN3'] = {}
    field_information['GGDM 3.0']['AeronauticPnt']['EnumeratedIndexValues']['FFN3']['AL351']  = (-999999,331,333,334,341,530,550,835,847,970,999)
    field_information['GGDM 3.0']['AeronauticPnt']['EnumeratedIndexValues']['FFN3']['AQ060']  = (-999999,486,490,495,505,507,508,510,511,513,520,525,847,999)
    field_information['GGDM 3.0']['AeronauticPnt']['EnumeratedIndexValues']['FFN3']['GB230']  = (-999999,341,520,530,536,847,862,881,999)
    field_information['GGDM 3.0']['AeronauticPnt']['EnumeratedIndexValues']['FFN3']['GB250']  = (-999999,341,520,530,536,835,836,847,999)
    field_information['GGDM 3.0']['AeronauticPnt']['FPT'] = ('Enumeration',('GB005','GB035'))
    field_information['GGDM 3.0']['AeronauticPnt']['EnumeratedIndexValues']['FPT'] = {}
    field_information['GGDM 3.0']['AeronauticPnt']['EnumeratedIndexValues']['FPT']['GB005']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['AeronauticPnt']['EnumeratedIndexValues']['FPT']['GB035']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['AeronauticPnt']['FUFI'] = ('StructuredText',('AL351','AL510','AQ060','AQ110','GB005','GB030','GB035','GB040','GB065','GB230','GB250'))
    field_information['GGDM 3.0']['AeronauticPnt']['FURL'] = ('StructuredText',('AL351','AL510','AQ060','AQ110','GB005','GB030','GB035','GB040','GB065','GB230','GB250'))
    field_information['GGDM 3.0']['AeronauticPnt']['GDBV'] = ('Enumeration',('AL351','AL510','AQ060','AQ110','GB005','GB030','GB035','GB040','GB065','GB230','GB250'))
    field_information['GGDM 3.0']['AeronauticPnt']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['AeronauticPnt']['EnumeratedIndexValues']['GDBV']['AL351']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['AeronauticPnt']['EnumeratedIndexValues']['GDBV']['AL510']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['AeronauticPnt']['EnumeratedIndexValues']['GDBV']['AQ060']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['AeronauticPnt']['EnumeratedIndexValues']['GDBV']['AQ110']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['AeronauticPnt']['EnumeratedIndexValues']['GDBV']['GB005']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['AeronauticPnt']['EnumeratedIndexValues']['GDBV']['GB030']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['AeronauticPnt']['EnumeratedIndexValues']['GDBV']['GB035']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['AeronauticPnt']['EnumeratedIndexValues']['GDBV']['GB040']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['AeronauticPnt']['EnumeratedIndexValues']['GDBV']['GB065']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['AeronauticPnt']['EnumeratedIndexValues']['GDBV']['GB230']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['AeronauticPnt']['EnumeratedIndexValues']['GDBV']['GB250']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['AeronauticPnt']['GUG'] = ('Boolean',('AQ110'))
    field_information['GGDM 3.0']['AeronauticPnt']['HAF'] = ('Enumeration',('GB030'))
    field_information['GGDM 3.0']['AeronauticPnt']['EnumeratedIndexValues']['HAF'] = {}
    field_information['GGDM 3.0']['AeronauticPnt']['EnumeratedIndexValues']['HAF']['GB030']  = (-999999,1,2,3,4,6,9,10,11,999)
    field_information['GGDM 3.0']['AeronauticPnt']['HGT'] = ('Real',('AL351','AL510','AQ060','AQ110','GB030','GB040','GB230','GB250'))
    field_information['GGDM 3.0']['AeronauticPnt']['HST'] = ('Enumeration',('GB250'))
    field_information['GGDM 3.0']['AeronauticPnt']['EnumeratedIndexValues']['HST'] = {}
    field_information['GGDM 3.0']['AeronauticPnt']['EnumeratedIndexValues']['HST']['GB250']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['AeronauticPnt']['HST2'] = ('Enumeration',('GB250'))
    field_information['GGDM 3.0']['AeronauticPnt']['EnumeratedIndexValues']['HST2'] = {}
    field_information['GGDM 3.0']['AeronauticPnt']['EnumeratedIndexValues']['HST2']['GB250']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['AeronauticPnt']['HST3'] = ('Enumeration',('GB250'))
    field_information['GGDM 3.0']['AeronauticPnt']['EnumeratedIndexValues']['HST3'] = {}
    field_information['GGDM 3.0']['AeronauticPnt']['EnumeratedIndexValues']['HST3']['GB250']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['AeronauticPnt']['HTP'] = ('Enumeration',('GB230','GB250'))
    field_information['GGDM 3.0']['AeronauticPnt']['EnumeratedIndexValues']['HTP'] = {}
    field_information['GGDM 3.0']['AeronauticPnt']['EnumeratedIndexValues']['HTP']['GB230']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['AeronauticPnt']['EnumeratedIndexValues']['HTP']['GB250']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['AeronauticPnt']['IKO'] = ('StructuredText',('GB005','GB035','GB065'))
    field_information['GGDM 3.0']['AeronauticPnt']['LASZ'] = ('String',('GB005','GB065'))
    field_information['GGDM 3.0']['AeronauticPnt']['LMC'] = ('Boolean',('AL351','AL510','AQ060','AQ110','GB230','GB250'))
    field_information['GGDM 3.0']['AeronauticPnt']['LZN'] = ('Real',('AL351','AQ060','AQ110','GB005','GB030','GB035','GB040','GB065','GB230','GB250'))
    field_information['GGDM 3.0']['AeronauticPnt']['MAG'] = ('Real',('GB005','GB035','GB065'))
    field_information['GGDM 3.0']['AeronauticPnt']['MCC'] = ('Enumeration',('GB040'))
    field_information['GGDM 3.0']['AeronauticPnt']['EnumeratedIndexValues']['MCC'] = {}
    field_information['GGDM 3.0']['AeronauticPnt']['EnumeratedIndexValues']['MCC']['GB040']  = (-999999,5,21,51,64,107,117,999)
    field_information['GGDM 3.0']['AeronauticPnt']['MCC2'] = ('Enumeration',('GB040'))
    field_information['GGDM 3.0']['AeronauticPnt']['EnumeratedIndexValues']['MCC2'] = {}
    field_information['GGDM 3.0']['AeronauticPnt']['EnumeratedIndexValues']['MCC2']['GB040']  = (-999999,5,21,51,64,107,117,999)
    field_information['GGDM 3.0']['AeronauticPnt']['MCC3'] = ('Enumeration',('GB040'))
    field_information['GGDM 3.0']['AeronauticPnt']['EnumeratedIndexValues']['MCC3'] = {}
    field_information['GGDM 3.0']['AeronauticPnt']['EnumeratedIndexValues']['MCC3']['GB040']  = (-999999,5,21,51,64,107,117,999)
    field_information['GGDM 3.0']['AeronauticPnt']['MUB'] = ('Boolean',('GB250'))
    field_information['GGDM 3.0']['AeronauticPnt']['NA8'] = ('String',('GB005','GB035','GB065'))
    field_information['GGDM 3.0']['AeronauticPnt']['NAO'] = ('String',('GB005','GB035','GB065'))
    field_information['GGDM 3.0']['AeronauticPnt']['OTH'] = ('StructuredText',('AL351','AL510','AQ060','AQ110','GB005','GB030','GB035','GB040','GB065','GB230','GB250'))
    field_information['GGDM 3.0']['AeronauticPnt']['PCF'] = ('Enumeration',('AL351','AQ060','AQ110','GB005','GB030','GB035','GB040','GB065','GB230','GB250'))
    field_information['GGDM 3.0']['AeronauticPnt']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['AeronauticPnt']['EnumeratedIndexValues']['PCF']['AL351']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['AeronauticPnt']['EnumeratedIndexValues']['PCF']['AQ060']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['AeronauticPnt']['EnumeratedIndexValues']['PCF']['AQ110']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['AeronauticPnt']['EnumeratedIndexValues']['PCF']['GB005']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['AeronauticPnt']['EnumeratedIndexValues']['PCF']['GB030']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['AeronauticPnt']['EnumeratedIndexValues']['PCF']['GB035']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['AeronauticPnt']['EnumeratedIndexValues']['PCF']['GB040']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['AeronauticPnt']['EnumeratedIndexValues']['PCF']['GB065']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['AeronauticPnt']['EnumeratedIndexValues']['PCF']['GB230']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['AeronauticPnt']['EnumeratedIndexValues']['PCF']['GB250']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['AeronauticPnt']['PEC'] = ('Boolean',('GB005','GB035','GB065'))
    field_information['GGDM 3.0']['AeronauticPnt']['PYM'] = ('Enumeration',('AQ110'))
    field_information['GGDM 3.0']['AeronauticPnt']['EnumeratedIndexValues']['PYM'] = {}
    field_information['GGDM 3.0']['AeronauticPnt']['EnumeratedIndexValues']['PYM']['AQ110']  = (-999999,1,3,4,5,7,8,9,10,999)
    field_information['GGDM 3.0']['AeronauticPnt']['SSR'] = ('Enumeration',('AQ060','GB230','GB250'))
    field_information['GGDM 3.0']['AeronauticPnt']['EnumeratedIndexValues']['SSR'] = {}
    field_information['GGDM 3.0']['AeronauticPnt']['EnumeratedIndexValues']['SSR']['AQ060']  = (-999999,6,7,38,40,41,42,47,50,55,64,999)
    field_information['GGDM 3.0']['AeronauticPnt']['EnumeratedIndexValues']['SSR']['GB230']  = (-999999,6,7,38,40,41,42,47,50,55,64,999)
    field_information['GGDM 3.0']['AeronauticPnt']['EnumeratedIndexValues']['SSR']['GB250']  = (-999999,6,7,38,40,41,42,47,50,55,64,999)
    field_information['GGDM 3.0']['AeronauticPnt']['SSR2'] = ('Enumeration',('AQ060','GB230','GB250'))
    field_information['GGDM 3.0']['AeronauticPnt']['EnumeratedIndexValues']['SSR2'] = {}
    field_information['GGDM 3.0']['AeronauticPnt']['EnumeratedIndexValues']['SSR2']['AQ060']  = (-999999,6,7,38,40,41,42,47,50,55,64,999)
    field_information['GGDM 3.0']['AeronauticPnt']['EnumeratedIndexValues']['SSR2']['GB230']  = (-999999,6,7,38,40,41,42,47,50,55,64,999)
    field_information['GGDM 3.0']['AeronauticPnt']['EnumeratedIndexValues']['SSR2']['GB250']  = (-999999,6,7,38,40,41,42,47,50,55,64,999)
    field_information['GGDM 3.0']['AeronauticPnt']['SSR3'] = ('Enumeration',('AQ060','GB230','GB250'))
    field_information['GGDM 3.0']['AeronauticPnt']['EnumeratedIndexValues']['SSR3'] = {}
    field_information['GGDM 3.0']['AeronauticPnt']['EnumeratedIndexValues']['SSR3']['AQ060']  = (-999999,6,7,38,40,41,42,47,50,55,64,999)
    field_information['GGDM 3.0']['AeronauticPnt']['EnumeratedIndexValues']['SSR3']['GB230']  = (-999999,6,7,38,40,41,42,47,50,55,64,999)
    field_information['GGDM 3.0']['AeronauticPnt']['EnumeratedIndexValues']['SSR3']['GB250']  = (-999999,6,7,38,40,41,42,47,50,55,64,999)
    field_information['GGDM 3.0']['AeronauticPnt']['TOS'] = ('Enumeration',('AQ110'))
    field_information['GGDM 3.0']['AeronauticPnt']['EnumeratedIndexValues']['TOS'] = {}
    field_information['GGDM 3.0']['AeronauticPnt']['EnumeratedIndexValues']['TOS']['AQ110']  = (-999999,6,12,13,999)
    field_information['GGDM 3.0']['AeronauticPnt']['TRS'] = ('Enumeration',('AQ060'))
    field_information['GGDM 3.0']['AeronauticPnt']['EnumeratedIndexValues']['TRS'] = {}
    field_information['GGDM 3.0']['AeronauticPnt']['EnumeratedIndexValues']['TRS']['AQ060']  = (-999999,2,5,7,8,9,12,13,17,20,999)
    field_information['GGDM 3.0']['AeronauticPnt']['TRS2'] = ('Enumeration',('AQ060'))
    field_information['GGDM 3.0']['AeronauticPnt']['EnumeratedIndexValues']['TRS2'] = {}
    field_information['GGDM 3.0']['AeronauticPnt']['EnumeratedIndexValues']['TRS2']['AQ060']  = (-999999,2,5,7,8,9,12,13,17,20,999)
    field_information['GGDM 3.0']['AeronauticPnt']['TRS3'] = ('Enumeration',('AQ060'))
    field_information['GGDM 3.0']['AeronauticPnt']['EnumeratedIndexValues']['TRS3'] = {}
    field_information['GGDM 3.0']['AeronauticPnt']['EnumeratedIndexValues']['TRS3']['AQ060']  = (-999999,2,5,7,8,9,12,13,17,20,999)
    field_information['GGDM 3.0']['AeronauticPnt']['UFI'] = ('StructuredText',('AL351','AL510','AQ060','AQ110','GB005','GB030','GB035','GB040','GB065','GB230','GB250'))
    field_information['GGDM 3.0']['AeronauticPnt']['VCM'] = ('Enumeration',('AQ060','GB230'))
    field_information['GGDM 3.0']['AeronauticPnt']['EnumeratedIndexValues']['VCM'] = {}
    field_information['GGDM 3.0']['AeronauticPnt']['EnumeratedIndexValues']['VCM']['AQ060']  = (-999999,2,3,4,6,7,8,9,12,13,15,18,999)
    field_information['GGDM 3.0']['AeronauticPnt']['EnumeratedIndexValues']['VCM']['GB230']  = (-999999,1,3,4,8,9,12,13,15,18,999)
    field_information['GGDM 3.0']['AeronauticPnt']['VCM2'] = ('Enumeration',('AQ060','GB230'))
    field_information['GGDM 3.0']['AeronauticPnt']['EnumeratedIndexValues']['VCM2'] = {}
    field_information['GGDM 3.0']['AeronauticPnt']['EnumeratedIndexValues']['VCM2']['AQ060']  = (-999999,2,3,4,6,7,8,9,12,13,15,18,999)
    field_information['GGDM 3.0']['AeronauticPnt']['EnumeratedIndexValues']['VCM2']['GB230']  = (-999999,1,3,4,8,9,12,13,15,18,999)
    field_information['GGDM 3.0']['AeronauticPnt']['VCM3'] = ('Enumeration',('AQ060','GB230'))
    field_information['GGDM 3.0']['AeronauticPnt']['EnumeratedIndexValues']['VCM3'] = {}
    field_information['GGDM 3.0']['AeronauticPnt']['EnumeratedIndexValues']['VCM3']['AQ060']  = (-999999,2,3,4,6,7,8,9,12,13,15,18,999)
    field_information['GGDM 3.0']['AeronauticPnt']['EnumeratedIndexValues']['VCM3']['GB230']  = (-999999,1,3,4,8,9,12,13,15,18,999)
    field_information['GGDM 3.0']['AeronauticPnt']['VOI'] = ('StructuredText',('AL510','AQ060','AQ110','GB230','GB250'))
    field_information['GGDM 3.0']['AeronauticPnt']['WID'] = ('Real',('AL351','AQ060','AQ110','GB005','GB030','GB035','GB040','GB065','GB230','GB250'))
    field_information['GGDM 3.0']['AeronauticPnt']['ZI001_SDV'] = ('StructuredText',('AL351','AL510','AQ060','AQ110','GB005','GB030','GB035','GB040','GB065','GB230','GB250'))
    field_information['GGDM 3.0']['AeronauticPnt']['ZI001_SRT'] = ('Enumeration',('AL351','AL510','AQ060','AQ110','GB005','GB030','GB035','GB040','GB065','GB230','GB250'))
    field_information['GGDM 3.0']['AeronauticPnt']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['AeronauticPnt']['EnumeratedIndexValues']['ZI001_SRT']['AL351']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['AeronauticPnt']['EnumeratedIndexValues']['ZI001_SRT']['AL510']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['AeronauticPnt']['EnumeratedIndexValues']['ZI001_SRT']['AQ060']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['AeronauticPnt']['EnumeratedIndexValues']['ZI001_SRT']['AQ110']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['AeronauticPnt']['EnumeratedIndexValues']['ZI001_SRT']['GB005']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['AeronauticPnt']['EnumeratedIndexValues']['ZI001_SRT']['GB030']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['AeronauticPnt']['EnumeratedIndexValues']['ZI001_SRT']['GB035']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['AeronauticPnt']['EnumeratedIndexValues']['ZI001_SRT']['GB040']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['AeronauticPnt']['EnumeratedIndexValues']['ZI001_SRT']['GB065']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['AeronauticPnt']['EnumeratedIndexValues']['ZI001_SRT']['GB230']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['AeronauticPnt']['EnumeratedIndexValues']['ZI001_SRT']['GB250']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['AeronauticPnt']['ZI002_UFI'] = ('StructuredText',('AL351','AL510','AQ060','AQ110','GB005','GB030','GB035','GB040','GB065','GB230','GB250'))
    field_information['GGDM 3.0']['AeronauticPnt']['ZI004_RCG'] = ('Enumeration',('AL351','AL510','AQ060','AQ110','GB005','GB030','GB035','GB040','GB065','GB230','GB250'))
    field_information['GGDM 3.0']['AeronauticPnt']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['AeronauticPnt']['EnumeratedIndexValues']['ZI004_RCG']['AL351']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['AeronauticPnt']['EnumeratedIndexValues']['ZI004_RCG']['AL510']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['AeronauticPnt']['EnumeratedIndexValues']['ZI004_RCG']['AQ060']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['AeronauticPnt']['EnumeratedIndexValues']['ZI004_RCG']['AQ110']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['AeronauticPnt']['EnumeratedIndexValues']['ZI004_RCG']['GB005']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['AeronauticPnt']['EnumeratedIndexValues']['ZI004_RCG']['GB030']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['AeronauticPnt']['EnumeratedIndexValues']['ZI004_RCG']['GB035']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['AeronauticPnt']['EnumeratedIndexValues']['ZI004_RCG']['GB040']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['AeronauticPnt']['EnumeratedIndexValues']['ZI004_RCG']['GB065']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['AeronauticPnt']['EnumeratedIndexValues']['ZI004_RCG']['GB230']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['AeronauticPnt']['EnumeratedIndexValues']['ZI004_RCG']['GB250']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['AeronauticPnt']['ZI005_FNA'] = ('String',('AL351','AL510','AQ060','AQ110','GB005','GB030','GB035','GB040','GB065','GB230'))
    field_information['GGDM 3.0']['AeronauticPnt']['ZI005_GNT'] = ('Enumeration',('AL351','AL510','AQ060','AQ110','GB005','GB030','GB035','GB040','GB065','GB230'))
    field_information['GGDM 3.0']['AeronauticPnt']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['AeronauticPnt']['EnumeratedIndexValues']['ZI005_GNT']['AL351']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['AeronauticPnt']['EnumeratedIndexValues']['ZI005_GNT']['AL510']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['AeronauticPnt']['EnumeratedIndexValues']['ZI005_GNT']['AQ060']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['AeronauticPnt']['EnumeratedIndexValues']['ZI005_GNT']['AQ110']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['AeronauticPnt']['EnumeratedIndexValues']['ZI005_GNT']['GB005']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['AeronauticPnt']['EnumeratedIndexValues']['ZI005_GNT']['GB030']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['AeronauticPnt']['EnumeratedIndexValues']['ZI005_GNT']['GB035']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['AeronauticPnt']['EnumeratedIndexValues']['ZI005_GNT']['GB040']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['AeronauticPnt']['EnumeratedIndexValues']['ZI005_GNT']['GB065']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['AeronauticPnt']['EnumeratedIndexValues']['ZI005_GNT']['GB230']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['AeronauticPnt']['ZI005_NFN'] = ('String',('AL351','AL510','AQ060','AQ110','GB005','GB030','GB035','GB040','GB065','GB230'))
    field_information['GGDM 3.0']['AeronauticPnt']['ZI006_MEM'] = ('String',('AL351','AL510','AQ060','AQ110','GB005','GB030','GB035','GB040','GB065','GB230','GB250'))
    field_information['GGDM 3.0']['AeronauticPnt']['ZI019_ASP'] = ('Enumeration',('GB030'))
    field_information['GGDM 3.0']['AeronauticPnt']['EnumeratedIndexValues']['ZI019_ASP'] = {}
    field_information['GGDM 3.0']['AeronauticPnt']['EnumeratedIndexValues']['ZI019_ASP']['GB030']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['GGDM 3.0']['AeronauticPnt']['ZI019_ASP2'] = ('Enumeration',('GB030'))
    field_information['GGDM 3.0']['AeronauticPnt']['EnumeratedIndexValues']['ZI019_ASP2'] = {}
    field_information['GGDM 3.0']['AeronauticPnt']['EnumeratedIndexValues']['ZI019_ASP2']['GB030']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['GGDM 3.0']['AeronauticPnt']['ZI019_ASP3'] = ('Enumeration',('GB030'))
    field_information['GGDM 3.0']['AeronauticPnt']['EnumeratedIndexValues']['ZI019_ASP3'] = {}
    field_information['GGDM 3.0']['AeronauticPnt']['EnumeratedIndexValues']['ZI019_ASP3']['GB030']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['GGDM 3.0']['AeronauticPnt']['ZI019_ASU'] = ('Enumeration',('GB030'))
    field_information['GGDM 3.0']['AeronauticPnt']['EnumeratedIndexValues']['ZI019_ASU'] = {}
    field_information['GGDM 3.0']['AeronauticPnt']['EnumeratedIndexValues']['ZI019_ASU']['GB030']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,20,21,999)
    field_information['GGDM 3.0']['AeronauticPnt']['ZI019_ASU2'] = ('Enumeration',('GB030'))
    field_information['GGDM 3.0']['AeronauticPnt']['EnumeratedIndexValues']['ZI019_ASU2'] = {}
    field_information['GGDM 3.0']['AeronauticPnt']['EnumeratedIndexValues']['ZI019_ASU2']['GB030']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,20,21,999)
    field_information['GGDM 3.0']['AeronauticPnt']['ZI019_ASU3'] = ('Enumeration',('GB030'))
    field_information['GGDM 3.0']['AeronauticPnt']['EnumeratedIndexValues']['ZI019_ASU3'] = {}
    field_information['GGDM 3.0']['AeronauticPnt']['EnumeratedIndexValues']['ZI019_ASU3']['GB030']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,20,21,999)
    field_information['GGDM 3.0']['AeronauticPnt']['ZI019_ASX'] = ('Enumeration',('GB030'))
    field_information['GGDM 3.0']['AeronauticPnt']['EnumeratedIndexValues']['ZI019_ASX'] = {}
    field_information['GGDM 3.0']['AeronauticPnt']['EnumeratedIndexValues']['ZI019_ASX']['GB030']  = (-999999,1,2,3,4,5,999)
    field_information['GGDM 3.0']['AeronauticPnt']['ZI019_SFS'] = ('Enumeration',('GB030'))
    field_information['GGDM 3.0']['AeronauticPnt']['EnumeratedIndexValues']['ZI019_SFS'] = {}
    field_information['GGDM 3.0']['AeronauticPnt']['EnumeratedIndexValues']['ZI019_SFS']['GB030']  = (-999999,1,2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['AeronauticPnt']['ZI020_GE4'] = ('CodeList',('AL351','AL510','AQ060','AQ110','GB005','GB030','GB035','GB040','GB065','GB230','GB250'))
    field_information['GGDM 3.0']['AeronauticPnt']['ZI026_CTUC'] = ('Enumeration',('AL351','AL510','AQ060','AQ110','GB005','GB030','GB035','GB040','GB065','GB230','GB250'))
    field_information['GGDM 3.0']['AeronauticPnt']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['AeronauticPnt']['EnumeratedIndexValues']['ZI026_CTUC']['AL351']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['AeronauticPnt']['EnumeratedIndexValues']['ZI026_CTUC']['AL510']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['AeronauticPnt']['EnumeratedIndexValues']['ZI026_CTUC']['AQ060']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['AeronauticPnt']['EnumeratedIndexValues']['ZI026_CTUC']['AQ110']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['AeronauticPnt']['EnumeratedIndexValues']['ZI026_CTUC']['GB005']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['AeronauticPnt']['EnumeratedIndexValues']['ZI026_CTUC']['GB030']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['AeronauticPnt']['EnumeratedIndexValues']['ZI026_CTUC']['GB035']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['AeronauticPnt']['EnumeratedIndexValues']['ZI026_CTUC']['GB040']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['AeronauticPnt']['EnumeratedIndexValues']['ZI026_CTUC']['GB065']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['AeronauticPnt']['EnumeratedIndexValues']['ZI026_CTUC']['GB230']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['AeronauticPnt']['EnumeratedIndexValues']['ZI026_CTUC']['GB250']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['AeronauticPnt']['ZI026_CTUL'] = ('integer',('AL351','AL510','AQ060','AQ110','GB005','GB030','GB035','GB040','GB065','GB230','GB250'))
    field_information['GGDM 3.0']['AeronauticPnt']['ZI026_CTUU'] = ('integer',('AL351','AL510','AQ060','AQ110','GB005','GB030','GB035','GB040','GB065','GB230','GB250'))
    field_information['GGDM 3.0']['AeronauticPnt']['ZI031S_URI'] = ('StructuredText',('AL351','AL510','AQ060','AQ110','GB005','GB030','GB035','GB040','GB065','GB230','GB250'))
    field_information['GGDM 3.0']['AeronauticPnt']['ZI039S_UFI'] = ('StructuredText',('AL351','AL510','AQ060','AQ110','GB005','GB030','GB035','GB040','GB065','GB230','GB250'))
    field_information['GGDM 3.0']['AeronauticPnt']['ZI103_MVD'] = ('StructuredText',('GB005','GB065'))
    field_information['GGDM 3.0']['AeronauticPnt']['ZSAX_RS0'] = ('CodeList',('AL351','AL510','AQ060','AQ110','GB005','GB030','GB035','GB040','GB065','GB230','GB250'))
    field_information['GGDM 3.0']['AeronauticPnt']['ZSAX_RX0'] = ('StructuredText',('AL351','AL510','AQ060','AQ110','GB005','GB030','GB035','GB040','GB065','GB230','GB250'))
    field_information['GGDM 3.0']['AeronauticPnt']['ZSAX_RX3'] = ('StructuredText',('AL351','AL510','AQ060','AQ110','GB005','GB030','GB035','GB040','GB065','GB230','GB250'))
    field_information['GGDM 3.0']['AeronauticPnt']['ZSAX_RX4'] = ('StructuredText',('AL351','AL510','AQ060','AQ110','GB005','GB030','GB035','GB040','GB065','GB230','GB250'))
    field_information['GGDM 3.0']['AeronauticPnt']['ZVA'] = ('Real',('GB005','GB035','GB065'))
    field_information['GGDM 3.0']['AeronauticPnt']['ZVH'] = ('Real',('AL351','AL510','AQ060','AQ110','GB005','GB030','GB035','GB040','GB065','GB230','GB250'))
    field_information['GGDM 3.0']['AeronauticPntExt']['ARA'] = ('Real',('GA033'))
    field_information['GGDM 3.0']['AeronauticPntExt']['ART'] = ('Enumeration',('GA033'))
    field_information['GGDM 3.0']['AeronauticPntExt']['EnumeratedIndexValues']['ART'] = {}
    field_information['GGDM 3.0']['AeronauticPntExt']['EnumeratedIndexValues']['ART']['GA033']  = (-999999,1,2,3)
    field_information['GGDM 3.0']['AeronauticPntExt']['ASO'] = ('Enumeration',('GA033'))
    field_information['GGDM 3.0']['AeronauticPntExt']['EnumeratedIndexValues']['ASO'] = {}
    field_information['GGDM 3.0']['AeronauticPntExt']['EnumeratedIndexValues']['ASO']['GA033']  = (-999999,1,2,3,4,6,7,8,10,11,12,13,14,15,16,17)
    field_information['GGDM 3.0']['AeronauticPntExt']['AWP'] = ('Boolean',('GA033'))
    field_information['GGDM 3.0']['AeronauticPntExt']['BEN'] = ('StructuredText',('GA033','GB013','STB23'))
    field_information['GGDM 3.0']['AeronauticPntExt']['CAA'] = ('Enumeration',('GB013'))
    field_information['GGDM 3.0']['AeronauticPntExt']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['AeronauticPntExt']['EnumeratedIndexValues']['CAA']['GB013']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['AeronauticPntExt']['CHA'] = ('Enumeration',('GB013'))
    field_information['GGDM 3.0']['AeronauticPntExt']['EnumeratedIndexValues']['CHA'] = {}
    field_information['GGDM 3.0']['AeronauticPntExt']['EnumeratedIndexValues']['CHA']['GB013']  = (-999999,1,4,5,6,8,11,12,13,14,15,16,17,28,29,44,45,46,47,48,49,50,51,57,58,59,60)
    field_information['GGDM 3.0']['AeronauticPntExt']['CMS'] = ('Enumeration',('GA033'))
    field_information['GGDM 3.0']['AeronauticPntExt']['EnumeratedIndexValues']['CMS'] = {}
    field_information['GGDM 3.0']['AeronauticPntExt']['EnumeratedIndexValues']['CMS']['GA033']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['AeronauticPntExt']['CNCP'] = ('StructuredText',('GB013'))
    field_information['GGDM 3.0']['AeronauticPntExt']['COC'] = ('Enumeration',('GB013'))
    field_information['GGDM 3.0']['AeronauticPntExt']['EnumeratedIndexValues']['COC'] = {}
    field_information['GGDM 3.0']['AeronauticPntExt']['EnumeratedIndexValues']['COC']['GB013']  = (-999999,1,2,3,4)
    field_information['GGDM 3.0']['AeronauticPntExt']['COL'] = ('StructuredText',('GB013'))
    field_information['GGDM 3.0']['AeronauticPntExt']['COS'] = ('Enumeration',('GB013'))
    field_information['GGDM 3.0']['AeronauticPntExt']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['AeronauticPntExt']['EnumeratedIndexValues']['COS']['GB013']  = (-999999,4,6,8,9,13,14)
    field_information['GGDM 3.0']['AeronauticPntExt']['DIA'] = ('StructuredText',('GA033'))
    field_information['GGDM 3.0']['AeronauticPntExt']['DIR'] = ('Enumeration',('GA033'))
    field_information['GGDM 3.0']['AeronauticPntExt']['EnumeratedIndexValues']['DIR'] = {}
    field_information['GGDM 3.0']['AeronauticPntExt']['EnumeratedIndexValues']['DIR']['GA033']  = (-999999,1,2,3)
    field_information['GGDM 3.0']['AeronauticPntExt']['F_CODE'] = ('CONSTRAINED_STRING',('GA033','GB013','STB23'))
    field_information['GGDM 3.0']['AeronauticPntExt']['FUFI'] = ('StructuredText',('GA033','GB013','STB23'))
    field_information['GGDM 3.0']['AeronauticPntExt']['FURL'] = ('StructuredText',('GA033','GB013','STB23'))
    field_information['GGDM 3.0']['AeronauticPntExt']['GA032_NSX'] = ('String',('GA033'))
    field_information['GGDM 3.0']['AeronauticPntExt']['GB001_AID'] = ('String',('GB013'))
    field_information['GGDM 3.0']['AeronauticPntExt']['GDBV'] = ('Enumeration',('GA033','GB013','STB23'))
    field_information['GGDM 3.0']['AeronauticPntExt']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['AeronauticPntExt']['EnumeratedIndexValues']['GDBV']['GA033']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['AeronauticPntExt']['EnumeratedIndexValues']['GDBV']['GB013']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['AeronauticPntExt']['EnumeratedIndexValues']['GDBV']['STB23']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['AeronauticPntExt']['HGT'] = ('Real',('GB013'))
    field_information['GGDM 3.0']['AeronauticPntExt']['LCN'] = ('Integer',('GB013'))
    field_information['GGDM 3.0']['AeronauticPntExt']['LOC'] = ('Enumeration',('GA033'))
    field_information['GGDM 3.0']['AeronauticPntExt']['EnumeratedIndexValues']['LOC'] = {}
    field_information['GGDM 3.0']['AeronauticPntExt']['EnumeratedIndexValues']['LOC']['GA033']  = (-999999,44,45)
    field_information['GGDM 3.0']['AeronauticPntExt']['LZN'] = ('Real',('GA033'))
    field_information['GGDM 3.0']['AeronauticPntExt']['MCA'] = ('String',('GA033'))
    field_information['GGDM 3.0']['AeronauticPntExt']['MCC'] = ('Enumeration',('GA033'))
    field_information['GGDM 3.0']['AeronauticPntExt']['EnumeratedIndexValues']['MCC'] = {}
    field_information['GGDM 3.0']['AeronauticPntExt']['EnumeratedIndexValues']['MCC']['GA033']  = (-999999,2,21,51,64,107,120,131,999)
    field_information['GGDM 3.0']['AeronauticPntExt']['MCC2'] = ('Enumeration',('GA033'))
    field_information['GGDM 3.0']['AeronauticPntExt']['EnumeratedIndexValues']['MCC2'] = {}
    field_information['GGDM 3.0']['AeronauticPntExt']['EnumeratedIndexValues']['MCC2']['GA033']  = (-999999,2,21,51,64,107,120,131,999)
    field_information['GGDM 3.0']['AeronauticPntExt']['MCC3'] = ('Enumeration',('GA033'))
    field_information['GGDM 3.0']['AeronauticPntExt']['EnumeratedIndexValues']['MCC3'] = {}
    field_information['GGDM 3.0']['AeronauticPntExt']['EnumeratedIndexValues']['MCC3']['GA033']  = (-999999,2,21,51,64,107,120,131,999)
    field_information['GGDM 3.0']['AeronauticPntExt']['OTH'] = ('StructuredText',('GA033','GB013','STB23'))
    field_information['GGDM 3.0']['AeronauticPntExt']['PCF'] = ('Enumeration',('GA033','GB013'))
    field_information['GGDM 3.0']['AeronauticPntExt']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['AeronauticPntExt']['EnumeratedIndexValues']['PCF']['GA033']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['AeronauticPntExt']['EnumeratedIndexValues']['PCF']['GB013']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['AeronauticPntExt']['PER'] = ('Real',('GB013'))
    field_information['GGDM 3.0']['AeronauticPntExt']['PRM'] = ('Boolean',('GA033'))
    field_information['GGDM 3.0']['AeronauticPntExt']['PWR'] = ('Real',('GA033'))
    field_information['GGDM 3.0']['AeronauticPntExt']['RAC'] = ('Enumeration',('GA033'))
    field_information['GGDM 3.0']['AeronauticPntExt']['EnumeratedIndexValues']['RAC'] = {}
    field_information['GGDM 3.0']['AeronauticPntExt']['EnumeratedIndexValues']['RAC']['GA033']  = (-999999,1,3,4,6,999)
    field_information['GGDM 3.0']['AeronauticPntExt']['RSI'] = ('Enumeration',('GA033'))
    field_information['GGDM 3.0']['AeronauticPntExt']['EnumeratedIndexValues']['RSI'] = {}
    field_information['GGDM 3.0']['AeronauticPntExt']['EnumeratedIndexValues']['RSI']['GA033']  = (-999999,1,2,3,4,5,999)
    field_information['GGDM 3.0']['AeronauticPntExt']['SPT'] = ('Boolean',('GA033'))
    field_information['GGDM 3.0']['AeronauticPntExt']['SRL'] = ('Enumeration',('GA033'))
    field_information['GGDM 3.0']['AeronauticPntExt']['EnumeratedIndexValues']['SRL'] = {}
    field_information['GGDM 3.0']['AeronauticPntExt']['EnumeratedIndexValues']['SRL']['GA033']  = (-999999,1,2,3)
    field_information['GGDM 3.0']['AeronauticPntExt']['UFI'] = ('StructuredText',('GA033','GB013','STB23'))
    field_information['GGDM 3.0']['AeronauticPntExt']['VIS'] = ('Enumeration',('GB013'))
    field_information['GGDM 3.0']['AeronauticPntExt']['EnumeratedIndexValues']['VIS'] = {}
    field_information['GGDM 3.0']['AeronauticPntExt']['EnumeratedIndexValues']['VIS']['GB013']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['GGDM 3.0']['AeronauticPntExt']['VIS2'] = ('Enumeration',('GB013'))
    field_information['GGDM 3.0']['AeronauticPntExt']['EnumeratedIndexValues']['VIS2'] = {}
    field_information['GGDM 3.0']['AeronauticPntExt']['EnumeratedIndexValues']['VIS2']['GB013']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['GGDM 3.0']['AeronauticPntExt']['VIS3'] = ('Enumeration',('GB013'))
    field_information['GGDM 3.0']['AeronauticPntExt']['EnumeratedIndexValues']['VIS3'] = {}
    field_information['GGDM 3.0']['AeronauticPntExt']['EnumeratedIndexValues']['VIS3']['GB013']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['GGDM 3.0']['AeronauticPntExt']['VOI'] = ('StructuredText',('GA033','GB013'))
    field_information['GGDM 3.0']['AeronauticPntExt']['WID'] = ('Real',('GA033'))
    field_information['GGDM 3.0']['AeronauticPntExt']['ZI001_SDV'] = ('StructuredText',('GA033','GB013','STB23'))
    field_information['GGDM 3.0']['AeronauticPntExt']['ZI001_SRT'] = ('Enumeration',('GA033','GB013','STB23'))
    field_information['GGDM 3.0']['AeronauticPntExt']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['AeronauticPntExt']['EnumeratedIndexValues']['ZI001_SRT']['GA033']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['AeronauticPntExt']['EnumeratedIndexValues']['ZI001_SRT']['GB013']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['AeronauticPntExt']['EnumeratedIndexValues']['ZI001_SRT']['STB23']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['AeronauticPntExt']['ZI002_UFI'] = ('StructuredText',('GA033','GB013','STB23'))
    field_information['GGDM 3.0']['AeronauticPntExt']['ZI004_RCG'] = ('Enumeration',('GA033','GB013','STB23'))
    field_information['GGDM 3.0']['AeronauticPntExt']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['AeronauticPntExt']['EnumeratedIndexValues']['ZI004_RCG']['GA033']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['AeronauticPntExt']['EnumeratedIndexValues']['ZI004_RCG']['GB013']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['AeronauticPntExt']['EnumeratedIndexValues']['ZI004_RCG']['STB23']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['AeronauticPntExt']['ZI005_FNA'] = ('String',('GA033','GB013'))
    field_information['GGDM 3.0']['AeronauticPntExt']['ZI005_GNT'] = ('Enumeration',('GA033','GB013'))
    field_information['GGDM 3.0']['AeronauticPntExt']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['AeronauticPntExt']['EnumeratedIndexValues']['ZI005_GNT']['GA033']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['AeronauticPntExt']['EnumeratedIndexValues']['ZI005_GNT']['GB013']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['AeronauticPntExt']['ZI005_NFN'] = ('String',('GA033','GB013'))
    field_information['GGDM 3.0']['AeronauticPntExt']['ZI006_MEM'] = ('String',('GA033','GB013','STB23'))
    field_information['GGDM 3.0']['AeronauticPntExt']['ZI020_GE4'] = ('CodeList',('GA033','GB013','STB23'))
    field_information['GGDM 3.0']['AeronauticPntExt']['ZI026_CTUC'] = ('Enumeration',('GA033','GB013','STB23'))
    field_information['GGDM 3.0']['AeronauticPntExt']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['AeronauticPntExt']['EnumeratedIndexValues']['ZI026_CTUC']['GA033']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['AeronauticPntExt']['EnumeratedIndexValues']['ZI026_CTUC']['GB013']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['AeronauticPntExt']['EnumeratedIndexValues']['ZI026_CTUC']['STB23']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['AeronauticPntExt']['ZI026_CTUL'] = ('integer',('GA033','GB013','STB23'))
    field_information['GGDM 3.0']['AeronauticPntExt']['ZI026_CTUU'] = ('integer',('GA033','GB013','STB23'))
    field_information['GGDM 3.0']['AeronauticPntExt']['ZI031S_URI'] = ('StructuredText',('GA033','GB013','STB23'))
    field_information['GGDM 3.0']['AeronauticPntExt']['ZI039S_UFI'] = ('StructuredText',('GA033','GB013','STB23'))
    field_information['GGDM 3.0']['AeronauticPntExt']['ZSAX_RS0'] = ('CodeList',('GA033','GB013','STB23'))
    field_information['GGDM 3.0']['AeronauticPntExt']['ZSAX_RX0'] = ('StructuredText',('GA033','GB013','STB23'))
    field_information['GGDM 3.0']['AeronauticPntExt']['ZSAX_RX3'] = ('StructuredText',('GA033','GB013','STB23'))
    field_information['GGDM 3.0']['AeronauticPntExt']['ZSAX_RX4'] = ('StructuredText',('GA033','GB013','STB23'))
    field_information['GGDM 3.0']['AeronauticPntExt']['ZVH'] = ('Real',('GA033','GB013'))
    field_information['GGDM 3.0']['AeronauticSrf']['ADR'] = ('String',('AL351','AQ060','GB230','GB250'))
    field_information['GGDM 3.0']['AeronauticSrf']['AOO'] = ('Real',('AL351','AQ060','GB040','GB070','GB230','GB250'))
    field_information['GGDM 3.0']['AeronauticSrf']['APT'] = ('Enumeration',('GB005'))
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['APT'] = {}
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['APT']['GB005']  = (-999999,1,2,3,5,6,7,8,12,13,16,999)
    field_information['GGDM 3.0']['AeronauticSrf']['APT2'] = ('Enumeration',('GB005'))
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['APT2'] = {}
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['APT2']['GB005']  = (-999999,1,2,3,5,6,7,8,12,13,16,999)
    field_information['GGDM 3.0']['AeronauticSrf']['APT3'] = ('Enumeration',('GB005'))
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['APT3'] = {}
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['APT3']['GB005']  = (-999999,1,2,3,5,6,7,8,12,13,16,999)
    field_information['GGDM 3.0']['AeronauticSrf']['APU'] = ('Enumeration',('GB015'))
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['APU'] = {}
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['APU']['GB015']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,999)
    field_information['GGDM 3.0']['AeronauticSrf']['APU2'] = ('Enumeration',('GB015'))
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['APU2'] = {}
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['APU2']['GB015']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,999)
    field_information['GGDM 3.0']['AeronauticSrf']['APU3'] = ('Enumeration',('GB015'))
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['APU3'] = {}
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['APU3']['GB015']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,999)
    field_information['GGDM 3.0']['AeronauticSrf']['APY'] = ('Enumeration',('GB015'))
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['APY'] = {}
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['APY']['GB015']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['GGDM 3.0']['AeronauticSrf']['ARA'] = ('Real',('AL351','AQ060','GB005','GB015','GB030','GB035','GB040','GB045','GB055','GB065','GB070','GB075','GB230','GB250'))
    field_information['GGDM 3.0']['AeronauticSrf']['ASU'] = ('Enumeration',('GB045'))
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['ASU'] = {}
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['ASU']['GB045']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,20,21,999)
    field_information['GGDM 3.0']['AeronauticSrf']['ASU2'] = ('Enumeration',('GB045'))
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['ASU2'] = {}
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['ASU2']['GB045']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,20,21,999)
    field_information['GGDM 3.0']['AeronauticSrf']['ASU3'] = ('Enumeration',('GB045'))
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['ASU3'] = {}
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['ASU3']['GB045']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,20,21,999)
    field_information['GGDM 3.0']['AeronauticSrf']['ASY'] = ('Enumeration',('GB005','GB035','GB065'))
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['ASY'] = {}
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['ASY']['GB005']  = (-999999,1,2,3,4,5,6,7,12)
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['ASY']['GB035']  = (-999999,8,9,10,11,12,13)
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['ASY']['GB065']  = (-999999,1,2,3,4,5,7,12)
    field_information['GGDM 3.0']['AeronauticSrf']['ATB'] = ('Boolean',('GB230'))
    field_information['GGDM 3.0']['AeronauticSrf']['AWP'] = ('Boolean',('AQ060','GB230','GB250'))
    field_information['GGDM 3.0']['AeronauticSrf']['AXS'] = ('Enumeration',('GB015','GB030','GB055','GB075'))
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['AXS'] = {}
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['AXS']['GB015']  = (-999999,1,2,3,4)
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['AXS']['GB030']  = (-999999,1,2,3,4)
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['AXS']['GB055']  = (-999999,1,2,3,4)
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['AXS']['GB075']  = (-999999,1,2,3,4)
    field_information['GGDM 3.0']['AeronauticSrf']['BEN'] = ('StructuredText',('AL351','AQ060','GB005','GB015','GB030','GB035','GB040','GB045','GB055','GB065','GB070','GB075','GB230','GB250'))
    field_information['GGDM 3.0']['AeronauticSrf']['CAA'] = ('Enumeration',('AL351','AQ060','GB005','GB030','GB035','GB055','GB065','GB070','GB230','GB250'))
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['CAA']['AL351']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['CAA']['AQ060']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['CAA']['GB005']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['CAA']['GB030']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['CAA']['GB035']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['CAA']['GB055']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['CAA']['GB065']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['CAA']['GB070']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['CAA']['GB230']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['CAA']['GB250']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['AeronauticSrf']['CNCP'] = ('StructuredText',('AL351','AQ060','GB005','GB015','GB030','GB035','GB040','GB045','GB055','GB065','GB070','GB075','GB230','GB250'))
    field_information['GGDM 3.0']['AeronauticSrf']['COS'] = ('Enumeration',('AL351','AQ060','GB005','GB015','GB030','GB035','GB040','GB045','GB055','GB065','GB070','GB075','GB230','GB250'))
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['COS']['AL351']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['COS']['AQ060']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['COS']['GB005']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['COS']['GB015']  = (-999999,4,6,8,13,14)
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['COS']['GB030']  = (-999999,4,6,8,13,14)
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['COS']['GB035']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['COS']['GB040']  = (-999999,4,6,8,9,13,14)
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['COS']['GB045']  = (-999999,4,6,8,9,13,14)
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['COS']['GB055']  = (-999999,4,6,8,13,14)
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['COS']['GB065']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['COS']['GB070']  = (-999999,8,9,13,14)
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['COS']['GB075']  = (-999999,4,6,13,14)
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['COS']['GB230']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['COS']['GB250']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['AeronauticSrf']['DEV'] = ('Integer',('GB055','GB075'))
    field_information['GGDM 3.0']['AeronauticSrf']['F_CODE'] = ('CONSTRAINED_STRING',('AL351','AQ060','GB005','GB015','GB030','GB035','GB040','GB045','GB055','GB065','GB070','GB075','GB230','GB250'))
    field_information['GGDM 3.0']['AeronauticSrf']['FFN'] = ('Enumeration',('AL351','AQ060','GB230','GB250'))
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['FFN'] = {}
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['FFN']['AL351']  = (-999999,331,333,334,341,530,550,835,847,970,999)
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['FFN']['AQ060']  = (-999999,486,490,495,505,507,508,510,511,513,520,525,847,999)
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['FFN']['GB230']  = (-999999,341,520,530,536,847,862,881,999)
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['FFN']['GB250']  = (-999999,341,520,530,536,835,836,847,999)
    field_information['GGDM 3.0']['AeronauticSrf']['FFN2'] = ('Enumeration',('AL351','AQ060','GB230','GB250'))
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['FFN2'] = {}
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['FFN2']['AL351']  = (-999999,331,333,334,341,530,550,835,847,970,999)
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['FFN2']['AQ060']  = (-999999,486,490,495,505,507,508,510,511,513,520,525,847,999)
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['FFN2']['GB230']  = (-999999,341,520,530,536,847,862,881,999)
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['FFN2']['GB250']  = (-999999,341,520,530,536,835,836,847,999)
    field_information['GGDM 3.0']['AeronauticSrf']['FFN3'] = ('Enumeration',('AL351','AQ060','GB230','GB250'))
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['FFN3'] = {}
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['FFN3']['AL351']  = (-999999,331,333,334,341,530,550,835,847,970,999)
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['FFN3']['AQ060']  = (-999999,486,490,495,505,507,508,510,511,513,520,525,847,999)
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['FFN3']['GB230']  = (-999999,341,520,530,536,847,862,881,999)
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['FFN3']['GB250']  = (-999999,341,520,530,536,835,836,847,999)
    field_information['GGDM 3.0']['AeronauticSrf']['FPT'] = ('Enumeration',('GB005','GB035'))
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['FPT'] = {}
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['FPT']['GB005']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['FPT']['GB035']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['AeronauticSrf']['FUFI'] = ('StructuredText',('AL351','AQ060','GB005','GB015','GB030','GB035','GB040','GB045','GB055','GB065','GB070','GB075','GB230','GB250'))
    field_information['GGDM 3.0']['AeronauticSrf']['FURL'] = ('StructuredText',('AL351','AQ060','GB005','GB015','GB030','GB035','GB040','GB045','GB055','GB065','GB070','GB075','GB230','GB250'))
    field_information['GGDM 3.0']['AeronauticSrf']['GB052_RIDH'] = ('StructuredText',('GB055'))
    field_information['GGDM 3.0']['AeronauticSrf']['GB052_RIDL'] = ('StructuredText',('GB055'))
    field_information['GGDM 3.0']['AeronauticSrf']['GB052_TRHH'] = ('Real',('GB055'))
    field_information['GGDM 3.0']['AeronauticSrf']['GB052_TRHL'] = ('Real',('GB055'))
    field_information['GGDM 3.0']['AeronauticSrf']['GDBV'] = ('Enumeration',('AL351','AQ060','GB005','GB015','GB030','GB035','GB040','GB045','GB055','GB065','GB070','GB075','GB230','GB250'))
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['GDBV']['AL351']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['GDBV']['AQ060']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['GDBV']['GB005']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['GDBV']['GB015']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['GDBV']['GB030']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['GDBV']['GB035']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['GDBV']['GB040']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['GDBV']['GB045']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['GDBV']['GB055']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['GDBV']['GB065']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['GDBV']['GB070']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['GDBV']['GB075']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['GDBV']['GB230']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['GDBV']['GB250']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['AeronauticSrf']['GSGCHC'] = ('Enumeration',('GB055'))
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['GSGCHC'] = {}
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['GSGCHC']['GB055']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['AeronauticSrf']['GSGCHL'] = ('real',('GB055'))
    field_information['GGDM 3.0']['AeronauticSrf']['GSGCHU'] = ('real',('GB055'))
    field_information['GGDM 3.0']['AeronauticSrf']['GSGCLC'] = ('Enumeration',('GB055'))
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['GSGCLC'] = {}
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['GSGCLC']['GB055']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['AeronauticSrf']['GSGCLL'] = ('real',('GB055'))
    field_information['GGDM 3.0']['AeronauticSrf']['GSGCLU'] = ('real',('GB055'))
    field_information['GGDM 3.0']['AeronauticSrf']['HAF'] = ('Enumeration',('GB030'))
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['HAF'] = {}
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['HAF']['GB030']  = (-999999,1,2,3,4,6,9,10,11,999)
    field_information['GGDM 3.0']['AeronauticSrf']['HGT'] = ('Real',('AL351','AQ060','GB030','GB040','GB230','GB250'))
    field_information['GGDM 3.0']['AeronauticSrf']['HST'] = ('Enumeration',('GB250'))
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['HST'] = {}
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['HST']['GB250']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['AeronauticSrf']['HST2'] = ('Enumeration',('GB250'))
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['HST2'] = {}
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['HST2']['GB250']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['AeronauticSrf']['HST3'] = ('Enumeration',('GB250'))
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['HST3'] = {}
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['HST3']['GB250']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['AeronauticSrf']['HTP'] = ('Enumeration',('GB230','GB250'))
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['HTP'] = {}
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['HTP']['GB230']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['HTP']['GB250']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['AeronauticSrf']['IKO'] = ('StructuredText',('GB005','GB035','GB065'))
    field_information['GGDM 3.0']['AeronauticSrf']['LASZ'] = ('String',('GB005','GB065'))
    field_information['GGDM 3.0']['AeronauticSrf']['LMC'] = ('Boolean',('AL351','AQ060','GB230','GB250'))
    field_information['GGDM 3.0']['AeronauticSrf']['LZN'] = ('Real',('AL351','AQ060','GB005','GB015','GB030','GB035','GB040','GB045','GB055','GB065','GB070','GB075','GB230','GB250'))
    field_information['GGDM 3.0']['AeronauticSrf']['MAG'] = ('Real',('GB005','GB035','GB065'))
    field_information['GGDM 3.0']['AeronauticSrf']['MCC'] = ('Enumeration',('GB040'))
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['MCC'] = {}
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['MCC']['GB040']  = (-999999,5,21,51,64,107,117,999)
    field_information['GGDM 3.0']['AeronauticSrf']['MCC2'] = ('Enumeration',('GB040'))
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['MCC2'] = {}
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['MCC2']['GB040']  = (-999999,5,21,51,64,107,117,999)
    field_information['GGDM 3.0']['AeronauticSrf']['MCC3'] = ('Enumeration',('GB040'))
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['MCC3'] = {}
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['MCC3']['GB040']  = (-999999,5,21,51,64,107,117,999)
    field_information['GGDM 3.0']['AeronauticSrf']['MUB'] = ('Boolean',('GB250'))
    field_information['GGDM 3.0']['AeronauticSrf']['NA8'] = ('String',('GB005','GB035','GB065'))
    field_information['GGDM 3.0']['AeronauticSrf']['NAO'] = ('String',('GB005','GB035','GB065'))
    field_information['GGDM 3.0']['AeronauticSrf']['OTH'] = ('StructuredText',('AL351','AQ060','GB005','GB015','GB030','GB035','GB040','GB045','GB055','GB065','GB070','GB075','GB230','GB250'))
    field_information['GGDM 3.0']['AeronauticSrf']['PCF'] = ('Enumeration',('AL351','AQ060','GB005','GB015','GB030','GB035','GB040','GB045','GB055','GB065','GB070','GB075','GB230','GB250'))
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['PCF']['AL351']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['PCF']['AQ060']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['PCF']['GB005']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['PCF']['GB015']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['PCF']['GB030']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['PCF']['GB035']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['PCF']['GB040']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['PCF']['GB045']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['PCF']['GB055']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['PCF']['GB065']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['PCF']['GB070']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['PCF']['GB075']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['PCF']['GB230']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['PCF']['GB250']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['AeronauticSrf']['PEC'] = ('Boolean',('GB005','GB035','GB065'))
    field_information['GGDM 3.0']['AeronauticSrf']['SBB'] = ('Boolean',('GB055','GB075'))
    field_information['GGDM 3.0']['AeronauticSrf']['SERP'] = ('Enumeration',('GB055'))
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['SERP'] = {}
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['SERP']['GB055']  = (-999999,6,7,8)
    field_information['GGDM 3.0']['AeronauticSrf']['SSR'] = ('Enumeration',('AQ060','GB230','GB250'))
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['SSR'] = {}
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['SSR']['AQ060']  = (-999999,6,7,38,40,41,42,47,50,55,64,999)
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['SSR']['GB230']  = (-999999,6,7,38,40,41,42,47,50,55,64,999)
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['SSR']['GB250']  = (-999999,6,7,38,40,41,42,47,50,55,64,999)
    field_information['GGDM 3.0']['AeronauticSrf']['SSR2'] = ('Enumeration',('AQ060','GB230','GB250'))
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['SSR2'] = {}
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['SSR2']['AQ060']  = (-999999,6,7,38,40,41,42,47,50,55,64,999)
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['SSR2']['GB230']  = (-999999,6,7,38,40,41,42,47,50,55,64,999)
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['SSR2']['GB250']  = (-999999,6,7,38,40,41,42,47,50,55,64,999)
    field_information['GGDM 3.0']['AeronauticSrf']['SSR3'] = ('Enumeration',('AQ060','GB230','GB250'))
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['SSR3'] = {}
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['SSR3']['AQ060']  = (-999999,6,7,38,40,41,42,47,50,55,64,999)
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['SSR3']['GB230']  = (-999999,6,7,38,40,41,42,47,50,55,64,999)
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['SSR3']['GB250']  = (-999999,6,7,38,40,41,42,47,50,55,64,999)
    field_information['GGDM 3.0']['AeronauticSrf']['TRS'] = ('Enumeration',('AQ060'))
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['TRS'] = {}
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['TRS']['AQ060']  = (-999999,2,5,7,8,9,12,13,17,20,999)
    field_information['GGDM 3.0']['AeronauticSrf']['TRS2'] = ('Enumeration',('AQ060'))
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['TRS2'] = {}
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['TRS2']['AQ060']  = (-999999,2,5,7,8,9,12,13,17,20,999)
    field_information['GGDM 3.0']['AeronauticSrf']['TRS3'] = ('Enumeration',('AQ060'))
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['TRS3'] = {}
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['TRS3']['AQ060']  = (-999999,2,5,7,8,9,12,13,17,20,999)
    field_information['GGDM 3.0']['AeronauticSrf']['TXP'] = ('Enumeration',('GB075'))
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['TXP'] = {}
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['TXP']['GB075']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,999)
    field_information['GGDM 3.0']['AeronauticSrf']['UFI'] = ('StructuredText',('AL351','AQ060','GB005','GB015','GB030','GB035','GB040','GB045','GB055','GB065','GB070','GB075','GB230','GB250'))
    field_information['GGDM 3.0']['AeronauticSrf']['VCM'] = ('Enumeration',('AQ060','GB230'))
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['VCM'] = {}
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['VCM']['AQ060']  = (-999999,2,3,4,6,7,8,9,12,13,15,18,999)
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['VCM']['GB230']  = (-999999,1,3,4,8,9,12,13,15,18,999)
    field_information['GGDM 3.0']['AeronauticSrf']['VCM2'] = ('Enumeration',('AQ060','GB230'))
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['VCM2'] = {}
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['VCM2']['AQ060']  = (-999999,2,3,4,6,7,8,9,12,13,15,18,999)
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['VCM2']['GB230']  = (-999999,1,3,4,8,9,12,13,15,18,999)
    field_information['GGDM 3.0']['AeronauticSrf']['VCM3'] = ('Enumeration',('AQ060','GB230'))
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['VCM3'] = {}
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['VCM3']['AQ060']  = (-999999,2,3,4,6,7,8,9,12,13,15,18,999)
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['VCM3']['GB230']  = (-999999,1,3,4,8,9,12,13,15,18,999)
    field_information['GGDM 3.0']['AeronauticSrf']['VOI'] = ('StructuredText',('AQ060','GB230','GB250'))
    field_information['GGDM 3.0']['AeronauticSrf']['WID'] = ('Real',('AL351','AQ060','GB005','GB015','GB030','GB035','GB040','GB045','GB055','GB065','GB070','GB075','GB230','GB250'))
    field_information['GGDM 3.0']['AeronauticSrf']['ZI001_SDV'] = ('StructuredText',('AL351','AQ060','GB005','GB015','GB030','GB035','GB040','GB045','GB055','GB065','GB070','GB075','GB230','GB250'))
    field_information['GGDM 3.0']['AeronauticSrf']['ZI001_SRT'] = ('Enumeration',('AL351','AQ060','GB005','GB015','GB030','GB035','GB040','GB045','GB055','GB065','GB070','GB075','GB230','GB250'))
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['ZI001_SRT']['AL351']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['ZI001_SRT']['AQ060']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['ZI001_SRT']['GB005']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['ZI001_SRT']['GB015']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['ZI001_SRT']['GB030']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['ZI001_SRT']['GB035']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['ZI001_SRT']['GB040']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['ZI001_SRT']['GB045']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['ZI001_SRT']['GB055']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['ZI001_SRT']['GB065']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['ZI001_SRT']['GB070']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['ZI001_SRT']['GB075']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['ZI001_SRT']['GB230']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['ZI001_SRT']['GB250']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['AeronauticSrf']['ZI002_UFI'] = ('StructuredText',('AL351','AQ060','GB005','GB015','GB030','GB035','GB040','GB045','GB055','GB065','GB070','GB075','GB230','GB250'))
    field_information['GGDM 3.0']['AeronauticSrf']['ZI004_RCG'] = ('Enumeration',('AL351','AQ060','GB005','GB015','GB030','GB035','GB040','GB045','GB055','GB065','GB070','GB075','GB230','GB250'))
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['ZI004_RCG']['AL351']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['ZI004_RCG']['AQ060']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['ZI004_RCG']['GB005']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['ZI004_RCG']['GB015']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['ZI004_RCG']['GB030']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['ZI004_RCG']['GB035']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['ZI004_RCG']['GB040']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['ZI004_RCG']['GB045']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['ZI004_RCG']['GB055']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['ZI004_RCG']['GB065']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['ZI004_RCG']['GB070']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['ZI004_RCG']['GB075']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['ZI004_RCG']['GB230']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['ZI004_RCG']['GB250']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['AeronauticSrf']['ZI005_FNA'] = ('String',('AL351','AQ060','GB005','GB015','GB030','GB035','GB040','GB045','GB055','GB065','GB070','GB075','GB230'))
    field_information['GGDM 3.0']['AeronauticSrf']['ZI005_GNT'] = ('Enumeration',('AL351','AQ060','GB005','GB015','GB030','GB035','GB040','GB045','GB055','GB065','GB070','GB075','GB230'))
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['ZI005_GNT']['AL351']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['ZI005_GNT']['AQ060']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['ZI005_GNT']['GB005']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['ZI005_GNT']['GB015']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['ZI005_GNT']['GB030']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['ZI005_GNT']['GB035']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['ZI005_GNT']['GB040']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['ZI005_GNT']['GB045']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['ZI005_GNT']['GB055']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['ZI005_GNT']['GB065']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['ZI005_GNT']['GB070']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['ZI005_GNT']['GB075']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['ZI005_GNT']['GB230']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['AeronauticSrf']['ZI005_NFN'] = ('String',('AL351','AQ060','GB005','GB015','GB030','GB035','GB040','GB045','GB055','GB065','GB070','GB075','GB230'))
    field_information['GGDM 3.0']['AeronauticSrf']['ZI006_MEM'] = ('String',('AL351','AQ060','GB005','GB015','GB030','GB035','GB040','GB045','GB055','GB065','GB070','GB075','GB230','GB250'))
    field_information['GGDM 3.0']['AeronauticSrf']['ZI019_ASP'] = ('Enumeration',('GB015','GB030','GB055','GB075'))
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['ZI019_ASP'] = {}
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['ZI019_ASP']['GB015']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['ZI019_ASP']['GB030']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['ZI019_ASP']['GB055']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['ZI019_ASP']['GB075']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['GGDM 3.0']['AeronauticSrf']['ZI019_ASP2'] = ('Enumeration',('GB015','GB030','GB055','GB075'))
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['ZI019_ASP2'] = {}
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['ZI019_ASP2']['GB015']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['ZI019_ASP2']['GB030']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['ZI019_ASP2']['GB055']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['ZI019_ASP2']['GB075']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['GGDM 3.0']['AeronauticSrf']['ZI019_ASP3'] = ('Enumeration',('GB015','GB030','GB055','GB075'))
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['ZI019_ASP3'] = {}
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['ZI019_ASP3']['GB015']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['ZI019_ASP3']['GB030']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['ZI019_ASP3']['GB055']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['ZI019_ASP3']['GB075']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['GGDM 3.0']['AeronauticSrf']['ZI019_ASU'] = ('Enumeration',('GB015','GB030','GB055','GB075'))
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['ZI019_ASU'] = {}
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['ZI019_ASU']['GB015']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,20,21,999)
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['ZI019_ASU']['GB030']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,20,21,999)
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['ZI019_ASU']['GB055']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,20,21,999)
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['ZI019_ASU']['GB075']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,20,21,999)
    field_information['GGDM 3.0']['AeronauticSrf']['ZI019_ASU2'] = ('Enumeration',('GB015','GB030','GB055','GB075'))
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['ZI019_ASU2'] = {}
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['ZI019_ASU2']['GB015']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,20,21,999)
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['ZI019_ASU2']['GB030']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,20,21,999)
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['ZI019_ASU2']['GB055']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,20,21,999)
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['ZI019_ASU2']['GB075']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,20,21,999)
    field_information['GGDM 3.0']['AeronauticSrf']['ZI019_ASU3'] = ('Enumeration',('GB015','GB030','GB055','GB075'))
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['ZI019_ASU3'] = {}
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['ZI019_ASU3']['GB015']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,20,21,999)
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['ZI019_ASU3']['GB030']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,20,21,999)
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['ZI019_ASU3']['GB055']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,20,21,999)
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['ZI019_ASU3']['GB075']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,20,21,999)
    field_information['GGDM 3.0']['AeronauticSrf']['ZI019_ASX'] = ('Enumeration',('GB015','GB030','GB055','GB075'))
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['ZI019_ASX'] = {}
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['ZI019_ASX']['GB015']  = (-999999,1,2,3,4,5,999)
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['ZI019_ASX']['GB030']  = (-999999,1,2,3,4,5,999)
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['ZI019_ASX']['GB055']  = (-999999,1,2,3,4,5,999)
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['ZI019_ASX']['GB075']  = (-999999,1,2,3,4,5,999)
    field_information['GGDM 3.0']['AeronauticSrf']['ZI019_SFS'] = ('Enumeration',('GB015','GB030','GB055','GB075'))
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['ZI019_SFS'] = {}
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['ZI019_SFS']['GB015']  = (-999999,1,2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['ZI019_SFS']['GB030']  = (-999999,1,2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['ZI019_SFS']['GB055']  = (-999999,1,2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['ZI019_SFS']['GB075']  = (-999999,1,2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['AeronauticSrf']['ZI020_GE4'] = ('CodeList',('AL351','AQ060','GB005','GB015','GB030','GB035','GB040','GB045','GB055','GB065','GB070','GB075','GB230','GB250'))
    field_information['GGDM 3.0']['AeronauticSrf']['ZI026_CTUC'] = ('Enumeration',('AL351','AQ060','GB005','GB015','GB030','GB035','GB040','GB045','GB055','GB065','GB070','GB075','GB230','GB250'))
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['ZI026_CTUC']['AL351']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['ZI026_CTUC']['AQ060']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['ZI026_CTUC']['GB005']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['ZI026_CTUC']['GB015']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['ZI026_CTUC']['GB030']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['ZI026_CTUC']['GB035']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['ZI026_CTUC']['GB040']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['ZI026_CTUC']['GB045']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['ZI026_CTUC']['GB055']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['ZI026_CTUC']['GB065']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['ZI026_CTUC']['GB070']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['ZI026_CTUC']['GB075']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['ZI026_CTUC']['GB230']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['AeronauticSrf']['EnumeratedIndexValues']['ZI026_CTUC']['GB250']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['AeronauticSrf']['ZI026_CTUL'] = ('integer',('AL351','AQ060','GB005','GB015','GB030','GB035','GB040','GB045','GB055','GB065','GB070','GB075','GB230','GB250'))
    field_information['GGDM 3.0']['AeronauticSrf']['ZI026_CTUU'] = ('integer',('AL351','AQ060','GB005','GB015','GB030','GB035','GB040','GB045','GB055','GB065','GB070','GB075','GB230','GB250'))
    field_information['GGDM 3.0']['AeronauticSrf']['ZI031S_URI'] = ('StructuredText',('AL351','AQ060','GB005','GB015','GB030','GB035','GB040','GB045','GB055','GB065','GB070','GB075','GB230','GB250'))
    field_information['GGDM 3.0']['AeronauticSrf']['ZI039S_UFI'] = ('StructuredText',('AL351','AQ060','GB005','GB015','GB030','GB035','GB040','GB045','GB055','GB065','GB070','GB075','GB230','GB250'))
    field_information['GGDM 3.0']['AeronauticSrf']['ZI103_MVD'] = ('StructuredText',('GB005','GB065'))
    field_information['GGDM 3.0']['AeronauticSrf']['ZSAX_RS0'] = ('CodeList',('AL351','AQ060','GB005','GB015','GB030','GB035','GB040','GB045','GB055','GB065','GB070','GB075','GB230','GB250'))
    field_information['GGDM 3.0']['AeronauticSrf']['ZSAX_RX0'] = ('StructuredText',('AL351','AQ060','GB005','GB015','GB030','GB035','GB040','GB045','GB055','GB065','GB070','GB075','GB230','GB250'))
    field_information['GGDM 3.0']['AeronauticSrf']['ZSAX_RX3'] = ('StructuredText',('AL351','AQ060','GB005','GB015','GB030','GB035','GB040','GB045','GB055','GB065','GB070','GB075','GB230','GB250'))
    field_information['GGDM 3.0']['AeronauticSrf']['ZSAX_RX4'] = ('StructuredText',('AL351','AQ060','GB005','GB015','GB030','GB035','GB040','GB045','GB055','GB065','GB070','GB075','GB230','GB250'))
    field_information['GGDM 3.0']['AeronauticSrf']['ZVA'] = ('Real',('GB005','GB035','GB065'))
    field_information['GGDM 3.0']['AeronauticSrf']['ZVH'] = ('Real',('AL351','AQ060','GB005','GB015','GB030','GB035','GB040','GB045','GB055','GB065','GB070','GB075','GB230','GB250'))
    field_information['GGDM 3.0']['AeronauticSrfExt']['BEN'] = ('StructuredText',('STB23'))
    field_information['GGDM 3.0']['AeronauticSrfExt']['F_CODE'] = ('CONSTRAINED_STRING',('STB23'))
    field_information['GGDM 3.0']['AeronauticSrfExt']['FUFI'] = ('StructuredText',('STB23'))
    field_information['GGDM 3.0']['AeronauticSrfExt']['FURL'] = ('StructuredText',('STB23'))
    field_information['GGDM 3.0']['AeronauticSrfExt']['GDBV'] = ('Enumeration',('STB23'))
    field_information['GGDM 3.0']['AeronauticSrfExt']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['AeronauticSrfExt']['EnumeratedIndexValues']['GDBV']['STB23']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['AeronauticSrfExt']['OTH'] = ('StructuredText',('STB23'))
    field_information['GGDM 3.0']['AeronauticSrfExt']['UFI'] = ('StructuredText',('STB23'))
    field_information['GGDM 3.0']['AeronauticSrfExt']['ZI001_SDV'] = ('StructuredText',('STB23'))
    field_information['GGDM 3.0']['AeronauticSrfExt']['ZI001_SRT'] = ('Enumeration',('STB23'))
    field_information['GGDM 3.0']['AeronauticSrfExt']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['AeronauticSrfExt']['EnumeratedIndexValues']['ZI001_SRT']['STB23']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['AeronauticSrfExt']['ZI002_UFI'] = ('StructuredText',('STB23'))
    field_information['GGDM 3.0']['AeronauticSrfExt']['ZI004_RCG'] = ('Enumeration',('STB23'))
    field_information['GGDM 3.0']['AeronauticSrfExt']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['AeronauticSrfExt']['EnumeratedIndexValues']['ZI004_RCG']['STB23']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['AeronauticSrfExt']['ZI006_MEM'] = ('String',('STB23'))
    field_information['GGDM 3.0']['AeronauticSrfExt']['ZI020_GE4'] = ('CodeList',('STB23'))
    field_information['GGDM 3.0']['AeronauticSrfExt']['ZI026_CTUC'] = ('Enumeration',('STB23'))
    field_information['GGDM 3.0']['AeronauticSrfExt']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['AeronauticSrfExt']['EnumeratedIndexValues']['ZI026_CTUC']['STB23']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['AeronauticSrfExt']['ZI026_CTUL'] = ('integer',('STB23'))
    field_information['GGDM 3.0']['AeronauticSrfExt']['ZI026_CTUU'] = ('integer',('STB23'))
    field_information['GGDM 3.0']['AeronauticSrfExt']['ZI031S_URI'] = ('StructuredText',('STB23'))
    field_information['GGDM 3.0']['AeronauticSrfExt']['ZI039S_UFI'] = ('StructuredText',('STB23'))
    field_information['GGDM 3.0']['AeronauticSrfExt']['ZSAX_RS0'] = ('CodeList',('STB23'))
    field_information['GGDM 3.0']['AeronauticSrfExt']['ZSAX_RX0'] = ('StructuredText',('STB23'))
    field_information['GGDM 3.0']['AeronauticSrfExt']['ZSAX_RX3'] = ('StructuredText',('STB23'))
    field_information['GGDM 3.0']['AeronauticSrfExt']['ZSAX_RX4'] = ('StructuredText',('STB23'))
    field_information['GGDM 3.0']['AgriculturePnt']['ADR'] = ('String',('AJ080','AJ085','AJ110','AL270'))
    field_information['GGDM 3.0']['AgriculturePnt']['AOO'] = ('Real',('AJ030','AJ050','AJ080','AJ085','AJ110','AL270','AM020','BH051'))
    field_information['GGDM 3.0']['AgriculturePnt']['ARA'] = ('Real',('AJ030','AJ050','AJ080','AJ085','AJ110','AL270','AM020','BH051'))
    field_information['GGDM 3.0']['AgriculturePnt']['ATB'] = ('Boolean',('AJ110'))
    field_information['GGDM 3.0']['AgriculturePnt']['AWP'] = ('Boolean',('AJ050','AM020'))
    field_information['GGDM 3.0']['AgriculturePnt']['BEN'] = ('StructuredText',('AJ030','AJ050','AJ080','AJ085','AJ110','AL270','AM020','BH051'))
    field_information['GGDM 3.0']['AgriculturePnt']['BNF'] = ('Integer',('AJ085'))
    field_information['GGDM 3.0']['AgriculturePnt']['CAA'] = ('Enumeration',('AJ050','AJ080','AJ085','AJ110','AL270','AM020','BH051'))
    field_information['GGDM 3.0']['AgriculturePnt']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['AgriculturePnt']['EnumeratedIndexValues']['CAA']['AJ050']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['AgriculturePnt']['EnumeratedIndexValues']['CAA']['AJ080']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['AgriculturePnt']['EnumeratedIndexValues']['CAA']['AJ085']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['AgriculturePnt']['EnumeratedIndexValues']['CAA']['AJ110']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['AgriculturePnt']['EnumeratedIndexValues']['CAA']['AL270']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['AgriculturePnt']['EnumeratedIndexValues']['CAA']['AM020']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['AgriculturePnt']['EnumeratedIndexValues']['CAA']['BH051']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['AgriculturePnt']['CNCP'] = ('StructuredText',('AJ030','AJ050','AJ080','AJ085','AJ110','AL270','AM020','BH051'))
    field_information['GGDM 3.0']['AgriculturePnt']['COS'] = ('Enumeration',('AJ030','AJ050','AJ080','AJ085','AJ110','AL270','AM020','BH051'))
    field_information['GGDM 3.0']['AgriculturePnt']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['AgriculturePnt']['EnumeratedIndexValues']['COS']['AJ030']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['AgriculturePnt']['EnumeratedIndexValues']['COS']['AJ050']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['AgriculturePnt']['EnumeratedIndexValues']['COS']['AJ080']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['AgriculturePnt']['EnumeratedIndexValues']['COS']['AJ085']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['AgriculturePnt']['EnumeratedIndexValues']['COS']['AJ110']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['AgriculturePnt']['EnumeratedIndexValues']['COS']['AL270']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['AgriculturePnt']['EnumeratedIndexValues']['COS']['AM020']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['AgriculturePnt']['EnumeratedIndexValues']['COS']['BH051']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['AgriculturePnt']['DMBC'] = ('Enumeration',('AL270'))
    field_information['GGDM 3.0']['AgriculturePnt']['EnumeratedIndexValues']['DMBC'] = {}
    field_information['GGDM 3.0']['AgriculturePnt']['EnumeratedIndexValues']['DMBC']['AL270']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['AgriculturePnt']['DMBL'] = ('real',('AL270'))
    field_information['GGDM 3.0']['AgriculturePnt']['DMBU'] = ('real',('AL270'))
    field_information['GGDM 3.0']['AgriculturePnt']['DMT'] = ('Real',('AL270'))
    field_information['GGDM 3.0']['AgriculturePnt']['F_CODE'] = ('CONSTRAINED_STRING',('AJ030','AJ050','AJ080','AJ085','AJ110','AL270','AM020','BH051'))
    field_information['GGDM 3.0']['AgriculturePnt']['FFN'] = ('Enumeration',('AJ080','AJ085','AJ110','AL270'))
    field_information['GGDM 3.0']['AgriculturePnt']['EnumeratedIndexValues']['FFN'] = {}
    field_information['GGDM 3.0']['AgriculturePnt']['EnumeratedIndexValues']['FFN']['AJ080']  = (-999999,9,919,921,923,999)
    field_information['GGDM 3.0']['AgriculturePnt']['EnumeratedIndexValues']['FFN']['AJ085']  = (-999999,2,3,9,106,530,919,921,999)
    field_information['GGDM 3.0']['AgriculturePnt']['EnumeratedIndexValues']['FFN']['AJ110']  = (-999999,2,3,850,907,922,999)
    field_information['GGDM 3.0']['AgriculturePnt']['EnumeratedIndexValues']['FFN']['AL270']  = (-999999,3,15,847,970,999)
    field_information['GGDM 3.0']['AgriculturePnt']['FFN2'] = ('Enumeration',('AJ080','AJ085','AJ110','AL270'))
    field_information['GGDM 3.0']['AgriculturePnt']['EnumeratedIndexValues']['FFN2'] = {}
    field_information['GGDM 3.0']['AgriculturePnt']['EnumeratedIndexValues']['FFN2']['AJ080']  = (-999999,9,919,921,923,999)
    field_information['GGDM 3.0']['AgriculturePnt']['EnumeratedIndexValues']['FFN2']['AJ085']  = (-999999,2,3,9,106,530,919,921,999)
    field_information['GGDM 3.0']['AgriculturePnt']['EnumeratedIndexValues']['FFN2']['AJ110']  = (-999999,2,3,850,907,922,999)
    field_information['GGDM 3.0']['AgriculturePnt']['EnumeratedIndexValues']['FFN2']['AL270']  = (-999999,3,15,847,970,999)
    field_information['GGDM 3.0']['AgriculturePnt']['FFN3'] = ('Enumeration',('AJ080','AJ085','AJ110','AL270'))
    field_information['GGDM 3.0']['AgriculturePnt']['EnumeratedIndexValues']['FFN3'] = {}
    field_information['GGDM 3.0']['AgriculturePnt']['EnumeratedIndexValues']['FFN3']['AJ080']  = (-999999,9,919,921,923,999)
    field_information['GGDM 3.0']['AgriculturePnt']['EnumeratedIndexValues']['FFN3']['AJ085']  = (-999999,2,3,9,106,530,919,921,999)
    field_information['GGDM 3.0']['AgriculturePnt']['EnumeratedIndexValues']['FFN3']['AJ110']  = (-999999,2,3,850,907,922,999)
    field_information['GGDM 3.0']['AgriculturePnt']['EnumeratedIndexValues']['FFN3']['AL270']  = (-999999,3,15,847,970,999)
    field_information['GGDM 3.0']['AgriculturePnt']['FUFI'] = ('StructuredText',('AJ030','AJ050','AJ080','AJ085','AJ110','AL270','AM020','BH051'))
    field_information['GGDM 3.0']['AgriculturePnt']['FURL'] = ('StructuredText',('AJ030','AJ050','AJ080','AJ085','AJ110','AL270','AM020','BH051'))
    field_information['GGDM 3.0']['AgriculturePnt']['GDBV'] = ('Enumeration',('AJ030','AJ050','AJ080','AJ085','AJ110','AL270','AM020','BH051'))
    field_information['GGDM 3.0']['AgriculturePnt']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['AgriculturePnt']['EnumeratedIndexValues']['GDBV']['AJ030']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['AgriculturePnt']['EnumeratedIndexValues']['GDBV']['AJ050']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['AgriculturePnt']['EnumeratedIndexValues']['GDBV']['AJ080']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['AgriculturePnt']['EnumeratedIndexValues']['GDBV']['AJ085']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['AgriculturePnt']['EnumeratedIndexValues']['GDBV']['AJ110']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['AgriculturePnt']['EnumeratedIndexValues']['GDBV']['AL270']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['AgriculturePnt']['EnumeratedIndexValues']['GDBV']['AM020']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['AgriculturePnt']['EnumeratedIndexValues']['GDBV']['BH051']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['AgriculturePnt']['HGT'] = ('Real',('AJ030','AJ050','AJ080','AJ085','AJ110','AL270','AM020'))
    field_information['GGDM 3.0']['AgriculturePnt']['LMC'] = ('Boolean',('AJ030','AJ050','AJ080','AJ085','AJ110','AL270','AM020','BH051'))
    field_information['GGDM 3.0']['AgriculturePnt']['LUN'] = ('Boolean',('AM020'))
    field_information['GGDM 3.0']['AgriculturePnt']['LZN'] = ('Real',('AJ030','AJ050','AJ080','AJ085','AJ110','AL270','AM020','BH051'))
    field_information['GGDM 3.0']['AgriculturePnt']['OTH'] = ('StructuredText',('AJ030','AJ050','AJ080','AJ085','AJ110','AL270','AM020','BH051'))
    field_information['GGDM 3.0']['AgriculturePnt']['PCF'] = ('Enumeration',('AJ030','AJ050','AJ080','AJ085','AJ110','AL270','AM020','BH051'))
    field_information['GGDM 3.0']['AgriculturePnt']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['AgriculturePnt']['EnumeratedIndexValues']['PCF']['AJ030']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['AgriculturePnt']['EnumeratedIndexValues']['PCF']['AJ050']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['AgriculturePnt']['EnumeratedIndexValues']['PCF']['AJ080']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['AgriculturePnt']['EnumeratedIndexValues']['PCF']['AJ085']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['AgriculturePnt']['EnumeratedIndexValues']['PCF']['AJ110']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['AgriculturePnt']['EnumeratedIndexValues']['PCF']['AL270']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['AgriculturePnt']['EnumeratedIndexValues']['PCF']['AM020']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['AgriculturePnt']['EnumeratedIndexValues']['PCF']['BH051']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['AgriculturePnt']['PPO'] = ('Enumeration',('AJ050','BH051'))
    field_information['GGDM 3.0']['AgriculturePnt']['EnumeratedIndexValues']['PPO'] = {}
    field_information['GGDM 3.0']['AgriculturePnt']['EnumeratedIndexValues']['PPO']['AJ050']  = (-999999,122,160,999)
    field_information['GGDM 3.0']['AgriculturePnt']['EnumeratedIndexValues']['PPO']['BH051']  = (-999999,11,29,30,39,72,77,999)
    field_information['GGDM 3.0']['AgriculturePnt']['PPO2'] = ('Enumeration',('AJ050','BH051'))
    field_information['GGDM 3.0']['AgriculturePnt']['EnumeratedIndexValues']['PPO2'] = {}
    field_information['GGDM 3.0']['AgriculturePnt']['EnumeratedIndexValues']['PPO2']['AJ050']  = (-999999,122,160,999)
    field_information['GGDM 3.0']['AgriculturePnt']['EnumeratedIndexValues']['PPO2']['BH051']  = (-999999,11,29,30,39,72,77,999)
    field_information['GGDM 3.0']['AgriculturePnt']['PPO3'] = ('Enumeration',('AJ050','BH051'))
    field_information['GGDM 3.0']['AgriculturePnt']['EnumeratedIndexValues']['PPO3'] = {}
    field_information['GGDM 3.0']['AgriculturePnt']['EnumeratedIndexValues']['PPO3']['AJ050']  = (-999999,122,160,999)
    field_information['GGDM 3.0']['AgriculturePnt']['EnumeratedIndexValues']['PPO3']['BH051']  = (-999999,11,29,30,39,72,77,999)
    field_information['GGDM 3.0']['AgriculturePnt']['PVH'] = ('Real',('AL270'))
    field_information['GGDM 3.0']['AgriculturePnt']['SDSC'] = ('Enumeration',('AL270'))
    field_information['GGDM 3.0']['AgriculturePnt']['EnumeratedIndexValues']['SDSC'] = {}
    field_information['GGDM 3.0']['AgriculturePnt']['EnumeratedIndexValues']['SDSC']['AL270']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['AgriculturePnt']['SDSL'] = ('real',('AL270'))
    field_information['GGDM 3.0']['AgriculturePnt']['SDSU'] = ('real',('AL270'))
    field_information['GGDM 3.0']['AgriculturePnt']['SSR'] = ('Enumeration',('AJ080','AJ085','AJ110','AM020'))
    field_information['GGDM 3.0']['AgriculturePnt']['EnumeratedIndexValues']['SSR'] = {}
    field_information['GGDM 3.0']['AgriculturePnt']['EnumeratedIndexValues']['SSR']['AJ080']  = (-999999,6,7,38,40,41,42,47,50,55,64,999)
    field_information['GGDM 3.0']['AgriculturePnt']['EnumeratedIndexValues']['SSR']['AJ085']  = (-999999,6,7,38,40,41,42,47,50,55,64,999)
    field_information['GGDM 3.0']['AgriculturePnt']['EnumeratedIndexValues']['SSR']['AJ110']  = (-999999,6,7,38,40,41,42,47,50,55,64,999)
    field_information['GGDM 3.0']['AgriculturePnt']['EnumeratedIndexValues']['SSR']['AM020']  = (-999999,6,7,38,40,41,42,999)
    field_information['GGDM 3.0']['AgriculturePnt']['SSR2'] = ('Enumeration',('AJ080','AJ085','AJ110','AM020'))
    field_information['GGDM 3.0']['AgriculturePnt']['EnumeratedIndexValues']['SSR2'] = {}
    field_information['GGDM 3.0']['AgriculturePnt']['EnumeratedIndexValues']['SSR2']['AJ080']  = (-999999,6,7,38,40,41,42,47,50,55,64,999)
    field_information['GGDM 3.0']['AgriculturePnt']['EnumeratedIndexValues']['SSR2']['AJ085']  = (-999999,6,7,38,40,41,42,47,50,55,64,999)
    field_information['GGDM 3.0']['AgriculturePnt']['EnumeratedIndexValues']['SSR2']['AJ110']  = (-999999,6,7,38,40,41,42,47,50,55,64,999)
    field_information['GGDM 3.0']['AgriculturePnt']['EnumeratedIndexValues']['SSR2']['AM020']  = (-999999,6,7,38,40,41,42,999)
    field_information['GGDM 3.0']['AgriculturePnt']['SSR3'] = ('Enumeration',('AJ080','AJ085','AJ110','AM020'))
    field_information['GGDM 3.0']['AgriculturePnt']['EnumeratedIndexValues']['SSR3'] = {}
    field_information['GGDM 3.0']['AgriculturePnt']['EnumeratedIndexValues']['SSR3']['AJ080']  = (-999999,6,7,38,40,41,42,47,50,55,64,999)
    field_information['GGDM 3.0']['AgriculturePnt']['EnumeratedIndexValues']['SSR3']['AJ085']  = (-999999,6,7,38,40,41,42,47,50,55,64,999)
    field_information['GGDM 3.0']['AgriculturePnt']['EnumeratedIndexValues']['SSR3']['AJ110']  = (-999999,6,7,38,40,41,42,47,50,55,64,999)
    field_information['GGDM 3.0']['AgriculturePnt']['EnumeratedIndexValues']['SSR3']['AM020']  = (-999999,6,7,38,40,41,42,999)
    field_information['GGDM 3.0']['AgriculturePnt']['TOS'] = ('Enumeration',('AJ050'))
    field_information['GGDM 3.0']['AgriculturePnt']['EnumeratedIndexValues']['TOS'] = {}
    field_information['GGDM 3.0']['AgriculturePnt']['EnumeratedIndexValues']['TOS']['AJ050']  = (-999999,6,11,12,13,14,999)
    field_information['GGDM 3.0']['AgriculturePnt']['TRE'] = ('Enumeration',('AL270'))
    field_information['GGDM 3.0']['AgriculturePnt']['EnumeratedIndexValues']['TRE'] = {}
    field_information['GGDM 3.0']['AgriculturePnt']['EnumeratedIndexValues']['TRE']['AL270']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['AgriculturePnt']['TSCC'] = ('Enumeration',('AL270'))
    field_information['GGDM 3.0']['AgriculturePnt']['EnumeratedIndexValues']['TSCC'] = {}
    field_information['GGDM 3.0']['AgriculturePnt']['EnumeratedIndexValues']['TSCC']['AL270']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['AgriculturePnt']['TSCL'] = ('real',('AL270'))
    field_information['GGDM 3.0']['AgriculturePnt']['TSCU'] = ('real',('AL270'))
    field_information['GGDM 3.0']['AgriculturePnt']['UFI'] = ('StructuredText',('AJ030','AJ050','AJ080','AJ085','AJ110','AL270','AM020','BH051'))
    field_information['GGDM 3.0']['AgriculturePnt']['VCM'] = ('Enumeration',('AJ050','AJ080','AJ085','AM020'))
    field_information['GGDM 3.0']['AgriculturePnt']['EnumeratedIndexValues']['VCM'] = {}
    field_information['GGDM 3.0']['AgriculturePnt']['EnumeratedIndexValues']['VCM']['AJ050']  = (-999999,2,3,4,7,8,9,15,16,18,999)
    field_information['GGDM 3.0']['AgriculturePnt']['EnumeratedIndexValues']['VCM']['AJ080']  = (-999999,1,3,4,7,8,9,12,13,14,15,16,18,999)
    field_information['GGDM 3.0']['AgriculturePnt']['EnumeratedIndexValues']['VCM']['AJ085']  = (-999999,1,3,4,7,8,9,12,13,14,15,16,18,999)
    field_information['GGDM 3.0']['AgriculturePnt']['EnumeratedIndexValues']['VCM']['AM020']  = (-999999,2,4,7,8,9,12,13,15,18,999)
    field_information['GGDM 3.0']['AgriculturePnt']['VCM2'] = ('Enumeration',('AJ050','AJ080','AJ085','AM020'))
    field_information['GGDM 3.0']['AgriculturePnt']['EnumeratedIndexValues']['VCM2'] = {}
    field_information['GGDM 3.0']['AgriculturePnt']['EnumeratedIndexValues']['VCM2']['AJ050']  = (-999999,2,3,4,7,8,9,15,16,18,999)
    field_information['GGDM 3.0']['AgriculturePnt']['EnumeratedIndexValues']['VCM2']['AJ080']  = (-999999,1,3,4,7,8,9,12,13,14,15,16,18,999)
    field_information['GGDM 3.0']['AgriculturePnt']['EnumeratedIndexValues']['VCM2']['AJ085']  = (-999999,1,3,4,7,8,9,12,13,14,15,16,18,999)
    field_information['GGDM 3.0']['AgriculturePnt']['EnumeratedIndexValues']['VCM2']['AM020']  = (-999999,2,4,7,8,9,12,13,15,18,999)
    field_information['GGDM 3.0']['AgriculturePnt']['VCM3'] = ('Enumeration',('AJ050','AJ080','AJ085','AM020'))
    field_information['GGDM 3.0']['AgriculturePnt']['EnumeratedIndexValues']['VCM3'] = {}
    field_information['GGDM 3.0']['AgriculturePnt']['EnumeratedIndexValues']['VCM3']['AJ050']  = (-999999,2,3,4,7,8,9,15,16,18,999)
    field_information['GGDM 3.0']['AgriculturePnt']['EnumeratedIndexValues']['VCM3']['AJ080']  = (-999999,1,3,4,7,8,9,12,13,14,15,16,18,999)
    field_information['GGDM 3.0']['AgriculturePnt']['EnumeratedIndexValues']['VCM3']['AJ085']  = (-999999,1,3,4,7,8,9,12,13,14,15,16,18,999)
    field_information['GGDM 3.0']['AgriculturePnt']['EnumeratedIndexValues']['VCM3']['AM020']  = (-999999,2,4,7,8,9,12,13,15,18,999)
    field_information['GGDM 3.0']['AgriculturePnt']['VLM'] = ('Real',('BH051'))
    field_information['GGDM 3.0']['AgriculturePnt']['VOI'] = ('StructuredText',('AJ050','AM020'))
    field_information['GGDM 3.0']['AgriculturePnt']['VSP'] = ('Enumeration',('AL270'))
    field_information['GGDM 3.0']['AgriculturePnt']['EnumeratedIndexValues']['VSP'] = {}
    field_information['GGDM 3.0']['AgriculturePnt']['EnumeratedIndexValues']['VSP']['AL270']  = (-999999,8,22,25,34,999)
    field_information['GGDM 3.0']['AgriculturePnt']['VSP2'] = ('Enumeration',('AL270'))
    field_information['GGDM 3.0']['AgriculturePnt']['EnumeratedIndexValues']['VSP2'] = {}
    field_information['GGDM 3.0']['AgriculturePnt']['EnumeratedIndexValues']['VSP2']['AL270']  = (-999999,8,22,25,34,999)
    field_information['GGDM 3.0']['AgriculturePnt']['VSP3'] = ('Enumeration',('AL270'))
    field_information['GGDM 3.0']['AgriculturePnt']['EnumeratedIndexValues']['VSP3'] = {}
    field_information['GGDM 3.0']['AgriculturePnt']['EnumeratedIndexValues']['VSP3']['AL270']  = (-999999,8,22,25,34,999)
    field_information['GGDM 3.0']['AgriculturePnt']['VTI'] = ('Real',('AL270'))
    field_information['GGDM 3.0']['AgriculturePnt']['WID'] = ('Real',('AJ030','AJ050','AJ080','AJ085','AJ110','AL270','AM020','BH051'))
    field_information['GGDM 3.0']['AgriculturePnt']['ZI001_SDV'] = ('StructuredText',('AJ030','AJ050','AJ080','AJ085','AJ110','AL270','AM020','BH051'))
    field_information['GGDM 3.0']['AgriculturePnt']['ZI001_SRT'] = ('Enumeration',('AJ030','AJ050','AJ080','AJ085','AJ110','AL270','AM020','BH051'))
    field_information['GGDM 3.0']['AgriculturePnt']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['AgriculturePnt']['EnumeratedIndexValues']['ZI001_SRT']['AJ030']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['AgriculturePnt']['EnumeratedIndexValues']['ZI001_SRT']['AJ050']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['AgriculturePnt']['EnumeratedIndexValues']['ZI001_SRT']['AJ080']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['AgriculturePnt']['EnumeratedIndexValues']['ZI001_SRT']['AJ085']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['AgriculturePnt']['EnumeratedIndexValues']['ZI001_SRT']['AJ110']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['AgriculturePnt']['EnumeratedIndexValues']['ZI001_SRT']['AL270']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['AgriculturePnt']['EnumeratedIndexValues']['ZI001_SRT']['AM020']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['AgriculturePnt']['EnumeratedIndexValues']['ZI001_SRT']['BH051']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['AgriculturePnt']['ZI002_UFI'] = ('StructuredText',('AJ030','AJ050','AJ080','AJ085','AJ110','AL270','AM020','BH051'))
    field_information['GGDM 3.0']['AgriculturePnt']['ZI004_RCG'] = ('Enumeration',('AJ030','AJ050','AJ080','AJ085','AJ110','AL270','AM020','BH051'))
    field_information['GGDM 3.0']['AgriculturePnt']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['AgriculturePnt']['EnumeratedIndexValues']['ZI004_RCG']['AJ030']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['AgriculturePnt']['EnumeratedIndexValues']['ZI004_RCG']['AJ050']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['AgriculturePnt']['EnumeratedIndexValues']['ZI004_RCG']['AJ080']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['AgriculturePnt']['EnumeratedIndexValues']['ZI004_RCG']['AJ085']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['AgriculturePnt']['EnumeratedIndexValues']['ZI004_RCG']['AJ110']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['AgriculturePnt']['EnumeratedIndexValues']['ZI004_RCG']['AL270']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['AgriculturePnt']['EnumeratedIndexValues']['ZI004_RCG']['AM020']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['AgriculturePnt']['EnumeratedIndexValues']['ZI004_RCG']['BH051']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['AgriculturePnt']['ZI005_FNA'] = ('String',('AJ030','AJ050','AJ080','AJ085','AJ110','AL270','AM020','BH051'))
    field_information['GGDM 3.0']['AgriculturePnt']['ZI005_GNT'] = ('Enumeration',('AJ030','AJ050','AJ080','AJ085','AJ110','AL270','AM020','BH051'))
    field_information['GGDM 3.0']['AgriculturePnt']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['AgriculturePnt']['EnumeratedIndexValues']['ZI005_GNT']['AJ030']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['AgriculturePnt']['EnumeratedIndexValues']['ZI005_GNT']['AJ050']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['AgriculturePnt']['EnumeratedIndexValues']['ZI005_GNT']['AJ080']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['AgriculturePnt']['EnumeratedIndexValues']['ZI005_GNT']['AJ085']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['AgriculturePnt']['EnumeratedIndexValues']['ZI005_GNT']['AJ110']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['AgriculturePnt']['EnumeratedIndexValues']['ZI005_GNT']['AL270']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['AgriculturePnt']['EnumeratedIndexValues']['ZI005_GNT']['AM020']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['AgriculturePnt']['EnumeratedIndexValues']['ZI005_GNT']['BH051']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['AgriculturePnt']['ZI005_NFN'] = ('String',('AJ030','AJ050','AJ080','AJ085','AJ110','AL270','AM020','BH051'))
    field_information['GGDM 3.0']['AgriculturePnt']['ZI006_MEM'] = ('String',('AJ030','AJ050','AJ080','AJ085','AJ110','AL270','AM020','BH051'))
    field_information['GGDM 3.0']['AgriculturePnt']['ZI013_CSP'] = ('Enumeration',('AL270'))
    field_information['GGDM 3.0']['AgriculturePnt']['EnumeratedIndexValues']['ZI013_CSP'] = {}
    field_information['GGDM 3.0']['AgriculturePnt']['EnumeratedIndexValues']['ZI013_CSP']['AL270']  = (-999999,8,9,10,22,29,33,34,35,41,42,43,44,45,46,48,999)
    field_information['GGDM 3.0']['AgriculturePnt']['ZI013_CSP2'] = ('Enumeration',('AL270'))
    field_information['GGDM 3.0']['AgriculturePnt']['EnumeratedIndexValues']['ZI013_CSP2'] = {}
    field_information['GGDM 3.0']['AgriculturePnt']['EnumeratedIndexValues']['ZI013_CSP2']['AL270']  = (-999999,8,9,10,22,29,33,34,35,41,42,43,44,45,46,48,999)
    field_information['GGDM 3.0']['AgriculturePnt']['ZI013_CSP3'] = ('Enumeration',('AL270'))
    field_information['GGDM 3.0']['AgriculturePnt']['EnumeratedIndexValues']['ZI013_CSP3'] = {}
    field_information['GGDM 3.0']['AgriculturePnt']['EnumeratedIndexValues']['ZI013_CSP3']['AL270']  = (-999999,8,9,10,22,29,33,34,35,41,42,43,44,45,46,48,999)
    field_information['GGDM 3.0']['AgriculturePnt']['ZI013_FFP'] = ('Enumeration',('AL270'))
    field_information['GGDM 3.0']['AgriculturePnt']['EnumeratedIndexValues']['ZI013_FFP'] = {}
    field_information['GGDM 3.0']['AgriculturePnt']['EnumeratedIndexValues']['ZI013_FFP']['AL270']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['GGDM 3.0']['AgriculturePnt']['ZI013_FFP2'] = ('Enumeration',('AL270'))
    field_information['GGDM 3.0']['AgriculturePnt']['EnumeratedIndexValues']['ZI013_FFP2'] = {}
    field_information['GGDM 3.0']['AgriculturePnt']['EnumeratedIndexValues']['ZI013_FFP2']['AL270']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['GGDM 3.0']['AgriculturePnt']['ZI013_FFP3'] = ('Enumeration',('AL270'))
    field_information['GGDM 3.0']['AgriculturePnt']['EnumeratedIndexValues']['ZI013_FFP3'] = {}
    field_information['GGDM 3.0']['AgriculturePnt']['EnumeratedIndexValues']['ZI013_FFP3']['AL270']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['GGDM 3.0']['AgriculturePnt']['ZI013_FMM'] = ('Enumeration',('AL270'))
    field_information['GGDM 3.0']['AgriculturePnt']['EnumeratedIndexValues']['ZI013_FMM'] = {}
    field_information['GGDM 3.0']['AgriculturePnt']['EnumeratedIndexValues']['ZI013_FMM']['AL270']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['AgriculturePnt']['ZI013_FMM2'] = ('Enumeration',('AL270'))
    field_information['GGDM 3.0']['AgriculturePnt']['EnumeratedIndexValues']['ZI013_FMM2'] = {}
    field_information['GGDM 3.0']['AgriculturePnt']['EnumeratedIndexValues']['ZI013_FMM2']['AL270']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['AgriculturePnt']['ZI013_FMM3'] = ('Enumeration',('AL270'))
    field_information['GGDM 3.0']['AgriculturePnt']['EnumeratedIndexValues']['ZI013_FMM3'] = {}
    field_information['GGDM 3.0']['AgriculturePnt']['EnumeratedIndexValues']['ZI013_FMM3']['AL270']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['AgriculturePnt']['ZI013_PIG'] = ('Boolean',('AL270'))
    field_information['GGDM 3.0']['AgriculturePnt']['ZI014_PPO'] = ('Enumeration',('AL270'))
    field_information['GGDM 3.0']['AgriculturePnt']['EnumeratedIndexValues']['ZI014_PPO'] = {}
    field_information['GGDM 3.0']['AgriculturePnt']['EnumeratedIndexValues']['ZI014_PPO']['AL270']  = (-999999,20,25,28,32,39,41,44,63,70,73,92,94,95,111,114,117,121,123,155,160,999)
    field_information['GGDM 3.0']['AgriculturePnt']['ZI014_PPO2'] = ('Enumeration',('AL270'))
    field_information['GGDM 3.0']['AgriculturePnt']['EnumeratedIndexValues']['ZI014_PPO2'] = {}
    field_information['GGDM 3.0']['AgriculturePnt']['EnumeratedIndexValues']['ZI014_PPO2']['AL270']  = (-999999,20,25,28,32,39,41,44,63,70,73,92,94,95,111,114,117,121,123,155,160,999)
    field_information['GGDM 3.0']['AgriculturePnt']['ZI014_PPO3'] = ('Enumeration',('AL270'))
    field_information['GGDM 3.0']['AgriculturePnt']['EnumeratedIndexValues']['ZI014_PPO3'] = {}
    field_information['GGDM 3.0']['AgriculturePnt']['EnumeratedIndexValues']['ZI014_PPO3']['AL270']  = (-999999,20,25,28,32,39,41,44,63,70,73,92,94,95,111,114,117,121,123,155,160,999)
    field_information['GGDM 3.0']['AgriculturePnt']['ZI020_GE4'] = ('CodeList',('AJ030','AJ050','AJ080','AJ085','AJ110','AL270','AM020','BH051'))
    field_information['GGDM 3.0']['AgriculturePnt']['ZI024_ASE'] = ('Real',('BH051'))
    field_information['GGDM 3.0']['AgriculturePnt']['ZI024_CFR'] = ('Real',('BH051'))
    field_information['GGDM 3.0']['AgriculturePnt']['ZI024_CLO'] = ('Real',('BH051'))
    field_information['GGDM 3.0']['AgriculturePnt']['ZI024_CYN'] = ('Real',('BH051'))
    field_information['GGDM 3.0']['AgriculturePnt']['ZI024_FMR'] = ('Real',('BH051'))
    field_information['GGDM 3.0']['AgriculturePnt']['ZI024_FRR'] = ('Real',('BH051'))
    field_information['GGDM 3.0']['AgriculturePnt']['ZI024_HAR'] = ('Real',('BH051'))
    field_information['GGDM 3.0']['AgriculturePnt']['ZI024_HYP'] = ('Enumeration',('BH051'))
    field_information['GGDM 3.0']['AgriculturePnt']['EnumeratedIndexValues']['ZI024_HYP'] = {}
    field_information['GGDM 3.0']['AgriculturePnt']['EnumeratedIndexValues']['ZI024_HYP']['BH051']  = (-999999,1,2,4)
    field_information['GGDM 3.0']['AgriculturePnt']['ZI024_MGN'] = ('Real',('BH051'))
    field_information['GGDM 3.0']['AgriculturePnt']['ZI024_PHW'] = ('Real',('BH051'))
    field_information['GGDM 3.0']['AgriculturePnt']['ZI024_SCC'] = ('Enumeration',('BH051'))
    field_information['GGDM 3.0']['AgriculturePnt']['EnumeratedIndexValues']['ZI024_SCC'] = {}
    field_information['GGDM 3.0']['AgriculturePnt']['EnumeratedIndexValues']['ZI024_SCC']['BH051']  = (-999999,1,4,10,11,12,13,14,998,999)
    field_information['GGDM 3.0']['AgriculturePnt']['ZI024_SUL'] = ('Real',('BH051'))
    field_information['GGDM 3.0']['AgriculturePnt']['ZI024_TDS'] = ('Real',('BH051'))
    field_information['GGDM 3.0']['AgriculturePnt']['ZI024_TEP'] = ('Real',('BH051'))
    field_information['GGDM 3.0']['AgriculturePnt']['ZI024_TUR'] = ('Real',('BH051'))
    field_information['GGDM 3.0']['AgriculturePnt']['ZI024_WAC'] = ('Real',('BH051'))
    field_information['GGDM 3.0']['AgriculturePnt']['ZI024_WTNO'] = ('Real',('BH051'))
    field_information['GGDM 3.0']['AgriculturePnt']['ZI024_WUR'] = ('Enumeration',('BH051'))
    field_information['GGDM 3.0']['AgriculturePnt']['EnumeratedIndexValues']['ZI024_WUR'] = {}
    field_information['GGDM 3.0']['AgriculturePnt']['EnumeratedIndexValues']['ZI024_WUR']['BH051']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['AgriculturePnt']['ZI024_WUR2'] = ('Enumeration',('BH051'))
    field_information['GGDM 3.0']['AgriculturePnt']['EnumeratedIndexValues']['ZI024_WUR2'] = {}
    field_information['GGDM 3.0']['AgriculturePnt']['EnumeratedIndexValues']['ZI024_WUR2']['BH051']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['AgriculturePnt']['ZI024_WUR3'] = ('Enumeration',('BH051'))
    field_information['GGDM 3.0']['AgriculturePnt']['EnumeratedIndexValues']['ZI024_WUR3'] = {}
    field_information['GGDM 3.0']['AgriculturePnt']['EnumeratedIndexValues']['ZI024_WUR3']['BH051']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['AgriculturePnt']['ZI024_WUR4'] = ('Enumeration',('BH051'))
    field_information['GGDM 3.0']['AgriculturePnt']['EnumeratedIndexValues']['ZI024_WUR4'] = {}
    field_information['GGDM 3.0']['AgriculturePnt']['EnumeratedIndexValues']['ZI024_WUR4']['BH051']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['AgriculturePnt']['ZI024_YWQ'] = ('Enumeration',('BH051'))
    field_information['GGDM 3.0']['AgriculturePnt']['EnumeratedIndexValues']['ZI024_YWQ'] = {}
    field_information['GGDM 3.0']['AgriculturePnt']['EnumeratedIndexValues']['ZI024_YWQ']['BH051']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['AgriculturePnt']['ZI026_CTUC'] = ('Enumeration',('AJ030','AJ050','AJ080','AJ085','AJ110','AL270','AM020','BH051'))
    field_information['GGDM 3.0']['AgriculturePnt']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['AgriculturePnt']['EnumeratedIndexValues']['ZI026_CTUC']['AJ030']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['AgriculturePnt']['EnumeratedIndexValues']['ZI026_CTUC']['AJ050']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['AgriculturePnt']['EnumeratedIndexValues']['ZI026_CTUC']['AJ080']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['AgriculturePnt']['EnumeratedIndexValues']['ZI026_CTUC']['AJ085']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['AgriculturePnt']['EnumeratedIndexValues']['ZI026_CTUC']['AJ110']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['AgriculturePnt']['EnumeratedIndexValues']['ZI026_CTUC']['AL270']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['AgriculturePnt']['EnumeratedIndexValues']['ZI026_CTUC']['AM020']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['AgriculturePnt']['EnumeratedIndexValues']['ZI026_CTUC']['BH051']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['AgriculturePnt']['ZI026_CTUL'] = ('integer',('AJ030','AJ050','AJ080','AJ085','AJ110','AL270','AM020','BH051'))
    field_information['GGDM 3.0']['AgriculturePnt']['ZI026_CTUU'] = ('integer',('AJ030','AJ050','AJ080','AJ085','AJ110','AL270','AM020','BH051'))
    field_information['GGDM 3.0']['AgriculturePnt']['ZI031S_URI'] = ('StructuredText',('AJ030','AJ050','AJ080','AJ085','AJ110','AL270','AM020','BH051'))
    field_information['GGDM 3.0']['AgriculturePnt']['ZI039S_UFI'] = ('StructuredText',('AJ030','AJ050','AJ080','AJ085','AJ110','AL270','AM020','BH051'))
    field_information['GGDM 3.0']['AgriculturePnt']['ZSAX_RS0'] = ('CodeList',('AJ030','AJ050','AJ080','AJ085','AJ110','AL270','AM020','BH051'))
    field_information['GGDM 3.0']['AgriculturePnt']['ZSAX_RX0'] = ('StructuredText',('AJ030','AJ050','AJ080','AJ085','AJ110','AL270','AM020','BH051'))
    field_information['GGDM 3.0']['AgriculturePnt']['ZSAX_RX3'] = ('StructuredText',('AJ030','AJ050','AJ080','AJ085','AJ110','AL270','AM020','BH051'))
    field_information['GGDM 3.0']['AgriculturePnt']['ZSAX_RX4'] = ('StructuredText',('AJ030','AJ050','AJ080','AJ085','AJ110','AL270','AM020','BH051'))
    field_information['GGDM 3.0']['AgriculturePnt']['ZVH'] = ('Real',('AJ030','AJ050','AJ080','AJ085','AJ110','AL270','AM020'))
    field_information['GGDM 3.0']['AgriculturePntExt']['ARA'] = ('Real',('EA040','EA050'))
    field_information['GGDM 3.0']['AgriculturePntExt']['BEN'] = ('StructuredText',('EA040','EA050'))
    field_information['GGDM 3.0']['AgriculturePntExt']['DMBC'] = ('Enumeration',('EA040'))
    field_information['GGDM 3.0']['AgriculturePntExt']['EnumeratedIndexValues']['DMBC'] = {}
    field_information['GGDM 3.0']['AgriculturePntExt']['EnumeratedIndexValues']['DMBC']['EA040']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['AgriculturePntExt']['DMBL'] = ('real',('EA040'))
    field_information['GGDM 3.0']['AgriculturePntExt']['DMBU'] = ('real',('EA040'))
    field_information['GGDM 3.0']['AgriculturePntExt']['DMT'] = ('Real',('EA040'))
    field_information['GGDM 3.0']['AgriculturePntExt']['F_CODE'] = ('CONSTRAINED_STRING',('EA040','EA050'))
    field_information['GGDM 3.0']['AgriculturePntExt']['FUFI'] = ('StructuredText',('EA040','EA050'))
    field_information['GGDM 3.0']['AgriculturePntExt']['FURL'] = ('StructuredText',('EA040','EA050'))
    field_information['GGDM 3.0']['AgriculturePntExt']['GDBV'] = ('Enumeration',('EA040','EA050'))
    field_information['GGDM 3.0']['AgriculturePntExt']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['AgriculturePntExt']['EnumeratedIndexValues']['GDBV']['EA040']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['AgriculturePntExt']['EnumeratedIndexValues']['GDBV']['EA050']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['AgriculturePntExt']['HGT'] = ('Real',('EA040','EA050'))
    field_information['GGDM 3.0']['AgriculturePntExt']['LMC'] = ('Boolean',('EA040','EA050'))
    field_information['GGDM 3.0']['AgriculturePntExt']['LZN'] = ('Real',('EA040','EA050'))
    field_information['GGDM 3.0']['AgriculturePntExt']['OTH'] = ('StructuredText',('EA040','EA050'))
    field_information['GGDM 3.0']['AgriculturePntExt']['PVH'] = ('Real',('EA040'))
    field_information['GGDM 3.0']['AgriculturePntExt']['SDSC'] = ('Enumeration',('EA040'))
    field_information['GGDM 3.0']['AgriculturePntExt']['EnumeratedIndexValues']['SDSC'] = {}
    field_information['GGDM 3.0']['AgriculturePntExt']['EnumeratedIndexValues']['SDSC']['EA040']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['AgriculturePntExt']['SDSL'] = ('real',('EA040'))
    field_information['GGDM 3.0']['AgriculturePntExt']['SDSU'] = ('real',('EA040'))
    field_information['GGDM 3.0']['AgriculturePntExt']['TRE'] = ('Enumeration',('EA040'))
    field_information['GGDM 3.0']['AgriculturePntExt']['EnumeratedIndexValues']['TRE'] = {}
    field_information['GGDM 3.0']['AgriculturePntExt']['EnumeratedIndexValues']['TRE']['EA040']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['AgriculturePntExt']['TSCC'] = ('Enumeration',('EA040'))
    field_information['GGDM 3.0']['AgriculturePntExt']['EnumeratedIndexValues']['TSCC'] = {}
    field_information['GGDM 3.0']['AgriculturePntExt']['EnumeratedIndexValues']['TSCC']['EA040']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['AgriculturePntExt']['TSCL'] = ('real',('EA040'))
    field_information['GGDM 3.0']['AgriculturePntExt']['TSCU'] = ('real',('EA040'))
    field_information['GGDM 3.0']['AgriculturePntExt']['UFI'] = ('StructuredText',('EA040','EA050'))
    field_information['GGDM 3.0']['AgriculturePntExt']['VTI'] = ('Real',('EA040','EA050'))
    field_information['GGDM 3.0']['AgriculturePntExt']['WID'] = ('Real',('EA040','EA050'))
    field_information['GGDM 3.0']['AgriculturePntExt']['ZI001_SDV'] = ('StructuredText',('EA040','EA050'))
    field_information['GGDM 3.0']['AgriculturePntExt']['ZI001_SRT'] = ('Enumeration',('EA040','EA050'))
    field_information['GGDM 3.0']['AgriculturePntExt']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['AgriculturePntExt']['EnumeratedIndexValues']['ZI001_SRT']['EA040']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['AgriculturePntExt']['EnumeratedIndexValues']['ZI001_SRT']['EA050']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['AgriculturePntExt']['ZI002_UFI'] = ('StructuredText',('EA040','EA050'))
    field_information['GGDM 3.0']['AgriculturePntExt']['ZI004_RCG'] = ('Enumeration',('EA040','EA050'))
    field_information['GGDM 3.0']['AgriculturePntExt']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['AgriculturePntExt']['EnumeratedIndexValues']['ZI004_RCG']['EA040']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['AgriculturePntExt']['EnumeratedIndexValues']['ZI004_RCG']['EA050']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['AgriculturePntExt']['ZI005_FNA'] = ('String',('EA040','EA050'))
    field_information['GGDM 3.0']['AgriculturePntExt']['ZI005_GNT'] = ('Enumeration',('EA040','EA050'))
    field_information['GGDM 3.0']['AgriculturePntExt']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['AgriculturePntExt']['EnumeratedIndexValues']['ZI005_GNT']['EA040']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['AgriculturePntExt']['EnumeratedIndexValues']['ZI005_GNT']['EA050']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['AgriculturePntExt']['ZI005_NFN'] = ('String',('EA040','EA050'))
    field_information['GGDM 3.0']['AgriculturePntExt']['ZI006_MEM'] = ('String',('EA040','EA050'))
    field_information['GGDM 3.0']['AgriculturePntExt']['ZI013_CSP'] = ('Enumeration',('EA040','EA050'))
    field_information['GGDM 3.0']['AgriculturePntExt']['EnumeratedIndexValues']['ZI013_CSP'] = {}
    field_information['GGDM 3.0']['AgriculturePntExt']['EnumeratedIndexValues']['ZI013_CSP']['EA040']  = (-999999,1,2,4,5,6,7,15,17,19,23,24,38,40,43,47,159,999)
    field_information['GGDM 3.0']['AgriculturePntExt']['EnumeratedIndexValues']['ZI013_CSP']['EA050']  = (16,)
    field_information['GGDM 3.0']['AgriculturePntExt']['ZI013_CSP2'] = ('Enumeration',('EA040'))
    field_information['GGDM 3.0']['AgriculturePntExt']['EnumeratedIndexValues']['ZI013_CSP2'] = {}
    field_information['GGDM 3.0']['AgriculturePntExt']['EnumeratedIndexValues']['ZI013_CSP2']['EA040']  = (-999999,1,2,4,5,6,7,15,17,19,23,24,38,40,43,47,159,999)
    field_information['GGDM 3.0']['AgriculturePntExt']['ZI013_CSP3'] = ('Enumeration',('EA040'))
    field_information['GGDM 3.0']['AgriculturePntExt']['EnumeratedIndexValues']['ZI013_CSP3'] = {}
    field_information['GGDM 3.0']['AgriculturePntExt']['EnumeratedIndexValues']['ZI013_CSP3']['EA040']  = (-999999,1,2,4,5,6,7,15,17,19,23,24,38,40,43,47,159,999)
    field_information['GGDM 3.0']['AgriculturePntExt']['ZI013_FFP'] = ('Enumeration',('EA040','EA050'))
    field_information['GGDM 3.0']['AgriculturePntExt']['EnumeratedIndexValues']['ZI013_FFP'] = {}
    field_information['GGDM 3.0']['AgriculturePntExt']['EnumeratedIndexValues']['ZI013_FFP']['EA040']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['GGDM 3.0']['AgriculturePntExt']['EnumeratedIndexValues']['ZI013_FFP']['EA050']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['GGDM 3.0']['AgriculturePntExt']['ZI013_FFP2'] = ('Enumeration',('EA040','EA050'))
    field_information['GGDM 3.0']['AgriculturePntExt']['EnumeratedIndexValues']['ZI013_FFP2'] = {}
    field_information['GGDM 3.0']['AgriculturePntExt']['EnumeratedIndexValues']['ZI013_FFP2']['EA040']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['GGDM 3.0']['AgriculturePntExt']['EnumeratedIndexValues']['ZI013_FFP2']['EA050']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['GGDM 3.0']['AgriculturePntExt']['ZI013_FFP3'] = ('Enumeration',('EA040','EA050'))
    field_information['GGDM 3.0']['AgriculturePntExt']['EnumeratedIndexValues']['ZI013_FFP3'] = {}
    field_information['GGDM 3.0']['AgriculturePntExt']['EnumeratedIndexValues']['ZI013_FFP3']['EA040']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['GGDM 3.0']['AgriculturePntExt']['EnumeratedIndexValues']['ZI013_FFP3']['EA050']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['GGDM 3.0']['AgriculturePntExt']['ZI013_IRG'] = ('Enumeration',('EA040','EA050'))
    field_information['GGDM 3.0']['AgriculturePntExt']['EnumeratedIndexValues']['ZI013_IRG'] = {}
    field_information['GGDM 3.0']['AgriculturePntExt']['EnumeratedIndexValues']['ZI013_IRG']['EA040']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['GGDM 3.0']['AgriculturePntExt']['EnumeratedIndexValues']['ZI013_IRG']['EA050']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['GGDM 3.0']['AgriculturePntExt']['ZI020_GE4'] = ('CodeList',('EA040','EA050'))
    field_information['GGDM 3.0']['AgriculturePntExt']['ZI026_CTUC'] = ('Enumeration',('EA040','EA050'))
    field_information['GGDM 3.0']['AgriculturePntExt']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['AgriculturePntExt']['EnumeratedIndexValues']['ZI026_CTUC']['EA040']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['AgriculturePntExt']['EnumeratedIndexValues']['ZI026_CTUC']['EA050']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['AgriculturePntExt']['ZI026_CTUL'] = ('integer',('EA040','EA050'))
    field_information['GGDM 3.0']['AgriculturePntExt']['ZI026_CTUU'] = ('integer',('EA040','EA050'))
    field_information['GGDM 3.0']['AgriculturePntExt']['ZI031S_URI'] = ('StructuredText',('EA040','EA050'))
    field_information['GGDM 3.0']['AgriculturePntExt']['ZI039S_UFI'] = ('StructuredText',('EA040','EA050'))
    field_information['GGDM 3.0']['AgriculturePntExt']['ZSAX_RS0'] = ('CodeList',('EA040','EA050'))
    field_information['GGDM 3.0']['AgriculturePntExt']['ZSAX_RX0'] = ('StructuredText',('EA040','EA050'))
    field_information['GGDM 3.0']['AgriculturePntExt']['ZSAX_RX3'] = ('StructuredText',('EA040','EA050'))
    field_information['GGDM 3.0']['AgriculturePntExt']['ZSAX_RX4'] = ('StructuredText',('EA040','EA050'))
    field_information['GGDM 3.0']['AgriculturePntExt']['ZVH'] = ('Real',('EA040','EA050'))
    field_information['GGDM 3.0']['AgricultureSrf']['ADR'] = ('String',('AJ080','AJ085','AJ110','AL270','EA030'))
    field_information['GGDM 3.0']['AgricultureSrf']['AOO'] = ('Real',('AJ030','AJ050','AJ080','AJ085','AJ110','AL270','AM020','BH051'))
    field_information['GGDM 3.0']['AgricultureSrf']['ARA'] = ('Real',('AJ030','AJ050','AJ080','AJ085','AJ110','AL270','AM020','BH051','BH135','EA010','EA030','EA040','EA050','EA055','EC010'))
    field_information['GGDM 3.0']['AgricultureSrf']['ATB'] = ('Boolean',('AJ110'))
    field_information['GGDM 3.0']['AgricultureSrf']['AWP'] = ('Boolean',('AJ050','AM020'))
    field_information['GGDM 3.0']['AgricultureSrf']['BEN'] = ('StructuredText',('AJ030','AJ050','AJ080','AJ085','AJ110','AL270','AM020','BH051','BH135','EA010','EA030','EA040','EA050','EA055','EC010'))
    field_information['GGDM 3.0']['AgricultureSrf']['BNF'] = ('Integer',('AJ085'))
    field_information['GGDM 3.0']['AgricultureSrf']['CAA'] = ('Enumeration',('AJ050','AJ080','AJ085','AJ110','AL270','AM020','BH051','BH135'))
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['CAA']['AJ050']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['CAA']['AJ080']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['CAA']['AJ085']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['CAA']['AJ110']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['CAA']['AL270']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['CAA']['AM020']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['CAA']['BH051']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['CAA']['BH135']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['AgricultureSrf']['CNCP'] = ('StructuredText',('AJ030','AJ050','AJ080','AJ085','AJ110','AL270','AM020','BH051'))
    field_information['GGDM 3.0']['AgricultureSrf']['COS'] = ('Enumeration',('AJ030','AJ050','AJ080','AJ085','AJ110','AL270','AM020','BH051'))
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['COS']['AJ030']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['COS']['AJ050']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['COS']['AJ080']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['COS']['AJ085']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['COS']['AJ110']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['COS']['AL270']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['COS']['AM020']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['COS']['BH051']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['AgricultureSrf']['DMBC'] = ('Enumeration',('AL270','EA040'))
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['DMBC'] = {}
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['DMBC']['AL270']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['DMBC']['EA040']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['AgricultureSrf']['DMBL'] = ('real',('AL270','EA040'))
    field_information['GGDM 3.0']['AgricultureSrf']['DMBU'] = ('real',('AL270','EA040'))
    field_information['GGDM 3.0']['AgricultureSrf']['DMT'] = ('Real',('AL270','EA040'))
    field_information['GGDM 3.0']['AgricultureSrf']['DZP'] = ('Real',('BH135'))
    field_information['GGDM 3.0']['AgricultureSrf']['F_CODE'] = ('CONSTRAINED_STRING',('AJ030','AJ050','AJ080','AJ085','AJ110','AL270','AM020','BH051','BH135','EA010','EA030','EA040','EA050','EA055','EC010'))
    field_information['GGDM 3.0']['AgricultureSrf']['FFN'] = ('Enumeration',('AJ080','AJ085','AJ110','AL270'))
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['FFN'] = {}
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['FFN']['AJ080']  = (-999999,9,919,921,923,999)
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['FFN']['AJ085']  = (-999999,2,3,9,106,530,919,921,999)
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['FFN']['AJ110']  = (-999999,2,3,850,907,922,999)
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['FFN']['AL270']  = (-999999,3,15,847,970,999)
    field_information['GGDM 3.0']['AgricultureSrf']['FFN2'] = ('Enumeration',('AJ080','AJ085','AJ110','AL270'))
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['FFN2'] = {}
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['FFN2']['AJ080']  = (-999999,9,919,921,923,999)
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['FFN2']['AJ085']  = (-999999,2,3,9,106,530,919,921,999)
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['FFN2']['AJ110']  = (-999999,2,3,850,907,922,999)
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['FFN2']['AL270']  = (-999999,3,15,847,970,999)
    field_information['GGDM 3.0']['AgricultureSrf']['FFN3'] = ('Enumeration',('AJ080','AJ085','AJ110','AL270'))
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['FFN3'] = {}
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['FFN3']['AJ080']  = (-999999,9,919,921,923,999)
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['FFN3']['AJ085']  = (-999999,2,3,9,106,530,919,921,999)
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['FFN3']['AJ110']  = (-999999,2,3,850,907,922,999)
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['FFN3']['AL270']  = (-999999,3,15,847,970,999)
    field_information['GGDM 3.0']['AgricultureSrf']['FUFI'] = ('StructuredText',('AJ030','AJ050','AJ080','AJ085','AJ110','AL270','AM020','BH051','BH135','EA010','EA030','EA040','EA050','EA055','EC010'))
    field_information['GGDM 3.0']['AgricultureSrf']['FURL'] = ('StructuredText',('AJ030','AJ050','AJ080','AJ085','AJ110','AL270','AM020','BH051','BH135','EA010','EA030','EA040','EA050','EA055','EC010'))
    field_information['GGDM 3.0']['AgricultureSrf']['GDBV'] = ('Enumeration',('AJ030','AJ050','AJ080','AJ085','AJ110','AL270','AM020','BH051','BH135','EA010','EA030','EA040','EA050','EA055','EC010'))
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['GDBV']['AJ030']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['GDBV']['AJ050']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['GDBV']['AJ080']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['GDBV']['AJ085']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['GDBV']['AJ110']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['GDBV']['AL270']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['GDBV']['AM020']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['GDBV']['BH051']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['GDBV']['BH135']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['GDBV']['EA010']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['GDBV']['EA030']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['GDBV']['EA040']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['GDBV']['EA050']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['GDBV']['EA055']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['GDBV']['EC010']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['AgricultureSrf']['HGT'] = ('Real',('AJ030','AJ050','AJ080','AJ085','AJ110','AL270','AM020','EA040','EA050','EA055','EC010'))
    field_information['GGDM 3.0']['AgricultureSrf']['LMC'] = ('Boolean',('AJ030','AJ050','AJ080','AJ085','AJ110','AL270','AM020','BH051','EA010','EA030','EA040','EA050','EA055'))
    field_information['GGDM 3.0']['AgricultureSrf']['LUN'] = ('Boolean',('AM020'))
    field_information['GGDM 3.0']['AgricultureSrf']['LZN'] = ('Real',('AJ030','AJ050','AJ080','AJ085','AJ110','AL270','AM020','BH051','BH135','EA010','EA030','EA040','EA050','EA055','EC010'))
    field_information['GGDM 3.0']['AgricultureSrf']['OTH'] = ('StructuredText',('AJ030','AJ050','AJ080','AJ085','AJ110','AL270','AM020','BH051','BH135','EA010','EA030','EA040','EA050','EA055','EC010'))
    field_information['GGDM 3.0']['AgricultureSrf']['PCF'] = ('Enumeration',('AJ030','AJ050','AJ080','AJ085','AJ110','AL270','AM020','BH051'))
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['PCF']['AJ030']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['PCF']['AJ050']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['PCF']['AJ080']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['PCF']['AJ085']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['PCF']['AJ110']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['PCF']['AL270']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['PCF']['AM020']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['PCF']['BH051']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['AgricultureSrf']['PPO'] = ('Enumeration',('AJ050','BH051'))
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['PPO'] = {}
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['PPO']['AJ050']  = (-999999,122,160,999)
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['PPO']['BH051']  = (-999999,11,29,30,39,72,77,999)
    field_information['GGDM 3.0']['AgricultureSrf']['PPO2'] = ('Enumeration',('AJ050','BH051'))
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['PPO2'] = {}
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['PPO2']['AJ050']  = (-999999,122,160,999)
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['PPO2']['BH051']  = (-999999,11,29,30,39,72,77,999)
    field_information['GGDM 3.0']['AgricultureSrf']['PPO3'] = ('Enumeration',('AJ050','BH051'))
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['PPO3'] = {}
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['PPO3']['AJ050']  = (-999999,122,160,999)
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['PPO3']['BH051']  = (-999999,11,29,30,39,72,77,999)
    field_information['GGDM 3.0']['AgricultureSrf']['PVH'] = ('Real',('AL270','EA040'))
    field_information['GGDM 3.0']['AgricultureSrf']['SDSC'] = ('Enumeration',('AL270','EA040'))
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['SDSC'] = {}
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['SDSC']['AL270']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['SDSC']['EA040']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['AgricultureSrf']['SDSL'] = ('real',('AL270','EA040'))
    field_information['GGDM 3.0']['AgricultureSrf']['SDSU'] = ('real',('AL270','EA040'))
    field_information['GGDM 3.0']['AgricultureSrf']['SSR'] = ('Enumeration',('AJ080','AJ085','AJ110','AM020'))
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['SSR'] = {}
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['SSR']['AJ080']  = (-999999,6,7,38,40,41,42,47,50,55,64,999)
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['SSR']['AJ085']  = (-999999,6,7,38,40,41,42,47,50,55,64,999)
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['SSR']['AJ110']  = (-999999,6,7,38,40,41,42,47,50,55,64,999)
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['SSR']['AM020']  = (-999999,6,7,38,40,41,42,999)
    field_information['GGDM 3.0']['AgricultureSrf']['SSR2'] = ('Enumeration',('AJ080','AJ085','AJ110','AM020'))
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['SSR2'] = {}
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['SSR2']['AJ080']  = (-999999,6,7,38,40,41,42,47,50,55,64,999)
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['SSR2']['AJ085']  = (-999999,6,7,38,40,41,42,47,50,55,64,999)
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['SSR2']['AJ110']  = (-999999,6,7,38,40,41,42,47,50,55,64,999)
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['SSR2']['AM020']  = (-999999,6,7,38,40,41,42,999)
    field_information['GGDM 3.0']['AgricultureSrf']['SSR3'] = ('Enumeration',('AJ080','AJ085','AJ110','AM020'))
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['SSR3'] = {}
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['SSR3']['AJ080']  = (-999999,6,7,38,40,41,42,47,50,55,64,999)
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['SSR3']['AJ085']  = (-999999,6,7,38,40,41,42,47,50,55,64,999)
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['SSR3']['AJ110']  = (-999999,6,7,38,40,41,42,47,50,55,64,999)
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['SSR3']['AM020']  = (-999999,6,7,38,40,41,42,999)
    field_information['GGDM 3.0']['AgricultureSrf']['TOS'] = ('Enumeration',('AJ050'))
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['TOS'] = {}
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['TOS']['AJ050']  = (-999999,6,11,12,13,14,999)
    field_information['GGDM 3.0']['AgricultureSrf']['TRE'] = ('Enumeration',('AL270','EA040'))
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['TRE'] = {}
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['TRE']['AL270']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['TRE']['EA040']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['AgricultureSrf']['TSCC'] = ('Enumeration',('AL270','EA040'))
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['TSCC'] = {}
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['TSCC']['AL270']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['TSCC']['EA040']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['AgricultureSrf']['TSCL'] = ('real',('AL270','EA040'))
    field_information['GGDM 3.0']['AgricultureSrf']['TSCU'] = ('real',('AL270','EA040'))
    field_information['GGDM 3.0']['AgricultureSrf']['UFI'] = ('StructuredText',('AJ030','AJ050','AJ080','AJ085','AJ110','AL270','AM020','BH051','BH135','EA010','EA030','EA040','EA050','EA055','EC010'))
    field_information['GGDM 3.0']['AgricultureSrf']['VCM'] = ('Enumeration',('AJ050','AJ080','AJ085','AM020'))
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['VCM'] = {}
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['VCM']['AJ050']  = (-999999,2,3,4,7,8,9,15,16,18,999)
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['VCM']['AJ080']  = (-999999,1,3,4,7,8,9,12,13,14,15,16,18,999)
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['VCM']['AJ085']  = (-999999,1,3,4,7,8,9,12,13,14,15,16,18,999)
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['VCM']['AM020']  = (-999999,2,4,7,8,9,12,13,15,18,999)
    field_information['GGDM 3.0']['AgricultureSrf']['VCM2'] = ('Enumeration',('AJ050','AJ080','AJ085','AM020'))
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['VCM2'] = {}
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['VCM2']['AJ050']  = (-999999,2,3,4,7,8,9,15,16,18,999)
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['VCM2']['AJ080']  = (-999999,1,3,4,7,8,9,12,13,14,15,16,18,999)
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['VCM2']['AJ085']  = (-999999,1,3,4,7,8,9,12,13,14,15,16,18,999)
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['VCM2']['AM020']  = (-999999,2,4,7,8,9,12,13,15,18,999)
    field_information['GGDM 3.0']['AgricultureSrf']['VCM3'] = ('Enumeration',('AJ050','AJ080','AJ085','AM020'))
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['VCM3'] = {}
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['VCM3']['AJ050']  = (-999999,2,3,4,7,8,9,15,16,18,999)
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['VCM3']['AJ080']  = (-999999,1,3,4,7,8,9,12,13,14,15,16,18,999)
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['VCM3']['AJ085']  = (-999999,1,3,4,7,8,9,12,13,14,15,16,18,999)
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['VCM3']['AM020']  = (-999999,2,4,7,8,9,12,13,15,18,999)
    field_information['GGDM 3.0']['AgricultureSrf']['VLM'] = ('Real',('BH051'))
    field_information['GGDM 3.0']['AgricultureSrf']['VOI'] = ('StructuredText',('AJ050','AM020'))
    field_information['GGDM 3.0']['AgricultureSrf']['VSP'] = ('Enumeration',('AL270'))
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['VSP'] = {}
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['VSP']['AL270']  = (-999999,8,22,25,34,999)
    field_information['GGDM 3.0']['AgricultureSrf']['VSP2'] = ('Enumeration',('AL270'))
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['VSP2'] = {}
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['VSP2']['AL270']  = (-999999,8,22,25,34,999)
    field_information['GGDM 3.0']['AgricultureSrf']['VSP3'] = ('Enumeration',('AL270'))
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['VSP3'] = {}
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['VSP3']['AL270']  = (-999999,8,22,25,34,999)
    field_information['GGDM 3.0']['AgricultureSrf']['VTI'] = ('Real',('AL270','BH135','EA010','EA030','EA040','EA050','EA055','EC010'))
    field_information['GGDM 3.0']['AgricultureSrf']['WDAC'] = ('Enumeration',('BH135'))
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['WDAC'] = {}
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['WDAC']['BH135']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['AgricultureSrf']['WDAL'] = ('real',('BH135'))
    field_information['GGDM 3.0']['AgricultureSrf']['WDAU'] = ('real',('BH135'))
    field_information['GGDM 3.0']['AgricultureSrf']['WID'] = ('Real',('AJ030','AJ050','AJ080','AJ085','AJ110','AL270','AM020','BH051','BH135','EA010','EA030','EA040','EA050','EA055','EC010'))
    field_information['GGDM 3.0']['AgricultureSrf']['ZI001_SDV'] = ('StructuredText',('AJ030','AJ050','AJ080','AJ085','AJ110','AL270','AM020','BH051','BH135','EA010','EA030','EA040','EA050','EA055','EC010'))
    field_information['GGDM 3.0']['AgricultureSrf']['ZI001_SRT'] = ('Enumeration',('AJ030','AJ050','AJ080','AJ085','AJ110','AL270','AM020','BH051','BH135','EA010','EA030','EA040','EA050','EA055','EC010'))
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['ZI001_SRT']['AJ030']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['ZI001_SRT']['AJ050']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['ZI001_SRT']['AJ080']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['ZI001_SRT']['AJ085']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['ZI001_SRT']['AJ110']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['ZI001_SRT']['AL270']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['ZI001_SRT']['AM020']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['ZI001_SRT']['BH051']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['ZI001_SRT']['BH135']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['ZI001_SRT']['EA010']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['ZI001_SRT']['EA030']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['ZI001_SRT']['EA040']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['ZI001_SRT']['EA050']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['ZI001_SRT']['EA055']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['ZI001_SRT']['EC010']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['AgricultureSrf']['ZI002_UFI'] = ('StructuredText',('AJ030','AJ050','AJ080','AJ085','AJ110','AL270','AM020','BH051','BH135','EA010','EA030','EA040','EA050','EA055','EC010'))
    field_information['GGDM 3.0']['AgricultureSrf']['ZI004_RCG'] = ('Enumeration',('AJ030','AJ050','AJ080','AJ085','AJ110','AL270','AM020','BH051','BH135','EA010','EA030','EA040','EA050','EA055','EC010'))
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['ZI004_RCG']['AJ030']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['ZI004_RCG']['AJ050']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['ZI004_RCG']['AJ080']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['ZI004_RCG']['AJ085']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['ZI004_RCG']['AJ110']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['ZI004_RCG']['AL270']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['ZI004_RCG']['AM020']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['ZI004_RCG']['BH051']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['ZI004_RCG']['BH135']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['ZI004_RCG']['EA010']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['ZI004_RCG']['EA030']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['ZI004_RCG']['EA040']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['ZI004_RCG']['EA050']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['ZI004_RCG']['EA055']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['ZI004_RCG']['EC010']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['AgricultureSrf']['ZI005_FNA'] = ('String',('AJ030','AJ050','AJ080','AJ085','AJ110','AL270','AM020','BH051','BH135','EA010','EA030','EA040','EA050','EC010'))
    field_information['GGDM 3.0']['AgricultureSrf']['ZI005_GNT'] = ('Enumeration',('AJ030','AJ050','AJ080','AJ085','AJ110','AL270','AM020','BH051','BH135','EA010','EA030','EA040','EA050','EC010'))
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['ZI005_GNT']['AJ030']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['ZI005_GNT']['AJ050']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['ZI005_GNT']['AJ080']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['ZI005_GNT']['AJ085']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['ZI005_GNT']['AJ110']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['ZI005_GNT']['AL270']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['ZI005_GNT']['AM020']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['ZI005_GNT']['BH051']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['ZI005_GNT']['BH135']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['ZI005_GNT']['EA010']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['ZI005_GNT']['EA030']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['ZI005_GNT']['EA040']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['ZI005_GNT']['EA050']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['ZI005_GNT']['EC010']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['AgricultureSrf']['ZI005_NFN'] = ('String',('AJ030','AJ050','AJ080','AJ085','AJ110','AL270','AM020','BH051','BH135','EA010','EA030','EA040','EA050','EC010'))
    field_information['GGDM 3.0']['AgricultureSrf']['ZI006_MEM'] = ('String',('AJ030','AJ050','AJ080','AJ085','AJ110','AL270','AM020','BH051','BH135','EA010','EA030','EA040','EA050','EA055','EC010'))
    field_information['GGDM 3.0']['AgricultureSrf']['ZI013_CSP'] = ('Enumeration',('AL270','BH135','EA010','EA030','EA040','EA050','EA055'))
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['ZI013_CSP'] = {}
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['ZI013_CSP']['AL270']  = (-999999,8,9,10,22,29,33,34,35,41,42,43,44,45,46,48,999)
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['ZI013_CSP']['BH135']  = (28,)
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['ZI013_CSP']['EA010']  = (-999999,3,5,8,10,11,13,14,20,21,22,25,26,27,30,31,32,33,35,36,37,39,45,117,152,159,999)
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['ZI013_CSP']['EA030']  = (-999999,1,2,4,5,6,7,10,15,17,19,23,24,29,38,40,41,42,43,45,46,47,159,999)
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['ZI013_CSP']['EA040']  = (-999999,1,2,4,5,6,7,15,17,19,23,24,38,40,43,47,159,999)
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['ZI013_CSP']['EA050']  = (16,)
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['ZI013_CSP']['EA055']  = (18,)
    field_information['GGDM 3.0']['AgricultureSrf']['ZI013_CSP2'] = ('Enumeration',('AL270','EA010','EA040'))
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['ZI013_CSP2'] = {}
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['ZI013_CSP2']['AL270']  = (-999999,8,9,10,22,29,33,34,35,41,42,43,44,45,46,48,999)
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['ZI013_CSP2']['EA010']  = (-999999,3,5,8,10,11,13,14,20,21,22,25,26,27,30,31,32,33,35,36,37,39,45,117,152,159,999)
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['ZI013_CSP2']['EA040']  = (-999999,1,2,4,5,6,7,15,17,19,23,24,38,40,43,47,159,999)
    field_information['GGDM 3.0']['AgricultureSrf']['ZI013_CSP3'] = ('Enumeration',('AL270','EA010','EA040'))
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['ZI013_CSP3'] = {}
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['ZI013_CSP3']['AL270']  = (-999999,8,9,10,22,29,33,34,35,41,42,43,44,45,46,48,999)
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['ZI013_CSP3']['EA010']  = (-999999,3,5,8,10,11,13,14,20,21,22,25,26,27,30,31,32,33,35,36,37,39,45,117,152,159,999)
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['ZI013_CSP3']['EA040']  = (-999999,1,2,4,5,6,7,15,17,19,23,24,38,40,43,47,159,999)
    field_information['GGDM 3.0']['AgricultureSrf']['ZI013_FFP'] = ('Enumeration',('AL270','BH135','EA010','EA030','EA040','EA050','EA055'))
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['ZI013_FFP'] = {}
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['ZI013_FFP']['AL270']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['ZI013_FFP']['BH135']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['ZI013_FFP']['EA010']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['ZI013_FFP']['EA030']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['ZI013_FFP']['EA040']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['ZI013_FFP']['EA050']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['ZI013_FFP']['EA055']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['GGDM 3.0']['AgricultureSrf']['ZI013_FFP2'] = ('Enumeration',('AL270','BH135','EA010','EA030','EA040','EA050','EA055'))
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['ZI013_FFP2'] = {}
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['ZI013_FFP2']['AL270']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['ZI013_FFP2']['BH135']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['ZI013_FFP2']['EA010']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['ZI013_FFP2']['EA030']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['ZI013_FFP2']['EA040']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['ZI013_FFP2']['EA050']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['ZI013_FFP2']['EA055']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['GGDM 3.0']['AgricultureSrf']['ZI013_FFP3'] = ('Enumeration',('AL270','BH135','EA010','EA030','EA040','EA050','EA055'))
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['ZI013_FFP3'] = {}
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['ZI013_FFP3']['AL270']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['ZI013_FFP3']['BH135']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['ZI013_FFP3']['EA010']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['ZI013_FFP3']['EA030']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['ZI013_FFP3']['EA040']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['ZI013_FFP3']['EA050']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['ZI013_FFP3']['EA055']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['GGDM 3.0']['AgricultureSrf']['ZI013_FMM'] = ('Enumeration',('AL270','BH135','EA010'))
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['ZI013_FMM'] = {}
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['ZI013_FMM']['AL270']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['ZI013_FMM']['BH135']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['ZI013_FMM']['EA010']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['AgricultureSrf']['ZI013_FMM2'] = ('Enumeration',('AL270','BH135','EA010'))
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['ZI013_FMM2'] = {}
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['ZI013_FMM2']['AL270']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['ZI013_FMM2']['BH135']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['ZI013_FMM2']['EA010']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['AgricultureSrf']['ZI013_FMM3'] = ('Enumeration',('AL270','BH135','EA010'))
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['ZI013_FMM3'] = {}
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['ZI013_FMM3']['AL270']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['ZI013_FMM3']['BH135']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['ZI013_FMM3']['EA010']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['AgricultureSrf']['ZI013_IRG'] = ('Enumeration',('EA010','EA040','EA050','EA055'))
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['ZI013_IRG'] = {}
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['ZI013_IRG']['EA010']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['ZI013_IRG']['EA040']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['ZI013_IRG']['EA050']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['ZI013_IRG']['EA055']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['GGDM 3.0']['AgricultureSrf']['ZI013_PIG'] = ('Boolean',('AL270','BH135','EA010'))
    field_information['GGDM 3.0']['AgricultureSrf']['ZI014_PPO'] = ('Enumeration',('AL270'))
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['ZI014_PPO'] = {}
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['ZI014_PPO']['AL270']  = (-999999,20,25,28,32,39,41,44,63,70,73,92,94,95,111,114,117,121,123,155,160,999)
    field_information['GGDM 3.0']['AgricultureSrf']['ZI014_PPO2'] = ('Enumeration',('AL270'))
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['ZI014_PPO2'] = {}
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['ZI014_PPO2']['AL270']  = (-999999,20,25,28,32,39,41,44,63,70,73,92,94,95,111,114,117,121,123,155,160,999)
    field_information['GGDM 3.0']['AgricultureSrf']['ZI014_PPO3'] = ('Enumeration',('AL270'))
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['ZI014_PPO3'] = {}
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['ZI014_PPO3']['AL270']  = (-999999,20,25,28,32,39,41,44,63,70,73,92,94,95,111,114,117,121,123,155,160,999)
    field_information['GGDM 3.0']['AgricultureSrf']['ZI020_GE4'] = ('CodeList',('AJ030','AJ050','AJ080','AJ085','AJ110','AL270','AM020','BH051','BH135','EA010','EA030','EA040','EA050','EA055','EC010'))
    field_information['GGDM 3.0']['AgricultureSrf']['ZI024_ASE'] = ('Real',('BH051','BH135'))
    field_information['GGDM 3.0']['AgricultureSrf']['ZI024_CFR'] = ('Real',('BH051','BH135'))
    field_information['GGDM 3.0']['AgricultureSrf']['ZI024_CLO'] = ('Real',('BH051','BH135'))
    field_information['GGDM 3.0']['AgricultureSrf']['ZI024_CYN'] = ('Real',('BH051','BH135'))
    field_information['GGDM 3.0']['AgricultureSrf']['ZI024_FMR'] = ('Real',('BH051','BH135'))
    field_information['GGDM 3.0']['AgricultureSrf']['ZI024_FRR'] = ('Real',('BH051','BH135'))
    field_information['GGDM 3.0']['AgricultureSrf']['ZI024_HAR'] = ('Real',('BH051','BH135'))
    field_information['GGDM 3.0']['AgricultureSrf']['ZI024_HYP'] = ('Enumeration',('BH051','BH135'))
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['ZI024_HYP'] = {}
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['ZI024_HYP']['BH051']  = (-999999,1,2,4)
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['ZI024_HYP']['BH135']  = (-999999,1,2,4)
    field_information['GGDM 3.0']['AgricultureSrf']['ZI024_MGN'] = ('Real',('BH051','BH135'))
    field_information['GGDM 3.0']['AgricultureSrf']['ZI024_PHW'] = ('Real',('BH051','BH135'))
    field_information['GGDM 3.0']['AgricultureSrf']['ZI024_SCC'] = ('Enumeration',('BH051','BH135'))
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['ZI024_SCC'] = {}
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['ZI024_SCC']['BH051']  = (-999999,1,4,10,11,12,13,14,998,999)
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['ZI024_SCC']['BH135']  = (-999999,1,4,10,11,12,13,14,998,999)
    field_information['GGDM 3.0']['AgricultureSrf']['ZI024_SUL'] = ('Real',('BH051','BH135'))
    field_information['GGDM 3.0']['AgricultureSrf']['ZI024_TDS'] = ('Real',('BH051','BH135'))
    field_information['GGDM 3.0']['AgricultureSrf']['ZI024_TEP'] = ('Real',('BH051','BH135'))
    field_information['GGDM 3.0']['AgricultureSrf']['ZI024_TUR'] = ('Real',('BH051','BH135'))
    field_information['GGDM 3.0']['AgricultureSrf']['ZI024_WAC'] = ('Real',('BH051','BH135'))
    field_information['GGDM 3.0']['AgricultureSrf']['ZI024_WTNO'] = ('Real',('BH051','BH135'))
    field_information['GGDM 3.0']['AgricultureSrf']['ZI024_WUR'] = ('Enumeration',('BH051','BH135'))
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['ZI024_WUR'] = {}
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['ZI024_WUR']['BH051']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['ZI024_WUR']['BH135']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['AgricultureSrf']['ZI024_WUR2'] = ('Enumeration',('BH051'))
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['ZI024_WUR2'] = {}
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['ZI024_WUR2']['BH051']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['AgricultureSrf']['ZI024_WUR3'] = ('Enumeration',('BH051'))
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['ZI024_WUR3'] = {}
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['ZI024_WUR3']['BH051']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['AgricultureSrf']['ZI024_WUR4'] = ('Enumeration',('BH051'))
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['ZI024_WUR4'] = {}
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['ZI024_WUR4']['BH051']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['AgricultureSrf']['ZI024_YWQ'] = ('Enumeration',('BH051','BH135'))
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['ZI024_YWQ'] = {}
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['ZI024_YWQ']['BH051']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['ZI024_YWQ']['BH135']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['AgricultureSrf']['ZI026_CTUC'] = ('Enumeration',('AJ030','AJ050','AJ080','AJ085','AJ110','AL270','AM020','BH051','BH135','EA010','EA030','EA040','EA050','EA055','EC010'))
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['ZI026_CTUC']['AJ030']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['ZI026_CTUC']['AJ050']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['ZI026_CTUC']['AJ080']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['ZI026_CTUC']['AJ085']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['ZI026_CTUC']['AJ110']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['ZI026_CTUC']['AL270']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['ZI026_CTUC']['AM020']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['ZI026_CTUC']['BH051']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['ZI026_CTUC']['BH135']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['ZI026_CTUC']['EA010']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['ZI026_CTUC']['EA030']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['ZI026_CTUC']['EA040']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['ZI026_CTUC']['EA050']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['ZI026_CTUC']['EA055']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['AgricultureSrf']['EnumeratedIndexValues']['ZI026_CTUC']['EC010']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['AgricultureSrf']['ZI026_CTUL'] = ('integer',('AJ030','AJ050','AJ080','AJ085','AJ110','AL270','AM020','BH051','BH135','EA010','EA030','EA040','EA050','EA055','EC010'))
    field_information['GGDM 3.0']['AgricultureSrf']['ZI026_CTUU'] = ('integer',('AJ030','AJ050','AJ080','AJ085','AJ110','AL270','AM020','BH051','BH135','EA010','EA030','EA040','EA050','EA055','EC010'))
    field_information['GGDM 3.0']['AgricultureSrf']['ZI031S_URI'] = ('StructuredText',('AJ030','AJ050','AJ080','AJ085','AJ110','AL270','AM020','BH051','BH135','EA010','EA030','EA040','EA050','EA055','EC010'))
    field_information['GGDM 3.0']['AgricultureSrf']['ZI039S_UFI'] = ('StructuredText',('AJ030','AJ050','AJ080','AJ085','AJ110','AL270','AM020','BH051','BH135','EA010','EA030','EA040','EA050','EA055','EC010'))
    field_information['GGDM 3.0']['AgricultureSrf']['ZSAX_RS0'] = ('CodeList',('AJ030','AJ050','AJ080','AJ085','AJ110','AL270','AM020','BH051','BH135','EA010','EA030','EA040','EA050','EA055','EC010'))
    field_information['GGDM 3.0']['AgricultureSrf']['ZSAX_RX0'] = ('StructuredText',('AJ030','AJ050','AJ080','AJ085','AJ110','AL270','AM020','BH051','BH135','EA010','EA030','EA040','EA050','EA055','EC010'))
    field_information['GGDM 3.0']['AgricultureSrf']['ZSAX_RX3'] = ('StructuredText',('AJ030','AJ050','AJ080','AJ085','AJ110','AL270','AM020','BH051','BH135','EA010','EA030','EA040','EA050','EA055','EC010'))
    field_information['GGDM 3.0']['AgricultureSrf']['ZSAX_RX4'] = ('StructuredText',('AJ030','AJ050','AJ080','AJ085','AJ110','AL270','AM020','BH051','BH135','EA010','EA030','EA040','EA050','EA055','EC010'))
    field_information['GGDM 3.0']['AgricultureSrf']['ZVH'] = ('Real',('AJ030','AJ050','AJ080','AJ085','AJ110','AL270','AM020','EA040','EA050','EA055'))
    field_information['GGDM 3.0']['BoundaryCrvExt']['BEN'] = ('StructuredText',('FA000','FA110'))
    field_information['GGDM 3.0']['BoundaryCrvExt']['BST'] = ('Enumeration',('FA000'))
    field_information['GGDM 3.0']['BoundaryCrvExt']['EnumeratedIndexValues']['BST'] = {}
    field_information['GGDM 3.0']['BoundaryCrvExt']['EnumeratedIndexValues']['BST']['FA000']  = (-999999,1,2,3,4)
    field_information['GGDM 3.0']['BoundaryCrvExt']['CAA'] = ('Enumeration',('FA000'))
    field_information['GGDM 3.0']['BoundaryCrvExt']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['BoundaryCrvExt']['EnumeratedIndexValues']['CAA']['FA000']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['BoundaryCrvExt']['DSP'] = ('Enumeration',('FA000'))
    field_information['GGDM 3.0']['BoundaryCrvExt']['EnumeratedIndexValues']['DSP'] = {}
    field_information['GGDM 3.0']['BoundaryCrvExt']['EnumeratedIndexValues']['DSP']['FA000']  = (-999999,1,2,3,4)
    field_information['GGDM 3.0']['BoundaryCrvExt']['F_CODE'] = ('CONSTRAINED_STRING',('FA000','FA110'))
    field_information['GGDM 3.0']['BoundaryCrvExt']['FA003_BAL'] = ('Enumeration',('FA000'))
    field_information['GGDM 3.0']['BoundaryCrvExt']['EnumeratedIndexValues']['FA003_BAL'] = {}
    field_information['GGDM 3.0']['BoundaryCrvExt']['EnumeratedIndexValues']['FA003_BAL']['FA000']  = (-999999,1,2,3,4,5,999)
    field_information['GGDM 3.0']['BoundaryCrvExt']['FUFI'] = ('StructuredText',('FA000','FA110'))
    field_information['GGDM 3.0']['BoundaryCrvExt']['FURL'] = ('StructuredText',('FA000','FA110'))
    field_information['GGDM 3.0']['BoundaryCrvExt']['GDBV'] = ('Enumeration',('FA000','FA110'))
    field_information['GGDM 3.0']['BoundaryCrvExt']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['BoundaryCrvExt']['EnumeratedIndexValues']['GDBV']['FA000']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['BoundaryCrvExt']['EnumeratedIndexValues']['GDBV']['FA110']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['BoundaryCrvExt']['LSP'] = ('Enumeration',('FA000'))
    field_information['GGDM 3.0']['BoundaryCrvExt']['EnumeratedIndexValues']['LSP'] = {}
    field_information['GGDM 3.0']['BoundaryCrvExt']['EnumeratedIndexValues']['LSP']['FA000']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,999)
    field_information['GGDM 3.0']['BoundaryCrvExt']['LZN'] = ('Real',('FA000'))
    field_information['GGDM 3.0']['BoundaryCrvExt']['MGL'] = ('Enumeration',('FA000'))
    field_information['GGDM 3.0']['BoundaryCrvExt']['EnumeratedIndexValues']['MGL'] = {}
    field_information['GGDM 3.0']['BoundaryCrvExt']['EnumeratedIndexValues']['MGL']['FA000']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['BoundaryCrvExt']['MGL2'] = ('Enumeration',('FA000'))
    field_information['GGDM 3.0']['BoundaryCrvExt']['EnumeratedIndexValues']['MGL2'] = {}
    field_information['GGDM 3.0']['BoundaryCrvExt']['EnumeratedIndexValues']['MGL2']['FA000']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['BoundaryCrvExt']['MGL3'] = ('Enumeration',('FA000'))
    field_information['GGDM 3.0']['BoundaryCrvExt']['EnumeratedIndexValues']['MGL3'] = {}
    field_information['GGDM 3.0']['BoundaryCrvExt']['EnumeratedIndexValues']['MGL3']['FA000']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['BoundaryCrvExt']['OTH'] = ('StructuredText',('FA000','FA110'))
    field_information['GGDM 3.0']['BoundaryCrvExt']['RPC'] = ('Enumeration',('FA000'))
    field_information['GGDM 3.0']['BoundaryCrvExt']['EnumeratedIndexValues']['RPC'] = {}
    field_information['GGDM 3.0']['BoundaryCrvExt']['EnumeratedIndexValues']['RPC']['FA000']  = (-999999,1,2,3,4,5,999)
    field_information['GGDM 3.0']['BoundaryCrvExt']['UFI'] = ('StructuredText',('FA000','FA110'))
    field_information['GGDM 3.0']['BoundaryCrvExt']['ZI001_SDV'] = ('StructuredText',('FA000','FA110'))
    field_information['GGDM 3.0']['BoundaryCrvExt']['ZI001_SRT'] = ('Enumeration',('FA000','FA110'))
    field_information['GGDM 3.0']['BoundaryCrvExt']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['BoundaryCrvExt']['EnumeratedIndexValues']['ZI001_SRT']['FA000']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['BoundaryCrvExt']['EnumeratedIndexValues']['ZI001_SRT']['FA110']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['BoundaryCrvExt']['ZI002_UFI'] = ('StructuredText',('FA000','FA110'))
    field_information['GGDM 3.0']['BoundaryCrvExt']['ZI004_RCG'] = ('Enumeration',('FA000','FA110'))
    field_information['GGDM 3.0']['BoundaryCrvExt']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['BoundaryCrvExt']['EnumeratedIndexValues']['ZI004_RCG']['FA000']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['BoundaryCrvExt']['EnumeratedIndexValues']['ZI004_RCG']['FA110']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['BoundaryCrvExt']['ZI005_FNAA'] = ('String',('FA000'))
    field_information['GGDM 3.0']['BoundaryCrvExt']['ZI005_FNAB'] = ('String',('FA000'))
    field_information['GGDM 3.0']['BoundaryCrvExt']['ZI005_GNTA'] = ('Enumeration',('FA000'))
    field_information['GGDM 3.0']['BoundaryCrvExt']['EnumeratedIndexValues']['ZI005_GNTA'] = {}
    field_information['GGDM 3.0']['BoundaryCrvExt']['EnumeratedIndexValues']['ZI005_GNTA']['FA000']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['BoundaryCrvExt']['ZI005_GNTB'] = ('Enumeration',('FA000'))
    field_information['GGDM 3.0']['BoundaryCrvExt']['EnumeratedIndexValues']['ZI005_GNTB'] = {}
    field_information['GGDM 3.0']['BoundaryCrvExt']['EnumeratedIndexValues']['ZI005_GNTB']['FA000']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['BoundaryCrvExt']['ZI005_NFNA'] = ('String',('FA000'))
    field_information['GGDM 3.0']['BoundaryCrvExt']['ZI005_NFNB'] = ('String',('FA000'))
    field_information['GGDM 3.0']['BoundaryCrvExt']['ZI006_MEM'] = ('String',('FA000','FA110'))
    field_information['GGDM 3.0']['BoundaryCrvExt']['ZI020_FI2A'] = ('String',('FA000'))
    field_information['GGDM 3.0']['BoundaryCrvExt']['ZI020_FI2B'] = ('String',('FA000'))
    field_information['GGDM 3.0']['BoundaryCrvExt']['ZI020_GE4'] = ('CodeList',('FA000','FA110'))
    field_information['GGDM 3.0']['BoundaryCrvExt']['ZI020_GE4A'] = ('CodeList',('FA000'))
    field_information['GGDM 3.0']['BoundaryCrvExt']['ZI020_GE4B'] = ('CodeList',('FA000'))
    field_information['GGDM 3.0']['BoundaryCrvExt']['ZI026_CTUC'] = ('Enumeration',('FA000','FA110'))
    field_information['GGDM 3.0']['BoundaryCrvExt']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['BoundaryCrvExt']['EnumeratedIndexValues']['ZI026_CTUC']['FA000']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['BoundaryCrvExt']['EnumeratedIndexValues']['ZI026_CTUC']['FA110']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['BoundaryCrvExt']['ZI026_CTUL'] = ('integer',('FA000','FA110'))
    field_information['GGDM 3.0']['BoundaryCrvExt']['ZI026_CTUU'] = ('integer',('FA000','FA110'))
    field_information['GGDM 3.0']['BoundaryCrvExt']['ZI031S_URI'] = ('StructuredText',('FA000','FA110'))
    field_information['GGDM 3.0']['BoundaryCrvExt']['ZI039S_UFI'] = ('StructuredText',('FA000','FA110'))
    field_information['GGDM 3.0']['BoundaryCrvExt']['ZSAX_RS0'] = ('CodeList',('FA000','FA110'))
    field_information['GGDM 3.0']['BoundaryCrvExt']['ZSAX_RX0'] = ('StructuredText',('FA000','FA110'))
    field_information['GGDM 3.0']['BoundaryCrvExt']['ZSAX_RX3'] = ('StructuredText',('FA000','FA110'))
    field_information['GGDM 3.0']['BoundaryCrvExt']['ZSAX_RX4'] = ('StructuredText',('FA000','FA110'))
    field_information['GGDM 3.0']['BoundaryPnt']['BEN'] = ('StructuredText',('ZB030'))
    field_information['GGDM 3.0']['BoundaryPnt']['CNCP'] = ('StructuredText',('ZB030'))
    field_information['GGDM 3.0']['BoundaryPnt']['COS'] = ('Enumeration',('ZB030'))
    field_information['GGDM 3.0']['BoundaryPnt']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['BoundaryPnt']['EnumeratedIndexValues']['COS']['ZB030']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['BoundaryPnt']['F_CODE'] = ('CONSTRAINED_STRING',('ZB030'))
    field_information['GGDM 3.0']['BoundaryPnt']['FUFI'] = ('StructuredText',('ZB030'))
    field_information['GGDM 3.0']['BoundaryPnt']['FURL'] = ('StructuredText',('ZB030'))
    field_information['GGDM 3.0']['BoundaryPnt']['GDBV'] = ('Enumeration',('ZB030'))
    field_information['GGDM 3.0']['BoundaryPnt']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['BoundaryPnt']['EnumeratedIndexValues']['GDBV']['ZB030']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['BoundaryPnt']['LZN'] = ('Real',('ZB030'))
    field_information['GGDM 3.0']['BoundaryPnt']['MCC'] = ('Enumeration',('ZB030'))
    field_information['GGDM 3.0']['BoundaryPnt']['EnumeratedIndexValues']['MCC'] = {}
    field_information['GGDM 3.0']['BoundaryPnt']['EnumeratedIndexValues']['MCC']['ZB030']  = (-999999,9,21,62,64,108,117,999)
    field_information['GGDM 3.0']['BoundaryPnt']['MCC2'] = ('Enumeration',('ZB030'))
    field_information['GGDM 3.0']['BoundaryPnt']['EnumeratedIndexValues']['MCC2'] = {}
    field_information['GGDM 3.0']['BoundaryPnt']['EnumeratedIndexValues']['MCC2']['ZB030']  = (-999999,9,21,62,64,108,117,999)
    field_information['GGDM 3.0']['BoundaryPnt']['MCC3'] = ('Enumeration',('ZB030'))
    field_information['GGDM 3.0']['BoundaryPnt']['EnumeratedIndexValues']['MCC3'] = {}
    field_information['GGDM 3.0']['BoundaryPnt']['EnumeratedIndexValues']['MCC3']['ZB030']  = (-999999,9,21,62,64,108,117,999)
    field_information['GGDM 3.0']['BoundaryPnt']['OTH'] = ('StructuredText',('ZB030'))
    field_information['GGDM 3.0']['BoundaryPnt']['PCF'] = ('Enumeration',('ZB030'))
    field_information['GGDM 3.0']['BoundaryPnt']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['BoundaryPnt']['EnumeratedIndexValues']['PCF']['ZB030']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['BoundaryPnt']['UFI'] = ('StructuredText',('ZB030'))
    field_information['GGDM 3.0']['BoundaryPnt']['WID'] = ('Real',('ZB030'))
    field_information['GGDM 3.0']['BoundaryPnt']['ZI001_SDV'] = ('StructuredText',('ZB030'))
    field_information['GGDM 3.0']['BoundaryPnt']['ZI001_SRT'] = ('Enumeration',('ZB030'))
    field_information['GGDM 3.0']['BoundaryPnt']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['BoundaryPnt']['EnumeratedIndexValues']['ZI001_SRT']['ZB030']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['BoundaryPnt']['ZI002_UFI'] = ('StructuredText',('ZB030'))
    field_information['GGDM 3.0']['BoundaryPnt']['ZI004_RCG'] = ('Enumeration',('ZB030'))
    field_information['GGDM 3.0']['BoundaryPnt']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['BoundaryPnt']['EnumeratedIndexValues']['ZI004_RCG']['ZB030']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['BoundaryPnt']['ZI005_FNA'] = ('String',('ZB030'))
    field_information['GGDM 3.0']['BoundaryPnt']['ZI005_GNT'] = ('Enumeration',('ZB030'))
    field_information['GGDM 3.0']['BoundaryPnt']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['BoundaryPnt']['EnumeratedIndexValues']['ZI005_GNT']['ZB030']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['BoundaryPnt']['ZI005_NFN'] = ('String',('ZB030'))
    field_information['GGDM 3.0']['BoundaryPnt']['ZI006_MEM'] = ('String',('ZB030'))
    field_information['GGDM 3.0']['BoundaryPnt']['ZI020_GE4'] = ('CodeList',('ZB030'))
    field_information['GGDM 3.0']['BoundaryPnt']['ZI026_CTUC'] = ('Enumeration',('ZB030'))
    field_information['GGDM 3.0']['BoundaryPnt']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['BoundaryPnt']['EnumeratedIndexValues']['ZI026_CTUC']['ZB030']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['BoundaryPnt']['ZI026_CTUL'] = ('integer',('ZB030'))
    field_information['GGDM 3.0']['BoundaryPnt']['ZI026_CTUU'] = ('integer',('ZB030'))
    field_information['GGDM 3.0']['BoundaryPnt']['ZI031S_URI'] = ('StructuredText',('ZB030'))
    field_information['GGDM 3.0']['BoundaryPnt']['ZI039S_UFI'] = ('StructuredText',('ZB030'))
    field_information['GGDM 3.0']['BoundaryPnt']['ZSAX_RS0'] = ('CodeList',('ZB030'))
    field_information['GGDM 3.0']['BoundaryPnt']['ZSAX_RX0'] = ('StructuredText',('ZB030'))
    field_information['GGDM 3.0']['BoundaryPnt']['ZSAX_RX3'] = ('StructuredText',('ZB030'))
    field_information['GGDM 3.0']['BoundaryPnt']['ZSAX_RX4'] = ('StructuredText',('ZB030'))
    field_information['GGDM 3.0']['BoundaryPnt']['ZVH'] = ('Real',('ZB030'))
    field_information['GGDM 3.0']['BoundarySrf']['ARA'] = ('Real',('IA040'))
    field_information['GGDM 3.0']['BoundarySrf']['BEN'] = ('StructuredText',('IA040'))
    field_information['GGDM 3.0']['BoundarySrf']['CAA'] = ('Enumeration',('IA040'))
    field_information['GGDM 3.0']['BoundarySrf']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['BoundarySrf']['EnumeratedIndexValues']['CAA']['IA040']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['BoundarySrf']['CDM'] = ('String',('IA040'))
    field_information['GGDM 3.0']['BoundarySrf']['CDY'] = ('Enumeration',('IA040'))
    field_information['GGDM 3.0']['BoundarySrf']['EnumeratedIndexValues']['CDY'] = {}
    field_information['GGDM 3.0']['BoundarySrf']['EnumeratedIndexValues']['CDY']['IA040']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,999)
    field_information['GGDM 3.0']['BoundarySrf']['CSI'] = ('String',('IA040'))
    field_information['GGDM 3.0']['BoundarySrf']['CSY'] = ('String',('IA040'))
    field_information['GGDM 3.0']['BoundarySrf']['F_CODE'] = ('CONSTRAINED_STRING',('IA040'))
    field_information['GGDM 3.0']['BoundarySrf']['FUFI'] = ('StructuredText',('IA040'))
    field_information['GGDM 3.0']['BoundarySrf']['FURL'] = ('StructuredText',('IA040'))
    field_information['GGDM 3.0']['BoundarySrf']['GDBV'] = ('Enumeration',('IA040'))
    field_information['GGDM 3.0']['BoundarySrf']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['BoundarySrf']['EnumeratedIndexValues']['GDBV']['IA040']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['BoundarySrf']['OTH'] = ('StructuredText',('IA040'))
    field_information['GGDM 3.0']['BoundarySrf']['UFI'] = ('StructuredText',('IA040'))
    field_information['GGDM 3.0']['BoundarySrf']['ZI001_SDV'] = ('StructuredText',('IA040'))
    field_information['GGDM 3.0']['BoundarySrf']['ZI001_SRT'] = ('Enumeration',('IA040'))
    field_information['GGDM 3.0']['BoundarySrf']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['BoundarySrf']['EnumeratedIndexValues']['ZI001_SRT']['IA040']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['BoundarySrf']['ZI002_UFI'] = ('StructuredText',('IA040'))
    field_information['GGDM 3.0']['BoundarySrf']['ZI004_RCG'] = ('Enumeration',('IA040'))
    field_information['GGDM 3.0']['BoundarySrf']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['BoundarySrf']['EnumeratedIndexValues']['ZI004_RCG']['IA040']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['BoundarySrf']['ZI005_FNA'] = ('String',('IA040'))
    field_information['GGDM 3.0']['BoundarySrf']['ZI005_GNT'] = ('Enumeration',('IA040'))
    field_information['GGDM 3.0']['BoundarySrf']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['BoundarySrf']['EnumeratedIndexValues']['ZI005_GNT']['IA040']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['BoundarySrf']['ZI005_NFN'] = ('String',('IA040'))
    field_information['GGDM 3.0']['BoundarySrf']['ZI006_MEM'] = ('String',('IA040'))
    field_information['GGDM 3.0']['BoundarySrf']['ZI020_GE4'] = ('CodeList',('IA040'))
    field_information['GGDM 3.0']['BoundarySrf']['ZI026_CTUC'] = ('Enumeration',('IA040'))
    field_information['GGDM 3.0']['BoundarySrf']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['BoundarySrf']['EnumeratedIndexValues']['ZI026_CTUC']['IA040']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['BoundarySrf']['ZI026_CTUL'] = ('integer',('IA040'))
    field_information['GGDM 3.0']['BoundarySrf']['ZI026_CTUU'] = ('integer',('IA040'))
    field_information['GGDM 3.0']['BoundarySrf']['ZI031S_URI'] = ('StructuredText',('IA040'))
    field_information['GGDM 3.0']['BoundarySrf']['ZI039S_UFI'] = ('StructuredText',('IA040'))
    field_information['GGDM 3.0']['BoundarySrf']['ZSAX_RS0'] = ('CodeList',('IA040'))
    field_information['GGDM 3.0']['BoundarySrf']['ZSAX_RX0'] = ('StructuredText',('IA040'))
    field_information['GGDM 3.0']['BoundarySrf']['ZSAX_RX3'] = ('StructuredText',('IA040'))
    field_information['GGDM 3.0']['BoundarySrf']['ZSAX_RX4'] = ('StructuredText',('IA040'))
    field_information['GGDM 3.0']['BoundarySrfExt']['ARA'] = ('Real',('FA002','FA003'))
    field_information['GGDM 3.0']['BoundarySrfExt']['BEN'] = ('StructuredText',('FA002','FA003'))
    field_information['GGDM 3.0']['BoundarySrfExt']['CAA'] = ('Enumeration',('FA003'))
    field_information['GGDM 3.0']['BoundarySrfExt']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['BoundarySrfExt']['EnumeratedIndexValues']['CAA']['FA003']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['BoundarySrfExt']['F_CODE'] = ('CONSTRAINED_STRING',('FA002','FA003'))
    field_information['GGDM 3.0']['BoundarySrfExt']['FUFI'] = ('StructuredText',('FA002','FA003'))
    field_information['GGDM 3.0']['BoundarySrfExt']['FURL'] = ('StructuredText',('FA002','FA003'))
    field_information['GGDM 3.0']['BoundarySrfExt']['GDBV'] = ('Enumeration',('FA002','FA003'))
    field_information['GGDM 3.0']['BoundarySrfExt']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['BoundarySrfExt']['EnumeratedIndexValues']['GDBV']['FA002']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['BoundarySrfExt']['EnumeratedIndexValues']['GDBV']['FA003']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['BoundarySrfExt']['GEC'] = ('Enumeration',('FA002'))
    field_information['GGDM 3.0']['BoundarySrfExt']['EnumeratedIndexValues']['GEC'] = {}
    field_information['GGDM 3.0']['BoundarySrfExt']['EnumeratedIndexValues']['GEC']['FA002']  = (-999999,5,7,8,9,10,11,12,13,14,15,16,17,999)
    field_information['GGDM 3.0']['BoundarySrfExt']['OTH'] = ('StructuredText',('FA002','FA003'))
    field_information['GGDM 3.0']['BoundarySrfExt']['PPL'] = ('Integer',('FA003'))
    field_information['GGDM 3.0']['BoundarySrfExt']['UFI'] = ('StructuredText',('FA002','FA003'))
    field_information['GGDM 3.0']['BoundarySrfExt']['ZI001_SDV'] = ('StructuredText',('FA002','FA003'))
    field_information['GGDM 3.0']['BoundarySrfExt']['ZI001_SRT'] = ('Enumeration',('FA002','FA003'))
    field_information['GGDM 3.0']['BoundarySrfExt']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['BoundarySrfExt']['EnumeratedIndexValues']['ZI001_SRT']['FA002']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['BoundarySrfExt']['EnumeratedIndexValues']['ZI001_SRT']['FA003']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['BoundarySrfExt']['ZI002_UFI'] = ('StructuredText',('FA002','FA003'))
    field_information['GGDM 3.0']['BoundarySrfExt']['ZI004_RCG'] = ('Enumeration',('FA002','FA003'))
    field_information['GGDM 3.0']['BoundarySrfExt']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['BoundarySrfExt']['EnumeratedIndexValues']['ZI004_RCG']['FA002']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['BoundarySrfExt']['EnumeratedIndexValues']['ZI004_RCG']['FA003']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['BoundarySrfExt']['ZI005_FNA'] = ('String',('FA002','FA003'))
    field_information['GGDM 3.0']['BoundarySrfExt']['ZI005_GNT'] = ('Enumeration',('FA002','FA003'))
    field_information['GGDM 3.0']['BoundarySrfExt']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['BoundarySrfExt']['EnumeratedIndexValues']['ZI005_GNT']['FA002']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['BoundarySrfExt']['EnumeratedIndexValues']['ZI005_GNT']['FA003']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['BoundarySrfExt']['ZI005_NFN'] = ('String',('FA002','FA003'))
    field_information['GGDM 3.0']['BoundarySrfExt']['ZI006_MEM'] = ('String',('FA002','FA003'))
    field_information['GGDM 3.0']['BoundarySrfExt']['ZI020_GE4'] = ('CodeList',('FA002','FA003'))
    field_information['GGDM 3.0']['BoundarySrfExt']['ZI020_IC4'] = ('String',('FA002'))
    field_information['GGDM 3.0']['BoundarySrfExt']['ZI026_CTUC'] = ('Enumeration',('FA002','FA003'))
    field_information['GGDM 3.0']['BoundarySrfExt']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['BoundarySrfExt']['EnumeratedIndexValues']['ZI026_CTUC']['FA002']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['BoundarySrfExt']['EnumeratedIndexValues']['ZI026_CTUC']['FA003']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['BoundarySrfExt']['ZI026_CTUL'] = ('integer',('FA002','FA003'))
    field_information['GGDM 3.0']['BoundarySrfExt']['ZI026_CTUU'] = ('integer',('FA002','FA003'))
    field_information['GGDM 3.0']['BoundarySrfExt']['ZI031S_URI'] = ('StructuredText',('FA002','FA003'))
    field_information['GGDM 3.0']['BoundarySrfExt']['ZI039S_UFI'] = ('StructuredText',('FA002','FA003'))
    field_information['GGDM 3.0']['BoundarySrfExt']['ZSAX_RS0'] = ('CodeList',('FA002','FA003'))
    field_information['GGDM 3.0']['BoundarySrfExt']['ZSAX_RX0'] = ('StructuredText',('FA002','FA003'))
    field_information['GGDM 3.0']['BoundarySrfExt']['ZSAX_RX3'] = ('StructuredText',('FA002','FA003'))
    field_information['GGDM 3.0']['BoundarySrfExt']['ZSAX_RX4'] = ('StructuredText',('FA002','FA003'))
    field_information['GGDM 3.0']['RESTRICTION_INFO_T']['CCN'] = ('String',('ZI002'))
    field_information['GGDM 3.0']['RESTRICTION_INFO_T']['CDR'] = ('String',('ZI002'))
    field_information['GGDM 3.0']['RESTRICTION_INFO_T']['F_CODE'] = ('CONSTRAINED_STRING',('ZI002'))
    field_information['GGDM 3.0']['RESTRICTION_INFO_T']['SAX_RS1'] = ('String',('ZI002'))
    field_information['GGDM 3.0']['RESTRICTION_INFO_T']['SAX_RS2'] = ('String',('ZI002'))
    field_information['GGDM 3.0']['RESTRICTION_INFO_T']['SAX_RS4'] = ('StructuredText',('ZI002'))
    field_information['GGDM 3.0']['RESTRICTION_INFO_T']['SAX_RS5'] = ('String',('ZI002'))
    field_information['GGDM 3.0']['RESTRICTION_INFO_T']['SAX_RS6'] = ('StructuredText',('ZI002'))
    field_information['GGDM 3.0']['RESTRICTION_INFO_T']['SAX_RS8'] = ('String',('ZI002'))
    field_information['GGDM 3.0']['RESTRICTION_INFO_T']['SAX_RS9'] = ('String',('ZI002'))
    field_information['GGDM 3.0']['RESTRICTION_INFO_T']['SAX_RX1'] = ('StructuredText',('ZI002'))
    field_information['GGDM 3.0']['RESTRICTION_INFO_T']['SAX_RX2'] = ('StructuredText',('ZI002'))
    field_information['GGDM 3.0']['RESTRICTION_INFO_T']['SAX_RX5'] = ('StructuredText',('ZI002'))
    field_information['GGDM 3.0']['RESTRICTION_INFO_T']['SAX_RX6'] = ('StructuredText',('ZI002'))
    field_information['GGDM 3.0']['RESTRICTION_INFO_T']['SAX_RX7'] = ('StructuredText',('ZI002'))
    field_information['GGDM 3.0']['RESTRICTION_INFO_T']['SAX_RX9'] = ('String',('ZI002'))
    field_information['GGDM 3.0']['RESTRICTION_INFO_T']['SAX_RY0'] = ('String',('ZI002'))
    field_information['GGDM 3.0']['RESTRICTION_INFO_T']['SAX_RY1'] = ('StructuredText',('ZI002'))
    field_information['GGDM 3.0']['RESTRICTION_INFO_T']['SAX_RY2'] = ('StructuredText',('ZI002'))
    field_information['GGDM 3.0']['RESTRICTION_INFO_T']['UFI'] = ('StructuredText',('ZI002'))
    field_information['GGDM 3.0']['CultureCrv']['AOO'] = ('Real',('AL130'))
    field_information['GGDM 3.0']['CultureCrv']['ARA'] = ('Real',('AL130'))
    field_information['GGDM 3.0']['CultureCrv']['AWP'] = ('Boolean',('AL130'))
    field_information['GGDM 3.0']['CultureCrv']['BEN'] = ('StructuredText',('AL130'))
    field_information['GGDM 3.0']['CultureCrv']['CAA'] = ('Enumeration',('AL130'))
    field_information['GGDM 3.0']['CultureCrv']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['CultureCrv']['EnumeratedIndexValues']['CAA']['AL130']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['CultureCrv']['CNCP'] = ('StructuredText',('AL130'))
    field_information['GGDM 3.0']['CultureCrv']['COS'] = ('Enumeration',('AL130'))
    field_information['GGDM 3.0']['CultureCrv']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['CultureCrv']['EnumeratedIndexValues']['COS']['AL130']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['CultureCrv']['F_CODE'] = ('CONSTRAINED_STRING',('AL130'))
    field_information['GGDM 3.0']['CultureCrv']['FUFI'] = ('StructuredText',('AL130'))
    field_information['GGDM 3.0']['CultureCrv']['FURL'] = ('StructuredText',('AL130'))
    field_information['GGDM 3.0']['CultureCrv']['GDBV'] = ('Enumeration',('AL130'))
    field_information['GGDM 3.0']['CultureCrv']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['CultureCrv']['EnumeratedIndexValues']['GDBV']['AL130']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['CultureCrv']['HEI'] = ('Real',('AL130'))
    field_information['GGDM 3.0']['CultureCrv']['HGT'] = ('Real',('AL130'))
    field_information['GGDM 3.0']['CultureCrv']['LMC'] = ('Boolean',('AL130'))
    field_information['GGDM 3.0']['CultureCrv']['LZN'] = ('Real',('AL130'))
    field_information['GGDM 3.0']['CultureCrv']['OTH'] = ('StructuredText',('AL130'))
    field_information['GGDM 3.0']['CultureCrv']['PCF'] = ('Enumeration',('AL130'))
    field_information['GGDM 3.0']['CultureCrv']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['CultureCrv']['EnumeratedIndexValues']['PCF']['AL130']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['CultureCrv']['SSC'] = ('Enumeration',('AL130'))
    field_information['GGDM 3.0']['CultureCrv']['EnumeratedIndexValues']['SSC'] = {}
    field_information['GGDM 3.0']['CultureCrv']['EnumeratedIndexValues']['SSC']['AL130']  = (-999999,12,17,77,78,95,96,97,98,109,112,999)
    field_information['GGDM 3.0']['CultureCrv']['SSR'] = ('Enumeration',('AL130'))
    field_information['GGDM 3.0']['CultureCrv']['EnumeratedIndexValues']['SSR'] = {}
    field_information['GGDM 3.0']['CultureCrv']['EnumeratedIndexValues']['SSR']['AL130']  = (-999999,6,7,38,40,41,42,999)
    field_information['GGDM 3.0']['CultureCrv']['SSR2'] = ('Enumeration',('AL130'))
    field_information['GGDM 3.0']['CultureCrv']['EnumeratedIndexValues']['SSR2'] = {}
    field_information['GGDM 3.0']['CultureCrv']['EnumeratedIndexValues']['SSR2']['AL130']  = (-999999,6,7,38,40,41,42,999)
    field_information['GGDM 3.0']['CultureCrv']['SSR3'] = ('Enumeration',('AL130'))
    field_information['GGDM 3.0']['CultureCrv']['EnumeratedIndexValues']['SSR3'] = {}
    field_information['GGDM 3.0']['CultureCrv']['EnumeratedIndexValues']['SSR3']['AL130']  = (-999999,6,7,38,40,41,42,999)
    field_information['GGDM 3.0']['CultureCrv']['TOS'] = ('Enumeration',('AL130'))
    field_information['GGDM 3.0']['CultureCrv']['EnumeratedIndexValues']['TOS'] = {}
    field_information['GGDM 3.0']['CultureCrv']['EnumeratedIndexValues']['TOS']['AL130']  = (-999999,1,2,3,5,6,999)
    field_information['GGDM 3.0']['CultureCrv']['UFI'] = ('StructuredText',('AL130'))
    field_information['GGDM 3.0']['CultureCrv']['VOI'] = ('StructuredText',('AL130'))
    field_information['GGDM 3.0']['CultureCrv']['WID'] = ('Real',('AL130'))
    field_information['GGDM 3.0']['CultureCrv']['ZI001_SDV'] = ('StructuredText',('AL130'))
    field_information['GGDM 3.0']['CultureCrv']['ZI001_SRT'] = ('Enumeration',('AL130'))
    field_information['GGDM 3.0']['CultureCrv']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['CultureCrv']['EnumeratedIndexValues']['ZI001_SRT']['AL130']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['CultureCrv']['ZI002_UFI'] = ('StructuredText',('AL130'))
    field_information['GGDM 3.0']['CultureCrv']['ZI004_RCG'] = ('Enumeration',('AL130'))
    field_information['GGDM 3.0']['CultureCrv']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['CultureCrv']['EnumeratedIndexValues']['ZI004_RCG']['AL130']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['CultureCrv']['ZI005_FNA'] = ('String',('AL130'))
    field_information['GGDM 3.0']['CultureCrv']['ZI005_GNT'] = ('Enumeration',('AL130'))
    field_information['GGDM 3.0']['CultureCrv']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['CultureCrv']['EnumeratedIndexValues']['ZI005_GNT']['AL130']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['CultureCrv']['ZI005_NFN'] = ('String',('AL130'))
    field_information['GGDM 3.0']['CultureCrv']['ZI006_MEM'] = ('String',('AL130'))
    field_information['GGDM 3.0']['CultureCrv']['ZI020_GE4'] = ('CodeList',('AL130'))
    field_information['GGDM 3.0']['CultureCrv']['ZI026_CTUC'] = ('Enumeration',('AL130'))
    field_information['GGDM 3.0']['CultureCrv']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['CultureCrv']['EnumeratedIndexValues']['ZI026_CTUC']['AL130']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['CultureCrv']['ZI026_CTUL'] = ('integer',('AL130'))
    field_information['GGDM 3.0']['CultureCrv']['ZI026_CTUU'] = ('integer',('AL130'))
    field_information['GGDM 3.0']['CultureCrv']['ZI031S_URI'] = ('StructuredText',('AL130'))
    field_information['GGDM 3.0']['CultureCrv']['ZI039S_UFI'] = ('StructuredText',('AL130'))
    field_information['GGDM 3.0']['CultureCrv']['ZSAX_RS0'] = ('CodeList',('AL130'))
    field_information['GGDM 3.0']['CultureCrv']['ZSAX_RX0'] = ('StructuredText',('AL130'))
    field_information['GGDM 3.0']['CultureCrv']['ZSAX_RX3'] = ('StructuredText',('AL130'))
    field_information['GGDM 3.0']['CultureCrv']['ZSAX_RX4'] = ('StructuredText',('AL130'))
    field_information['GGDM 3.0']['CultureCrv']['ZVH'] = ('Real',('AL130'))
    field_information['GGDM 3.0']['CulturePnt']['ADR'] = ('String',('AL030','AL201'))
    field_information['GGDM 3.0']['CulturePnt']['AOO'] = ('Real',('AL012','AL030','AL036','AL130','AL200'))
    field_information['GGDM 3.0']['CulturePnt']['ARA'] = ('Real',('AK121','AL012','AL030','AL036','AL130','AL200','AL201','BH075','FA012'))
    field_information['GGDM 3.0']['CulturePnt']['AWP'] = ('Boolean',('AL012','AL130'))
    field_information['GGDM 3.0']['CulturePnt']['BEN'] = ('StructuredText',('AK121','AL012','AL025','AL030','AL036','AL130','AL200','AL201','BH075','FA012'))
    field_information['GGDM 3.0']['CulturePnt']['CAA'] = ('Enumeration',('AL030','AL036','AL130','BH075'))
    field_information['GGDM 3.0']['CulturePnt']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['CulturePnt']['EnumeratedIndexValues']['CAA']['AL030']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['CulturePnt']['EnumeratedIndexValues']['CAA']['AL036']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['CulturePnt']['EnumeratedIndexValues']['CAA']['AL130']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['CulturePnt']['EnumeratedIndexValues']['CAA']['BH075']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['CulturePnt']['CCG'] = ('Enumeration',('FA012'))
    field_information['GGDM 3.0']['CulturePnt']['EnumeratedIndexValues']['CCG'] = {}
    field_information['GGDM 3.0']['CulturePnt']['EnumeratedIndexValues']['CCG']['FA012']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['CulturePnt']['CNCP'] = ('StructuredText',('AK121','AL030','AL130','AL201','BH075'))
    field_information['GGDM 3.0']['CulturePnt']['COS'] = ('Enumeration',('AK121','AL030','AL130','AL201','BH075'))
    field_information['GGDM 3.0']['CulturePnt']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['CulturePnt']['EnumeratedIndexValues']['COS']['AK121']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['CulturePnt']['EnumeratedIndexValues']['COS']['AL030']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['CulturePnt']['EnumeratedIndexValues']['COS']['AL130']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['CulturePnt']['EnumeratedIndexValues']['COS']['AL201']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['CulturePnt']['EnumeratedIndexValues']['COS']['BH075']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['CulturePnt']['CSO'] = ('Enumeration',('FA012'))
    field_information['GGDM 3.0']['CulturePnt']['EnumeratedIndexValues']['CSO'] = {}
    field_information['GGDM 3.0']['CulturePnt']['EnumeratedIndexValues']['CSO']['FA012']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['GGDM 3.0']['CulturePnt']['DZP'] = ('Real',('AL036'))
    field_information['GGDM 3.0']['CulturePnt']['F_CODE'] = ('CONSTRAINED_STRING',('AK121','AL012','AL025','AL030','AL036','AL130','AL200','AL201','BH075','FA012'))
    field_information['GGDM 3.0']['CulturePnt']['FUFI'] = ('StructuredText',('AK121','AL012','AL025','AL030','AL036','AL130','AL200','AL201','BH075','FA012'))
    field_information['GGDM 3.0']['CulturePnt']['FURL'] = ('StructuredText',('AK121','AL012','AL025','AL030','AL036','AL130','AL200','AL201','BH075','FA012'))
    field_information['GGDM 3.0']['CulturePnt']['GDBV'] = ('Enumeration',('AK121','AL012','AL025','AL030','AL036','AL130','AL200','AL201','BH075','FA012'))
    field_information['GGDM 3.0']['CulturePnt']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['CulturePnt']['EnumeratedIndexValues']['GDBV']['AK121']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['CulturePnt']['EnumeratedIndexValues']['GDBV']['AL012']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['CulturePnt']['EnumeratedIndexValues']['GDBV']['AL025']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['CulturePnt']['EnumeratedIndexValues']['GDBV']['AL030']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['CulturePnt']['EnumeratedIndexValues']['GDBV']['AL036']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['CulturePnt']['EnumeratedIndexValues']['GDBV']['AL130']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['CulturePnt']['EnumeratedIndexValues']['GDBV']['AL200']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['CulturePnt']['EnumeratedIndexValues']['GDBV']['AL201']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['CulturePnt']['EnumeratedIndexValues']['GDBV']['BH075']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['CulturePnt']['EnumeratedIndexValues']['GDBV']['FA012']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['CulturePnt']['HEI'] = ('Real',('AL036','AL130'))
    field_information['GGDM 3.0']['CulturePnt']['HGT'] = ('Real',('AL012','AL025','AL030','AL036','AL130','AL200','AL201','BH075'))
    field_information['GGDM 3.0']['CulturePnt']['HSS'] = ('Enumeration',('AL201'))
    field_information['GGDM 3.0']['CulturePnt']['EnumeratedIndexValues']['HSS'] = {}
    field_information['GGDM 3.0']['CulturePnt']['EnumeratedIndexValues']['HSS']['AL201']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['GGDM 3.0']['CulturePnt']['LEA'] = ('Real',('AL036'))
    field_information['GGDM 3.0']['CulturePnt']['LMC'] = ('Boolean',('AK121','AL012','AL025','AL030','AL036','AL130','AL200','AL201','BH075'))
    field_information['GGDM 3.0']['CulturePnt']['LZN'] = ('Real',('AK121','AL012','AL025','AL030','AL036','AL130','AL200','AL201','BH075','FA012'))
    field_information['GGDM 3.0']['CulturePnt']['OTH'] = ('StructuredText',('AK121','AL012','AL025','AL030','AL036','AL130','AL200','AL201','BH075','FA012'))
    field_information['GGDM 3.0']['CulturePnt']['PCF'] = ('Enumeration',('AK121','AL012','AL025','AL030','AL036','AL130','AL201','BH075'))
    field_information['GGDM 3.0']['CulturePnt']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['CulturePnt']['EnumeratedIndexValues']['PCF']['AK121']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['CulturePnt']['EnumeratedIndexValues']['PCF']['AL012']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['CulturePnt']['EnumeratedIndexValues']['PCF']['AL025']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['CulturePnt']['EnumeratedIndexValues']['PCF']['AL030']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['CulturePnt']['EnumeratedIndexValues']['PCF']['AL036']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['CulturePnt']['EnumeratedIndexValues']['PCF']['AL130']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['CulturePnt']['EnumeratedIndexValues']['PCF']['AL201']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['CulturePnt']['EnumeratedIndexValues']['PCF']['BH075']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['CulturePnt']['SDQ'] = ('Boolean',('AL030'))
    field_information['GGDM 3.0']['CulturePnt']['SRL'] = ('Enumeration',('AL200'))
    field_information['GGDM 3.0']['CulturePnt']['EnumeratedIndexValues']['SRL'] = {}
    field_information['GGDM 3.0']['CulturePnt']['EnumeratedIndexValues']['SRL']['AL200']  = (-999999,1,2,3)
    field_information['GGDM 3.0']['CulturePnt']['SSC'] = ('Enumeration',('AL036','AL130'))
    field_information['GGDM 3.0']['CulturePnt']['EnumeratedIndexValues']['SSC'] = {}
    field_information['GGDM 3.0']['CulturePnt']['EnumeratedIndexValues']['SSC']['AL036']  = (-999999,12,17,77,78,95,96,97,98,109,112,999)
    field_information['GGDM 3.0']['CulturePnt']['EnumeratedIndexValues']['SSC']['AL130']  = (-999999,12,17,77,78,95,96,97,98,109,112,999)
    field_information['GGDM 3.0']['CulturePnt']['SSR'] = ('Enumeration',('AL130'))
    field_information['GGDM 3.0']['CulturePnt']['EnumeratedIndexValues']['SSR'] = {}
    field_information['GGDM 3.0']['CulturePnt']['EnumeratedIndexValues']['SSR']['AL130']  = (-999999,6,7,38,40,41,42,999)
    field_information['GGDM 3.0']['CulturePnt']['SSR2'] = ('Enumeration',('AL130'))
    field_information['GGDM 3.0']['CulturePnt']['EnumeratedIndexValues']['SSR2'] = {}
    field_information['GGDM 3.0']['CulturePnt']['EnumeratedIndexValues']['SSR2']['AL130']  = (-999999,6,7,38,40,41,42,999)
    field_information['GGDM 3.0']['CulturePnt']['SSR3'] = ('Enumeration',('AL130'))
    field_information['GGDM 3.0']['CulturePnt']['EnumeratedIndexValues']['SSR3'] = {}
    field_information['GGDM 3.0']['CulturePnt']['EnumeratedIndexValues']['SSR3']['AL130']  = (-999999,6,7,38,40,41,42,999)
    field_information['GGDM 3.0']['CulturePnt']['TOS'] = ('Enumeration',('AL130'))
    field_information['GGDM 3.0']['CulturePnt']['EnumeratedIndexValues']['TOS'] = {}
    field_information['GGDM 3.0']['CulturePnt']['EnumeratedIndexValues']['TOS']['AL130']  = (-999999,1,2,3,5,6,999)
    field_information['GGDM 3.0']['CulturePnt']['TTY'] = ('Enumeration',('AL036'))
    field_information['GGDM 3.0']['CulturePnt']['EnumeratedIndexValues']['TTY'] = {}
    field_information['GGDM 3.0']['CulturePnt']['EnumeratedIndexValues']['TTY']['AL036']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['CulturePnt']['UFI'] = ('StructuredText',('AK121','AL012','AL025','AL030','AL036','AL130','AL200','AL201','BH075','FA012'))
    field_information['GGDM 3.0']['CulturePnt']['VLM'] = ('Real',('BH075'))
    field_information['GGDM 3.0']['CulturePnt']['VOI'] = ('StructuredText',('AL012','AL130'))
    field_information['GGDM 3.0']['CulturePnt']['WID'] = ('Real',('AK121','AL012','AL025','AL030','AL036','AL130','AL200','AL201','BH075','FA012'))
    field_information['GGDM 3.0']['CulturePnt']['ZI001_SDV'] = ('StructuredText',('AK121','AL012','AL025','AL030','AL036','AL130','AL200','AL201','BH075','FA012'))
    field_information['GGDM 3.0']['CulturePnt']['ZI001_SRT'] = ('Enumeration',('AK121','AL012','AL025','AL030','AL036','AL130','AL200','AL201','BH075','FA012'))
    field_information['GGDM 3.0']['CulturePnt']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['CulturePnt']['EnumeratedIndexValues']['ZI001_SRT']['AK121']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['CulturePnt']['EnumeratedIndexValues']['ZI001_SRT']['AL012']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['CulturePnt']['EnumeratedIndexValues']['ZI001_SRT']['AL025']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['CulturePnt']['EnumeratedIndexValues']['ZI001_SRT']['AL030']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['CulturePnt']['EnumeratedIndexValues']['ZI001_SRT']['AL036']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['CulturePnt']['EnumeratedIndexValues']['ZI001_SRT']['AL130']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['CulturePnt']['EnumeratedIndexValues']['ZI001_SRT']['AL200']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['CulturePnt']['EnumeratedIndexValues']['ZI001_SRT']['AL201']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['CulturePnt']['EnumeratedIndexValues']['ZI001_SRT']['BH075']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['CulturePnt']['EnumeratedIndexValues']['ZI001_SRT']['FA012']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['CulturePnt']['ZI002_UFI'] = ('StructuredText',('AK121','AL012','AL025','AL030','AL036','AL130','AL200','AL201','BH075','FA012'))
    field_information['GGDM 3.0']['CulturePnt']['ZI004_RCG'] = ('Enumeration',('AK121','AL012','AL025','AL030','AL036','AL130','AL200','AL201','BH075','FA012'))
    field_information['GGDM 3.0']['CulturePnt']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['CulturePnt']['EnumeratedIndexValues']['ZI004_RCG']['AK121']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['CulturePnt']['EnumeratedIndexValues']['ZI004_RCG']['AL012']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['CulturePnt']['EnumeratedIndexValues']['ZI004_RCG']['AL025']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['CulturePnt']['EnumeratedIndexValues']['ZI004_RCG']['AL030']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['CulturePnt']['EnumeratedIndexValues']['ZI004_RCG']['AL036']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['CulturePnt']['EnumeratedIndexValues']['ZI004_RCG']['AL130']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['CulturePnt']['EnumeratedIndexValues']['ZI004_RCG']['AL200']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['CulturePnt']['EnumeratedIndexValues']['ZI004_RCG']['AL201']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['CulturePnt']['EnumeratedIndexValues']['ZI004_RCG']['BH075']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['CulturePnt']['EnumeratedIndexValues']['ZI004_RCG']['FA012']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['CulturePnt']['ZI005_FNA'] = ('String',('AK121','AL012','AL025','AL030','AL036','AL130','AL200','AL201','BH075','FA012'))
    field_information['GGDM 3.0']['CulturePnt']['ZI005_GNT'] = ('Enumeration',('AK121','AL012','AL025','AL030','AL036','AL130','AL200','AL201','BH075','FA012'))
    field_information['GGDM 3.0']['CulturePnt']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['CulturePnt']['EnumeratedIndexValues']['ZI005_GNT']['AK121']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['CulturePnt']['EnumeratedIndexValues']['ZI005_GNT']['AL012']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['CulturePnt']['EnumeratedIndexValues']['ZI005_GNT']['AL025']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['CulturePnt']['EnumeratedIndexValues']['ZI005_GNT']['AL030']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['CulturePnt']['EnumeratedIndexValues']['ZI005_GNT']['AL036']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['CulturePnt']['EnumeratedIndexValues']['ZI005_GNT']['AL130']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['CulturePnt']['EnumeratedIndexValues']['ZI005_GNT']['AL200']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['CulturePnt']['EnumeratedIndexValues']['ZI005_GNT']['AL201']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['CulturePnt']['EnumeratedIndexValues']['ZI005_GNT']['BH075']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['CulturePnt']['EnumeratedIndexValues']['ZI005_GNT']['FA012']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['CulturePnt']['ZI005_NFN'] = ('String',('AK121','AL012','AL025','AL030','AL036','AL130','AL200','AL201','BH075','FA012'))
    field_information['GGDM 3.0']['CulturePnt']['ZI006_MEM'] = ('String',('AK121','AL012','AL025','AL030','AL036','AL130','AL200','AL201','BH075','FA012'))
    field_information['GGDM 3.0']['CulturePnt']['ZI020_GE4'] = ('CodeList',('AK121','AL012','AL025','AL030','AL036','AL130','AL200','AL201','BH075','FA012'))
    field_information['GGDM 3.0']['CulturePnt']['ZI024_ASE'] = ('Real',('BH075'))
    field_information['GGDM 3.0']['CulturePnt']['ZI024_CFR'] = ('Real',('BH075'))
    field_information['GGDM 3.0']['CulturePnt']['ZI024_CLO'] = ('Real',('BH075'))
    field_information['GGDM 3.0']['CulturePnt']['ZI024_CYN'] = ('Real',('BH075'))
    field_information['GGDM 3.0']['CulturePnt']['ZI024_FMR'] = ('Real',('BH075'))
    field_information['GGDM 3.0']['CulturePnt']['ZI024_FRR'] = ('Real',('BH075'))
    field_information['GGDM 3.0']['CulturePnt']['ZI024_HAR'] = ('Real',('BH075'))
    field_information['GGDM 3.0']['CulturePnt']['ZI024_MGN'] = ('Real',('BH075'))
    field_information['GGDM 3.0']['CulturePnt']['ZI024_PHW'] = ('Real',('BH075'))
    field_information['GGDM 3.0']['CulturePnt']['ZI024_SCC'] = ('Enumeration',('BH075'))
    field_information['GGDM 3.0']['CulturePnt']['EnumeratedIndexValues']['ZI024_SCC'] = {}
    field_information['GGDM 3.0']['CulturePnt']['EnumeratedIndexValues']['ZI024_SCC']['BH075']  = (-999999,1,4,10,11,12,13,14,998,999)
    field_information['GGDM 3.0']['CulturePnt']['ZI024_SUL'] = ('Real',('BH075'))
    field_information['GGDM 3.0']['CulturePnt']['ZI024_TDS'] = ('Real',('BH075'))
    field_information['GGDM 3.0']['CulturePnt']['ZI024_TEP'] = ('Real',('BH075'))
    field_information['GGDM 3.0']['CulturePnt']['ZI024_TUR'] = ('Real',('BH075'))
    field_information['GGDM 3.0']['CulturePnt']['ZI024_WAC'] = ('Real',('BH075'))
    field_information['GGDM 3.0']['CulturePnt']['ZI024_WTNO'] = ('Real',('BH075'))
    field_information['GGDM 3.0']['CulturePnt']['ZI024_WUR'] = ('Enumeration',('BH075'))
    field_information['GGDM 3.0']['CulturePnt']['EnumeratedIndexValues']['ZI024_WUR'] = {}
    field_information['GGDM 3.0']['CulturePnt']['EnumeratedIndexValues']['ZI024_WUR']['BH075']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['CulturePnt']['ZI024_WUR2'] = ('Enumeration',('BH075'))
    field_information['GGDM 3.0']['CulturePnt']['EnumeratedIndexValues']['ZI024_WUR2'] = {}
    field_information['GGDM 3.0']['CulturePnt']['EnumeratedIndexValues']['ZI024_WUR2']['BH075']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['CulturePnt']['ZI024_WUR3'] = ('Enumeration',('BH075'))
    field_information['GGDM 3.0']['CulturePnt']['EnumeratedIndexValues']['ZI024_WUR3'] = {}
    field_information['GGDM 3.0']['CulturePnt']['EnumeratedIndexValues']['ZI024_WUR3']['BH075']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['CulturePnt']['ZI024_WUR4'] = ('Enumeration',('BH075'))
    field_information['GGDM 3.0']['CulturePnt']['EnumeratedIndexValues']['ZI024_WUR4'] = {}
    field_information['GGDM 3.0']['CulturePnt']['EnumeratedIndexValues']['ZI024_WUR4']['BH075']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['CulturePnt']['ZI024_YWQ'] = ('Enumeration',('BH075'))
    field_information['GGDM 3.0']['CulturePnt']['EnumeratedIndexValues']['ZI024_YWQ'] = {}
    field_information['GGDM 3.0']['CulturePnt']['EnumeratedIndexValues']['ZI024_YWQ']['BH075']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['CulturePnt']['ZI025_HDP'] = ('Real',('AL200'))
    field_information['GGDM 3.0']['CulturePnt']['ZI026_CTUC'] = ('Enumeration',('AK121','AL012','AL025','AL030','AL036','AL130','AL200','AL201','BH075','FA012'))
    field_information['GGDM 3.0']['CulturePnt']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['CulturePnt']['EnumeratedIndexValues']['ZI026_CTUC']['AK121']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['CulturePnt']['EnumeratedIndexValues']['ZI026_CTUC']['AL012']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['CulturePnt']['EnumeratedIndexValues']['ZI026_CTUC']['AL025']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['CulturePnt']['EnumeratedIndexValues']['ZI026_CTUC']['AL030']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['CulturePnt']['EnumeratedIndexValues']['ZI026_CTUC']['AL036']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['CulturePnt']['EnumeratedIndexValues']['ZI026_CTUC']['AL130']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['CulturePnt']['EnumeratedIndexValues']['ZI026_CTUC']['AL200']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['CulturePnt']['EnumeratedIndexValues']['ZI026_CTUC']['AL201']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['CulturePnt']['EnumeratedIndexValues']['ZI026_CTUC']['BH075']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['CulturePnt']['EnumeratedIndexValues']['ZI026_CTUC']['FA012']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['CulturePnt']['ZI026_CTUL'] = ('integer',('AK121','AL012','AL025','AL030','AL036','AL130','AL200','AL201','BH075','FA012'))
    field_information['GGDM 3.0']['CulturePnt']['ZI026_CTUU'] = ('integer',('AK121','AL012','AL025','AL030','AL036','AL130','AL200','AL201','BH075','FA012'))
    field_information['GGDM 3.0']['CulturePnt']['ZI031S_URI'] = ('StructuredText',('AK121','AL012','AL025','AL030','AL036','AL130','AL200','AL201','BH075','FA012'))
    field_information['GGDM 3.0']['CulturePnt']['ZI037_REL'] = ('Enumeration',('AL030','AL036','AL201'))
    field_information['GGDM 3.0']['CulturePnt']['EnumeratedIndexValues']['ZI037_REL'] = {}
    field_information['GGDM 3.0']['CulturePnt']['EnumeratedIndexValues']['ZI037_REL']['AL030']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,999)
    field_information['GGDM 3.0']['CulturePnt']['EnumeratedIndexValues']['ZI037_REL']['AL036']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,999)
    field_information['GGDM 3.0']['CulturePnt']['EnumeratedIndexValues']['ZI037_REL']['AL201']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,999)
    field_information['GGDM 3.0']['CulturePnt']['ZI037_RFA'] = ('Enumeration',('AL201'))
    field_information['GGDM 3.0']['CulturePnt']['EnumeratedIndexValues']['ZI037_RFA'] = {}
    field_information['GGDM 3.0']['CulturePnt']['EnumeratedIndexValues']['ZI037_RFA']['AL201']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,18,19,20,21,22,23,25,999)
    field_information['GGDM 3.0']['CulturePnt']['ZI039S_UFI'] = ('StructuredText',('AK121','AL012','AL025','AL030','AL036','AL130','AL200','AL201','BH075','FA012'))
    field_information['GGDM 3.0']['CulturePnt']['ZSAX_RS0'] = ('CodeList',('AK121','AL012','AL025','AL030','AL036','AL130','AL200','AL201','BH075','FA012'))
    field_information['GGDM 3.0']['CulturePnt']['ZSAX_RX0'] = ('StructuredText',('AK121','AL012','AL025','AL030','AL036','AL130','AL200','AL201','BH075','FA012'))
    field_information['GGDM 3.0']['CulturePnt']['ZSAX_RX3'] = ('StructuredText',('AK121','AL012','AL025','AL030','AL036','AL130','AL200','AL201','BH075','FA012'))
    field_information['GGDM 3.0']['CulturePnt']['ZSAX_RX4'] = ('StructuredText',('AK121','AL012','AL025','AL030','AL036','AL130','AL200','AL201','BH075','FA012'))
    field_information['GGDM 3.0']['CulturePnt']['ZVH'] = ('Real',('AL012','AL025','AL030','AL036','AL130','AL200','AL201','BH075'))
    field_information['GGDM 3.0']['CulturePntExt']['ARA'] = ('Real',('ZD030'))
    field_information['GGDM 3.0']['CulturePntExt']['BEN'] = ('StructuredText',('ZD030'))
    field_information['GGDM 3.0']['CulturePntExt']['CUL'] = ('Enumeration',('ZD030'))
    field_information['GGDM 3.0']['CulturePntExt']['EnumeratedIndexValues']['CUL'] = {}
    field_information['GGDM 3.0']['CulturePntExt']['EnumeratedIndexValues']['CUL']['ZD030']  = (-999999,1,2,3,4,5,6,999)
    field_information['GGDM 3.0']['CulturePntExt']['F_CODE'] = ('CONSTRAINED_STRING',('ZD030'))
    field_information['GGDM 3.0']['CulturePntExt']['FUFI'] = ('StructuredText',('ZD030'))
    field_information['GGDM 3.0']['CulturePntExt']['FURL'] = ('StructuredText',('ZD030'))
    field_information['GGDM 3.0']['CulturePntExt']['GDBV'] = ('Enumeration',('ZD030'))
    field_information['GGDM 3.0']['CulturePntExt']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['CulturePntExt']['EnumeratedIndexValues']['GDBV']['ZD030']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['CulturePntExt']['LZN'] = ('Real',('ZD030'))
    field_information['GGDM 3.0']['CulturePntExt']['OTH'] = ('StructuredText',('ZD030'))
    field_information['GGDM 3.0']['CulturePntExt']['UFI'] = ('StructuredText',('ZD030'))
    field_information['GGDM 3.0']['CulturePntExt']['WID'] = ('Real',('ZD030'))
    field_information['GGDM 3.0']['CulturePntExt']['ZI001_SDV'] = ('StructuredText',('ZD030'))
    field_information['GGDM 3.0']['CulturePntExt']['ZI001_SRT'] = ('Enumeration',('ZD030'))
    field_information['GGDM 3.0']['CulturePntExt']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['CulturePntExt']['EnumeratedIndexValues']['ZI001_SRT']['ZD030']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['CulturePntExt']['ZI002_UFI'] = ('StructuredText',('ZD030'))
    field_information['GGDM 3.0']['CulturePntExt']['ZI004_RCG'] = ('Enumeration',('ZD030'))
    field_information['GGDM 3.0']['CulturePntExt']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['CulturePntExt']['EnumeratedIndexValues']['ZI004_RCG']['ZD030']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['CulturePntExt']['ZI005_FNA'] = ('String',('ZD030'))
    field_information['GGDM 3.0']['CulturePntExt']['ZI005_GNT'] = ('Enumeration',('ZD030'))
    field_information['GGDM 3.0']['CulturePntExt']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['CulturePntExt']['EnumeratedIndexValues']['ZI005_GNT']['ZD030']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['CulturePntExt']['ZI005_NFN'] = ('String',('ZD030'))
    field_information['GGDM 3.0']['CulturePntExt']['ZI006_MEM'] = ('String',('ZD030'))
    field_information['GGDM 3.0']['CulturePntExt']['ZI020_GE4'] = ('CodeList',('ZD030'))
    field_information['GGDM 3.0']['CulturePntExt']['ZI026_CTUC'] = ('Enumeration',('ZD030'))
    field_information['GGDM 3.0']['CulturePntExt']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['CulturePntExt']['EnumeratedIndexValues']['ZI026_CTUC']['ZD030']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['CulturePntExt']['ZI026_CTUL'] = ('integer',('ZD030'))
    field_information['GGDM 3.0']['CulturePntExt']['ZI026_CTUU'] = ('integer',('ZD030'))
    field_information['GGDM 3.0']['CulturePntExt']['ZI031S_URI'] = ('StructuredText',('ZD030'))
    field_information['GGDM 3.0']['CulturePntExt']['ZI037_REL'] = ('Enumeration',('ZD030'))
    field_information['GGDM 3.0']['CulturePntExt']['EnumeratedIndexValues']['ZI037_REL'] = {}
    field_information['GGDM 3.0']['CulturePntExt']['EnumeratedIndexValues']['ZI037_REL']['ZD030']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,999)
    field_information['GGDM 3.0']['CulturePntExt']['ZI039S_UFI'] = ('StructuredText',('ZD030'))
    field_information['GGDM 3.0']['CulturePntExt']['ZSAX_RS0'] = ('CodeList',('ZD030'))
    field_information['GGDM 3.0']['CulturePntExt']['ZSAX_RX0'] = ('StructuredText',('ZD030'))
    field_information['GGDM 3.0']['CulturePntExt']['ZSAX_RX3'] = ('StructuredText',('ZD030'))
    field_information['GGDM 3.0']['CulturePntExt']['ZSAX_RX4'] = ('StructuredText',('ZD030'))
    field_information['GGDM 3.0']['CultureSrf']['ADI'] = ('Enumeration',('AK120'))
    field_information['GGDM 3.0']['CultureSrf']['EnumeratedIndexValues']['ADI'] = {}
    field_information['GGDM 3.0']['CultureSrf']['EnumeratedIndexValues']['ADI']['AK120']  = (-999999,2,3,4,6,999)
    field_information['GGDM 3.0']['CultureSrf']['ADR'] = ('String',('AK120','AL030','AL201','EA031'))
    field_information['GGDM 3.0']['CultureSrf']['AOO'] = ('Real',('AL012','AL030','AL036','AL130','AL180','AL200'))
    field_information['GGDM 3.0']['CultureSrf']['ARA'] = ('Real',('AK120','AK121','AL012','AL030','AL036','AL130','AL175','AL180','AL200','AL201','BH075','EA031','FA012','FA210'))
    field_information['GGDM 3.0']['CultureSrf']['AWP'] = ('Boolean',('AL012','AL130'))
    field_information['GGDM 3.0']['CultureSrf']['BEN'] = ('StructuredText',('AK120','AK121','AL012','AL030','AL036','AL130','AL175','AL180','AL200','AL201','BH075','EA031','FA012','FA210'))
    field_information['GGDM 3.0']['CultureSrf']['CAA'] = ('Enumeration',('AK120','AL030','AL036','AL130','BH075','FA210'))
    field_information['GGDM 3.0']['CultureSrf']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['CultureSrf']['EnumeratedIndexValues']['CAA']['AK120']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['CultureSrf']['EnumeratedIndexValues']['CAA']['AL030']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['CultureSrf']['EnumeratedIndexValues']['CAA']['AL036']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['CultureSrf']['EnumeratedIndexValues']['CAA']['AL130']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['CultureSrf']['EnumeratedIndexValues']['CAA']['BH075']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['CultureSrf']['EnumeratedIndexValues']['CAA']['FA210']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['CultureSrf']['CAM'] = ('Enumeration',('FA210'))
    field_information['GGDM 3.0']['CultureSrf']['EnumeratedIndexValues']['CAM'] = {}
    field_information['GGDM 3.0']['CultureSrf']['EnumeratedIndexValues']['CAM']['FA210']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['CultureSrf']['CCG'] = ('Enumeration',('FA012'))
    field_information['GGDM 3.0']['CultureSrf']['EnumeratedIndexValues']['CCG'] = {}
    field_information['GGDM 3.0']['CultureSrf']['EnumeratedIndexValues']['CCG']['FA012']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['CultureSrf']['CNCP'] = ('StructuredText',('AK120','AK121','AL030','AL130','AL180','AL201','BH075'))
    field_information['GGDM 3.0']['CultureSrf']['COS'] = ('Enumeration',('AK120','AK121','AL030','AL130','AL180','AL201','BH075'))
    field_information['GGDM 3.0']['CultureSrf']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['CultureSrf']['EnumeratedIndexValues']['COS']['AK120']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['CultureSrf']['EnumeratedIndexValues']['COS']['AK121']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['CultureSrf']['EnumeratedIndexValues']['COS']['AL030']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['CultureSrf']['EnumeratedIndexValues']['COS']['AL130']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['CultureSrf']['EnumeratedIndexValues']['COS']['AL180']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['CultureSrf']['EnumeratedIndexValues']['COS']['AL201']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['CultureSrf']['EnumeratedIndexValues']['COS']['BH075']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['CultureSrf']['CSO'] = ('Enumeration',('FA012'))
    field_information['GGDM 3.0']['CultureSrf']['EnumeratedIndexValues']['CSO'] = {}
    field_information['GGDM 3.0']['CultureSrf']['EnumeratedIndexValues']['CSO']['FA012']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['GGDM 3.0']['CultureSrf']['DZP'] = ('Real',('AL036'))
    field_information['GGDM 3.0']['CultureSrf']['F_CODE'] = ('CONSTRAINED_STRING',('AK120','AK121','AL012','AL030','AL036','AL130','AL175','AL180','AL200','AL201','BH075','EA031','FA012','FA210'))
    field_information['GGDM 3.0']['CultureSrf']['FFN'] = ('Enumeration',('AL180'))
    field_information['GGDM 3.0']['CultureSrf']['EnumeratedIndexValues']['FFN'] = {}
    field_information['GGDM 3.0']['CultureSrf']['EnumeratedIndexValues']['FFN']['AL180']  = (-999999,460,540,545,570,572,621,643,999)
    field_information['GGDM 3.0']['CultureSrf']['FFN2'] = ('Enumeration',('AL180'))
    field_information['GGDM 3.0']['CultureSrf']['EnumeratedIndexValues']['FFN2'] = {}
    field_information['GGDM 3.0']['CultureSrf']['EnumeratedIndexValues']['FFN2']['AL180']  = (-999999,460,540,545,570,572,621,643,999)
    field_information['GGDM 3.0']['CultureSrf']['FFN3'] = ('Enumeration',('AL180'))
    field_information['GGDM 3.0']['CultureSrf']['EnumeratedIndexValues']['FFN3'] = {}
    field_information['GGDM 3.0']['CultureSrf']['EnumeratedIndexValues']['FFN3']['AL180']  = (-999999,460,540,545,570,572,621,643,999)
    field_information['GGDM 3.0']['CultureSrf']['FUFI'] = ('StructuredText',('AK120','AK121','AL012','AL030','AL036','AL130','AL175','AL180','AL200','AL201','BH075','EA031','FA012','FA210'))
    field_information['GGDM 3.0']['CultureSrf']['FURL'] = ('StructuredText',('AK120','AK121','AL012','AL030','AL036','AL130','AL175','AL180','AL200','AL201','BH075','EA031','FA012','FA210'))
    field_information['GGDM 3.0']['CultureSrf']['GDBV'] = ('Enumeration',('AK120','AK121','AL012','AL030','AL036','AL130','AL175','AL180','AL200','AL201','BH075','EA031','FA012','FA210'))
    field_information['GGDM 3.0']['CultureSrf']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['CultureSrf']['EnumeratedIndexValues']['GDBV']['AK120']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['CultureSrf']['EnumeratedIndexValues']['GDBV']['AK121']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['CultureSrf']['EnumeratedIndexValues']['GDBV']['AL012']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['CultureSrf']['EnumeratedIndexValues']['GDBV']['AL030']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['CultureSrf']['EnumeratedIndexValues']['GDBV']['AL036']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['CultureSrf']['EnumeratedIndexValues']['GDBV']['AL130']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['CultureSrf']['EnumeratedIndexValues']['GDBV']['AL175']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['CultureSrf']['EnumeratedIndexValues']['GDBV']['AL180']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['CultureSrf']['EnumeratedIndexValues']['GDBV']['AL200']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['CultureSrf']['EnumeratedIndexValues']['GDBV']['AL201']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['CultureSrf']['EnumeratedIndexValues']['GDBV']['BH075']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['CultureSrf']['EnumeratedIndexValues']['GDBV']['EA031']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['CultureSrf']['EnumeratedIndexValues']['GDBV']['FA012']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['CultureSrf']['EnumeratedIndexValues']['GDBV']['FA210']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['CultureSrf']['HEI'] = ('Real',('AL036','AL130'))
    field_information['GGDM 3.0']['CultureSrf']['HGT'] = ('Real',('AL012','AL030','AL036','AL130','AL175','AL180','AL200','AL201','BH075'))
    field_information['GGDM 3.0']['CultureSrf']['HSS'] = ('Enumeration',('AL201'))
    field_information['GGDM 3.0']['CultureSrf']['EnumeratedIndexValues']['HSS'] = {}
    field_information['GGDM 3.0']['CultureSrf']['EnumeratedIndexValues']['HSS']['AL201']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['GGDM 3.0']['CultureSrf']['LEA'] = ('Real',('AL036'))
    field_information['GGDM 3.0']['CultureSrf']['LMC'] = ('Boolean',('AK120','AK121','AL012','AL030','AL036','AL130','AL180','AL200','AL201','BH075','EA031'))
    field_information['GGDM 3.0']['CultureSrf']['LZN'] = ('Real',('AK120','AK121','AL012','AL030','AL036','AL130','AL175','AL180','AL200','AL201','BH075','EA031','FA012','FA210'))
    field_information['GGDM 3.0']['CultureSrf']['MCC'] = ('Enumeration',('AL180'))
    field_information['GGDM 3.0']['CultureSrf']['EnumeratedIndexValues']['MCC'] = {}
    field_information['GGDM 3.0']['CultureSrf']['EnumeratedIndexValues']['MCC']['AL180']  = (-999999,9,21,62,64,74,117,999)
    field_information['GGDM 3.0']['CultureSrf']['MCC2'] = ('Enumeration',('AL180'))
    field_information['GGDM 3.0']['CultureSrf']['EnumeratedIndexValues']['MCC2'] = {}
    field_information['GGDM 3.0']['CultureSrf']['EnumeratedIndexValues']['MCC2']['AL180']  = (-999999,9,21,62,64,74,117,999)
    field_information['GGDM 3.0']['CultureSrf']['MCC3'] = ('Enumeration',('AL180'))
    field_information['GGDM 3.0']['CultureSrf']['EnumeratedIndexValues']['MCC3'] = {}
    field_information['GGDM 3.0']['CultureSrf']['EnumeratedIndexValues']['MCC3']['AL180']  = (-999999,9,21,62,64,74,117,999)
    field_information['GGDM 3.0']['CultureSrf']['OTH'] = ('StructuredText',('AK120','AK121','AL012','AL030','AL036','AL130','AL175','AL180','AL200','AL201','BH075','EA031','FA012','FA210'))
    field_information['GGDM 3.0']['CultureSrf']['PCF'] = ('Enumeration',('AK120','AK121','AL012','AL030','AL036','AL130','AL175','AL180','AL201','BH075'))
    field_information['GGDM 3.0']['CultureSrf']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['CultureSrf']['EnumeratedIndexValues']['PCF']['AK120']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['CultureSrf']['EnumeratedIndexValues']['PCF']['AK121']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['CultureSrf']['EnumeratedIndexValues']['PCF']['AL012']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['CultureSrf']['EnumeratedIndexValues']['PCF']['AL030']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['CultureSrf']['EnumeratedIndexValues']['PCF']['AL036']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['CultureSrf']['EnumeratedIndexValues']['PCF']['AL130']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['CultureSrf']['EnumeratedIndexValues']['PCF']['AL175']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['CultureSrf']['EnumeratedIndexValues']['PCF']['AL180']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['CultureSrf']['EnumeratedIndexValues']['PCF']['AL201']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['CultureSrf']['EnumeratedIndexValues']['PCF']['BH075']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['CultureSrf']['SDQ'] = ('Boolean',('AL030'))
    field_information['GGDM 3.0']['CultureSrf']['SRL'] = ('Enumeration',('AK120','AL200','FA210'))
    field_information['GGDM 3.0']['CultureSrf']['EnumeratedIndexValues']['SRL'] = {}
    field_information['GGDM 3.0']['CultureSrf']['EnumeratedIndexValues']['SRL']['AK120']  = (-999999,1,2,3)
    field_information['GGDM 3.0']['CultureSrf']['EnumeratedIndexValues']['SRL']['AL200']  = (-999999,1,2,3)
    field_information['GGDM 3.0']['CultureSrf']['EnumeratedIndexValues']['SRL']['FA210']  = (-999999,1,2,3)
    field_information['GGDM 3.0']['CultureSrf']['SSC'] = ('Enumeration',('AL036','AL130'))
    field_information['GGDM 3.0']['CultureSrf']['EnumeratedIndexValues']['SSC'] = {}
    field_information['GGDM 3.0']['CultureSrf']['EnumeratedIndexValues']['SSC']['AL036']  = (-999999,12,17,77,78,95,96,97,98,109,112,999)
    field_information['GGDM 3.0']['CultureSrf']['EnumeratedIndexValues']['SSC']['AL130']  = (-999999,12,17,77,78,95,96,97,98,109,112,999)
    field_information['GGDM 3.0']['CultureSrf']['SSR'] = ('Enumeration',('AL130'))
    field_information['GGDM 3.0']['CultureSrf']['EnumeratedIndexValues']['SSR'] = {}
    field_information['GGDM 3.0']['CultureSrf']['EnumeratedIndexValues']['SSR']['AL130']  = (-999999,6,7,38,40,41,42,999)
    field_information['GGDM 3.0']['CultureSrf']['SSR2'] = ('Enumeration',('AL130'))
    field_information['GGDM 3.0']['CultureSrf']['EnumeratedIndexValues']['SSR2'] = {}
    field_information['GGDM 3.0']['CultureSrf']['EnumeratedIndexValues']['SSR2']['AL130']  = (-999999,6,7,38,40,41,42,999)
    field_information['GGDM 3.0']['CultureSrf']['SSR3'] = ('Enumeration',('AL130'))
    field_information['GGDM 3.0']['CultureSrf']['EnumeratedIndexValues']['SSR3'] = {}
    field_information['GGDM 3.0']['CultureSrf']['EnumeratedIndexValues']['SSR3']['AL130']  = (-999999,6,7,38,40,41,42,999)
    field_information['GGDM 3.0']['CultureSrf']['TOS'] = ('Enumeration',('AL130'))
    field_information['GGDM 3.0']['CultureSrf']['EnumeratedIndexValues']['TOS'] = {}
    field_information['GGDM 3.0']['CultureSrf']['EnumeratedIndexValues']['TOS']['AL130']  = (-999999,1,2,3,5,6,999)
    field_information['GGDM 3.0']['CultureSrf']['TRE'] = ('Enumeration',('EA031'))
    field_information['GGDM 3.0']['CultureSrf']['EnumeratedIndexValues']['TRE'] = {}
    field_information['GGDM 3.0']['CultureSrf']['EnumeratedIndexValues']['TRE']['EA031']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['CultureSrf']['TTY'] = ('Enumeration',('AL036'))
    field_information['GGDM 3.0']['CultureSrf']['EnumeratedIndexValues']['TTY'] = {}
    field_information['GGDM 3.0']['CultureSrf']['EnumeratedIndexValues']['TTY']['AL036']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['CultureSrf']['UFI'] = ('StructuredText',('AK120','AK121','AL012','AL030','AL036','AL130','AL175','AL180','AL200','AL201','BH075','EA031','FA012','FA210'))
    field_information['GGDM 3.0']['CultureSrf']['VLM'] = ('Real',('BH075'))
    field_information['GGDM 3.0']['CultureSrf']['VOI'] = ('StructuredText',('AL012','AL130'))
    field_information['GGDM 3.0']['CultureSrf']['WID'] = ('Real',('AK120','AK121','AL012','AL030','AL036','AL130','AL175','AL180','AL200','AL201','BH075','EA031','FA012','FA210'))
    field_information['GGDM 3.0']['CultureSrf']['ZI001_SDV'] = ('StructuredText',('AK120','AK121','AL012','AL030','AL036','AL130','AL175','AL180','AL200','AL201','BH075','EA031','FA012','FA210'))
    field_information['GGDM 3.0']['CultureSrf']['ZI001_SRT'] = ('Enumeration',('AK120','AK121','AL012','AL030','AL036','AL130','AL175','AL180','AL200','AL201','BH075','EA031','FA012','FA210'))
    field_information['GGDM 3.0']['CultureSrf']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['CultureSrf']['EnumeratedIndexValues']['ZI001_SRT']['AK120']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['CultureSrf']['EnumeratedIndexValues']['ZI001_SRT']['AK121']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['CultureSrf']['EnumeratedIndexValues']['ZI001_SRT']['AL012']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['CultureSrf']['EnumeratedIndexValues']['ZI001_SRT']['AL030']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['CultureSrf']['EnumeratedIndexValues']['ZI001_SRT']['AL036']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['CultureSrf']['EnumeratedIndexValues']['ZI001_SRT']['AL130']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['CultureSrf']['EnumeratedIndexValues']['ZI001_SRT']['AL175']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['CultureSrf']['EnumeratedIndexValues']['ZI001_SRT']['AL180']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['CultureSrf']['EnumeratedIndexValues']['ZI001_SRT']['AL200']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['CultureSrf']['EnumeratedIndexValues']['ZI001_SRT']['AL201']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['CultureSrf']['EnumeratedIndexValues']['ZI001_SRT']['BH075']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['CultureSrf']['EnumeratedIndexValues']['ZI001_SRT']['EA031']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['CultureSrf']['EnumeratedIndexValues']['ZI001_SRT']['FA012']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['CultureSrf']['EnumeratedIndexValues']['ZI001_SRT']['FA210']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['CultureSrf']['ZI002_UFI'] = ('StructuredText',('AK120','AK121','AL012','AL030','AL036','AL130','AL175','AL180','AL200','AL201','BH075','EA031','FA012','FA210'))
    field_information['GGDM 3.0']['CultureSrf']['ZI004_RCG'] = ('Enumeration',('AK120','AK121','AL012','AL030','AL036','AL130','AL175','AL180','AL200','AL201','BH075','EA031','FA012','FA210'))
    field_information['GGDM 3.0']['CultureSrf']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['CultureSrf']['EnumeratedIndexValues']['ZI004_RCG']['AK120']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['CultureSrf']['EnumeratedIndexValues']['ZI004_RCG']['AK121']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['CultureSrf']['EnumeratedIndexValues']['ZI004_RCG']['AL012']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['CultureSrf']['EnumeratedIndexValues']['ZI004_RCG']['AL030']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['CultureSrf']['EnumeratedIndexValues']['ZI004_RCG']['AL036']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['CultureSrf']['EnumeratedIndexValues']['ZI004_RCG']['AL130']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['CultureSrf']['EnumeratedIndexValues']['ZI004_RCG']['AL175']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['CultureSrf']['EnumeratedIndexValues']['ZI004_RCG']['AL180']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['CultureSrf']['EnumeratedIndexValues']['ZI004_RCG']['AL200']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['CultureSrf']['EnumeratedIndexValues']['ZI004_RCG']['AL201']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['CultureSrf']['EnumeratedIndexValues']['ZI004_RCG']['BH075']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['CultureSrf']['EnumeratedIndexValues']['ZI004_RCG']['EA031']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['CultureSrf']['EnumeratedIndexValues']['ZI004_RCG']['FA012']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['CultureSrf']['EnumeratedIndexValues']['ZI004_RCG']['FA210']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['CultureSrf']['ZI005_FNA'] = ('String',('AK120','AK121','AL012','AL030','AL036','AL130','AL175','AL180','AL200','AL201','BH075','EA031','FA012','FA210'))
    field_information['GGDM 3.0']['CultureSrf']['ZI005_GNT'] = ('Enumeration',('AK120','AK121','AL012','AL030','AL036','AL130','AL175','AL180','AL200','AL201','BH075','EA031','FA012','FA210'))
    field_information['GGDM 3.0']['CultureSrf']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['CultureSrf']['EnumeratedIndexValues']['ZI005_GNT']['AK120']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['CultureSrf']['EnumeratedIndexValues']['ZI005_GNT']['AK121']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['CultureSrf']['EnumeratedIndexValues']['ZI005_GNT']['AL012']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['CultureSrf']['EnumeratedIndexValues']['ZI005_GNT']['AL030']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['CultureSrf']['EnumeratedIndexValues']['ZI005_GNT']['AL036']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['CultureSrf']['EnumeratedIndexValues']['ZI005_GNT']['AL130']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['CultureSrf']['EnumeratedIndexValues']['ZI005_GNT']['AL175']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['CultureSrf']['EnumeratedIndexValues']['ZI005_GNT']['AL180']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['CultureSrf']['EnumeratedIndexValues']['ZI005_GNT']['AL200']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['CultureSrf']['EnumeratedIndexValues']['ZI005_GNT']['AL201']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['CultureSrf']['EnumeratedIndexValues']['ZI005_GNT']['BH075']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['CultureSrf']['EnumeratedIndexValues']['ZI005_GNT']['EA031']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['CultureSrf']['EnumeratedIndexValues']['ZI005_GNT']['FA012']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['CultureSrf']['EnumeratedIndexValues']['ZI005_GNT']['FA210']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['CultureSrf']['ZI005_NFN'] = ('String',('AK120','AK121','AL012','AL030','AL036','AL130','AL175','AL180','AL200','AL201','BH075','EA031','FA012','FA210'))
    field_information['GGDM 3.0']['CultureSrf']['ZI006_MEM'] = ('String',('AK120','AK121','AL012','AL030','AL036','AL130','AL175','AL180','AL200','AL201','BH075','EA031','FA012','FA210'))
    field_information['GGDM 3.0']['CultureSrf']['ZI020_GE4'] = ('CodeList',('AK120','AK121','AL012','AL030','AL036','AL130','AL175','AL180','AL200','AL201','BH075','EA031','FA012','FA210'))
    field_information['GGDM 3.0']['CultureSrf']['ZI024_ASE'] = ('Real',('BH075'))
    field_information['GGDM 3.0']['CultureSrf']['ZI024_CFR'] = ('Real',('BH075'))
    field_information['GGDM 3.0']['CultureSrf']['ZI024_CLO'] = ('Real',('BH075'))
    field_information['GGDM 3.0']['CultureSrf']['ZI024_CYN'] = ('Real',('BH075'))
    field_information['GGDM 3.0']['CultureSrf']['ZI024_FMR'] = ('Real',('BH075'))
    field_information['GGDM 3.0']['CultureSrf']['ZI024_FRR'] = ('Real',('BH075'))
    field_information['GGDM 3.0']['CultureSrf']['ZI024_HAR'] = ('Real',('BH075'))
    field_information['GGDM 3.0']['CultureSrf']['ZI024_MGN'] = ('Real',('BH075'))
    field_information['GGDM 3.0']['CultureSrf']['ZI024_PHW'] = ('Real',('BH075'))
    field_information['GGDM 3.0']['CultureSrf']['ZI024_SCC'] = ('Enumeration',('BH075'))
    field_information['GGDM 3.0']['CultureSrf']['EnumeratedIndexValues']['ZI024_SCC'] = {}
    field_information['GGDM 3.0']['CultureSrf']['EnumeratedIndexValues']['ZI024_SCC']['BH075']  = (-999999,1,4,10,11,12,13,14,998,999)
    field_information['GGDM 3.0']['CultureSrf']['ZI024_SUL'] = ('Real',('BH075'))
    field_information['GGDM 3.0']['CultureSrf']['ZI024_TDS'] = ('Real',('BH075'))
    field_information['GGDM 3.0']['CultureSrf']['ZI024_TEP'] = ('Real',('BH075'))
    field_information['GGDM 3.0']['CultureSrf']['ZI024_TUR'] = ('Real',('BH075'))
    field_information['GGDM 3.0']['CultureSrf']['ZI024_WAC'] = ('Real',('BH075'))
    field_information['GGDM 3.0']['CultureSrf']['ZI024_WTNO'] = ('Real',('BH075'))
    field_information['GGDM 3.0']['CultureSrf']['ZI024_WUR'] = ('Enumeration',('BH075'))
    field_information['GGDM 3.0']['CultureSrf']['EnumeratedIndexValues']['ZI024_WUR'] = {}
    field_information['GGDM 3.0']['CultureSrf']['EnumeratedIndexValues']['ZI024_WUR']['BH075']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['CultureSrf']['ZI024_WUR2'] = ('Enumeration',('BH075'))
    field_information['GGDM 3.0']['CultureSrf']['EnumeratedIndexValues']['ZI024_WUR2'] = {}
    field_information['GGDM 3.0']['CultureSrf']['EnumeratedIndexValues']['ZI024_WUR2']['BH075']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['CultureSrf']['ZI024_WUR3'] = ('Enumeration',('BH075'))
    field_information['GGDM 3.0']['CultureSrf']['EnumeratedIndexValues']['ZI024_WUR3'] = {}
    field_information['GGDM 3.0']['CultureSrf']['EnumeratedIndexValues']['ZI024_WUR3']['BH075']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['CultureSrf']['ZI024_WUR4'] = ('Enumeration',('BH075'))
    field_information['GGDM 3.0']['CultureSrf']['EnumeratedIndexValues']['ZI024_WUR4'] = {}
    field_information['GGDM 3.0']['CultureSrf']['EnumeratedIndexValues']['ZI024_WUR4']['BH075']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['CultureSrf']['ZI024_YWQ'] = ('Enumeration',('BH075'))
    field_information['GGDM 3.0']['CultureSrf']['EnumeratedIndexValues']['ZI024_YWQ'] = {}
    field_information['GGDM 3.0']['CultureSrf']['EnumeratedIndexValues']['ZI024_YWQ']['BH075']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['CultureSrf']['ZI025_HDP'] = ('Real',('AL200'))
    field_information['GGDM 3.0']['CultureSrf']['ZI026_CTUC'] = ('Enumeration',('AK120','AK121','AL012','AL030','AL036','AL130','AL175','AL180','AL200','AL201','BH075','EA031','FA012','FA210'))
    field_information['GGDM 3.0']['CultureSrf']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['CultureSrf']['EnumeratedIndexValues']['ZI026_CTUC']['AK120']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['CultureSrf']['EnumeratedIndexValues']['ZI026_CTUC']['AK121']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['CultureSrf']['EnumeratedIndexValues']['ZI026_CTUC']['AL012']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['CultureSrf']['EnumeratedIndexValues']['ZI026_CTUC']['AL030']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['CultureSrf']['EnumeratedIndexValues']['ZI026_CTUC']['AL036']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['CultureSrf']['EnumeratedIndexValues']['ZI026_CTUC']['AL130']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['CultureSrf']['EnumeratedIndexValues']['ZI026_CTUC']['AL175']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['CultureSrf']['EnumeratedIndexValues']['ZI026_CTUC']['AL180']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['CultureSrf']['EnumeratedIndexValues']['ZI026_CTUC']['AL200']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['CultureSrf']['EnumeratedIndexValues']['ZI026_CTUC']['AL201']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['CultureSrf']['EnumeratedIndexValues']['ZI026_CTUC']['BH075']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['CultureSrf']['EnumeratedIndexValues']['ZI026_CTUC']['EA031']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['CultureSrf']['EnumeratedIndexValues']['ZI026_CTUC']['FA012']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['CultureSrf']['EnumeratedIndexValues']['ZI026_CTUC']['FA210']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['CultureSrf']['ZI026_CTUL'] = ('integer',('AK120','AK121','AL012','AL030','AL036','AL130','AL175','AL180','AL200','AL201','BH075','EA031','FA012','FA210'))
    field_information['GGDM 3.0']['CultureSrf']['ZI026_CTUU'] = ('integer',('AK120','AK121','AL012','AL030','AL036','AL130','AL175','AL180','AL200','AL201','BH075','EA031','FA012','FA210'))
    field_information['GGDM 3.0']['CultureSrf']['ZI031S_URI'] = ('StructuredText',('AK120','AK121','AL012','AL030','AL036','AL130','AL175','AL180','AL200','AL201','BH075','EA031','FA012','FA210'))
    field_information['GGDM 3.0']['CultureSrf']['ZI037_REL'] = ('Enumeration',('AL030','AL036','AL175','AL201'))
    field_information['GGDM 3.0']['CultureSrf']['EnumeratedIndexValues']['ZI037_REL'] = {}
    field_information['GGDM 3.0']['CultureSrf']['EnumeratedIndexValues']['ZI037_REL']['AL030']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,999)
    field_information['GGDM 3.0']['CultureSrf']['EnumeratedIndexValues']['ZI037_REL']['AL036']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,999)
    field_information['GGDM 3.0']['CultureSrf']['EnumeratedIndexValues']['ZI037_REL']['AL175']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,999)
    field_information['GGDM 3.0']['CultureSrf']['EnumeratedIndexValues']['ZI037_REL']['AL201']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,999)
    field_information['GGDM 3.0']['CultureSrf']['ZI037_RFA'] = ('Enumeration',('AL175','AL201'))
    field_information['GGDM 3.0']['CultureSrf']['EnumeratedIndexValues']['ZI037_RFA'] = {}
    field_information['GGDM 3.0']['CultureSrf']['EnumeratedIndexValues']['ZI037_RFA']['AL175']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,18,19,20,21,22,23.25,999)
    field_information['GGDM 3.0']['CultureSrf']['EnumeratedIndexValues']['ZI037_RFA']['AL201']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,18,19,20,21,22,23,25,999)
    field_information['GGDM 3.0']['CultureSrf']['ZI039S_UFI'] = ('StructuredText',('AK120','AK121','AL012','AL030','AL036','AL130','AL175','AL180','AL200','AL201','BH075','EA031','FA012','FA210'))
    field_information['GGDM 3.0']['CultureSrf']['ZSAX_RS0'] = ('CodeList',('AK120','AK121','AL012','AL030','AL036','AL130','AL175','AL180','AL200','AL201','BH075','EA031','FA012','FA210'))
    field_information['GGDM 3.0']['CultureSrf']['ZSAX_RX0'] = ('StructuredText',('AK120','AK121','AL012','AL030','AL036','AL130','AL175','AL180','AL200','AL201','BH075','EA031','FA012','FA210'))
    field_information['GGDM 3.0']['CultureSrf']['ZSAX_RX3'] = ('StructuredText',('AK120','AK121','AL012','AL030','AL036','AL130','AL175','AL180','AL200','AL201','BH075','EA031','FA012','FA210'))
    field_information['GGDM 3.0']['CultureSrf']['ZSAX_RX4'] = ('StructuredText',('AK120','AK121','AL012','AL030','AL036','AL130','AL175','AL180','AL200','AL201','BH075','EA031','FA012','FA210'))
    field_information['GGDM 3.0']['CultureSrf']['ZVH'] = ('Real',('AL012','AL030','AL036','AL130','AL180','AL200','AL201','BH075','EA031'))
    field_information['GGDM 3.0']['CultureSrfExt']['ARA'] = ('Real',('ZD030'))
    field_information['GGDM 3.0']['CultureSrfExt']['BEN'] = ('StructuredText',('ZD030'))
    field_information['GGDM 3.0']['CultureSrfExt']['CUL'] = ('Enumeration',('ZD030'))
    field_information['GGDM 3.0']['CultureSrfExt']['EnumeratedIndexValues']['CUL'] = {}
    field_information['GGDM 3.0']['CultureSrfExt']['EnumeratedIndexValues']['CUL']['ZD030']  = (-999999,1,2,3,4,5,6,999)
    field_information['GGDM 3.0']['CultureSrfExt']['F_CODE'] = ('CONSTRAINED_STRING',('ZD030'))
    field_information['GGDM 3.0']['CultureSrfExt']['FUFI'] = ('StructuredText',('ZD030'))
    field_information['GGDM 3.0']['CultureSrfExt']['FURL'] = ('StructuredText',('ZD030'))
    field_information['GGDM 3.0']['CultureSrfExt']['GDBV'] = ('Enumeration',('ZD030'))
    field_information['GGDM 3.0']['CultureSrfExt']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['CultureSrfExt']['EnumeratedIndexValues']['GDBV']['ZD030']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['CultureSrfExt']['LZN'] = ('Real',('ZD030'))
    field_information['GGDM 3.0']['CultureSrfExt']['OTH'] = ('StructuredText',('ZD030'))
    field_information['GGDM 3.0']['CultureSrfExt']['UFI'] = ('StructuredText',('ZD030'))
    field_information['GGDM 3.0']['CultureSrfExt']['WID'] = ('Real',('ZD030'))
    field_information['GGDM 3.0']['CultureSrfExt']['ZI001_SDV'] = ('StructuredText',('ZD030'))
    field_information['GGDM 3.0']['CultureSrfExt']['ZI001_SRT'] = ('Enumeration',('ZD030'))
    field_information['GGDM 3.0']['CultureSrfExt']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['CultureSrfExt']['EnumeratedIndexValues']['ZI001_SRT']['ZD030']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['CultureSrfExt']['ZI002_UFI'] = ('StructuredText',('ZD030'))
    field_information['GGDM 3.0']['CultureSrfExt']['ZI004_RCG'] = ('Enumeration',('ZD030'))
    field_information['GGDM 3.0']['CultureSrfExt']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['CultureSrfExt']['EnumeratedIndexValues']['ZI004_RCG']['ZD030']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['CultureSrfExt']['ZI005_FNA'] = ('String',('ZD030'))
    field_information['GGDM 3.0']['CultureSrfExt']['ZI005_GNT'] = ('Enumeration',('ZD030'))
    field_information['GGDM 3.0']['CultureSrfExt']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['CultureSrfExt']['EnumeratedIndexValues']['ZI005_GNT']['ZD030']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['CultureSrfExt']['ZI005_NFN'] = ('String',('ZD030'))
    field_information['GGDM 3.0']['CultureSrfExt']['ZI006_MEM'] = ('String',('ZD030'))
    field_information['GGDM 3.0']['CultureSrfExt']['ZI020_GE4'] = ('CodeList',('ZD030'))
    field_information['GGDM 3.0']['CultureSrfExt']['ZI026_CTUC'] = ('Enumeration',('ZD030'))
    field_information['GGDM 3.0']['CultureSrfExt']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['CultureSrfExt']['EnumeratedIndexValues']['ZI026_CTUC']['ZD030']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['CultureSrfExt']['ZI026_CTUL'] = ('integer',('ZD030'))
    field_information['GGDM 3.0']['CultureSrfExt']['ZI026_CTUU'] = ('integer',('ZD030'))
    field_information['GGDM 3.0']['CultureSrfExt']['ZI031S_URI'] = ('StructuredText',('ZD030'))
    field_information['GGDM 3.0']['CultureSrfExt']['ZI037_REL'] = ('Enumeration',('ZD030'))
    field_information['GGDM 3.0']['CultureSrfExt']['EnumeratedIndexValues']['ZI037_REL'] = {}
    field_information['GGDM 3.0']['CultureSrfExt']['EnumeratedIndexValues']['ZI037_REL']['ZD030']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,999)
    field_information['GGDM 3.0']['CultureSrfExt']['ZI039S_UFI'] = ('StructuredText',('ZD030'))
    field_information['GGDM 3.0']['CultureSrfExt']['ZSAX_RS0'] = ('CodeList',('ZD030'))
    field_information['GGDM 3.0']['CultureSrfExt']['ZSAX_RX0'] = ('StructuredText',('ZD030'))
    field_information['GGDM 3.0']['CultureSrfExt']['ZSAX_RX3'] = ('StructuredText',('ZD030'))
    field_information['GGDM 3.0']['CultureSrfExt']['ZSAX_RX4'] = ('StructuredText',('ZD030'))
    field_information['GGDM 3.0']['FacilityPnt']['ADR'] = ('String',('AL010','AL011','AT045'))
    field_information['GGDM 3.0']['FacilityPnt']['ADUR'] = ('Integer',('AL010'))
    field_information['GGDM 3.0']['FacilityPnt']['AOO'] = ('Real',('AL010','AL011','AT045'))
    field_information['GGDM 3.0']['FacilityPnt']['ARA'] = ('Real',('AL010','AL011','AT045'))
    field_information['GGDM 3.0']['FacilityPnt']['BEN'] = ('StructuredText',('AL010','AL011','AT045'))
    field_information['GGDM 3.0']['FacilityPnt']['CAA'] = ('Enumeration',('AL010','AL011','AT045'))
    field_information['GGDM 3.0']['FacilityPnt']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['FacilityPnt']['EnumeratedIndexValues']['CAA']['AL010']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['FacilityPnt']['EnumeratedIndexValues']['CAA']['AL011']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['FacilityPnt']['EnumeratedIndexValues']['CAA']['AT045']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['FacilityPnt']['CNCP'] = ('StructuredText',('AL010','AL011','AT045'))
    field_information['GGDM 3.0']['FacilityPnt']['COS'] = ('Enumeration',('AL010','AL011','AT045'))
    field_information['GGDM 3.0']['FacilityPnt']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['FacilityPnt']['EnumeratedIndexValues']['COS']['AL010']  = (-999999,1,2,3,4,6,9,13,14)
    field_information['GGDM 3.0']['FacilityPnt']['EnumeratedIndexValues']['COS']['AL011']  = (-999999,2,4,6,9,13,14)
    field_information['GGDM 3.0']['FacilityPnt']['EnumeratedIndexValues']['COS']['AT045']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['FacilityPnt']['F_CODE'] = ('CONSTRAINED_STRING',('AL010','AL011','AT045'))
    field_information['GGDM 3.0']['FacilityPnt']['FFN'] = ('Enumeration',('AL010','AT045'))
    field_information['GGDM 3.0']['FacilityPnt']['EnumeratedIndexValues']['FFN'] = {}
    field_information['GGDM 3.0']['FacilityPnt']['EnumeratedIndexValues']['FFN']['AL010']  = (-999999,2,3,9,14,15,19,20,21,27,30,35,40,50,60,70,83,87,91,95,99,100,101,102,103,104,105,106,107,110,111,112,113,114,115,116,118,119,120,121,122,123,124,125,129,130,140,150,155,160,161,165,171,181,190,191,192,195,210,221,225,230,231,232,233,234,235,236,237,240,241,242,243,250,251,255,257,260,270,272,280,289,290,301,304,305,306,310,320,321,322,323,324,325,330,331,332,333,334,340,341,342,343,350,351,352,355,356,360,361,362,363,370,372,382,385,440,459,460,464,465,466,470,473,474,475,476,477,478,480,481,482,483,484,486,487,488,489,490,491,494,495,496,497,500,501,505,507,508,510,511,512,513,520,525,529,530,535,536,537,538,539,540,541,545,548,549,550,551,552,553,554,555,556,557,558,559,563,570,572,573,574,578,579,580,582,594,601,604,610,612,614,615,616,617,620,621,622,625,626,632,633,640,642,643,651,662,663,671,680,681,691,696,701,706,711,714,717,720,721,722,725,730,741,752,757,760,761,770,775,780,781,791,795,801,807,808,809,810,811,812,813,814,815,817,818,819,821,822,825,826,827,828,829,830,831,832,833,835,836,837,838,839,840,841,842,843,844,845,846,847,848,850,851,852,855,857,860,861,862,863,864,865,866,871,873,875,881,882,883,884,885,887,888,890,891,892,893,894,895,900,902,905,906,907,909,912,913,914,915,919,921,922,923,930,931,950,954,955,961,962,963,964,965,966,967,970,980,999)
    field_information['GGDM 3.0']['FacilityPnt']['EnumeratedIndexValues']['FFN']['AT045']  = (-999999,520,722,811,829,835,999)
    field_information['GGDM 3.0']['FacilityPnt']['FFN2'] = ('Enumeration',('AL010','AT045'))
    field_information['GGDM 3.0']['FacilityPnt']['EnumeratedIndexValues']['FFN2'] = {}
    field_information['GGDM 3.0']['FacilityPnt']['EnumeratedIndexValues']['FFN2']['AL010']  = (-999999,2,3,9,14,15,19,20,21,27,30,35,40,50,60,70,83,87,91,95,99,100,101,102,103,104,105,106,107,110,111,112,113,114,115,116,118,119,120,121,122,123,124,125,129,130,140,150,155,160,161,165,171,181,190,191,192,195,210,221,225,230,231,232,233,234,235,236,237,240,241,242,243,250,251,255,257,260,270,272,280,289,290,301,304,305,306,310,320,321,322,323,324,325,330,331,332,333,334,340,341,342,343,350,351,352,355,356,360,361,362,363,370,372,382,385,440,459,460,464,465,466,470,473,474,475,476,477,478,480,481,482,483,484,486,487,488,489,490,491,494,495,496,497,500,501,505,507,508,510,511,512,513,520,525,529,530,535,536,537,538,539,540,541,545,548,549,550,551,552,553,554,555,556,557,558,559,563,570,572,573,574,578,579,580,582,594,601,604,610,612,614,615,616,617,620,621,622,625,626,632,633,640,642,643,651,662,663,671,680,681,691,696,701,706,711,714,717,720,721,722,725,730,741,752,757,760,761,770,775,780,781,791,795,801,807,808,809,810,811,812,813,814,815,817,818,819,821,822,825,826,827,828,829,830,831,832,833,835,836,837,838,839,840,841,842,843,844,845,846,847,848,850,851,852,855,857,860,861,862,863,864,865,866,871,873,875,881,882,883,884,885,887,888,890,891,892,893,894,895,900,902,905,906,907,909,912,913,914,915,919,921,922,923,930,931,950,954,955,961,962,963,964,965,966,967,970,980,999)
    field_information['GGDM 3.0']['FacilityPnt']['EnumeratedIndexValues']['FFN2']['AT045']  = (-999999,520,722,811,829,835,999)
    field_information['GGDM 3.0']['FacilityPnt']['FFN3'] = ('Enumeration',('AL010','AT045'))
    field_information['GGDM 3.0']['FacilityPnt']['EnumeratedIndexValues']['FFN3'] = {}
    field_information['GGDM 3.0']['FacilityPnt']['EnumeratedIndexValues']['FFN3']['AL010']  = (-999999,2,3,9,14,15,19,20,21,27,30,35,40,50,60,70,83,87,91,95,99,100,101,102,103,104,105,106,107,110,111,112,113,114,115,116,118,119,120,121,122,123,124,125,129,130,140,150,155,160,161,165,171,181,190,191,192,195,210,221,225,230,231,232,233,234,235,236,237,240,241,242,243,250,251,255,257,260,270,272,280,289,290,301,304,305,306,310,320,321,322,323,324,325,330,331,332,333,334,340,341,342,343,350,351,352,355,356,360,361,362,363,370,372,382,385,440,459,460,464,465,466,470,473,474,475,476,477,478,480,481,482,483,484,486,487,488,489,490,491,494,495,496,497,500,501,505,507,508,510,511,512,513,520,525,529,530,535,536,537,538,539,540,541,545,548,549,550,551,552,553,554,555,556,557,558,559,563,570,572,573,574,578,579,580,582,594,601,604,610,612,614,615,616,617,620,621,622,625,626,632,633,640,642,643,651,662,663,671,680,681,691,696,701,706,711,714,717,720,721,722,725,730,741,752,757,760,761,770,775,780,781,791,795,801,807,808,809,810,811,812,813,814,815,817,818,819,821,822,825,826,827,828,829,830,831,832,833,835,836,837,838,839,840,841,842,843,844,845,846,847,848,850,851,852,855,857,860,861,862,863,864,865,866,871,873,875,881,882,883,884,885,887,888,890,891,892,893,894,895,900,902,905,906,907,909,912,913,914,915,919,921,922,923,930,931,950,954,955,961,962,963,964,965,966,967,970,980,999)
    field_information['GGDM 3.0']['FacilityPnt']['EnumeratedIndexValues']['FFN3']['AT045']  = (-999999,520,722,811,829,835,999)
    field_information['GGDM 3.0']['FacilityPnt']['FUFI'] = ('StructuredText',('AL010','AL011','AT045'))
    field_information['GGDM 3.0']['FacilityPnt']['FURL'] = ('StructuredText',('AL010','AL011','AT045'))
    field_information['GGDM 3.0']['FacilityPnt']['GDBV'] = ('Enumeration',('AL010','AL011','AT045'))
    field_information['GGDM 3.0']['FacilityPnt']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['FacilityPnt']['EnumeratedIndexValues']['GDBV']['AL010']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['FacilityPnt']['EnumeratedIndexValues']['GDBV']['AL011']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['FacilityPnt']['EnumeratedIndexValues']['GDBV']['AT045']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['FacilityPnt']['HGT'] = ('Real',('AL010','AT045'))
    field_information['GGDM 3.0']['FacilityPnt']['LMC'] = ('Boolean',('AL010','AL011','AT045'))
    field_information['GGDM 3.0']['FacilityPnt']['LZN'] = ('Real',('AL010','AL011','AT045'))
    field_information['GGDM 3.0']['FacilityPnt']['OTH'] = ('StructuredText',('AL010','AL011','AT045'))
    field_information['GGDM 3.0']['FacilityPnt']['PCF'] = ('Enumeration',('AL010','AL011','AT045'))
    field_information['GGDM 3.0']['FacilityPnt']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['FacilityPnt']['EnumeratedIndexValues']['PCF']['AL010']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['FacilityPnt']['EnumeratedIndexValues']['PCF']['AL011']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['FacilityPnt']['EnumeratedIndexValues']['PCF']['AT045']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['FacilityPnt']['PRM'] = ('Boolean',('AT045'))
    field_information['GGDM 3.0']['FacilityPnt']['RAS'] = ('Enumeration',('AT045'))
    field_information['GGDM 3.0']['FacilityPnt']['EnumeratedIndexValues']['RAS'] = {}
    field_information['GGDM 3.0']['FacilityPnt']['EnumeratedIndexValues']['RAS']['AT045']  = (-999999,1,2,5,6,7,8,9,10,11,12,999)
    field_information['GGDM 3.0']['FacilityPnt']['UFI'] = ('StructuredText',('AL010','AL011','AT045'))
    field_information['GGDM 3.0']['FacilityPnt']['VCM'] = ('Enumeration',('AL010'))
    field_information['GGDM 3.0']['FacilityPnt']['EnumeratedIndexValues']['VCM'] = {}
    field_information['GGDM 3.0']['FacilityPnt']['EnumeratedIndexValues']['VCM']['AL010']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,999)
    field_information['GGDM 3.0']['FacilityPnt']['VCM2'] = ('Enumeration',('AL010'))
    field_information['GGDM 3.0']['FacilityPnt']['EnumeratedIndexValues']['VCM2'] = {}
    field_information['GGDM 3.0']['FacilityPnt']['EnumeratedIndexValues']['VCM2']['AL010']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,999)
    field_information['GGDM 3.0']['FacilityPnt']['VCM3'] = ('Enumeration',('AL010'))
    field_information['GGDM 3.0']['FacilityPnt']['EnumeratedIndexValues']['VCM3'] = {}
    field_information['GGDM 3.0']['FacilityPnt']['EnumeratedIndexValues']['VCM3']['AL010']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,999)
    field_information['GGDM 3.0']['FacilityPnt']['WID'] = ('Real',('AL010','AL011','AT045'))
    field_information['GGDM 3.0']['FacilityPnt']['WLSS'] = ('Real',('AL010'))
    field_information['GGDM 3.0']['FacilityPnt']['WSRC'] = ('Enumeration',('AL010'))
    field_information['GGDM 3.0']['FacilityPnt']['EnumeratedIndexValues']['WSRC'] = {}
    field_information['GGDM 3.0']['FacilityPnt']['EnumeratedIndexValues']['WSRC']['AL010']  = (-999999,1,2,3,4,5,998,999)
    field_information['GGDM 3.0']['FacilityPnt']['YSU'] = ('Enumeration',('AT045'))
    field_information['GGDM 3.0']['FacilityPnt']['EnumeratedIndexValues']['YSU'] = {}
    field_information['GGDM 3.0']['FacilityPnt']['EnumeratedIndexValues']['YSU']['AT045']  = (-999999,1,2,3,4,5,7,999)
    field_information['GGDM 3.0']['FacilityPnt']['ZI001_SDV'] = ('StructuredText',('AL010','AL011','AT045'))
    field_information['GGDM 3.0']['FacilityPnt']['ZI001_SRT'] = ('Enumeration',('AL010','AL011','AT045'))
    field_information['GGDM 3.0']['FacilityPnt']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['FacilityPnt']['EnumeratedIndexValues']['ZI001_SRT']['AL010']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['FacilityPnt']['EnumeratedIndexValues']['ZI001_SRT']['AL011']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['FacilityPnt']['EnumeratedIndexValues']['ZI001_SRT']['AT045']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['FacilityPnt']['ZI002_UFI'] = ('StructuredText',('AL010','AL011','AT045'))
    field_information['GGDM 3.0']['FacilityPnt']['ZI004_RCG'] = ('Enumeration',('AL010','AL011','AT045'))
    field_information['GGDM 3.0']['FacilityPnt']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['FacilityPnt']['EnumeratedIndexValues']['ZI004_RCG']['AL010']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['FacilityPnt']['EnumeratedIndexValues']['ZI004_RCG']['AL011']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['FacilityPnt']['EnumeratedIndexValues']['ZI004_RCG']['AT045']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['FacilityPnt']['ZI005_FNA'] = ('String',('AL010','AL011','AT045'))
    field_information['GGDM 3.0']['FacilityPnt']['ZI005_FNA2'] = ('String',('AL010'))
    field_information['GGDM 3.0']['FacilityPnt']['ZI005_FNA3'] = ('String',('AL010'))
    field_information['GGDM 3.0']['FacilityPnt']['ZI005_GNT'] = ('Enumeration',('AL010','AL011','AT045'))
    field_information['GGDM 3.0']['FacilityPnt']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['FacilityPnt']['EnumeratedIndexValues']['ZI005_GNT']['AL010']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['FacilityPnt']['EnumeratedIndexValues']['ZI005_GNT']['AL011']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['FacilityPnt']['EnumeratedIndexValues']['ZI005_GNT']['AT045']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['FacilityPnt']['ZI005_GNT2'] = ('Enumeration',('AL010'))
    field_information['GGDM 3.0']['FacilityPnt']['EnumeratedIndexValues']['ZI005_GNT2'] = {}
    field_information['GGDM 3.0']['FacilityPnt']['EnumeratedIndexValues']['ZI005_GNT2']['AL010']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['FacilityPnt']['ZI005_GNT3'] = ('Enumeration',('AL010'))
    field_information['GGDM 3.0']['FacilityPnt']['EnumeratedIndexValues']['ZI005_GNT3'] = {}
    field_information['GGDM 3.0']['FacilityPnt']['EnumeratedIndexValues']['ZI005_GNT3']['AL010']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['FacilityPnt']['ZI005_NFN'] = ('String',('AL010','AL011','AT045'))
    field_information['GGDM 3.0']['FacilityPnt']['ZI005_NFN2'] = ('String',('AL010'))
    field_information['GGDM 3.0']['FacilityPnt']['ZI005_NFN3'] = ('String',('AL010'))
    field_information['GGDM 3.0']['FacilityPnt']['ZI006_MEM'] = ('String',('AL010','AL011','AT045'))
    field_information['GGDM 3.0']['FacilityPnt']['ZI014_PBY'] = ('Enumeration',('AL010'))
    field_information['GGDM 3.0']['FacilityPnt']['EnumeratedIndexValues']['ZI014_PBY'] = {}
    field_information['GGDM 3.0']['FacilityPnt']['EnumeratedIndexValues']['ZI014_PBY']['AL010']  = (-999999,1,2,6,7,8,12,13,15,89,999)
    field_information['GGDM 3.0']['FacilityPnt']['ZI014_PBY2'] = ('Enumeration',('AL010'))
    field_information['GGDM 3.0']['FacilityPnt']['EnumeratedIndexValues']['ZI014_PBY2'] = {}
    field_information['GGDM 3.0']['FacilityPnt']['EnumeratedIndexValues']['ZI014_PBY2']['AL010']  = (-999999,1,2,6,7,8,12,13,15,89,999)
    field_information['GGDM 3.0']['FacilityPnt']['ZI014_PBY3'] = ('Enumeration',('AL010'))
    field_information['GGDM 3.0']['FacilityPnt']['EnumeratedIndexValues']['ZI014_PBY3'] = {}
    field_information['GGDM 3.0']['FacilityPnt']['EnumeratedIndexValues']['ZI014_PBY3']['AL010']  = (-999999,1,2,6,7,8,12,13,15,89,999)
    field_information['GGDM 3.0']['FacilityPnt']['ZI014_PPO'] = ('Enumeration',('AL010'))
    field_information['GGDM 3.0']['FacilityPnt']['EnumeratedIndexValues']['ZI014_PPO'] = {}
    field_information['GGDM 3.0']['FacilityPnt']['EnumeratedIndexValues']['ZI014_PPO']['AL010']  = (-999999,1,2,3,4,5,13,15,16,18,20,21,23,25,26,28,32,37,38,39,41,43,44,45,46,47,48,57,58,59,60,61,62,63,65,69,70,73,74,80,83,84,87,90,92,94,95,101,105,106,109,111,114,117,120,121,122,123,126,136,137,146,147,148,150,154,155,156,157,160,165,192,200,214,279,325,435,999)
    field_information['GGDM 3.0']['FacilityPnt']['ZI014_PPO2'] = ('Enumeration',('AL010'))
    field_information['GGDM 3.0']['FacilityPnt']['EnumeratedIndexValues']['ZI014_PPO2'] = {}
    field_information['GGDM 3.0']['FacilityPnt']['EnumeratedIndexValues']['ZI014_PPO2']['AL010']  = (-999999,1,2,3,4,5,13,15,16,18,20,21,23,25,26,28,32,37,38,39,41,43,44,45,46,47,48,57,58,59,60,61,62,63,65,69,70,73,74,80,83,84,87,90,92,94,95,101,105,106,109,111,114,117,120,121,122,123,126,136,137,146,147,148,150,154,155,156,157,160,165,192,200,214,279,325,435,999)
    field_information['GGDM 3.0']['FacilityPnt']['ZI014_PPO3'] = ('Enumeration',('AL010'))
    field_information['GGDM 3.0']['FacilityPnt']['EnumeratedIndexValues']['ZI014_PPO3'] = {}
    field_information['GGDM 3.0']['FacilityPnt']['EnumeratedIndexValues']['ZI014_PPO3']['AL010']  = (-999999,1,2,3,4,5,13,15,16,18,20,21,23,25,26,28,32,37,38,39,41,43,44,45,46,47,48,57,58,59,60,61,62,63,65,69,70,73,74,80,83,84,87,90,92,94,95,101,105,106,109,111,114,117,120,121,122,123,126,136,137,146,147,148,150,154,155,156,157,160,165,192,200,214,279,325,435,999)
    field_information['GGDM 3.0']['FacilityPnt']['ZI014_PRW'] = ('Enumeration',('AL010'))
    field_information['GGDM 3.0']['FacilityPnt']['EnumeratedIndexValues']['ZI014_PRW'] = {}
    field_information['GGDM 3.0']['FacilityPnt']['EnumeratedIndexValues']['ZI014_PRW']['AL010']  = (-999999,1,2,5,9,10,11,12,14,16,18,27,28,29,30,33,38,39,41,45,46,48,50,52,54,57,60,64,66,68,70,75,78,79,83,84,85,87,90,93,94,96,97,99,118,119,999)
    field_information['GGDM 3.0']['FacilityPnt']['ZI014_PRW2'] = ('Enumeration',('AL010'))
    field_information['GGDM 3.0']['FacilityPnt']['EnumeratedIndexValues']['ZI014_PRW2'] = {}
    field_information['GGDM 3.0']['FacilityPnt']['EnumeratedIndexValues']['ZI014_PRW2']['AL010']  = (-999999,1,2,5,9,10,11,12,14,16,18,27,28,29,30,33,38,39,41,45,46,48,50,52,54,57,60,64,66,68,70,75,78,79,83,84,85,87,90,93,94,96,97,99,118,119,999)
    field_information['GGDM 3.0']['FacilityPnt']['ZI014_PRW3'] = ('Enumeration',('AL010'))
    field_information['GGDM 3.0']['FacilityPnt']['EnumeratedIndexValues']['ZI014_PRW3'] = {}
    field_information['GGDM 3.0']['FacilityPnt']['EnumeratedIndexValues']['ZI014_PRW3']['AL010']  = (-999999,1,2,5,9,10,11,12,14,16,18,27,28,29,30,33,38,39,41,45,46,48,50,52,54,57,60,64,66,68,70,75,78,79,83,84,85,87,90,93,94,96,97,99,118,119,999)
    field_information['GGDM 3.0']['FacilityPnt']['ZI018_WIT'] = ('Enumeration',('AL010'))
    field_information['GGDM 3.0']['FacilityPnt']['EnumeratedIndexValues']['ZI018_WIT'] = {}
    field_information['GGDM 3.0']['FacilityPnt']['EnumeratedIndexValues']['ZI018_WIT']['AL010']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['FacilityPnt']['ZI020_GE4'] = ('CodeList',('AL010','AL011','AT045'))
    field_information['GGDM 3.0']['FacilityPnt']['ZI026_CTUC'] = ('Enumeration',('AL010','AL011','AT045'))
    field_information['GGDM 3.0']['FacilityPnt']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['FacilityPnt']['EnumeratedIndexValues']['ZI026_CTUC']['AL010']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['FacilityPnt']['EnumeratedIndexValues']['ZI026_CTUC']['AL011']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['FacilityPnt']['EnumeratedIndexValues']['ZI026_CTUC']['AT045']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['FacilityPnt']['ZI026_CTUL'] = ('integer',('AL010','AL011','AT045'))
    field_information['GGDM 3.0']['FacilityPnt']['ZI026_CTUU'] = ('integer',('AL010','AL011','AT045'))
    field_information['GGDM 3.0']['FacilityPnt']['ZI031S_URI'] = ('StructuredText',('AL010','AL011','AT045'))
    field_information['GGDM 3.0']['FacilityPnt']['ZI037_REL'] = ('Enumeration',('AL010'))
    field_information['GGDM 3.0']['FacilityPnt']['EnumeratedIndexValues']['ZI037_REL'] = {}
    field_information['GGDM 3.0']['FacilityPnt']['EnumeratedIndexValues']['ZI037_REL']['AL010']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,999)
    field_information['GGDM 3.0']['FacilityPnt']['ZI037_RFA'] = ('Enumeration',('AL010'))
    field_information['GGDM 3.0']['FacilityPnt']['EnumeratedIndexValues']['ZI037_RFA'] = {}
    field_information['GGDM 3.0']['FacilityPnt']['EnumeratedIndexValues']['ZI037_RFA']['AL010']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,18,19,20,21,22,23,25,999)
    field_information['GGDM 3.0']['FacilityPnt']['ZI039S_UFI'] = ('StructuredText',('AL010','AL011','AT045'))
    field_information['GGDM 3.0']['FacilityPnt']['ZSAX_RS0'] = ('CodeList',('AL010','AL011','AT045'))
    field_information['GGDM 3.0']['FacilityPnt']['ZSAX_RX0'] = ('StructuredText',('AL010','AL011','AT045'))
    field_information['GGDM 3.0']['FacilityPnt']['ZSAX_RX3'] = ('StructuredText',('AL010','AL011','AT045'))
    field_information['GGDM 3.0']['FacilityPnt']['ZSAX_RX4'] = ('StructuredText',('AL010','AL011','AT045'))
    field_information['GGDM 3.0']['FacilityPnt']['ZVH'] = ('Real',('AL010','AT045'))
    field_information['GGDM 3.0']['FacilitySrf']['ADR'] = ('String',('AG030','AG040','AL010','AL011','AT045'))
    field_information['GGDM 3.0']['FacilitySrf']['ADUR'] = ('Integer',('AL010'))
    field_information['GGDM 3.0']['FacilitySrf']['AOO'] = ('Real',('AG030','AG040','AL010','AL011','AT045'))
    field_information['GGDM 3.0']['FacilitySrf']['ARA'] = ('Real',('AG030','AG040','AL010','AL011','AT045'))
    field_information['GGDM 3.0']['FacilitySrf']['BEN'] = ('StructuredText',('AG030','AG040','AL010','AL011','AT045'))
    field_information['GGDM 3.0']['FacilitySrf']['CAA'] = ('Enumeration',('AG030','AG040','AL010','AL011','AT045'))
    field_information['GGDM 3.0']['FacilitySrf']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['FacilitySrf']['EnumeratedIndexValues']['CAA']['AG030']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['FacilitySrf']['EnumeratedIndexValues']['CAA']['AG040']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['FacilitySrf']['EnumeratedIndexValues']['CAA']['AL010']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['FacilitySrf']['EnumeratedIndexValues']['CAA']['AL011']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['FacilitySrf']['EnumeratedIndexValues']['CAA']['AT045']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['FacilitySrf']['CNCP'] = ('StructuredText',('AG030','AG040','AL010','AL011','AT045'))
    field_information['GGDM 3.0']['FacilitySrf']['COS'] = ('Enumeration',('AG030','AG040','AL010','AL011','AT045'))
    field_information['GGDM 3.0']['FacilitySrf']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['FacilitySrf']['EnumeratedIndexValues']['COS']['AG030']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['FacilitySrf']['EnumeratedIndexValues']['COS']['AG040']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['FacilitySrf']['EnumeratedIndexValues']['COS']['AL010']  = (-999999,1,2,3,4,6,9,13,14)
    field_information['GGDM 3.0']['FacilitySrf']['EnumeratedIndexValues']['COS']['AL011']  = (-999999,2,4,6,9,13,14)
    field_information['GGDM 3.0']['FacilitySrf']['EnumeratedIndexValues']['COS']['AT045']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['FacilitySrf']['F_CODE'] = ('CONSTRAINED_STRING',('AG030','AG040','AL010','AL011','AT045'))
    field_information['GGDM 3.0']['FacilitySrf']['FFN'] = ('Enumeration',('AG030','AG040','AL010','AT045'))
    field_information['GGDM 3.0']['FacilitySrf']['EnumeratedIndexValues']['FFN'] = {}
    field_information['GGDM 3.0']['FacilitySrf']['EnumeratedIndexValues']['FFN']['AG030']  = (-999999,272,330,332,333,382,440,460,464,465,466,470,475,476,477,478,482,535,540,550,570,572,573,578,582,594,610,612,621,640,643,651,680,681,691,696,741,752,760,761,770,775,811,833,838,841,847,857,860,862,863,865,881,885,887,888,890,891,893,895,900,905,906,909,913,921,922,923,930,961,962,966,970,999)
    field_information['GGDM 3.0']['FacilitySrf']['EnumeratedIndexValues']['FFN']['AG040']  = (-999999,382,459,466,482,535,550,572,601,604,610,621,640,642,643,651,662,663,671,680,681,691,696,701,706,711,714,717,720,741,752,757,760,761,770,775,791,795,801,807,808,809,810,811,812,813,822,828,838,841,847,848,850,857,860,862,863,865,885,887,888,913,930,961,970,999)
    field_information['GGDM 3.0']['FacilitySrf']['EnumeratedIndexValues']['FFN']['AL010']  = (-999999,2,3,9,14,15,19,20,21,27,30,35,40,50,60,70,83,87,91,95,99,100,101,102,103,104,105,106,107,110,111,112,113,114,115,116,118,119,120,121,122,123,124,125,129,130,140,150,155,160,161,165,171,181,190,191,192,195,210,221,225,230,231,232,233,234,235,236,237,240,241,242,243,250,251,255,257,260,270,272,280,289,290,301,304,305,306,310,320,321,322,323,324,325,330,331,332,333,334,340,341,342,343,350,351,352,355,356,360,361,362,363,370,372,382,385,440,459,460,464,465,466,470,473,474,475,476,477,478,480,481,482,483,484,486,487,488,489,490,491,494,495,496,497,500,501,505,507,508,510,511,512,513,520,525,529,530,535,536,537,538,539,540,541,545,548,549,550,551,552,553,554,555,556,557,558,559,563,570,572,573,574,578,579,580,582,594,601,604,610,612,614,615,616,617,620,621,622,625,626,632,633,640,642,643,651,662,663,671,680,681,691,696,701,706,711,714,717,720,721,722,725,730,741,752,757,760,761,770,775,780,781,791,795,801,807,808,809,810,811,812,813,814,815,817,818,819,821,822,825,826,827,828,829,830,831,832,833,835,836,837,838,839,840,841,842,843,844,845,846,847,848,850,851,852,855,857,860,861,862,863,864,865,866,871,873,875,881,882,883,884,885,887,888,890,891,892,893,894,895,900,902,905,906,907,909,912,913,914,915,919,921,922,923,930,931,950,954,955,961,962,963,964,965,966,967,970,980,999)
    field_information['GGDM 3.0']['FacilitySrf']['EnumeratedIndexValues']['FFN']['AT045']  = (-999999,520,722,811,829,835,999)
    field_information['GGDM 3.0']['FacilitySrf']['FFN2'] = ('Enumeration',('AG030','AG040','AL010','AT045'))
    field_information['GGDM 3.0']['FacilitySrf']['EnumeratedIndexValues']['FFN2'] = {}
    field_information['GGDM 3.0']['FacilitySrf']['EnumeratedIndexValues']['FFN2']['AG030']  = (-999999,272,330,332,333,382,440,460,464,465,466,470,475,476,477,478,482,535,540,550,570,572,573,578,582,594,610,612,621,640,643,651,680,681,691,696,741,752,760,761,770,775,811,833,838,841,847,857,860,862,863,865,881,885,887,888,890,891,893,895,900,905,906,909,913,921,922,923,930,961,962,966,970,999)
    field_information['GGDM 3.0']['FacilitySrf']['EnumeratedIndexValues']['FFN2']['AG040']  = (-999999,382,459,466,482,535,550,572,601,604,610,621,640,642,643,651,662,663,671,680,681,691,696,701,706,711,714,717,720,741,752,757,760,761,770,775,791,795,801,807,808,809,810,811,812,813,822,828,838,841,847,848,850,857,860,862,863,865,885,887,888,913,930,961,970,999)
    field_information['GGDM 3.0']['FacilitySrf']['EnumeratedIndexValues']['FFN2']['AL010']  = (-999999,2,3,9,14,15,19,20,21,27,30,35,40,50,60,70,83,87,91,95,99,100,101,102,103,104,105,106,107,110,111,112,113,114,115,116,118,119,120,121,122,123,124,125,129,130,140,150,155,160,161,165,171,181,190,191,192,195,210,221,225,230,231,232,233,234,235,236,237,240,241,242,243,250,251,255,257,260,270,272,280,289,290,301,304,305,306,310,320,321,322,323,324,325,330,331,332,333,334,340,341,342,343,350,351,352,355,356,360,361,362,363,370,372,382,385,440,459,460,464,465,466,470,473,474,475,476,477,478,480,481,482,483,484,486,487,488,489,490,491,494,495,496,497,500,501,505,507,508,510,511,512,513,520,525,529,530,535,536,537,538,539,540,541,545,548,549,550,551,552,553,554,555,556,557,558,559,563,570,572,573,574,578,579,580,582,594,601,604,610,612,614,615,616,617,620,621,622,625,626,632,633,640,642,643,651,662,663,671,680,681,691,696,701,706,711,714,717,720,721,722,725,730,741,752,757,760,761,770,775,780,781,791,795,801,807,808,809,810,811,812,813,814,815,817,818,819,821,822,825,826,827,828,829,830,831,832,833,835,836,837,838,839,840,841,842,843,844,845,846,847,848,850,851,852,855,857,860,861,862,863,864,865,866,871,873,875,881,882,883,884,885,887,888,890,891,892,893,894,895,900,902,905,906,907,909,912,913,914,915,919,921,922,923,930,931,950,954,955,961,962,963,964,965,966,967,970,980,999)
    field_information['GGDM 3.0']['FacilitySrf']['EnumeratedIndexValues']['FFN2']['AT045']  = (-999999,520,722,811,829,835,999)
    field_information['GGDM 3.0']['FacilitySrf']['FFN3'] = ('Enumeration',('AG030','AG040','AL010','AT045'))
    field_information['GGDM 3.0']['FacilitySrf']['EnumeratedIndexValues']['FFN3'] = {}
    field_information['GGDM 3.0']['FacilitySrf']['EnumeratedIndexValues']['FFN3']['AG030']  = (-999999,272,330,332,333,382,440,460,464,465,466,470,475,476,477,478,482,535,540,550,570,572,573,578,582,594,610,612,621,640,643,651,680,681,691,696,741,752,760,761,770,775,811,833,838,841,847,857,860,862,863,865,881,885,887,888,890,891,893,895,900,905,906,909,913,921,922,923,930,961,962,966,970,999)
    field_information['GGDM 3.0']['FacilitySrf']['EnumeratedIndexValues']['FFN3']['AG040']  = (-999999,382,459,466,482,535,550,572,601,604,610,621,640,642,643,651,662,663,671,680,681,691,696,701,706,711,714,717,720,741,752,757,760,761,770,775,791,795,801,807,808,809,810,811,812,813,822,828,838,841,847,848,850,857,860,862,863,865,885,887,888,913,930,961,970,999)
    field_information['GGDM 3.0']['FacilitySrf']['EnumeratedIndexValues']['FFN3']['AL010']  = (-999999,2,3,9,14,15,19,20,21,27,30,35,40,50,60,70,83,87,91,95,99,100,101,102,103,104,105,106,107,110,111,112,113,114,115,116,118,119,120,121,122,123,124,125,129,130,140,150,155,160,161,165,171,181,190,191,192,195,210,221,225,230,231,232,233,234,235,236,237,240,241,242,243,250,251,255,257,260,270,272,280,289,290,301,304,305,306,310,320,321,322,323,324,325,330,331,332,333,334,340,341,342,343,350,351,352,355,356,360,361,362,363,370,372,382,385,440,459,460,464,465,466,470,473,474,475,476,477,478,480,481,482,483,484,486,487,488,489,490,491,494,495,496,497,500,501,505,507,508,510,511,512,513,520,525,529,530,535,536,537,538,539,540,541,545,548,549,550,551,552,553,554,555,556,557,558,559,563,570,572,573,574,578,579,580,582,594,601,604,610,612,614,615,616,617,620,621,622,625,626,632,633,640,642,643,651,662,663,671,680,681,691,696,701,706,711,714,717,720,721,722,725,730,741,752,757,760,761,770,775,780,781,791,795,801,807,808,809,810,811,812,813,814,815,817,818,819,821,822,825,826,827,828,829,830,831,832,833,835,836,837,838,839,840,841,842,843,844,845,846,847,848,850,851,852,855,857,860,861,862,863,864,865,866,871,873,875,881,882,883,884,885,887,888,890,891,892,893,894,895,900,902,905,906,907,909,912,913,914,915,919,921,922,923,930,931,950,954,955,961,962,963,964,965,966,967,970,980,999)
    field_information['GGDM 3.0']['FacilitySrf']['EnumeratedIndexValues']['FFN3']['AT045']  = (-999999,520,722,811,829,835,999)
    field_information['GGDM 3.0']['FacilitySrf']['FUFI'] = ('StructuredText',('AG030','AG040','AL010','AL011','AT045'))
    field_information['GGDM 3.0']['FacilitySrf']['FURL'] = ('StructuredText',('AG030','AG040','AL010','AL011','AT045'))
    field_information['GGDM 3.0']['FacilitySrf']['GDBV'] = ('Enumeration',('AG030','AG040','AL010','AL011','AT045'))
    field_information['GGDM 3.0']['FacilitySrf']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['FacilitySrf']['EnumeratedIndexValues']['GDBV']['AG030']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['FacilitySrf']['EnumeratedIndexValues']['GDBV']['AG040']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['FacilitySrf']['EnumeratedIndexValues']['GDBV']['AL010']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['FacilitySrf']['EnumeratedIndexValues']['GDBV']['AL011']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['FacilitySrf']['EnumeratedIndexValues']['GDBV']['AT045']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['FacilitySrf']['HGT'] = ('Real',('AG030','AG040','AL010','AT045'))
    field_information['GGDM 3.0']['FacilitySrf']['LMC'] = ('Boolean',('AG030','AG040','AL010','AL011','AT045'))
    field_information['GGDM 3.0']['FacilitySrf']['LZN'] = ('Real',('AG030','AG040','AL010','AL011','AT045'))
    field_information['GGDM 3.0']['FacilitySrf']['OTH'] = ('StructuredText',('AG030','AG040','AL010','AL011','AT045'))
    field_information['GGDM 3.0']['FacilitySrf']['PCF'] = ('Enumeration',('AG030','AG040','AL010','AL011','AT045'))
    field_information['GGDM 3.0']['FacilitySrf']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['FacilitySrf']['EnumeratedIndexValues']['PCF']['AG030']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['FacilitySrf']['EnumeratedIndexValues']['PCF']['AG040']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['FacilitySrf']['EnumeratedIndexValues']['PCF']['AL010']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['FacilitySrf']['EnumeratedIndexValues']['PCF']['AL011']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['FacilitySrf']['EnumeratedIndexValues']['PCF']['AT045']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['FacilitySrf']['PRM'] = ('Boolean',('AT045'))
    field_information['GGDM 3.0']['FacilitySrf']['RAS'] = ('Enumeration',('AT045'))
    field_information['GGDM 3.0']['FacilitySrf']['EnumeratedIndexValues']['RAS'] = {}
    field_information['GGDM 3.0']['FacilitySrf']['EnumeratedIndexValues']['RAS']['AT045']  = (-999999,1,2,5,6,7,8,9,10,11,12,999)
    field_information['GGDM 3.0']['FacilitySrf']['UFI'] = ('StructuredText',('AG030','AG040','AL010','AL011','AT045'))
    field_information['GGDM 3.0']['FacilitySrf']['VCM'] = ('Enumeration',('AL010'))
    field_information['GGDM 3.0']['FacilitySrf']['EnumeratedIndexValues']['VCM'] = {}
    field_information['GGDM 3.0']['FacilitySrf']['EnumeratedIndexValues']['VCM']['AL010']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,999)
    field_information['GGDM 3.0']['FacilitySrf']['VCM2'] = ('Enumeration',('AL010'))
    field_information['GGDM 3.0']['FacilitySrf']['EnumeratedIndexValues']['VCM2'] = {}
    field_information['GGDM 3.0']['FacilitySrf']['EnumeratedIndexValues']['VCM2']['AL010']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,999)
    field_information['GGDM 3.0']['FacilitySrf']['VCM3'] = ('Enumeration',('AL010'))
    field_information['GGDM 3.0']['FacilitySrf']['EnumeratedIndexValues']['VCM3'] = {}
    field_information['GGDM 3.0']['FacilitySrf']['EnumeratedIndexValues']['VCM3']['AL010']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,999)
    field_information['GGDM 3.0']['FacilitySrf']['WID'] = ('Real',('AG030','AG040','AL010','AL011','AT045'))
    field_information['GGDM 3.0']['FacilitySrf']['WLSS'] = ('Real',('AL010'))
    field_information['GGDM 3.0']['FacilitySrf']['WSRC'] = ('Enumeration',('AL010'))
    field_information['GGDM 3.0']['FacilitySrf']['EnumeratedIndexValues']['WSRC'] = {}
    field_information['GGDM 3.0']['FacilitySrf']['EnumeratedIndexValues']['WSRC']['AL010']  = (-999999,1,2,3,4,5,998,999)
    field_information['GGDM 3.0']['FacilitySrf']['YSU'] = ('Enumeration',('AT045'))
    field_information['GGDM 3.0']['FacilitySrf']['EnumeratedIndexValues']['YSU'] = {}
    field_information['GGDM 3.0']['FacilitySrf']['EnumeratedIndexValues']['YSU']['AT045']  = (-999999,1,2,3,4,5,7,999)
    field_information['GGDM 3.0']['FacilitySrf']['ZI001_SDV'] = ('StructuredText',('AG030','AG040','AL010','AL011','AT045'))
    field_information['GGDM 3.0']['FacilitySrf']['ZI001_SRT'] = ('Enumeration',('AG030','AG040','AL010','AL011','AT045'))
    field_information['GGDM 3.0']['FacilitySrf']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['FacilitySrf']['EnumeratedIndexValues']['ZI001_SRT']['AG030']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['FacilitySrf']['EnumeratedIndexValues']['ZI001_SRT']['AG040']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['FacilitySrf']['EnumeratedIndexValues']['ZI001_SRT']['AL010']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['FacilitySrf']['EnumeratedIndexValues']['ZI001_SRT']['AL011']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['FacilitySrf']['EnumeratedIndexValues']['ZI001_SRT']['AT045']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['FacilitySrf']['ZI002_UFI'] = ('StructuredText',('AG030','AG040','AL010','AL011','AT045'))
    field_information['GGDM 3.0']['FacilitySrf']['ZI004_RCG'] = ('Enumeration',('AG030','AG040','AL010','AL011','AT045'))
    field_information['GGDM 3.0']['FacilitySrf']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['FacilitySrf']['EnumeratedIndexValues']['ZI004_RCG']['AG030']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['FacilitySrf']['EnumeratedIndexValues']['ZI004_RCG']['AG040']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['FacilitySrf']['EnumeratedIndexValues']['ZI004_RCG']['AL010']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['FacilitySrf']['EnumeratedIndexValues']['ZI004_RCG']['AL011']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['FacilitySrf']['EnumeratedIndexValues']['ZI004_RCG']['AT045']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['FacilitySrf']['ZI005_FNA'] = ('String',('AG030','AG040','AL010','AL011','AT045'))
    field_information['GGDM 3.0']['FacilitySrf']['ZI005_FNA2'] = ('String',('AL010'))
    field_information['GGDM 3.0']['FacilitySrf']['ZI005_FNA3'] = ('String',('AL010'))
    field_information['GGDM 3.0']['FacilitySrf']['ZI005_GNT'] = ('Enumeration',('AG030','AG040','AL010','AL011','AT045'))
    field_information['GGDM 3.0']['FacilitySrf']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['FacilitySrf']['EnumeratedIndexValues']['ZI005_GNT']['AG030']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['FacilitySrf']['EnumeratedIndexValues']['ZI005_GNT']['AG040']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['FacilitySrf']['EnumeratedIndexValues']['ZI005_GNT']['AL010']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['FacilitySrf']['EnumeratedIndexValues']['ZI005_GNT']['AL011']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['FacilitySrf']['EnumeratedIndexValues']['ZI005_GNT']['AT045']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['FacilitySrf']['ZI005_GNT2'] = ('Enumeration',('AL010'))
    field_information['GGDM 3.0']['FacilitySrf']['EnumeratedIndexValues']['ZI005_GNT2'] = {}
    field_information['GGDM 3.0']['FacilitySrf']['EnumeratedIndexValues']['ZI005_GNT2']['AL010']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['FacilitySrf']['ZI005_GNT3'] = ('Enumeration',('AL010'))
    field_information['GGDM 3.0']['FacilitySrf']['EnumeratedIndexValues']['ZI005_GNT3'] = {}
    field_information['GGDM 3.0']['FacilitySrf']['EnumeratedIndexValues']['ZI005_GNT3']['AL010']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['FacilitySrf']['ZI005_NFN'] = ('String',('AG030','AG040','AL010','AL011','AT045'))
    field_information['GGDM 3.0']['FacilitySrf']['ZI005_NFN2'] = ('String',('AL010'))
    field_information['GGDM 3.0']['FacilitySrf']['ZI005_NFN3'] = ('String',('AL010'))
    field_information['GGDM 3.0']['FacilitySrf']['ZI006_MEM'] = ('String',('AG030','AG040','AL010','AL011','AT045'))
    field_information['GGDM 3.0']['FacilitySrf']['ZI014_PBY'] = ('Enumeration',('AG040','AL010'))
    field_information['GGDM 3.0']['FacilitySrf']['EnumeratedIndexValues']['ZI014_PBY'] = {}
    field_information['GGDM 3.0']['FacilitySrf']['EnumeratedIndexValues']['ZI014_PBY']['AG040']  = (-999999,1,2,6,7,8,12,13,15,89,999)
    field_information['GGDM 3.0']['FacilitySrf']['EnumeratedIndexValues']['ZI014_PBY']['AL010']  = (-999999,1,2,6,7,8,12,13,15,89,999)
    field_information['GGDM 3.0']['FacilitySrf']['ZI014_PBY2'] = ('Enumeration',('AG040','AL010'))
    field_information['GGDM 3.0']['FacilitySrf']['EnumeratedIndexValues']['ZI014_PBY2'] = {}
    field_information['GGDM 3.0']['FacilitySrf']['EnumeratedIndexValues']['ZI014_PBY2']['AG040']  = (-999999,1,2,6,7,8,12,13,15,89,999)
    field_information['GGDM 3.0']['FacilitySrf']['EnumeratedIndexValues']['ZI014_PBY2']['AL010']  = (-999999,1,2,6,7,8,12,13,15,89,999)
    field_information['GGDM 3.0']['FacilitySrf']['ZI014_PBY3'] = ('Enumeration',('AG040','AL010'))
    field_information['GGDM 3.0']['FacilitySrf']['EnumeratedIndexValues']['ZI014_PBY3'] = {}
    field_information['GGDM 3.0']['FacilitySrf']['EnumeratedIndexValues']['ZI014_PBY3']['AG040']  = (-999999,1,2,6,7,8,12,13,15,89,999)
    field_information['GGDM 3.0']['FacilitySrf']['EnumeratedIndexValues']['ZI014_PBY3']['AL010']  = (-999999,1,2,6,7,8,12,13,15,89,999)
    field_information['GGDM 3.0']['FacilitySrf']['ZI014_PPO'] = ('Enumeration',('AG040','AL010'))
    field_information['GGDM 3.0']['FacilitySrf']['EnumeratedIndexValues']['ZI014_PPO'] = {}
    field_information['GGDM 3.0']['FacilitySrf']['EnumeratedIndexValues']['ZI014_PPO']['AG040']  = (-999999,1,2,3,4,5,13,15,16,18,20,21,23,25,26,28,32,37,38,39,41,43,44,45,46,47,48,57,58,59,60,61,62,63,65,69,70,73,74,80,83,84,87,90,92,94,95,101,105,106,109,111,114,117,120,121,122,123,126,136,137,146,147,148,150,154,155,156,157,160,165,192,200,214,279,325,435,999)
    field_information['GGDM 3.0']['FacilitySrf']['EnumeratedIndexValues']['ZI014_PPO']['AL010']  = (-999999,1,2,3,4,5,13,15,16,18,20,21,23,25,26,28,32,37,38,39,41,43,44,45,46,47,48,57,58,59,60,61,62,63,65,69,70,73,74,80,83,84,87,90,92,94,95,101,105,106,109,111,114,117,120,121,122,123,126,136,137,146,147,148,150,154,155,156,157,160,165,192,200,214,279,325,435,999)
    field_information['GGDM 3.0']['FacilitySrf']['ZI014_PPO2'] = ('Enumeration',('AG040','AL010'))
    field_information['GGDM 3.0']['FacilitySrf']['EnumeratedIndexValues']['ZI014_PPO2'] = {}
    field_information['GGDM 3.0']['FacilitySrf']['EnumeratedIndexValues']['ZI014_PPO2']['AG040']  = (-999999,1,2,3,4,5,13,15,16,18,20,21,23,25,26,28,32,37,38,39,41,43,44,45,46,47,48,57,58,59,60,61,62,63,65,69,70,73,74,80,83,84,87,90,92,94,95,101,105,106,109,111,114,117,120,121,122,123,126,136,137,146,147,148,150,154,155,156,157,160,165,192,200,214,279,325,435,999)
    field_information['GGDM 3.0']['FacilitySrf']['EnumeratedIndexValues']['ZI014_PPO2']['AL010']  = (-999999,1,2,3,4,5,13,15,16,18,20,21,23,25,26,28,32,37,38,39,41,43,44,45,46,47,48,57,58,59,60,61,62,63,65,69,70,73,74,80,83,84,87,90,92,94,95,101,105,106,109,111,114,117,120,121,122,123,126,136,137,146,147,148,150,154,155,156,157,160,165,192,200,214,279,325,435,999)
    field_information['GGDM 3.0']['FacilitySrf']['ZI014_PPO3'] = ('Enumeration',('AG040','AL010'))
    field_information['GGDM 3.0']['FacilitySrf']['EnumeratedIndexValues']['ZI014_PPO3'] = {}
    field_information['GGDM 3.0']['FacilitySrf']['EnumeratedIndexValues']['ZI014_PPO3']['AG040']  = (-999999,1,2,3,4,5,13,15,16,18,20,21,23,25,26,28,32,37,38,39,41,43,44,45,46,47,48,57,58,59,60,61,62,63,65,69,70,73,74,80,83,84,87,90,92,94,95,101,105,106,109,111,114,117,120,121,122,123,126,136,137,146,147,148,150,154,155,156,157,160,165,192,200,214,279,325,435,999)
    field_information['GGDM 3.0']['FacilitySrf']['EnumeratedIndexValues']['ZI014_PPO3']['AL010']  = (-999999,1,2,3,4,5,13,15,16,18,20,21,23,25,26,28,32,37,38,39,41,43,44,45,46,47,48,57,58,59,60,61,62,63,65,69,70,73,74,80,83,84,87,90,92,94,95,101,105,106,109,111,114,117,120,121,122,123,126,136,137,146,147,148,150,154,155,156,157,160,165,192,200,214,279,325,435,999)
    field_information['GGDM 3.0']['FacilitySrf']['ZI014_PRW'] = ('Enumeration',('AG040','AL010'))
    field_information['GGDM 3.0']['FacilitySrf']['EnumeratedIndexValues']['ZI014_PRW'] = {}
    field_information['GGDM 3.0']['FacilitySrf']['EnumeratedIndexValues']['ZI014_PRW']['AG040']  = (-999999,1,2,5,9,10,11,12,14,16,18,27,28,29,30,33,38,39,41,45,46,48,50,52,54,57,60,64,66,68,70,75,78,79,83,84,85,87,90,93,94,96,97,99,118,119,999)
    field_information['GGDM 3.0']['FacilitySrf']['EnumeratedIndexValues']['ZI014_PRW']['AL010']  = (-999999,1,2,5,9,10,11,12,14,16,18,27,28,29,30,33,38,39,41,45,46,48,50,52,54,57,60,64,66,68,70,75,78,79,83,84,85,87,90,93,94,96,97,99,118,119,999)
    field_information['GGDM 3.0']['FacilitySrf']['ZI014_PRW2'] = ('Enumeration',('AG040','AL010'))
    field_information['GGDM 3.0']['FacilitySrf']['EnumeratedIndexValues']['ZI014_PRW2'] = {}
    field_information['GGDM 3.0']['FacilitySrf']['EnumeratedIndexValues']['ZI014_PRW2']['AG040']  = (-999999,1,2,5,9,10,11,12,14,16,18,27,28,29,30,33,38,39,41,45,46,48,50,52,54,57,60,64,66,68,70,75,78,79,83,84,85,87,90,93,94,96,97,99,118,119,999)
    field_information['GGDM 3.0']['FacilitySrf']['EnumeratedIndexValues']['ZI014_PRW2']['AL010']  = (-999999,1,2,5,9,10,11,12,14,16,18,27,28,29,30,33,38,39,41,45,46,48,50,52,54,57,60,64,66,68,70,75,78,79,83,84,85,87,90,93,94,96,97,99,118,119,999)
    field_information['GGDM 3.0']['FacilitySrf']['ZI014_PRW3'] = ('Enumeration',('AG040','AL010'))
    field_information['GGDM 3.0']['FacilitySrf']['EnumeratedIndexValues']['ZI014_PRW3'] = {}
    field_information['GGDM 3.0']['FacilitySrf']['EnumeratedIndexValues']['ZI014_PRW3']['AG040']  = (-999999,1,2,5,9,10,11,12,14,16,18,27,28,29,30,33,38,39,41,45,46,48,50,52,54,57,60,64,66,68,70,75,78,79,83,84,85,87,90,93,94,96,97,99,118,119,999)
    field_information['GGDM 3.0']['FacilitySrf']['EnumeratedIndexValues']['ZI014_PRW3']['AL010']  = (-999999,1,2,5,9,10,11,12,14,16,18,27,28,29,30,33,38,39,41,45,46,48,50,52,54,57,60,64,66,68,70,75,78,79,83,84,85,87,90,93,94,96,97,99,118,119,999)
    field_information['GGDM 3.0']['FacilitySrf']['ZI018_WIT'] = ('Enumeration',('AG040','AL010'))
    field_information['GGDM 3.0']['FacilitySrf']['EnumeratedIndexValues']['ZI018_WIT'] = {}
    field_information['GGDM 3.0']['FacilitySrf']['EnumeratedIndexValues']['ZI018_WIT']['AG040']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['FacilitySrf']['EnumeratedIndexValues']['ZI018_WIT']['AL010']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['FacilitySrf']['ZI020_GE4'] = ('CodeList',('AG030','AG040','AL010','AL011','AT045'))
    field_information['GGDM 3.0']['FacilitySrf']['ZI026_CTUC'] = ('Enumeration',('AG030','AG040','AL010','AL011','AT045'))
    field_information['GGDM 3.0']['FacilitySrf']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['FacilitySrf']['EnumeratedIndexValues']['ZI026_CTUC']['AG030']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['FacilitySrf']['EnumeratedIndexValues']['ZI026_CTUC']['AG040']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['FacilitySrf']['EnumeratedIndexValues']['ZI026_CTUC']['AL010']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['FacilitySrf']['EnumeratedIndexValues']['ZI026_CTUC']['AL011']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['FacilitySrf']['EnumeratedIndexValues']['ZI026_CTUC']['AT045']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['FacilitySrf']['ZI026_CTUL'] = ('integer',('AG030','AG040','AL010','AL011','AT045'))
    field_information['GGDM 3.0']['FacilitySrf']['ZI026_CTUU'] = ('integer',('AG030','AG040','AL010','AL011','AT045'))
    field_information['GGDM 3.0']['FacilitySrf']['ZI031S_URI'] = ('StructuredText',('AG030','AG040','AL010','AL011','AT045'))
    field_information['GGDM 3.0']['FacilitySrf']['ZI037_REL'] = ('Enumeration',('AG040','AL010'))
    field_information['GGDM 3.0']['FacilitySrf']['EnumeratedIndexValues']['ZI037_REL'] = {}
    field_information['GGDM 3.0']['FacilitySrf']['EnumeratedIndexValues']['ZI037_REL']['AG040']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,999)
    field_information['GGDM 3.0']['FacilitySrf']['EnumeratedIndexValues']['ZI037_REL']['AL010']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,999)
    field_information['GGDM 3.0']['FacilitySrf']['ZI037_RFA'] = ('Enumeration',('AG040','AL010'))
    field_information['GGDM 3.0']['FacilitySrf']['EnumeratedIndexValues']['ZI037_RFA'] = {}
    field_information['GGDM 3.0']['FacilitySrf']['EnumeratedIndexValues']['ZI037_RFA']['AG040']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,18,19,20,21,22,23,25,999)
    field_information['GGDM 3.0']['FacilitySrf']['EnumeratedIndexValues']['ZI037_RFA']['AL010']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,18,19,20,21,22,23,25,999)
    field_information['GGDM 3.0']['FacilitySrf']['ZI039S_UFI'] = ('StructuredText',('AG030','AG040','AL010','AL011','AT045'))
    field_information['GGDM 3.0']['FacilitySrf']['ZSAX_RS0'] = ('CodeList',('AG030','AG040','AL010','AL011','AT045'))
    field_information['GGDM 3.0']['FacilitySrf']['ZSAX_RX0'] = ('StructuredText',('AG030','AG040','AL010','AL011','AT045'))
    field_information['GGDM 3.0']['FacilitySrf']['ZSAX_RX3'] = ('StructuredText',('AG030','AG040','AL010','AL011','AT045'))
    field_information['GGDM 3.0']['FacilitySrf']['ZSAX_RX4'] = ('StructuredText',('AG030','AG040','AL010','AL011','AT045'))
    field_information['GGDM 3.0']['FacilitySrf']['ZVH'] = ('Real',('AG030','AG040','AL010','AT045'))
    field_information['GGDM 3.0']['HydroAidNavigationCrvExt']['BEN'] = ('StructuredText',('FC130'))
    field_information['GGDM 3.0']['HydroAidNavigationCrvExt']['BRR'] = ('StructuredText',('FC130'))
    field_information['GGDM 3.0']['HydroAidNavigationCrvExt']['F_CODE'] = ('CONSTRAINED_STRING',('FC130'))
    field_information['GGDM 3.0']['HydroAidNavigationCrvExt']['FUFI'] = ('StructuredText',('FC130'))
    field_information['GGDM 3.0']['HydroAidNavigationCrvExt']['FURL'] = ('StructuredText',('FC130'))
    field_information['GGDM 3.0']['HydroAidNavigationCrvExt']['GDBV'] = ('Enumeration',('FC130'))
    field_information['GGDM 3.0']['HydroAidNavigationCrvExt']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['HydroAidNavigationCrvExt']['EnumeratedIndexValues']['GDBV']['FC130']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['HydroAidNavigationCrvExt']['OTH'] = ('StructuredText',('FC130'))
    field_information['GGDM 3.0']['HydroAidNavigationCrvExt']['UFI'] = ('StructuredText',('FC130'))
    field_information['GGDM 3.0']['HydroAidNavigationCrvExt']['ZI001_SDV'] = ('StructuredText',('FC130'))
    field_information['GGDM 3.0']['HydroAidNavigationCrvExt']['ZI001_SRT'] = ('Enumeration',('FC130'))
    field_information['GGDM 3.0']['HydroAidNavigationCrvExt']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['HydroAidNavigationCrvExt']['EnumeratedIndexValues']['ZI001_SRT']['FC130']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['HydroAidNavigationCrvExt']['ZI002_UFI'] = ('StructuredText',('FC130'))
    field_information['GGDM 3.0']['HydroAidNavigationCrvExt']['ZI004_RCG'] = ('Enumeration',('FC130'))
    field_information['GGDM 3.0']['HydroAidNavigationCrvExt']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['HydroAidNavigationCrvExt']['EnumeratedIndexValues']['ZI004_RCG']['FC130']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['HydroAidNavigationCrvExt']['ZI005_FNA'] = ('String',('FC130'))
    field_information['GGDM 3.0']['HydroAidNavigationCrvExt']['ZI005_GNT'] = ('Enumeration',('FC130'))
    field_information['GGDM 3.0']['HydroAidNavigationCrvExt']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['HydroAidNavigationCrvExt']['EnumeratedIndexValues']['ZI005_GNT']['FC130']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['HydroAidNavigationCrvExt']['ZI005_NFN'] = ('String',('FC130'))
    field_information['GGDM 3.0']['HydroAidNavigationCrvExt']['ZI006_MEM'] = ('String',('FC130'))
    field_information['GGDM 3.0']['HydroAidNavigationCrvExt']['ZI020_GE4'] = ('CodeList',('FC130'))
    field_information['GGDM 3.0']['HydroAidNavigationCrvExt']['ZI026_CTUC'] = ('Enumeration',('FC130'))
    field_information['GGDM 3.0']['HydroAidNavigationCrvExt']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['HydroAidNavigationCrvExt']['EnumeratedIndexValues']['ZI026_CTUC']['FC130']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['HydroAidNavigationCrvExt']['ZI026_CTUL'] = ('integer',('FC130'))
    field_information['GGDM 3.0']['HydroAidNavigationCrvExt']['ZI026_CTUU'] = ('integer',('FC130'))
    field_information['GGDM 3.0']['HydroAidNavigationCrvExt']['ZI031S_URI'] = ('StructuredText',('FC130'))
    field_information['GGDM 3.0']['HydroAidNavigationCrvExt']['ZI039S_UFI'] = ('StructuredText',('FC130'))
    field_information['GGDM 3.0']['HydroAidNavigationCrvExt']['ZSAX_RS0'] = ('CodeList',('FC130'))
    field_information['GGDM 3.0']['HydroAidNavigationCrvExt']['ZSAX_RX0'] = ('StructuredText',('FC130'))
    field_information['GGDM 3.0']['HydroAidNavigationCrvExt']['ZSAX_RX3'] = ('StructuredText',('FC130'))
    field_information['GGDM 3.0']['HydroAidNavigationCrvExt']['ZSAX_RX4'] = ('StructuredText',('FC130'))
    field_information['GGDM 3.0']['HydroAidNavigationPnt']['ADR'] = ('String',('BC050'))
    field_information['GGDM 3.0']['HydroAidNavigationPnt']['AOO'] = ('Real',('BC050','BC070'))
    field_information['GGDM 3.0']['HydroAidNavigationPnt']['ARA'] = ('Real',('BC050','BC070'))
    field_information['GGDM 3.0']['HydroAidNavigationPnt']['ATB'] = ('Boolean',('BC050'))
    field_information['GGDM 3.0']['HydroAidNavigationPnt']['AWP'] = ('Boolean',('BC050','BC070'))
    field_information['GGDM 3.0']['HydroAidNavigationPnt']['BC034_BRF'] = ('Integer',('BC070'))
    field_information['GGDM 3.0']['HydroAidNavigationPnt']['BC034_BRF2'] = ('Integer',('BC070'))
    field_information['GGDM 3.0']['HydroAidNavigationPnt']['BC034_MRT'] = ('Enumeration',('BC070'))
    field_information['GGDM 3.0']['HydroAidNavigationPnt']['EnumeratedIndexValues']['BC034_MRT'] = {}
    field_information['GGDM 3.0']['HydroAidNavigationPnt']['EnumeratedIndexValues']['BC034_MRT']['BC070']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['HydroAidNavigationPnt']['BC034_MRT2'] = ('Enumeration',('BC070'))
    field_information['GGDM 3.0']['HydroAidNavigationPnt']['EnumeratedIndexValues']['BC034_MRT2'] = {}
    field_information['GGDM 3.0']['HydroAidNavigationPnt']['EnumeratedIndexValues']['BC034_MRT2']['BC070']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['HydroAidNavigationPnt']['BC034_MRT3'] = ('Enumeration',('BC070'))
    field_information['GGDM 3.0']['HydroAidNavigationPnt']['EnumeratedIndexValues']['BC034_MRT3'] = {}
    field_information['GGDM 3.0']['HydroAidNavigationPnt']['EnumeratedIndexValues']['BC034_MRT3']['BC070']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['HydroAidNavigationPnt']['BC040_COL'] = ('StructuredText',('BC070'))
    field_information['GGDM 3.0']['HydroAidNavigationPnt']['BC040_EOL'] = ('Real',('BC070'))
    field_information['GGDM 3.0']['HydroAidNavigationPnt']['BC040_LCN'] = ('Integer',('BC050'))
    field_information['GGDM 3.0']['HydroAidNavigationPnt']['BC040_LVN'] = ('Integer',('BC070'))
    field_information['GGDM 3.0']['HydroAidNavigationPnt']['BC040_MLR'] = ('StructuredText',('BC070'))
    field_information['GGDM 3.0']['HydroAidNavigationPnt']['BC040_PER'] = ('Real',('BC050'))
    field_information['GGDM 3.0']['HydroAidNavigationPnt']['BC101_SST'] = ('Enumeration',('BC070'))
    field_information['GGDM 3.0']['HydroAidNavigationPnt']['EnumeratedIndexValues']['BC101_SST'] = {}
    field_information['GGDM 3.0']['HydroAidNavigationPnt']['EnumeratedIndexValues']['BC101_SST']['BC070']  = (-999999,1,2,3,4,6,7,8,9,10,14,15,16,98,999)
    field_information['GGDM 3.0']['HydroAidNavigationPnt']['BEN'] = ('StructuredText',('BC050','BC070'))
    field_information['GGDM 3.0']['HydroAidNavigationPnt']['CAA'] = ('Enumeration',('BC050','BC070'))
    field_information['GGDM 3.0']['HydroAidNavigationPnt']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['HydroAidNavigationPnt']['EnumeratedIndexValues']['CAA']['BC050']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['HydroAidNavigationPnt']['EnumeratedIndexValues']['CAA']['BC070']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['HydroAidNavigationPnt']['CNCP'] = ('StructuredText',('BC050','BC070'))
    field_information['GGDM 3.0']['HydroAidNavigationPnt']['COS'] = ('Enumeration',('BC050','BC070'))
    field_information['GGDM 3.0']['HydroAidNavigationPnt']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['HydroAidNavigationPnt']['EnumeratedIndexValues']['COS']['BC050']  = (-999999,4,6,8,9,13,14)
    field_information['GGDM 3.0']['HydroAidNavigationPnt']['EnumeratedIndexValues']['COS']['BC070']  = (-999999,2,4,6,9,13,14)
    field_information['GGDM 3.0']['HydroAidNavigationPnt']['F_CODE'] = ('CONSTRAINED_STRING',('BC050','BC070'))
    field_information['GGDM 3.0']['HydroAidNavigationPnt']['FFN'] = ('Enumeration',('BC050'))
    field_information['GGDM 3.0']['HydroAidNavigationPnt']['EnumeratedIndexValues']['FFN'] = {}
    field_information['GGDM 3.0']['HydroAidNavigationPnt']['EnumeratedIndexValues']['FFN']['BC050']  = (-999999,486,505,507,511,512,846,881,905,923,999)
    field_information['GGDM 3.0']['HydroAidNavigationPnt']['FFN2'] = ('Enumeration',('BC050'))
    field_information['GGDM 3.0']['HydroAidNavigationPnt']['EnumeratedIndexValues']['FFN2'] = {}
    field_information['GGDM 3.0']['HydroAidNavigationPnt']['EnumeratedIndexValues']['FFN2']['BC050']  = (-999999,486,505,507,511,512,846,881,905,923,999)
    field_information['GGDM 3.0']['HydroAidNavigationPnt']['FFN3'] = ('Enumeration',('BC050'))
    field_information['GGDM 3.0']['HydroAidNavigationPnt']['EnumeratedIndexValues']['FFN3'] = {}
    field_information['GGDM 3.0']['HydroAidNavigationPnt']['EnumeratedIndexValues']['FFN3']['BC050']  = (-999999,486,505,507,511,512,846,881,905,923,999)
    field_information['GGDM 3.0']['HydroAidNavigationPnt']['FUFI'] = ('StructuredText',('BC050','BC070'))
    field_information['GGDM 3.0']['HydroAidNavigationPnt']['FURL'] = ('StructuredText',('BC050','BC070'))
    field_information['GGDM 3.0']['HydroAidNavigationPnt']['GDBV'] = ('Enumeration',('BC050','BC070'))
    field_information['GGDM 3.0']['HydroAidNavigationPnt']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['HydroAidNavigationPnt']['EnumeratedIndexValues']['GDBV']['BC050']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['HydroAidNavigationPnt']['EnumeratedIndexValues']['GDBV']['BC070']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['HydroAidNavigationPnt']['HGT'] = ('Real',('BC050','BC070'))
    field_information['GGDM 3.0']['HydroAidNavigationPnt']['LMC'] = ('Boolean',('BC050','BC070'))
    field_information['GGDM 3.0']['HydroAidNavigationPnt']['LZN'] = ('Real',('BC050','BC070'))
    field_information['GGDM 3.0']['HydroAidNavigationPnt']['MAN'] = ('Boolean',('BC050'))
    field_information['GGDM 3.0']['HydroAidNavigationPnt']['OTH'] = ('StructuredText',('BC050','BC070'))
    field_information['GGDM 3.0']['HydroAidNavigationPnt']['PCF'] = ('Enumeration',('BC050','BC070'))
    field_information['GGDM 3.0']['HydroAidNavigationPnt']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['HydroAidNavigationPnt']['EnumeratedIndexValues']['PCF']['BC050']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['HydroAidNavigationPnt']['EnumeratedIndexValues']['PCF']['BC070']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['HydroAidNavigationPnt']['REF'] = ('Boolean',('BC070'))
    field_information['GGDM 3.0']['HydroAidNavigationPnt']['SSR'] = ('Enumeration',('BC050'))
    field_information['GGDM 3.0']['HydroAidNavigationPnt']['EnumeratedIndexValues']['SSR'] = {}
    field_information['GGDM 3.0']['HydroAidNavigationPnt']['EnumeratedIndexValues']['SSR']['BC050']  = (-999999,6,7,40,41,42,999)
    field_information['GGDM 3.0']['HydroAidNavigationPnt']['SSR2'] = ('Enumeration',('BC050'))
    field_information['GGDM 3.0']['HydroAidNavigationPnt']['EnumeratedIndexValues']['SSR2'] = {}
    field_information['GGDM 3.0']['HydroAidNavigationPnt']['EnumeratedIndexValues']['SSR2']['BC050']  = (-999999,6,7,40,41,42,999)
    field_information['GGDM 3.0']['HydroAidNavigationPnt']['SSR3'] = ('Enumeration',('BC050'))
    field_information['GGDM 3.0']['HydroAidNavigationPnt']['EnumeratedIndexValues']['SSR3'] = {}
    field_information['GGDM 3.0']['HydroAidNavigationPnt']['EnumeratedIndexValues']['SSR3']['BC050']  = (-999999,6,7,40,41,42,999)
    field_information['GGDM 3.0']['HydroAidNavigationPnt']['UFI'] = ('StructuredText',('BC050','BC070'))
    field_information['GGDM 3.0']['HydroAidNavigationPnt']['VCM'] = ('Enumeration',('BC050'))
    field_information['GGDM 3.0']['HydroAidNavigationPnt']['EnumeratedIndexValues']['VCM'] = {}
    field_information['GGDM 3.0']['HydroAidNavigationPnt']['EnumeratedIndexValues']['VCM']['BC050']  = (-999999,3,4,6,7,8,9,12,13,15,16,999)
    field_information['GGDM 3.0']['HydroAidNavigationPnt']['VCM2'] = ('Enumeration',('BC050'))
    field_information['GGDM 3.0']['HydroAidNavigationPnt']['EnumeratedIndexValues']['VCM2'] = {}
    field_information['GGDM 3.0']['HydroAidNavigationPnt']['EnumeratedIndexValues']['VCM2']['BC050']  = (-999999,3,4,6,7,8,9,12,13,15,16,999)
    field_information['GGDM 3.0']['HydroAidNavigationPnt']['VCM3'] = ('Enumeration',('BC050'))
    field_information['GGDM 3.0']['HydroAidNavigationPnt']['EnumeratedIndexValues']['VCM3'] = {}
    field_information['GGDM 3.0']['HydroAidNavigationPnt']['EnumeratedIndexValues']['VCM3']['BC050']  = (-999999,3,4,6,7,8,9,12,13,15,16,999)
    field_information['GGDM 3.0']['HydroAidNavigationPnt']['VOI'] = ('StructuredText',('BC050','BC070'))
    field_information['GGDM 3.0']['HydroAidNavigationPnt']['WID'] = ('Real',('BC050','BC070'))
    field_information['GGDM 3.0']['HydroAidNavigationPnt']['ZI001_SDV'] = ('StructuredText',('BC050','BC070'))
    field_information['GGDM 3.0']['HydroAidNavigationPnt']['ZI001_SRT'] = ('Enumeration',('BC050','BC070'))
    field_information['GGDM 3.0']['HydroAidNavigationPnt']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['HydroAidNavigationPnt']['EnumeratedIndexValues']['ZI001_SRT']['BC050']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['HydroAidNavigationPnt']['EnumeratedIndexValues']['ZI001_SRT']['BC070']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['HydroAidNavigationPnt']['ZI002_UFI'] = ('StructuredText',('BC050','BC070'))
    field_information['GGDM 3.0']['HydroAidNavigationPnt']['ZI004_RCG'] = ('Enumeration',('BC050','BC070'))
    field_information['GGDM 3.0']['HydroAidNavigationPnt']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['HydroAidNavigationPnt']['EnumeratedIndexValues']['ZI004_RCG']['BC050']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['HydroAidNavigationPnt']['EnumeratedIndexValues']['ZI004_RCG']['BC070']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['HydroAidNavigationPnt']['ZI005_FNA'] = ('String',('BC050','BC070'))
    field_information['GGDM 3.0']['HydroAidNavigationPnt']['ZI005_GNT'] = ('Enumeration',('BC050','BC070'))
    field_information['GGDM 3.0']['HydroAidNavigationPnt']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['HydroAidNavigationPnt']['EnumeratedIndexValues']['ZI005_GNT']['BC050']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['HydroAidNavigationPnt']['EnumeratedIndexValues']['ZI005_GNT']['BC070']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['HydroAidNavigationPnt']['ZI005_NFN'] = ('String',('BC050','BC070'))
    field_information['GGDM 3.0']['HydroAidNavigationPnt']['ZI006_MEM'] = ('String',('BC050','BC070'))
    field_information['GGDM 3.0']['HydroAidNavigationPnt']['ZI020_GE4'] = ('CodeList',('BC050','BC070'))
    field_information['GGDM 3.0']['HydroAidNavigationPnt']['ZI026_CTUC'] = ('Enumeration',('BC050','BC070'))
    field_information['GGDM 3.0']['HydroAidNavigationPnt']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['HydroAidNavigationPnt']['EnumeratedIndexValues']['ZI026_CTUC']['BC050']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['HydroAidNavigationPnt']['EnumeratedIndexValues']['ZI026_CTUC']['BC070']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['HydroAidNavigationPnt']['ZI026_CTUL'] = ('integer',('BC050','BC070'))
    field_information['GGDM 3.0']['HydroAidNavigationPnt']['ZI026_CTUU'] = ('integer',('BC050','BC070'))
    field_information['GGDM 3.0']['HydroAidNavigationPnt']['ZI031S_URI'] = ('StructuredText',('BC050','BC070'))
    field_information['GGDM 3.0']['HydroAidNavigationPnt']['ZI039S_UFI'] = ('StructuredText',('BC050','BC070'))
    field_information['GGDM 3.0']['HydroAidNavigationPnt']['ZSAX_RS0'] = ('CodeList',('BC050','BC070'))
    field_information['GGDM 3.0']['HydroAidNavigationPnt']['ZSAX_RX0'] = ('StructuredText',('BC050','BC070'))
    field_information['GGDM 3.0']['HydroAidNavigationPnt']['ZSAX_RX3'] = ('StructuredText',('BC050','BC070'))
    field_information['GGDM 3.0']['HydroAidNavigationPnt']['ZSAX_RX4'] = ('StructuredText',('BC050','BC070'))
    field_information['GGDM 3.0']['HydroAidNavigationPnt']['ZVH'] = ('Real',('BC050','BC070'))
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['ARA'] = ('Real',('BB155','BC041'))
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['BC010_REF'] = ('Boolean',('BC034','BC040'))
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['BC010_TZP'] = ('Enumeration',('BC034','BC040'))
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['EnumeratedIndexValues']['BC010_TZP'] = {}
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['EnumeratedIndexValues']['BC010_TZP']['BC034']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,998,999)
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['EnumeratedIndexValues']['BC010_TZP']['BC040']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,998,999)
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['BC034_BRF'] = ('Integer',('BC020','BC041'))
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['BC034_BRF2'] = ('Integer',('BC020','BC041'))
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['BC034_MRT'] = ('Enumeration',('BC020','BC041'))
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['EnumeratedIndexValues']['BC034_MRT'] = {}
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['EnumeratedIndexValues']['BC034_MRT']['BC020']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['EnumeratedIndexValues']['BC034_MRT']['BC041']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['BC034_MRT2'] = ('Enumeration',('BC020','BC041'))
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['EnumeratedIndexValues']['BC034_MRT2'] = {}
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['EnumeratedIndexValues']['BC034_MRT2']['BC020']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['EnumeratedIndexValues']['BC034_MRT2']['BC041']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['BC034_MRT3'] = ('Enumeration',('BC020','BC041'))
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['EnumeratedIndexValues']['BC034_MRT3'] = {}
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['EnumeratedIndexValues']['BC034_MRT3']['BC020']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['EnumeratedIndexValues']['BC034_MRT3']['BC041']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['BC040_CAA'] = ('Enumeration',('BC060'))
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['EnumeratedIndexValues']['BC040_CAA'] = {}
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['EnumeratedIndexValues']['BC040_CAA']['BC060']  = (-999999,3,5,7,16,999)
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['BC040_COL'] = ('StructuredText',('BC010','BC020','BC041'))
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['BC040_EOL'] = ('Real',('BC020'))
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['BC040_LVN'] = ('Integer',('BC020'))
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['BC040_MLR'] = ('StructuredText',('BC010','BC020','BC041'))
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['BC040_ZVH'] = ('Real',('BC060'))
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['BC101_SST'] = ('Enumeration',('BC010','BC020','BC041'))
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['EnumeratedIndexValues']['BC101_SST'] = {}
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['EnumeratedIndexValues']['BC101_SST']['BC010']  = (-999999,1,2,3,4,6,7,8,9,10,14,15,16,98,998,999)
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['EnumeratedIndexValues']['BC101_SST']['BC020']  = (-999999,1,2,3,4,6,7,8,9,10,14,15,16,98,998,999)
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['EnumeratedIndexValues']['BC101_SST']['BC041']  = (-999999,1,2,3,4,6,7,8,9,10,14,15,16,98,998,999)
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['BEN'] = ('StructuredText',('BB155','BC010','BC020','BC034','BC040','BC041','BC055','BC060','BC080'))
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['BET'] = ('Enumeration',('BC080'))
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['EnumeratedIndexValues']['BET'] = {}
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['EnumeratedIndexValues']['BET']['BC080']  = (-999999,7,11,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,39,44,45,46,47,48,49,50,51,52,53,54,55,56,57,58,59,60,61,62,63,64,65,66,67,68,69,70,71,72,73,74,75,76,77,78,79,80,81,86,87,91,92,93,94,95,96,97,98,101,102,103,111,113,114,115,116,117,118,119,122,123,998,999)
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['BRF'] = ('Integer',('BC034'))
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['BRF2'] = ('Integer',('BC034'))
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['BUS'] = ('Enumeration',('BC020'))
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['EnumeratedIndexValues']['BUS'] = {}
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['EnumeratedIndexValues']['BUS']['BC020']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['BUT'] = ('Enumeration',('BC020'))
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['EnumeratedIndexValues']['BUT'] = {}
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['EnumeratedIndexValues']['BUT']['BC020']  = (-999999,3,4,6,7,10,11,15,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,39,81,82,84,85,86,87,88,89,91,92,93,94,95,96,97,98,99,100,101,102,103,104,105,106,107,108,109,110,111,112,113,114,115,116,117,118,119,120,121,122,123,124,125,126,127,128,129,130,131,132,133,134,135,136,137,138,139,140,141,142,143,144,145,149,150,999)
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['CAA'] = ('Enumeration',('BB155','BC041'))
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['EnumeratedIndexValues']['CAA']['BB155']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['EnumeratedIndexValues']['CAA']['BC041']  = (-999999,3,5,16,999)
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['CCR'] = ('String',('BC041'))
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['CNCP'] = ('StructuredText',('BB155','BC010','BC020','BC034','BC040','BC041'))
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['COC'] = ('Enumeration',('BC041'))
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['EnumeratedIndexValues']['COC'] = {}
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['EnumeratedIndexValues']['COC']['BC041']  = (-999999,1,2,3,4)
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['COL'] = ('StructuredText',('BC040','BC060'))
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['COS'] = ('Enumeration',('BB155','BC010','BC020','BC034','BC040','BC041'))
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['EnumeratedIndexValues']['COS']['BB155']  = (-999999,3,4,6,9,13,14)
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['EnumeratedIndexValues']['COS']['BC010']  = (-999999,2,4,6,9,13,14)
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['EnumeratedIndexValues']['COS']['BC020']  = (-999999,2,4,6,9,13,14)
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['EnumeratedIndexValues']['COS']['BC034']  = (-999999,2,4,6,9,13,14)
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['EnumeratedIndexValues']['COS']['BC040']  = (-999999,2,3,4,6,9,13,14)
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['EnumeratedIndexValues']['COS']['BC041']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['CPT'] = ('Enumeration',('BC041'))
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['EnumeratedIndexValues']['CPT'] = {}
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['EnumeratedIndexValues']['CPT']['BC041']  = (-999999,1,2,3,4,5,6,7)
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['CSS'] = ('Enumeration',('BC020'))
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['EnumeratedIndexValues']['CSS'] = {}
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['EnumeratedIndexValues']['CSS']['BC020']  = (-999999,1,4,5,6,999)
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['DKS'] = ('Enumeration',('BC041'))
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['EnumeratedIndexValues']['DKS'] = {}
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['EnumeratedIndexValues']['DKS']['BC041']  = (-999999,1,2,3,4,5,6,7)
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['EOL'] = ('Real',('BC040'))
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['F_CODE'] = ('CONSTRAINED_STRING',('BB155','BC010','BC020','BC034','BC040','BC041','BC055','BC060','BC080'))
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['FLT'] = ('Boolean',('BC041'))
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['FUFI'] = ('StructuredText',('BB155','BC010','BC020','BC034','BC040','BC041','BC055','BC060','BC080'))
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['FURL'] = ('StructuredText',('BB155','BC010','BC020','BC034','BC040','BC041','BC055','BC060','BC080'))
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['GDBV'] = ('Enumeration',('BB155','BC010','BC020','BC034','BC040','BC041','BC055','BC060','BC080'))
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['EnumeratedIndexValues']['GDBV']['BB155']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['EnumeratedIndexValues']['GDBV']['BC010']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['EnumeratedIndexValues']['GDBV']['BC020']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['EnumeratedIndexValues']['GDBV']['BC034']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['EnumeratedIndexValues']['GDBV']['BC040']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['EnumeratedIndexValues']['GDBV']['BC041']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['EnumeratedIndexValues']['GDBV']['BC055']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['EnumeratedIndexValues']['GDBV']['BC060']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['EnumeratedIndexValues']['GDBV']['BC080']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['GUG'] = ('Boolean',('BC041'))
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['HBH'] = ('Real',('BC080'))
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['HGT'] = ('Real',('BB155','BC041','BC080'))
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['IAA'] = ('Boolean',('BC040','BC041'))
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['IAS'] = ('Boolean',('BC041'))
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['LFC'] = ('Enumeration',('BC040'))
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['EnumeratedIndexValues']['LFC'] = {}
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['EnumeratedIndexValues']['LFC']['BC040']  = (-999999,1,4,6,7,8,9,10,11,12,13,14,16,17,18,19,20,21,22,25,999)
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['LFC2'] = ('Enumeration',('BC040'))
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['EnumeratedIndexValues']['LFC2'] = {}
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['EnumeratedIndexValues']['LFC2']['BC040']  = (-999999,1,4,6,7,8,9,10,11,12,13,14,16,17,18,19,20,21,22,25,999)
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['LFC3'] = ('Enumeration',('BC040'))
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['EnumeratedIndexValues']['LFC3'] = {}
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['EnumeratedIndexValues']['LFC3']['BC040']  = (-999999,1,4,6,7,8,9,10,11,12,13,14,16,17,18,19,20,21,22,25,999)
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['LMC'] = ('Boolean',('BB155'))
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['LOC'] = ('Enumeration',('BC041'))
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['EnumeratedIndexValues']['LOC'] = {}
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['EnumeratedIndexValues']['LOC']['BC041']  = (-999999,44,45)
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['LSA'] = ('Integer',('BC060'))
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['LSI'] = ('Integer',('BC060'))
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['LST'] = ('Integer',('BC060'))
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['LVN'] = ('Integer',('BC040','BC060'))
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['LZN'] = ('Real',('BB155','BC041','BC055'))
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['MCC'] = ('Enumeration',('BC041','BC055','BC080'))
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['EnumeratedIndexValues']['MCC'] = {}
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['EnumeratedIndexValues']['MCC']['BC041']  = (-999999,21,64,74,117,152,999)
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['EnumeratedIndexValues']['MCC']['BC055']  = (-999999,64,74,117,999)
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['EnumeratedIndexValues']['MCC']['BC080']  = (-999999,64,74,117,999)
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['MCC2'] = ('Enumeration',('BC055','BC080'))
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['EnumeratedIndexValues']['MCC2'] = {}
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['EnumeratedIndexValues']['MCC2']['BC055']  = (-999999,64,74,117,999)
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['EnumeratedIndexValues']['MCC2']['BC080']  = (-999999,64,74,117,999)
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['MCC3'] = ('Enumeration',('BC055','BC080'))
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['EnumeratedIndexValues']['MCC3'] = {}
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['EnumeratedIndexValues']['MCC3']['BC055']  = (-999999,64,74,117,999)
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['EnumeratedIndexValues']['MCC3']['BC080']  = (-999999,64,74,117,999)
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['MLR'] = ('StructuredText',('BC040'))
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['MRP'] = ('Boolean',('BC041'))
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['MRT'] = ('Enumeration',('BC034'))
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['EnumeratedIndexValues']['MRT'] = {}
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['EnumeratedIndexValues']['MRT']['BC034']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['NMC'] = ('Enumeration',('BC010','BC020','BC040'))
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['EnumeratedIndexValues']['NMC'] = {}
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['EnumeratedIndexValues']['NMC']['BC010']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,999)
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['EnumeratedIndexValues']['NMC']['BC020']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,999)
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['EnumeratedIndexValues']['NMC']['BC040']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,999)
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['NMC2'] = ('Enumeration',('BC010','BC020','BC040'))
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['EnumeratedIndexValues']['NMC2'] = {}
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['EnumeratedIndexValues']['NMC2']['BC010']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,999)
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['EnumeratedIndexValues']['NMC2']['BC020']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,999)
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['EnumeratedIndexValues']['NMC2']['BC040']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,999)
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['NMC3'] = ('Enumeration',('BC010','BC020','BC040'))
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['EnumeratedIndexValues']['NMC3'] = {}
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['EnumeratedIndexValues']['NMC3']['BC010']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,999)
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['EnumeratedIndexValues']['NMC3']['BC020']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,999)
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['EnumeratedIndexValues']['NMC3']['BC040']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,999)
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['NSC'] = ('Enumeration',('BC041'))
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['EnumeratedIndexValues']['NSC'] = {}
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['EnumeratedIndexValues']['NSC']['BC041']  = (-999999,2,3,6,7,8,9,10)
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['ORC'] = ('Real',('BC034'))
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['OTH'] = ('StructuredText',('BB155','BC010','BC020','BC034','BC040','BC041','BC055','BC060','BC080'))
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['PCF'] = ('Enumeration',('BB155','BC010','BC020','BC034','BC040','BC041','BC055','BC080'))
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['EnumeratedIndexValues']['PCF']['BB155']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['EnumeratedIndexValues']['PCF']['BC010']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['EnumeratedIndexValues']['PCF']['BC020']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['EnumeratedIndexValues']['PCF']['BC034']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['EnumeratedIndexValues']['PCF']['BC040']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['EnumeratedIndexValues']['PCF']['BC041']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['EnumeratedIndexValues']['PCF']['BC055']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['EnumeratedIndexValues']['PCF']['BC080']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['PRM'] = ('Boolean',('BC041'))
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['REF'] = ('Boolean',('BC010','BC020','BC041'))
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['SPT'] = ('Boolean',('BC041'))
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['SRL'] = ('Enumeration',('BC041'))
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['EnumeratedIndexValues']['SRL'] = {}
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['EnumeratedIndexValues']['SRL']['BC041']  = (-999999,1,2,3)
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['STA'] = ('Enumeration',('BB155'))
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['EnumeratedIndexValues']['STA'] = {}
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['EnumeratedIndexValues']['STA']['BB155']  = (-999999,1,2,3,4,5,6,11,13,14,15,17,18,19,20,21,22,27,28,29,30,32,33,35,36,37,48,49,50,51,52,53,54,55,56,57,58,59,60,999)
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['STA2'] = ('Enumeration',('BB155'))
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['EnumeratedIndexValues']['STA2'] = {}
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['EnumeratedIndexValues']['STA2']['BB155']  = (-999999,1,2,3,4,5,6,11,13,14,15,17,18,19,20,21,22,27,28,29,30,32,33,35,36,37,48,49,50,51,52,53,54,55,56,57,58,59,60,999)
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['STA3'] = ('Enumeration',('BB155'))
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['EnumeratedIndexValues']['STA3'] = {}
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['EnumeratedIndexValues']['STA3']['BB155']  = (-999999,1,2,3,4,5,6,11,13,14,15,17,18,19,20,21,22,27,28,29,30,32,33,35,36,37,48,49,50,51,52,53,54,55,56,57,58,59,60,999)
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['TOS'] = ('Enumeration',('BC041'))
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['EnumeratedIndexValues']['TOS'] = {}
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['EnumeratedIndexValues']['TOS']['BC041']  = (-999999,6,8,999)
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['TZP'] = ('Enumeration',('BC010','BC020','BC041','BC080'))
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['EnumeratedIndexValues']['TZP'] = {}
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['EnumeratedIndexValues']['TZP']['BC010']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,998,999)
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['EnumeratedIndexValues']['TZP']['BC020']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,998,999)
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['EnumeratedIndexValues']['TZP']['BC041']  = (-999999,1,2,3,4,5,7,8,10,11,12,13,14,15,16,19,28,33,34,35,36,37,999)
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['EnumeratedIndexValues']['TZP']['BC080']  = (-999999,1,5,15,16,33,34,35,36,37,999)
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['UFI'] = ('StructuredText',('BB155','BC010','BC020','BC034','BC040','BC041','BC055','BC060','BC080'))
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['VOI'] = ('StructuredText',('BC040'))
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['WID'] = ('Real',('BB155','BC041'))
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['ZHBH_DCR'] = ('Boolean',('BC080'))
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['ZHBH_DKC'] = ('Enumeration',('BC080'))
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['EnumeratedIndexValues']['ZHBH_DKC'] = {}
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['EnumeratedIndexValues']['ZHBH_DKC']['BC080']  = (-999999,1,3,4,5,6,7,8,9,10,11,12,998,999)
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['ZHBH_DKC2'] = ('Enumeration',('BC080'))
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['EnumeratedIndexValues']['ZHBH_DKC2'] = {}
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['EnumeratedIndexValues']['ZHBH_DKC2']['BC080']  = (-999999,1,3,4,5,6,7,8,9,10,11,12,998,999)
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['ZHBH_DKC3'] = ('Enumeration',('BC080'))
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['EnumeratedIndexValues']['ZHBH_DKC3'] = {}
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['EnumeratedIndexValues']['ZHBH_DKC3']['BC080']  = (-999999,1,3,4,5,6,7,8,9,10,11,12,998,999)
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['ZHBH_SVC'] = ('Enumeration',('BC080'))
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['EnumeratedIndexValues']['ZHBH_SVC'] = {}
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['EnumeratedIndexValues']['ZHBH_SVC']['BC080']  = (-999999,1,2,3,4,5,998,999)
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['ZHBH_TEC'] = ('Enumeration',('BC080'))
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['EnumeratedIndexValues']['ZHBH_TEC'] = {}
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['EnumeratedIndexValues']['ZHBH_TEC']['BC080']  = (-999999,1,2,3,4,5,6,8,9,10,11,12,13,14,15,17,18,999)
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['ZHBH_TEC2'] = ('Enumeration',('BC080'))
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['EnumeratedIndexValues']['ZHBH_TEC2'] = {}
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['EnumeratedIndexValues']['ZHBH_TEC2']['BC080']  = (-999999,1,2,3,4,5,6,8,9,10,11,12,13,14,15,17,18,999)
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['ZHBH_TEC3'] = ('Enumeration',('BC080'))
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['EnumeratedIndexValues']['ZHBH_TEC3'] = {}
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['EnumeratedIndexValues']['ZHBH_TEC3']['BC080']  = (-999999,1,2,3,4,5,6,8,9,10,11,12,13,14,15,17,18,999)
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['ZHBH_VDC'] = ('Enumeration',('BC080'))
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['EnumeratedIndexValues']['ZHBH_VDC'] = {}
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['EnumeratedIndexValues']['ZHBH_VDC']['BC080']  = (-999999,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,24,28,30,90,91,92,93,94,95,96,97,98,99,100,101,102,103,104,105,107,999)
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['ZHBH_VDR'] = ('String',('BC080'))
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['ZI001_SDV'] = ('StructuredText',('BB155','BC010','BC020','BC034','BC040','BC041','BC055','BC060','BC080'))
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['ZI001_SRT'] = ('Enumeration',('BB155','BC010','BC020','BC034','BC040','BC041','BC055','BC060','BC080'))
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['EnumeratedIndexValues']['ZI001_SRT']['BB155']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['EnumeratedIndexValues']['ZI001_SRT']['BC010']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['EnumeratedIndexValues']['ZI001_SRT']['BC020']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['EnumeratedIndexValues']['ZI001_SRT']['BC034']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['EnumeratedIndexValues']['ZI001_SRT']['BC040']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['EnumeratedIndexValues']['ZI001_SRT']['BC041']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['EnumeratedIndexValues']['ZI001_SRT']['BC055']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['EnumeratedIndexValues']['ZI001_SRT']['BC060']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['EnumeratedIndexValues']['ZI001_SRT']['BC080']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['ZI002_UFI'] = ('StructuredText',('BB155','BC010','BC020','BC034','BC040','BC041','BC055','BC060','BC080'))
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['ZI004_RCG'] = ('Enumeration',('BB155','BC010','BC020','BC034','BC040','BC041','BC055','BC060','BC080'))
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['EnumeratedIndexValues']['ZI004_RCG']['BB155']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['EnumeratedIndexValues']['ZI004_RCG']['BC010']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['EnumeratedIndexValues']['ZI004_RCG']['BC020']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['EnumeratedIndexValues']['ZI004_RCG']['BC034']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['EnumeratedIndexValues']['ZI004_RCG']['BC040']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['EnumeratedIndexValues']['ZI004_RCG']['BC041']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['EnumeratedIndexValues']['ZI004_RCG']['BC055']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['EnumeratedIndexValues']['ZI004_RCG']['BC060']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['EnumeratedIndexValues']['ZI004_RCG']['BC080']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['ZI005_FNA'] = ('String',('BB155','BC010','BC020','BC034','BC040','BC055','BC080'))
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['ZI005_GNT'] = ('Enumeration',('BB155','BC010','BC020','BC034','BC040','BC055','BC080'))
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['EnumeratedIndexValues']['ZI005_GNT']['BB155']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['EnumeratedIndexValues']['ZI005_GNT']['BC010']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['EnumeratedIndexValues']['ZI005_GNT']['BC020']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['EnumeratedIndexValues']['ZI005_GNT']['BC034']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['EnumeratedIndexValues']['ZI005_GNT']['BC040']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['EnumeratedIndexValues']['ZI005_GNT']['BC055']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['EnumeratedIndexValues']['ZI005_GNT']['BC080']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['ZI005_NFN'] = ('String',('BB155','BC010','BC020','BC034','BC040','BC055','BC080'))
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['ZI006_MEM'] = ('String',('BB155','BC010','BC020','BC034','BC040','BC041','BC055','BC060','BC080'))
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['ZI018_BRF'] = ('Integer',('BB155'))
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['ZI018_WIT'] = ('Enumeration',('BB155'))
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['EnumeratedIndexValues']['ZI018_WIT'] = {}
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['EnumeratedIndexValues']['ZI018_WIT']['BB155']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['ZI020_GE4'] = ('CodeList',('BB155','BC010','BC020','BC034','BC040','BC041','BC055','BC060','BC080'))
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['ZI026_CTUC'] = ('Enumeration',('BB155','BC010','BC020','BC034','BC040','BC041','BC055','BC060','BC080'))
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['EnumeratedIndexValues']['ZI026_CTUC']['BB155']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['EnumeratedIndexValues']['ZI026_CTUC']['BC010']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['EnumeratedIndexValues']['ZI026_CTUC']['BC020']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['EnumeratedIndexValues']['ZI026_CTUC']['BC034']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['EnumeratedIndexValues']['ZI026_CTUC']['BC040']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['EnumeratedIndexValues']['ZI026_CTUC']['BC041']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['EnumeratedIndexValues']['ZI026_CTUC']['BC055']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['EnumeratedIndexValues']['ZI026_CTUC']['BC060']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['EnumeratedIndexValues']['ZI026_CTUC']['BC080']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['ZI026_CTUL'] = ('integer',('BB155','BC010','BC020','BC034','BC040','BC041','BC055','BC060','BC080'))
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['ZI026_CTUU'] = ('integer',('BB155','BC010','BC020','BC034','BC040','BC041','BC055','BC060','BC080'))
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['ZI031S_URI'] = ('StructuredText',('BB155','BC010','BC020','BC034','BC040','BC041','BC055','BC060','BC080'))
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['ZI039S_UFI'] = ('StructuredText',('BB155','BC010','BC020','BC034','BC040','BC041','BC055','BC060','BC080'))
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['ZSAX_RS0'] = ('CodeList',('BB155','BC010','BC020','BC034','BC040','BC041','BC055','BC060','BC080'))
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['ZSAX_RX0'] = ('StructuredText',('BB155','BC010','BC020','BC034','BC040','BC041','BC055','BC060','BC080'))
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['ZSAX_RX3'] = ('StructuredText',('BB155','BC010','BC020','BC034','BC040','BC041','BC055','BC060','BC080'))
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['ZSAX_RX4'] = ('StructuredText',('BB155','BC010','BC020','BC034','BC040','BC041','BC055','BC060','BC080'))
    field_information['GGDM 3.0']['HydroAidNavigationPntExt']['ZVH'] = ('Real',('BC041','BC080'))
    field_information['GGDM 3.0']['HydroAidNavigationSrf']['ADR'] = ('String',('BC050'))
    field_information['GGDM 3.0']['HydroAidNavigationSrf']['AOO'] = ('Real',('BC050'))
    field_information['GGDM 3.0']['HydroAidNavigationSrf']['ARA'] = ('Real',('BC050'))
    field_information['GGDM 3.0']['HydroAidNavigationSrf']['ATB'] = ('Boolean',('BC050'))
    field_information['GGDM 3.0']['HydroAidNavigationSrf']['AWP'] = ('Boolean',('BC050'))
    field_information['GGDM 3.0']['HydroAidNavigationSrf']['BC040_LCN'] = ('Integer',('BC050'))
    field_information['GGDM 3.0']['HydroAidNavigationSrf']['BC040_PER'] = ('Real',('BC050'))
    field_information['GGDM 3.0']['HydroAidNavigationSrf']['BEN'] = ('StructuredText',('BC050'))
    field_information['GGDM 3.0']['HydroAidNavigationSrf']['CAA'] = ('Enumeration',('BC050'))
    field_information['GGDM 3.0']['HydroAidNavigationSrf']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['HydroAidNavigationSrf']['EnumeratedIndexValues']['CAA']['BC050']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['HydroAidNavigationSrf']['CNCP'] = ('StructuredText',('BC050'))
    field_information['GGDM 3.0']['HydroAidNavigationSrf']['COS'] = ('Enumeration',('BC050'))
    field_information['GGDM 3.0']['HydroAidNavigationSrf']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['HydroAidNavigationSrf']['EnumeratedIndexValues']['COS']['BC050']  = (-999999,4,6,8,9,13,14)
    field_information['GGDM 3.0']['HydroAidNavigationSrf']['F_CODE'] = ('CONSTRAINED_STRING',('BC050'))
    field_information['GGDM 3.0']['HydroAidNavigationSrf']['FFN'] = ('Enumeration',('BC050'))
    field_information['GGDM 3.0']['HydroAidNavigationSrf']['EnumeratedIndexValues']['FFN'] = {}
    field_information['GGDM 3.0']['HydroAidNavigationSrf']['EnumeratedIndexValues']['FFN']['BC050']  = (-999999,486,505,507,511,512,846,881,905,923,999)
    field_information['GGDM 3.0']['HydroAidNavigationSrf']['FFN2'] = ('Enumeration',('BC050'))
    field_information['GGDM 3.0']['HydroAidNavigationSrf']['EnumeratedIndexValues']['FFN2'] = {}
    field_information['GGDM 3.0']['HydroAidNavigationSrf']['EnumeratedIndexValues']['FFN2']['BC050']  = (-999999,486,505,507,511,512,846,881,905,923,999)
    field_information['GGDM 3.0']['HydroAidNavigationSrf']['FFN3'] = ('Enumeration',('BC050'))
    field_information['GGDM 3.0']['HydroAidNavigationSrf']['EnumeratedIndexValues']['FFN3'] = {}
    field_information['GGDM 3.0']['HydroAidNavigationSrf']['EnumeratedIndexValues']['FFN3']['BC050']  = (-999999,486,505,507,511,512,846,881,905,923,999)
    field_information['GGDM 3.0']['HydroAidNavigationSrf']['FUFI'] = ('StructuredText',('BC050'))
    field_information['GGDM 3.0']['HydroAidNavigationSrf']['FURL'] = ('StructuredText',('BC050'))
    field_information['GGDM 3.0']['HydroAidNavigationSrf']['GDBV'] = ('Enumeration',('BC050'))
    field_information['GGDM 3.0']['HydroAidNavigationSrf']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['HydroAidNavigationSrf']['EnumeratedIndexValues']['GDBV']['BC050']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['HydroAidNavigationSrf']['HGT'] = ('Real',('BC050'))
    field_information['GGDM 3.0']['HydroAidNavigationSrf']['LMC'] = ('Boolean',('BC050'))
    field_information['GGDM 3.0']['HydroAidNavigationSrf']['LZN'] = ('Real',('BC050'))
    field_information['GGDM 3.0']['HydroAidNavigationSrf']['MAN'] = ('Boolean',('BC050'))
    field_information['GGDM 3.0']['HydroAidNavigationSrf']['OTH'] = ('StructuredText',('BC050'))
    field_information['GGDM 3.0']['HydroAidNavigationSrf']['PCF'] = ('Enumeration',('BC050'))
    field_information['GGDM 3.0']['HydroAidNavigationSrf']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['HydroAidNavigationSrf']['EnumeratedIndexValues']['PCF']['BC050']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['HydroAidNavigationSrf']['SSR'] = ('Enumeration',('BC050'))
    field_information['GGDM 3.0']['HydroAidNavigationSrf']['EnumeratedIndexValues']['SSR'] = {}
    field_information['GGDM 3.0']['HydroAidNavigationSrf']['EnumeratedIndexValues']['SSR']['BC050']  = (-999999,6,7,40,41,42,999)
    field_information['GGDM 3.0']['HydroAidNavigationSrf']['SSR2'] = ('Enumeration',('BC050'))
    field_information['GGDM 3.0']['HydroAidNavigationSrf']['EnumeratedIndexValues']['SSR2'] = {}
    field_information['GGDM 3.0']['HydroAidNavigationSrf']['EnumeratedIndexValues']['SSR2']['BC050']  = (-999999,6,7,40,41,42,999)
    field_information['GGDM 3.0']['HydroAidNavigationSrf']['SSR3'] = ('Enumeration',('BC050'))
    field_information['GGDM 3.0']['HydroAidNavigationSrf']['EnumeratedIndexValues']['SSR3'] = {}
    field_information['GGDM 3.0']['HydroAidNavigationSrf']['EnumeratedIndexValues']['SSR3']['BC050']  = (-999999,6,7,40,41,42,999)
    field_information['GGDM 3.0']['HydroAidNavigationSrf']['UFI'] = ('StructuredText',('BC050'))
    field_information['GGDM 3.0']['HydroAidNavigationSrf']['VCM'] = ('Enumeration',('BC050'))
    field_information['GGDM 3.0']['HydroAidNavigationSrf']['EnumeratedIndexValues']['VCM'] = {}
    field_information['GGDM 3.0']['HydroAidNavigationSrf']['EnumeratedIndexValues']['VCM']['BC050']  = (-999999,3,4,6,7,8,9,12,13,15,16,999)
    field_information['GGDM 3.0']['HydroAidNavigationSrf']['VCM2'] = ('Enumeration',('BC050'))
    field_information['GGDM 3.0']['HydroAidNavigationSrf']['EnumeratedIndexValues']['VCM2'] = {}
    field_information['GGDM 3.0']['HydroAidNavigationSrf']['EnumeratedIndexValues']['VCM2']['BC050']  = (-999999,3,4,6,7,8,9,12,13,15,16,999)
    field_information['GGDM 3.0']['HydroAidNavigationSrf']['VCM3'] = ('Enumeration',('BC050'))
    field_information['GGDM 3.0']['HydroAidNavigationSrf']['EnumeratedIndexValues']['VCM3'] = {}
    field_information['GGDM 3.0']['HydroAidNavigationSrf']['EnumeratedIndexValues']['VCM3']['BC050']  = (-999999,3,4,6,7,8,9,12,13,15,16,999)
    field_information['GGDM 3.0']['HydroAidNavigationSrf']['VOI'] = ('StructuredText',('BC050'))
    field_information['GGDM 3.0']['HydroAidNavigationSrf']['WID'] = ('Real',('BC050'))
    field_information['GGDM 3.0']['HydroAidNavigationSrf']['ZI001_SDV'] = ('StructuredText',('BC050'))
    field_information['GGDM 3.0']['HydroAidNavigationSrf']['ZI001_SRT'] = ('Enumeration',('BC050'))
    field_information['GGDM 3.0']['HydroAidNavigationSrf']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['HydroAidNavigationSrf']['EnumeratedIndexValues']['ZI001_SRT']['BC050']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['HydroAidNavigationSrf']['ZI002_UFI'] = ('StructuredText',('BC050'))
    field_information['GGDM 3.0']['HydroAidNavigationSrf']['ZI004_RCG'] = ('Enumeration',('BC050'))
    field_information['GGDM 3.0']['HydroAidNavigationSrf']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['HydroAidNavigationSrf']['EnumeratedIndexValues']['ZI004_RCG']['BC050']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['HydroAidNavigationSrf']['ZI005_FNA'] = ('String',('BC050'))
    field_information['GGDM 3.0']['HydroAidNavigationSrf']['ZI005_GNT'] = ('Enumeration',('BC050'))
    field_information['GGDM 3.0']['HydroAidNavigationSrf']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['HydroAidNavigationSrf']['EnumeratedIndexValues']['ZI005_GNT']['BC050']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['HydroAidNavigationSrf']['ZI005_NFN'] = ('String',('BC050'))
    field_information['GGDM 3.0']['HydroAidNavigationSrf']['ZI006_MEM'] = ('String',('BC050'))
    field_information['GGDM 3.0']['HydroAidNavigationSrf']['ZI020_GE4'] = ('CodeList',('BC050'))
    field_information['GGDM 3.0']['HydroAidNavigationSrf']['ZI026_CTUC'] = ('Enumeration',('BC050'))
    field_information['GGDM 3.0']['HydroAidNavigationSrf']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['HydroAidNavigationSrf']['EnumeratedIndexValues']['ZI026_CTUC']['BC050']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['HydroAidNavigationSrf']['ZI026_CTUL'] = ('integer',('BC050'))
    field_information['GGDM 3.0']['HydroAidNavigationSrf']['ZI026_CTUU'] = ('integer',('BC050'))
    field_information['GGDM 3.0']['HydroAidNavigationSrf']['ZI031S_URI'] = ('StructuredText',('BC050'))
    field_information['GGDM 3.0']['HydroAidNavigationSrf']['ZI039S_UFI'] = ('StructuredText',('BC050'))
    field_information['GGDM 3.0']['HydroAidNavigationSrf']['ZSAX_RS0'] = ('CodeList',('BC050'))
    field_information['GGDM 3.0']['HydroAidNavigationSrf']['ZSAX_RX0'] = ('StructuredText',('BC050'))
    field_information['GGDM 3.0']['HydroAidNavigationSrf']['ZSAX_RX3'] = ('StructuredText',('BC050'))
    field_information['GGDM 3.0']['HydroAidNavigationSrf']['ZSAX_RX4'] = ('StructuredText',('BC050'))
    field_information['GGDM 3.0']['HydroAidNavigationSrf']['ZVH'] = ('Real',('BC050'))
    field_information['GGDM 3.0']['HydrographyAONExt']['AQN'] = ('String',('NM170','NM230'))
    field_information['GGDM 3.0']['HydrographyAONExt']['ARA'] = ('Real',('NM010','NM030','NM082','NM140','NM170','NM230','NU010'))
    field_information['GGDM 3.0']['HydrographyAONExt']['ATC'] = ('Enumeration',('NM010'))
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['ATC'] = {}
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['ATC']['NM010']  = (-999999,3,4,5,6)
    field_information['GGDM 3.0']['HydrographyAONExt']['AZC'] = ('Boolean',('NM082'))
    field_information['GGDM 3.0']['HydrographyAONExt']['BBMCA'] = ('Enumeration',('NM140'))
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['BBMCA'] = {}
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['BBMCA']['NM140']  = (-999999,1,2,3,4,5,6,7,8,9,11,14,15,16,17,18,999)
    field_information['GGDM 3.0']['HydrographyAONExt']['BBMCA2'] = ('Enumeration',('NM140'))
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['BBMCA2'] = {}
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['BBMCA2']['NM140']  = (-999999,1,2,3,4,5,6,7,8,9,11,14,15,16,17,18,999)
    field_information['GGDM 3.0']['HydrographyAONExt']['BBMCA3'] = ('Enumeration',('NM140'))
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['BBMCA3'] = {}
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['BBMCA3']['NM140']  = (-999999,1,2,3,4,5,6,7,8,9,11,14,15,16,17,18,999)
    field_information['GGDM 3.0']['HydrographyAONExt']['BBMCB'] = ('Enumeration',('NM140'))
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['BBMCB'] = {}
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['BBMCB']['NM140']  = (-999999,1,2,3,4,5,6,7,8,9,11,14,15,16,17,18,999)
    field_information['GGDM 3.0']['HydrographyAONExt']['BBMCB2'] = ('Enumeration',('NM140'))
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['BBMCB2'] = {}
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['BBMCB2']['NM140']  = (-999999,1,2,3,4,5,6,7,8,9,11,14,15,16,17,18,999)
    field_information['GGDM 3.0']['HydrographyAONExt']['BBMCB3'] = ('Enumeration',('NM140'))
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['BBMCB3'] = {}
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['BBMCB3']['NM140']  = (-999999,1,2,3,4,5,6,7,8,9,11,14,15,16,17,18,999)
    field_information['GGDM 3.0']['HydrographyAONExt']['BEN'] = ('StructuredText',('NM010','NM030','NM082','NM140','NM170','NM230','NU010'))
    field_information['GGDM 3.0']['HydrographyAONExt']['BH141_AWBA'] = ('Real',('NM030','NM082','NM140'))
    field_information['GGDM 3.0']['HydrographyAONExt']['BH141_AWBB'] = ('Real',('NM030','NM082','NM140'))
    field_information['GGDM 3.0']['HydrographyAONExt']['BH141_IBOA'] = ('Enumeration',('NM140'))
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['BH141_IBOA'] = {}
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['BH141_IBOA']['NM140']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['HydrographyAONExt']['BH141_IBOB'] = ('Enumeration',('NM140'))
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['BH141_IBOB'] = {}
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['BH141_IBOB']['NM140']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['HydrographyAONExt']['BH141_SHDA'] = ('Boolean',('NM030','NM082','NM140'))
    field_information['GGDM 3.0']['HydrographyAONExt']['BH141_SHDB'] = ('Boolean',('NM030','NM082','NM140'))
    field_information['GGDM 3.0']['HydrographyAONExt']['BH141_SLTA'] = ('Enumeration',('NM030','NM082','NM140'))
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['BH141_SLTA'] = {}
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['BH141_SLTA']['NM030']  = (-999999,6,8,10,11,12,13,14,16,17,18,999)
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['BH141_SLTA']['NM082']  = (-999999,6,8,10,11,12,13,14,17,18,999)
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['BH141_SLTA']['NM140']  = (-999999,6,8,10,11,12,13,14,16,17,18,999)
    field_information['GGDM 3.0']['HydrographyAONExt']['BH141_SLTB'] = ('Enumeration',('NM030','NM082','NM140'))
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['BH141_SLTB'] = {}
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['BH141_SLTB']['NM030']  = (-999999,6,8,10,11,12,13,14,17,18,999)
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['BH141_SLTB']['NM082']  = (-999999,6,8,10,11,12,13,14,16,17,18,999)
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['BH141_SLTB']['NM140']  = (-999999,6,8,10,11,12,13,14,17,18,999)
    field_information['GGDM 3.0']['HydrographyAONExt']['BH141_WBHA'] = ('Real',('NM030','NM082','NM140'))
    field_information['GGDM 3.0']['HydrographyAONExt']['BH141_WBHB'] = ('Real',('NM140'))
    field_information['GGDM 3.0']['HydrographyAONExt']['BMC'] = ('Enumeration',('NM140'))
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['BMC'] = {}
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['BMC']['NM140']  = (-999999,1,2,3,4,5,6,7,9,14,15,18,999)
    field_information['GGDM 3.0']['HydrographyAONExt']['BMC2'] = ('Enumeration',('NM140'))
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['BMC2'] = {}
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['BMC2']['NM140']  = (-999999,1,2,3,4,5,6,7,9,14,15,18,999)
    field_information['GGDM 3.0']['HydrographyAONExt']['BMC3'] = ('Enumeration',('NM140'))
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['BMC3'] = {}
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['BMC3']['NM140']  = (-999999,1,2,3,4,5,6,7,9,14,15,18,999)
    field_information['GGDM 3.0']['HydrographyAONExt']['BPWHAC'] = ('Enumeration',('NM030','NM082','NM140'))
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['BPWHAC'] = {}
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['BPWHAC']['NM030']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['BPWHAC']['NM082']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['BPWHAC']['NM140']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['HydrographyAONExt']['BPWHAL'] = ('real',('NM030','NM082','NM140'))
    field_information['GGDM 3.0']['HydrographyAONExt']['BPWHAU'] = ('real',('NM030','NM082','NM140'))
    field_information['GGDM 3.0']['HydrographyAONExt']['BPWHBC'] = ('Enumeration',('NM030','NM082','NM140'))
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['BPWHBC'] = {}
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['BPWHBC']['NM030']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['BPWHBC']['NM082']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['BPWHBC']['NM140']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['HydrographyAONExt']['BPWHBL'] = ('real',('NM030','NM082','NM140'))
    field_information['GGDM 3.0']['HydrographyAONExt']['BPWHBU'] = ('real',('NM030','NM082','NM140'))
    field_information['GGDM 3.0']['HydrographyAONExt']['BPWSAC'] = ('Enumeration',('NM140'))
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['BPWSAC'] = {}
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['BPWSAC']['NM140']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['HydrographyAONExt']['BPWSAL'] = ('real',('NM140'))
    field_information['GGDM 3.0']['HydrographyAONExt']['BPWSAU'] = ('real',('NM140'))
    field_information['GGDM 3.0']['HydrographyAONExt']['BPWSBC'] = ('Enumeration',('NM140'))
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['BPWSBC'] = {}
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['BPWSBC']['NM140']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['HydrographyAONExt']['BPWSBL'] = ('real',('NM140'))
    field_information['GGDM 3.0']['HydrographyAONExt']['BPWSBU'] = ('real',('NM140'))
    field_information['GGDM 3.0']['HydrographyAONExt']['BWVCAC'] = ('Enumeration',('NM010','NM030','NM082','NM140'))
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['BWVCAC'] = {}
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['BWVCAC']['NM010']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['BWVCAC']['NM030']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['BWVCAC']['NM082']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['BWVCAC']['NM140']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['HydrographyAONExt']['BWVCAL'] = ('real',('NM010','NM030','NM082','NM140'))
    field_information['GGDM 3.0']['HydrographyAONExt']['BWVCAU'] = ('real',('NM010','NM030','NM082','NM140'))
    field_information['GGDM 3.0']['HydrographyAONExt']['BWVCBC'] = ('Enumeration',('NM010','NM030','NM082','NM140'))
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['BWVCBC'] = {}
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['BWVCBC']['NM010']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['BWVCBC']['NM030']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['BWVCBC']['NM082']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['BWVCBC']['NM140']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['HydrographyAONExt']['BWVCBL'] = ('real',('NM010','NM030','NM082','NM140'))
    field_information['GGDM 3.0']['HydrographyAONExt']['BWVCBU'] = ('real',('NM010','NM030','NM082','NM140'))
    field_information['GGDM 3.0']['HydrographyAONExt']['CAA'] = ('Enumeration',('NM010','NM030','NM082','NM140','NM170','NM230','NU010'))
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['CAA']['NM010']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['CAA']['NM030']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['CAA']['NM082']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['CAA']['NM140']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['CAA']['NM170']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['CAA']['NM230']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['CAA']['NU010']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['HydrographyAONExt']['CDA'] = ('Boolean',('NM010','NM030','NM140'))
    field_information['GGDM 3.0']['HydrographyAONExt']['CDL'] = ('Real',('NM010','NM140'))
    field_information['GGDM 3.0']['HydrographyAONExt']['CNCP'] = ('StructuredText',('NM010','NM030','NM082','NM170','NM230','NU010'))
    field_information['GGDM 3.0']['HydrographyAONExt']['COS'] = ('Enumeration',('NM010','NM030','NM082','NM170','NM230','NU010'))
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['COS']['NM010']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['COS']['NM030']  = (-999999,2,4,6,9,13,14)
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['COS']['NM082']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['COS']['NM170']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['COS']['NM230']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['COS']['NU010']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['HydrographyAONExt']['CWT'] = ('Boolean',('NM010'))
    field_information['GGDM 3.0']['HydrographyAONExt']['DEV'] = ('Integer',('NM010'))
    field_information['GGDM 3.0']['HydrographyAONExt']['DIT'] = ('Enumeration',('NM030'))
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['DIT'] = {}
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['DIT']['NM030']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['HydrographyAONExt']['DMD'] = ('Boolean',('NM082'))
    field_information['GGDM 3.0']['HydrographyAONExt']['DMF'] = ('Integer',('NM010','NM030','NM082','NM140','NM170','NM230','NU010'))
    field_information['GGDM 3.0']['HydrographyAONExt']['DOF'] = ('Real',('NM170'))
    field_information['GGDM 3.0']['HydrographyAONExt']['DOXY'] = ('Real',('NM010','NM030','NM082','NM140'))
    field_information['GGDM 3.0']['HydrographyAONExt']['DZP'] = ('Real',('NM030','NM082','NM140','NM170'))
    field_information['GGDM 3.0']['HydrographyAONExt']['F_CODE'] = ('CONSTRAINED_STRING',('NM010','NM030','NM082','NM140','NM170','NM230','NU010'))
    field_information['GGDM 3.0']['HydrographyAONExt']['FFN'] = ('Enumeration',('NM082'))
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['FFN'] = {}
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['FFN']['NM082']  = (-999999,30,35,351,361,440,488,505,921,955,999)
    field_information['GGDM 3.0']['HydrographyAONExt']['FFN2'] = ('Enumeration',('NM082'))
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['FFN2'] = {}
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['FFN2']['NM082']  = (-999999,30,35,351,361,440,488,505,921,955,999)
    field_information['GGDM 3.0']['HydrographyAONExt']['FFN3'] = ('Enumeration',('NM082'))
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['FFN3'] = {}
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['FFN3']['NM082']  = (-999999,30,35,351,361,440,488,505,921,955,999)
    field_information['GGDM 3.0']['HydrographyAONExt']['FRZ'] = ('Boolean',('NM010','NM030','NM082','NM140'))
    field_information['GGDM 3.0']['HydrographyAONExt']['FUFI'] = ('StructuredText',('NM010','NM030','NM082','NM140','NM170','NM230','NU010'))
    field_information['GGDM 3.0']['HydrographyAONExt']['FURL'] = ('StructuredText',('NM010','NM030','NM082','NM140','NM170','NM230','NU010'))
    field_information['GGDM 3.0']['HydrographyAONExt']['GDBV'] = ('Enumeration',('NM010','NM030','NM082','NM140','NM170','NM230','NU010'))
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['GDBV']['NM010']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['GDBV']['NM030']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['GDBV']['NM082']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['GDBV']['NM140']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['GDBV']['NM170']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['GDBV']['NM230']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['GDBV']['NU010']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['HydrographyAONExt']['HGT'] = ('Real',('NU010'))
    field_information['GGDM 3.0']['HydrographyAONExt']['IWT'] = ('Enumeration',('NM082'))
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['IWT'] = {}
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['IWT']['NM082']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['HydrographyAONExt']['LMC'] = ('Boolean',('NM010','NM030','NM082','NM230','NU010'))
    field_information['GGDM 3.0']['HydrographyAONExt']['LOC'] = ('Enumeration',('NM140'))
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['LOC'] = {}
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['LOC']['NM140']  = (-999999,40,44)
    field_information['GGDM 3.0']['HydrographyAONExt']['LUN'] = ('Boolean',('NM170','NU010'))
    field_information['GGDM 3.0']['HydrographyAONExt']['LZN'] = ('Real',('NM140','NU010'))
    field_information['GGDM 3.0']['HydrographyAONExt']['MNS'] = ('Boolean',('NM082'))
    field_information['GGDM 3.0']['HydrographyAONExt']['MWD'] = ('Real',('NM010'))
    field_information['GGDM 3.0']['HydrographyAONExt']['NVS'] = ('Enumeration',('NM140'))
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['NVS'] = {}
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['NVS']['NM140']  = (-999999,1,2,3,4,5,999)
    field_information['GGDM 3.0']['HydrographyAONExt']['OTH'] = ('StructuredText',('NM010','NM030','NM082','NM140','NM170','NM230','NU010'))
    field_information['GGDM 3.0']['HydrographyAONExt']['PCF'] = ('Enumeration',('NM010','NM030','NM082','NM170','NM230','NU010'))
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['PCF']['NM010']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['PCF']['NM030']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['PCF']['NM082']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['PCF']['NM170']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['PCF']['NM230']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['PCF']['NU010']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['HydrographyAONExt']['PMPR'] = ('Boolean',('NU010'))
    field_information['GGDM 3.0']['HydrographyAONExt']['PWA'] = ('Real',('NM140'))
    field_information['GGDM 3.0']['HydrographyAONExt']['PWAC'] = ('Enumeration',('NM010','NM030','NM082'))
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['PWAC'] = {}
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['PWAC']['NM010']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['PWAC']['NM030']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['PWAC']['NM082']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['HydrographyAONExt']['PWAL'] = ('real',('NM010','NM030','NM082'))
    field_information['GGDM 3.0']['HydrographyAONExt']['PWAU'] = ('real',('NM010','NM030','NM082'))
    field_information['GGDM 3.0']['HydrographyAONExt']['RLE'] = ('Enumeration',('NM010'))
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['RLE'] = {}
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['RLE']['NM010']  = (-999999,1,2,3,998)
    field_information['GGDM 3.0']['HydrographyAONExt']['SBB'] = ('Boolean',('NM010'))
    field_information['GGDM 3.0']['HydrographyAONExt']['SWT'] = ('Enumeration',('NM170'))
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['SWT'] = {}
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['SWT']['NM170']  = (-999999,4,6,7,999)
    field_information['GGDM 3.0']['HydrographyAONExt']['SWW'] = ('Real',('NM230'))
    field_information['GGDM 3.0']['HydrographyAONExt']['TID'] = ('Boolean',('NM082','NM140'))
    field_information['GGDM 3.0']['HydrographyAONExt']['TSSM'] = ('Enumeration',('NM230'))
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['TSSM'] = {}
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['TSSM']['NM230']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,999)
    field_information['GGDM 3.0']['HydrographyAONExt']['TSSM2'] = ('Enumeration',('NM230'))
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['TSSM2'] = {}
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['TSSM2']['NM230']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,999)
    field_information['GGDM 3.0']['HydrographyAONExt']['TSSM3'] = ('Enumeration',('NM230'))
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['TSSM3'] = {}
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['TSSM3']['NM230']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,999)
    field_information['GGDM 3.0']['HydrographyAONExt']['UFI'] = ('StructuredText',('NM010','NM030','NM082','NM140','NM170','NM230','NU010'))
    field_information['GGDM 3.0']['HydrographyAONExt']['VCM'] = ('Enumeration',('NU010'))
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['VCM'] = {}
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['VCM']['NU010']  = (-999999,3,4,7,8,9,12,13,15,16,999)
    field_information['GGDM 3.0']['HydrographyAONExt']['VCM2'] = ('Enumeration',('NU010'))
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['VCM2'] = {}
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['VCM2']['NU010']  = (-999999,3,4,7,8,9,12,13,15,16,999)
    field_information['GGDM 3.0']['HydrographyAONExt']['VCM3'] = ('Enumeration',('NU010'))
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['VCM3'] = {}
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['VCM3']['NU010']  = (-999999,3,4,7,8,9,12,13,15,16,999)
    field_information['GGDM 3.0']['HydrographyAONExt']['VLM'] = ('Real',('NM082','NM170','NU010'))
    field_information['GGDM 3.0']['HydrographyAONExt']['WAD'] = ('String',('NM230'))
    field_information['GGDM 3.0']['HydrographyAONExt']['WCC'] = ('Enumeration',('NM140'))
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['WCC'] = {}
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['WCC']['NM140']  = (-999999,1,2,3,4,7,999)
    field_information['GGDM 3.0']['HydrographyAONExt']['WD3'] = ('Real',('NM140'))
    field_information['GGDM 3.0']['HydrographyAONExt']['WDAC'] = ('Enumeration',('NM010','NM082','NM140'))
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['WDAC'] = {}
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['WDAC']['NM010']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['WDAC']['NM082']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['WDAC']['NM140']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['HydrographyAONExt']['WDAL'] = ('real',('NM010','NM082','NM140'))
    field_information['GGDM 3.0']['HydrographyAONExt']['WDAU'] = ('real',('NM010','NM082','NM140'))
    field_information['GGDM 3.0']['HydrographyAONExt']['WDH'] = ('Real',('NM082','NM140'))
    field_information['GGDM 3.0']['HydrographyAONExt']['WDL'] = ('Real',('NM082','NM140'))
    field_information['GGDM 3.0']['HydrographyAONExt']['WDST'] = ('Enumeration',('NM230','NU010'))
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['WDST'] = {}
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['WDST']['NM230']  = (-999999,1,2,3,4,5,6,7,8,998,999)
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['WDST']['NU010']  = (-999999,1,2,3,4,5,6,7,8,998,999)
    field_information['GGDM 3.0']['HydrographyAONExt']['WFT'] = ('Enumeration',('NM230'))
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['WFT'] = {}
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['WFT']['NM230']  = (-999999,2,3,5,6,7,999)
    field_information['GGDM 3.0']['HydrographyAONExt']['WID'] = ('Real',('NM140'))
    field_information['GGDM 3.0']['HydrographyAONExt']['WMT'] = ('Enumeration',('NM140'))
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['WMT'] = {}
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['WMT']['NM140']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,999)
    field_information['GGDM 3.0']['HydrographyAONExt']['WVA'] = ('Real',('NM010','NM030','NM140'))
    field_information['GGDM 3.0']['HydrographyAONExt']['WVH'] = ('Real',('NM140'))
    field_information['GGDM 3.0']['HydrographyAONExt']['WVL'] = ('Real',('NM140'))
    field_information['GGDM 3.0']['HydrographyAONExt']['WWM'] = ('Enumeration',('NM230'))
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['WWM'] = {}
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['WWM']['NM230']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,999)
    field_information['GGDM 3.0']['HydrographyAONExt']['WWM2'] = ('Enumeration',('NM230'))
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['WWM2'] = {}
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['WWM2']['NM230']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,999)
    field_information['GGDM 3.0']['HydrographyAONExt']['WWM3'] = ('Enumeration',('NM230'))
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['WWM3'] = {}
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['WWM3']['NM230']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,999)
    field_information['GGDM 3.0']['HydrographyAONExt']['ZI001_SDV'] = ('StructuredText',('NM010','NM030','NM082','NM140','NM170','NM230','NU010'))
    field_information['GGDM 3.0']['HydrographyAONExt']['ZI001_SRT'] = ('Enumeration',('NM010','NM030','NM082','NM140','NM170','NM230','NU010'))
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['ZI001_SRT']['NM010']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['ZI001_SRT']['NM030']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['ZI001_SRT']['NM082']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['ZI001_SRT']['NM140']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['ZI001_SRT']['NM170']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['ZI001_SRT']['NM230']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['ZI001_SRT']['NU010']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['HydrographyAONExt']['ZI002_UFI'] = ('StructuredText',('NM010','NM030','NM082','NM140','NM170','NM230','NU010'))
    field_information['GGDM 3.0']['HydrographyAONExt']['ZI004_RCG'] = ('Enumeration',('NM010','NM030','NM082','NM140','NM170','NM230','NU010'))
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['ZI004_RCG']['NM010']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['ZI004_RCG']['NM030']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['ZI004_RCG']['NM082']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['ZI004_RCG']['NM140']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['ZI004_RCG']['NM170']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['ZI004_RCG']['NM230']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['ZI004_RCG']['NU010']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['HydrographyAONExt']['ZI005_FNA'] = ('String',('NM010','NM140','NM230','NU010'))
    field_information['GGDM 3.0']['HydrographyAONExt']['ZI005_FNA2'] = ('String',('NM010','NM140','NM230','NU010'))
    field_information['GGDM 3.0']['HydrographyAONExt']['ZI005_FNA3'] = ('String',('NM140'))
    field_information['GGDM 3.0']['HydrographyAONExt']['ZI005_GNT'] = ('Enumeration',('NM010','NM140','NM230','NU010'))
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['ZI005_GNT']['NM010']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['ZI005_GNT']['NM140']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['ZI005_GNT']['NM230']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['ZI005_GNT']['NU010']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['HydrographyAONExt']['ZI005_GNT2'] = ('Enumeration',('NM010','NM140','NM230','NU010'))
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['ZI005_GNT2'] = {}
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['ZI005_GNT2']['NM010']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['ZI005_GNT2']['NM140']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['ZI005_GNT2']['NM230']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['ZI005_GNT2']['NU010']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['HydrographyAONExt']['ZI005_GNT3'] = ('Enumeration',('NM140'))
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['ZI005_GNT3'] = {}
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['ZI005_GNT3']['NM140']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['HydrographyAONExt']['ZI005_NFN'] = ('String',('NM010','NM140','NM230','NU010'))
    field_information['GGDM 3.0']['HydrographyAONExt']['ZI005_NFN2'] = ('String',('NM010','NM140','NM230','NU010'))
    field_information['GGDM 3.0']['HydrographyAONExt']['ZI005_NFN3'] = ('String',('NM140'))
    field_information['GGDM 3.0']['HydrographyAONExt']['ZI006_MEM'] = ('String',('NM010','NM030','NM082','NM140','NM170','NM230','NU010'))
    field_information['GGDM 3.0']['HydrographyAONExt']['ZI020_GE4'] = ('CodeList',('NM010','NM030','NM082','NM140','NM170','NM230','NU010'))
    field_information['GGDM 3.0']['HydrographyAONExt']['ZI024_ASE'] = ('Real',('NM010','NM030','NM082','NM140','NM170','NM230','NU010'))
    field_information['GGDM 3.0']['HydrographyAONExt']['ZI024_AWO'] = ('Real',('NM010','NM140','NM170','NM230'))
    field_information['GGDM 3.0']['HydrographyAONExt']['ZI024_AWOI'] = ('Real',('NM010','NM140','NM170','NM230'))
    field_information['GGDM 3.0']['HydrographyAONExt']['ZI024_AWOX'] = ('Real',('NM010','NM140','NM170','NM230'))
    field_information['GGDM 3.0']['HydrographyAONExt']['ZI024_CFR'] = ('Real',('NM010','NM030','NM082','NM140','NM170','NM230','NU010'))
    field_information['GGDM 3.0']['HydrographyAONExt']['ZI024_CLO'] = ('Real',('NM010','NM030','NM082','NM140','NM170','NM230','NU010'))
    field_information['GGDM 3.0']['HydrographyAONExt']['ZI024_CYN'] = ('Real',('NM010','NM030','NM082','NM140','NM170','NM230','NU010'))
    field_information['GGDM 3.0']['HydrographyAONExt']['ZI024_DRL'] = ('Enumeration',('NM230'))
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['ZI024_DRL'] = {}
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['ZI024_DRL']['NM230']  = (-999999,17,40,44,45,50,999)
    field_information['GGDM 3.0']['HydrographyAONExt']['ZI024_FMR'] = ('Real',('NM010','NM030','NM082','NM140','NM170','NM230','NU010'))
    field_information['GGDM 3.0']['HydrographyAONExt']['ZI024_FRR'] = ('Real',('NM010','NM030','NM082','NM140','NM170','NM230','NU010'))
    field_information['GGDM 3.0']['HydrographyAONExt']['ZI024_HAR'] = ('Real',('NM010','NM030','NM082','NM140','NM170','NM230','NU010'))
    field_information['GGDM 3.0']['HydrographyAONExt']['ZI024_HYP'] = ('Enumeration',('NM010','NM030','NM082','NM140','NM170','NM230','NU010'))
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['ZI024_HYP'] = {}
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['ZI024_HYP']['NM010']  = (-999999,1,2,4)
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['ZI024_HYP']['NM030']  = (-999999,1,2,4)
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['ZI024_HYP']['NM082']  = (-999999,1,2,4)
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['ZI024_HYP']['NM140']  = (-999999,1,2,4)
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['ZI024_HYP']['NM170']  = (-999999,1,2,4)
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['ZI024_HYP']['NM230']  = (-999999,1,2,4)
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['ZI024_HYP']['NU010']  = (-999999,1,2,4)
    field_information['GGDM 3.0']['HydrographyAONExt']['ZI024_MGN'] = ('Real',('NM010','NM030','NM082','NM140','NM170','NM230','NU010'))
    field_information['GGDM 3.0']['HydrographyAONExt']['ZI024_PHW'] = ('Real',('NM010','NM030','NM082','NM140','NM170','NM230','NU010'))
    field_information['GGDM 3.0']['HydrographyAONExt']['ZI024_PMP'] = ('Enumeration',('NM230'))
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['ZI024_PMP'] = {}
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['ZI024_PMP']['NM230']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['GGDM 3.0']['HydrographyAONExt']['ZI024_RTP'] = ('Enumeration',('NM082'))
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['ZI024_RTP'] = {}
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['ZI024_RTP']['NM082']  = (-999999,1,2,999)
    field_information['GGDM 3.0']['HydrographyAONExt']['ZI024_SCC'] = ('Enumeration',('NM010','NM030','NM082','NM140','NM170','NM230','NU010'))
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['ZI024_SCC'] = {}
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['ZI024_SCC']['NM010']  = (-999999,1,4,10,11,12,13,14,998,999)
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['ZI024_SCC']['NM030']  = (-999999,1,4,10,11,12,13,14,998,999)
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['ZI024_SCC']['NM082']  = (-999999,1,4,10,11,12,13,14,998,999)
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['ZI024_SCC']['NM140']  = (-999999,1,4,10,11,12,13,14,998,999)
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['ZI024_SCC']['NM170']  = (-999999,1,4,10,11,12,13,14,998,999)
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['ZI024_SCC']['NM230']  = (-999999,1,4,10,11,12,13,14,998,999)
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['ZI024_SCC']['NU010']  = (-999999,1,4,10,11,12,13,14,998,999)
    field_information['GGDM 3.0']['HydrographyAONExt']['ZI024_SQN'] = ('Enumeration',('NM140'))
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['ZI024_SQN'] = {}
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['ZI024_SQN']['NM140']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['HydrographyAONExt']['ZI024_SUL'] = ('Real',('NM010','NM030','NM082','NM140','NM170','NM230','NU010'))
    field_information['GGDM 3.0']['HydrographyAONExt']['ZI024_TDS'] = ('Real',('NM010','NM030','NM082','NM140','NM170','NM230','NU010'))
    field_information['GGDM 3.0']['HydrographyAONExt']['ZI024_TEP'] = ('Real',('NM010','NM030','NM082','NM140','NM170','NM230','NU010'))
    field_information['GGDM 3.0']['HydrographyAONExt']['ZI024_TUR'] = ('Real',('NM010','NM030','NM082','NM140','NM170','NM230','NU010'))
    field_information['GGDM 3.0']['HydrographyAONExt']['ZI024_WAC'] = ('Real',('NM010','NM030','NM082','NM140','NM170','NM230','NU010'))
    field_information['GGDM 3.0']['HydrographyAONExt']['ZI024_WPAC'] = ('Enumeration',('NM010','NM030','NM140'))
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['ZI024_WPAC'] = {}
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['ZI024_WPAC']['NM010']  = (-999999,100,101,102,103)
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['ZI024_WPAC']['NM030']  = (-999999,100,101,102,103,104,105,106,107)
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['ZI024_WPAC']['NM140']  = (-999999,100,101,102,103,104,105,106,107)
    field_information['GGDM 3.0']['HydrographyAONExt']['ZI024_WSG'] = ('Enumeration',('NM140'))
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['ZI024_WSG'] = {}
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['ZI024_WSG']['NM140']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['HydrographyAONExt']['ZI024_WTNO'] = ('Real',('NM010','NM030','NM082','NM140','NM170','NM230','NU010'))
    field_information['GGDM 3.0']['HydrographyAONExt']['ZI024_WUR'] = ('Enumeration',('NM010','NM030','NM082','NM140','NM170','NM230','NU010'))
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['ZI024_WUR'] = {}
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['ZI024_WUR']['NM010']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['ZI024_WUR']['NM030']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['ZI024_WUR']['NM082']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['ZI024_WUR']['NM140']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['ZI024_WUR']['NM170']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['ZI024_WUR']['NM230']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['ZI024_WUR']['NU010']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['HydrographyAONExt']['ZI024_WUR2'] = ('Enumeration',('NM010','NM030','NM082','NM140','NM170','NM230','NU010'))
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['ZI024_WUR2'] = {}
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['ZI024_WUR2']['NM010']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['ZI024_WUR2']['NM030']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['ZI024_WUR2']['NM082']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['ZI024_WUR2']['NM140']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['ZI024_WUR2']['NM170']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['ZI024_WUR2']['NM230']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['ZI024_WUR2']['NU010']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['HydrographyAONExt']['ZI024_WUR3'] = ('Enumeration',('NM010','NM030','NM082','NM140','NM170','NM230','NU010'))
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['ZI024_WUR3'] = {}
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['ZI024_WUR3']['NM010']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['ZI024_WUR3']['NM030']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['ZI024_WUR3']['NM082']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['ZI024_WUR3']['NM140']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['ZI024_WUR3']['NM170']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['ZI024_WUR3']['NM230']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['ZI024_WUR3']['NU010']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['HydrographyAONExt']['ZI024_WUR4'] = ('Enumeration',('NM010','NM030','NM082','NM140','NM170','NM230','NU010'))
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['ZI024_WUR4'] = {}
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['ZI024_WUR4']['NM010']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['ZI024_WUR4']['NM030']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['ZI024_WUR4']['NM082']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['ZI024_WUR4']['NM140']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['ZI024_WUR4']['NM170']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['ZI024_WUR4']['NM230']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['ZI024_WUR4']['NU010']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['HydrographyAONExt']['ZI024_YWQ'] = ('Enumeration',('NM010','NM030','NM082','NM140','NM170','NM230','NU010'))
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['ZI024_YWQ'] = {}
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['ZI024_YWQ']['NM010']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['ZI024_YWQ']['NM030']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['ZI024_YWQ']['NM082']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['ZI024_YWQ']['NM140']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['ZI024_YWQ']['NM170']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['ZI024_YWQ']['NM230']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['ZI024_YWQ']['NU010']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['HydrographyAONExt']['ZI025_HDP'] = ('Real',('NM140'))
    field_information['GGDM 3.0']['HydrographyAONExt']['ZI026_CTUC'] = ('Enumeration',('NM010','NM030','NM082','NM140','NM170','NM230','NU010'))
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['ZI026_CTUC']['NM010']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['ZI026_CTUC']['NM030']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['ZI026_CTUC']['NM082']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['ZI026_CTUC']['NM140']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['ZI026_CTUC']['NM170']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['ZI026_CTUC']['NM230']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['HydrographyAONExt']['EnumeratedIndexValues']['ZI026_CTUC']['NU010']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['HydrographyAONExt']['ZI026_CTUL'] = ('integer',('NM010','NM030','NM082','NM140','NM170','NM230','NU010'))
    field_information['GGDM 3.0']['HydrographyAONExt']['ZI026_CTUU'] = ('integer',('NM010','NM030','NM082','NM140','NM170','NM230','NU010'))
    field_information['GGDM 3.0']['HydrographyAONExt']['ZI031S_URI'] = ('StructuredText',('NM010','NM030','NM082','NM140','NM170','NM230','NU010'))
    field_information['GGDM 3.0']['HydrographyAONExt']['ZI039S_UFI'] = ('StructuredText',('NM010','NM030','NM082','NM140','NM170','NM230','NU010'))
    field_information['GGDM 3.0']['HydrographyAONExt']['ZSAX_RS0'] = ('CodeList',('NM010','NM030','NM082','NM140','NM170','NM230','NU010'))
    field_information['GGDM 3.0']['HydrographyAONExt']['ZSAX_RX0'] = ('StructuredText',('NM010','NM030','NM082','NM140','NM170','NM230','NU010'))
    field_information['GGDM 3.0']['HydrographyAONExt']['ZSAX_RX3'] = ('StructuredText',('NM010','NM030','NM082','NM140','NM170','NM230','NU010'))
    field_information['GGDM 3.0']['HydrographyAONExt']['ZSAX_RX4'] = ('StructuredText',('NM010','NM030','NM082','NM140','NM170','NM230','NU010'))
    field_information['GGDM 3.0']['HydrographyAONExt']['ZVH'] = ('Real',('NM030','NM082','NU010'))
    field_information['GGDM 3.0']['HydrographyCrv']['AOO'] = ('Real',('BH120','BH180','BI020','BI040','BI044'))
    field_information['GGDM 3.0']['HydrographyCrv']['ARA'] = ('Real',('BH010','BH030','BH065','BH100','BH110','BH120','BH140','BH165','BH180','BI020','BI044','BI060'))
    field_information['GGDM 3.0']['HydrographyCrv']['ATC'] = ('Enumeration',('BH010'))
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['ATC'] = {}
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['ATC']['BH010']  = (-999999,3,4,5,6)
    field_information['GGDM 3.0']['HydrographyCrv']['AWP'] = ('Boolean',('BI020'))
    field_information['GGDM 3.0']['HydrographyCrv']['BBMCA'] = ('Enumeration',('BH030','BH140'))
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['BBMCA'] = {}
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['BBMCA']['BH030']  = (-999999,1,2,3,4,5,6,7,8,9,11,14,15,16,17,18,999)
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['BBMCA']['BH140']  = (-999999,1,2,3,4,5,6,7,8,9,11,14,15,16,17,18,999)
    field_information['GGDM 3.0']['HydrographyCrv']['BBMCA2'] = ('Enumeration',('BH030','BH140'))
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['BBMCA2'] = {}
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['BBMCA2']['BH030']  = (-999999,1,2,3,4,5,6,7,8,9,11,14,15,16,17,18,999)
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['BBMCA2']['BH140']  = (-999999,1,2,3,4,5,6,7,8,9,11,14,15,16,17,18,999)
    field_information['GGDM 3.0']['HydrographyCrv']['BBMCA3'] = ('Enumeration',('BH030','BH140'))
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['BBMCA3'] = {}
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['BBMCA3']['BH030']  = (-999999,1,2,3,4,5,6,7,8,9,11,14,15,16,17,18,999)
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['BBMCA3']['BH140']  = (-999999,1,2,3,4,5,6,7,8,9,11,14,15,16,17,18,999)
    field_information['GGDM 3.0']['HydrographyCrv']['BBMCB'] = ('Enumeration',('BH030','BH140'))
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['BBMCB'] = {}
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['BBMCB']['BH030']  = (-999999,1,2,3,4,5,6,7,8,9,11,14,15,16,17,18,999)
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['BBMCB']['BH140']  = (-999999,1,2,3,4,5,6,7,8,9,11,14,15,16,17,18,999)
    field_information['GGDM 3.0']['HydrographyCrv']['BBMCB2'] = ('Enumeration',('BH030','BH140'))
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['BBMCB2'] = {}
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['BBMCB2']['BH030']  = (-999999,1,2,3,4,5,6,7,8,9,11,14,15,16,17,18,999)
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['BBMCB2']['BH140']  = (-999999,1,2,3,4,5,6,7,8,9,11,14,15,16,17,18,999)
    field_information['GGDM 3.0']['HydrographyCrv']['BBMCB3'] = ('Enumeration',('BH030','BH140'))
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['BBMCB3'] = {}
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['BBMCB3']['BH030']  = (-999999,1,2,3,4,5,6,7,8,9,11,14,15,16,17,18,999)
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['BBMCB3']['BH140']  = (-999999,1,2,3,4,5,6,7,8,9,11,14,15,16,17,18,999)
    field_information['GGDM 3.0']['HydrographyCrv']['BEN'] = ('StructuredText',('BH010','BH030','BH065','BH100','BH110','BH120','BH140','BH165','BH180','BI020','BI040','BI044','BI060'))
    field_information['GGDM 3.0']['HydrographyCrv']['BH141_AWBA'] = ('Real',('BH010','BH030','BH140'))
    field_information['GGDM 3.0']['HydrographyCrv']['BH141_AWBB'] = ('Real',('BH010','BH030','BH140'))
    field_information['GGDM 3.0']['HydrographyCrv']['BH141_IBOA'] = ('Enumeration',('BH010','BH030','BH140'))
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['BH141_IBOA'] = {}
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['BH141_IBOA']['BH010']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['BH141_IBOA']['BH030']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['BH141_IBOA']['BH140']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['HydrographyCrv']['BH141_IBOB'] = ('Enumeration',('BH010','BH030','BH140'))
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['BH141_IBOB'] = {}
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['BH141_IBOB']['BH010']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['BH141_IBOB']['BH030']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['BH141_IBOB']['BH140']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['HydrographyCrv']['BH141_SHDA'] = ('Boolean',('BH010','BH030','BH140'))
    field_information['GGDM 3.0']['HydrographyCrv']['BH141_SHDB'] = ('Boolean',('BH010','BH030','BH140'))
    field_information['GGDM 3.0']['HydrographyCrv']['BH141_SLTA'] = ('Enumeration',('BH010','BH030','BH140'))
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['BH141_SLTA'] = {}
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['BH141_SLTA']['BH010']  = (-999999,6,8,10,11,12,13,14,16,17,18,999)
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['BH141_SLTA']['BH030']  = (-999999,6,8,10,11,12,13,14,16,17,18,999)
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['BH141_SLTA']['BH140']  = (-999999,6,8,10,11,12,13,14,16,17,18,999)
    field_information['GGDM 3.0']['HydrographyCrv']['BH141_SLTB'] = ('Enumeration',('BH010','BH030','BH140'))
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['BH141_SLTB'] = {}
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['BH141_SLTB']['BH010']  = (-999999,6,8,10,11,12,13,14,17,18,999)
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['BH141_SLTB']['BH030']  = (-999999,6,8,10,11,12,13,14,17,18,999)
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['BH141_SLTB']['BH140']  = (-999999,6,8,10,11,12,13,14,17,18,999)
    field_information['GGDM 3.0']['HydrographyCrv']['BH141_WBHA'] = ('Real',('BH010','BH030','BH140'))
    field_information['GGDM 3.0']['HydrographyCrv']['BH141_WBHB'] = ('Real',('BH010','BH030','BH140'))
    field_information['GGDM 3.0']['HydrographyCrv']['BMC'] = ('Enumeration',('BH030','BH140'))
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['BMC'] = {}
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['BMC']['BH030']  = (-999999,1,2,3,4,5,6,7,8,9,14,15,16,17,18,999)
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['BMC']['BH140']  = (-999999,1,2,3,4,5,6,7,9,14,15,18,999)
    field_information['GGDM 3.0']['HydrographyCrv']['BMC2'] = ('Enumeration',('BH030','BH140'))
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['BMC2'] = {}
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['BMC2']['BH030']  = (-999999,1,2,3,4,5,6,7,8,9,14,15,16,17,18,999)
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['BMC2']['BH140']  = (-999999,1,2,3,4,5,6,7,9,14,15,18,999)
    field_information['GGDM 3.0']['HydrographyCrv']['BMC3'] = ('Enumeration',('BH030','BH140'))
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['BMC3'] = {}
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['BMC3']['BH030']  = (-999999,1,2,3,4,5,6,7,8,9,14,15,16,17,18,999)
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['BMC3']['BH140']  = (-999999,1,2,3,4,5,6,7,9,14,15,18,999)
    field_information['GGDM 3.0']['HydrographyCrv']['BPWHAC'] = ('Enumeration',('BH010','BH030','BH140'))
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['BPWHAC'] = {}
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['BPWHAC']['BH010']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['BPWHAC']['BH030']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['BPWHAC']['BH140']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['HydrographyCrv']['BPWHAL'] = ('real',('BH010','BH030','BH140'))
    field_information['GGDM 3.0']['HydrographyCrv']['BPWHAU'] = ('real',('BH010','BH030','BH140'))
    field_information['GGDM 3.0']['HydrographyCrv']['BPWHBC'] = ('Enumeration',('BH010','BH030','BH140'))
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['BPWHBC'] = {}
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['BPWHBC']['BH010']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['BPWHBC']['BH030']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['BPWHBC']['BH140']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['HydrographyCrv']['BPWHBL'] = ('real',('BH010','BH030','BH140'))
    field_information['GGDM 3.0']['HydrographyCrv']['BPWHBU'] = ('real',('BH010','BH030','BH140'))
    field_information['GGDM 3.0']['HydrographyCrv']['BPWSAC'] = ('Enumeration',('BH010','BH030','BH140'))
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['BPWSAC'] = {}
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['BPWSAC']['BH010']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['BPWSAC']['BH030']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['BPWSAC']['BH140']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['HydrographyCrv']['BPWSAL'] = ('real',('BH010','BH030','BH140'))
    field_information['GGDM 3.0']['HydrographyCrv']['BPWSAU'] = ('real',('BH010','BH030','BH140'))
    field_information['GGDM 3.0']['HydrographyCrv']['BPWSBC'] = ('Enumeration',('BH010','BH030','BH140'))
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['BPWSBC'] = {}
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['BPWSBC']['BH010']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['BPWSBC']['BH030']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['BPWSBC']['BH140']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['HydrographyCrv']['BPWSBL'] = ('real',('BH010','BH030','BH140'))
    field_information['GGDM 3.0']['HydrographyCrv']['BPWSBU'] = ('real',('BH010','BH030','BH140'))
    field_information['GGDM 3.0']['HydrographyCrv']['BWVCAC'] = ('Enumeration',('BH010','BH030','BH140'))
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['BWVCAC'] = {}
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['BWVCAC']['BH010']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['BWVCAC']['BH030']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['BWVCAC']['BH140']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['HydrographyCrv']['BWVCAL'] = ('real',('BH010','BH030','BH140'))
    field_information['GGDM 3.0']['HydrographyCrv']['BWVCAU'] = ('real',('BH010','BH030','BH140'))
    field_information['GGDM 3.0']['HydrographyCrv']['BWVCBC'] = ('Enumeration',('BH010','BH030','BH140'))
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['BWVCBC'] = {}
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['BWVCBC']['BH010']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['BWVCBC']['BH030']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['BWVCBC']['BH140']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['HydrographyCrv']['BWVCBL'] = ('real',('BH010','BH030','BH140'))
    field_information['GGDM 3.0']['HydrographyCrv']['BWVCBU'] = ('real',('BH010','BH030','BH140'))
    field_information['GGDM 3.0']['HydrographyCrv']['CAA'] = ('Enumeration',('BH010','BH030','BH065','BH140','BI020'))
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['CAA']['BH010']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['CAA']['BH030']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['CAA']['BH065']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['CAA']['BH140']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['CAA']['BI020']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['HydrographyCrv']['CDA'] = ('Boolean',('BH010','BH030','BH140'))
    field_information['GGDM 3.0']['HydrographyCrv']['CDL'] = ('Real',('BH010','BH030','BH140'))
    field_information['GGDM 3.0']['HydrographyCrv']['CNCP'] = ('StructuredText',('BH010','BH030','BH065','BH100','BH110','BH165','BI020','BI040','BI044','BI060'))
    field_information['GGDM 3.0']['HydrographyCrv']['COS'] = ('Enumeration',('BH010','BH030','BH065','BH100','BH110','BH165','BI020','BI040','BI044','BI060'))
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['COS']['BH010']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['COS']['BH030']  = (-999999,2,4,6,9,13,14)
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['COS']['BH065']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['COS']['BH100']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['COS']['BH110']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['COS']['BH165']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['COS']['BI020']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['COS']['BI040']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['COS']['BI044']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['COS']['BI060']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['HydrographyCrv']['CWT'] = ('Boolean',('BH010','BH030'))
    field_information['GGDM 3.0']['HydrographyCrv']['DEV'] = ('Integer',('BH010','BH030'))
    field_information['GGDM 3.0']['HydrographyCrv']['DFT'] = ('Enumeration',('BI020'))
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['DFT'] = {}
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['DFT']['BI020']  = (-999999,1,2)
    field_information['GGDM 3.0']['HydrographyCrv']['DFU'] = ('Enumeration',('BI020'))
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['DFU'] = {}
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['DFU']['BI020']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['GGDM 3.0']['HydrographyCrv']['DFU2'] = ('Enumeration',('BI020'))
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['DFU2'] = {}
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['DFU2']['BI020']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['GGDM 3.0']['HydrographyCrv']['DFU3'] = ('Enumeration',('BI020'))
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['DFU3'] = {}
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['DFU3']['BI020']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['GGDM 3.0']['HydrographyCrv']['DIM'] = ('Real',('BH110'))
    field_information['GGDM 3.0']['HydrographyCrv']['DIT'] = ('Enumeration',('BH030'))
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['DIT'] = {}
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['DIT']['BH030']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['HydrographyCrv']['DOXY'] = ('Real',('BH010','BH030','BH140'))
    field_information['GGDM 3.0']['HydrographyCrv']['DSD'] = ('Enumeration',('BI020'))
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['DSD'] = {}
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['DSD']['BI020']  = (-999999,101,102,103,104,105,106,107,999)
    field_information['GGDM 3.0']['HydrographyCrv']['DZP'] = ('Real',('BH010','BH030','BH100','BH140'))
    field_information['GGDM 3.0']['HydrographyCrv']['F_CODE'] = ('CONSTRAINED_STRING',('BH010','BH030','BH065','BH100','BH110','BH120','BH140','BH165','BH180','BI020','BI040','BI044','BI060'))
    field_information['GGDM 3.0']['HydrographyCrv']['FCS'] = ('Enumeration',('BI044'))
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['FCS'] = {}
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['FCS']['BI044']  = (-999999,1,2,3,4,5,999)
    field_information['GGDM 3.0']['HydrographyCrv']['FRZ'] = ('Boolean',('BH010','BH030','BH140'))
    field_information['GGDM 3.0']['HydrographyCrv']['FUFI'] = ('StructuredText',('BH010','BH030','BH065','BH100','BH110','BH120','BH140','BH165','BH180','BI020','BI040','BI044','BI060'))
    field_information['GGDM 3.0']['HydrographyCrv']['FURL'] = ('StructuredText',('BH010','BH030','BH065','BH100','BH110','BH120','BH140','BH165','BH180','BI020','BI040','BI044','BI060'))
    field_information['GGDM 3.0']['HydrographyCrv']['GDBV'] = ('Enumeration',('BH010','BH030','BH065','BH100','BH110','BH120','BH140','BH165','BH180','BI020','BI040','BI044','BI060'))
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['GDBV']['BH010']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['GDBV']['BH030']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['GDBV']['BH065']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['GDBV']['BH100']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['GDBV']['BH110']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['GDBV']['BH120']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['GDBV']['BH140']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['GDBV']['BH165']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['GDBV']['BH180']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['GDBV']['BI020']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['GDBV']['BI040']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['GDBV']['BI044']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['GDBV']['BI060']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['HydrographyCrv']['HDP'] = ('Real',('BH030','BI044'))
    field_information['GGDM 3.0']['HydrographyCrv']['HGS'] = ('Real',('BI020'))
    field_information['GGDM 3.0']['HydrographyCrv']['HGT'] = ('Real',('BH010','BH030','BH065','BH110','BH180','BI020','BI044'))
    field_information['GGDM 3.0']['HydrographyCrv']['LDC'] = ('Real',('BI020'))
    field_information['GGDM 3.0']['HydrographyCrv']['LEA'] = ('Real',('BH010','BH030','BH140'))
    field_information['GGDM 3.0']['HydrographyCrv']['LMC'] = ('Boolean',('BH010','BH030','BH065','BH110','BH120','BH140','BH180','BI020','BI040'))
    field_information['GGDM 3.0']['HydrographyCrv']['LOC'] = ('Enumeration',('BH030','BH065','BH110','BH140'))
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['LOC'] = {}
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['LOC']['BH030']  = (-999999,40,44)
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['LOC']['BH065']  = (-999999,40,44,45)
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['LOC']['BH110']  = (-999999,40,44,45)
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['LOC']['BH140']  = (-999999,40,44)
    field_information['GGDM 3.0']['HydrographyCrv']['LUN'] = ('Boolean',('BH010'))
    field_information['GGDM 3.0']['HydrographyCrv']['LZN'] = ('Real',('BH010','BH030','BH065','BH100','BH110','BH120','BH140','BH165','BH180','BI040','BI044','BI060'))
    field_information['GGDM 3.0']['HydrographyCrv']['MCC'] = ('Enumeration',('BH165','BI020','BI040','BI044'))
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['MCC'] = {}
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['MCC']['BH165']  = (-999999,5,9,21,62,77,83,84,104,108,999)
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['MCC']['BI020']  = (-999999,8,9,21,62,64,86,104,107,108,117,150,160,999)
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['MCC']['BI040']  = (-999999,21,64,77,83,107,117,150,999)
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['MCC']['BI044']  = (-999999,9,21,46,62,77,83,84,104,107,117,150,999)
    field_information['GGDM 3.0']['HydrographyCrv']['MCC2'] = ('Enumeration',('BH165','BI020','BI040','BI044'))
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['MCC2'] = {}
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['MCC2']['BH165']  = (-999999,5,9,21,62,77,83,84,104,108,999)
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['MCC2']['BI020']  = (-999999,8,9,21,62,64,86,104,107,108,117,150,160,999)
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['MCC2']['BI040']  = (-999999,21,64,77,83,107,117,150,999)
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['MCC2']['BI044']  = (-999999,9,21,46,62,77,83,84,104,107,117,150,999)
    field_information['GGDM 3.0']['HydrographyCrv']['MCC3'] = ('Enumeration',('BH165','BI020','BI040','BI044'))
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['MCC3'] = {}
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['MCC3']['BH165']  = (-999999,5,9,21,62,77,83,84,104,108,999)
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['MCC3']['BI020']  = (-999999,8,9,21,62,64,86,104,107,108,117,150,160,999)
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['MCC3']['BI040']  = (-999999,21,64,77,83,107,117,150,999)
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['MCC3']['BI044']  = (-999999,9,21,46,62,77,83,84,104,107,117,150,999)
    field_information['GGDM 3.0']['HydrographyCrv']['MWD'] = ('Real',('BH010','BH030','BH100'))
    field_information['GGDM 3.0']['HydrographyCrv']['NVS'] = ('Enumeration',('BH140'))
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['NVS'] = {}
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['NVS']['BH140']  = (-999999,1,2,3,4,5,999)
    field_information['GGDM 3.0']['HydrographyCrv']['OTH'] = ('StructuredText',('BH010','BH030','BH065','BH100','BH110','BH120','BH140','BH165','BH180','BI020','BI040','BI044','BI060'))
    field_information['GGDM 3.0']['HydrographyCrv']['PCF'] = ('Enumeration',('BH010','BH030','BH065','BH100','BH110','BH165','BI020','BI040','BI044','BI060'))
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['PCF']['BH010']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['PCF']['BH030']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['PCF']['BH065']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['PCF']['BH100']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['PCF']['BH110']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['PCF']['BH165']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['PCF']['BI020']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['PCF']['BI040']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['PCF']['BI044']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['PCF']['BI060']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['HydrographyCrv']['PWA'] = ('Real',('BH030','BH140'))
    field_information['GGDM 3.0']['HydrographyCrv']['PWAC'] = ('Enumeration',('BH010'))
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['PWAC'] = {}
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['PWAC']['BH010']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['HydrographyCrv']['PWAL'] = ('real',('BH010'))
    field_information['GGDM 3.0']['HydrographyCrv']['PWAU'] = ('real',('BH010'))
    field_information['GGDM 3.0']['HydrographyCrv']['RLE'] = ('Enumeration',('BH010','BH030','BH065'))
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['RLE'] = {}
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['RLE']['BH010']  = (-999999,1,2,3,998)
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['RLE']['BH030']  = (-999999,1,2,3,998)
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['RLE']['BH065']  = (-999999,1,2,3)
    field_information['GGDM 3.0']['HydrographyCrv']['SBB'] = ('Boolean',('BH010','BH030'))
    field_information['GGDM 3.0']['HydrographyCrv']['SPT'] = ('Boolean',('BH065','BH110'))
    field_information['GGDM 3.0']['HydrographyCrv']['STNB'] = ('Integer',('BH140'))
    field_information['GGDM 3.0']['HydrographyCrv']['THI'] = ('Real',('BI040'))
    field_information['GGDM 3.0']['HydrographyCrv']['TID'] = ('Boolean',('BH140'))
    field_information['GGDM 3.0']['HydrographyCrv']['TRS'] = ('Enumeration',('BI020'))
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['TRS'] = {}
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['TRS']['BI020']  = (-999999,8,9,12,13,999)
    field_information['GGDM 3.0']['HydrographyCrv']['TRS2'] = ('Enumeration',('BI020'))
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['TRS2'] = {}
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['TRS2']['BI020']  = (-999999,8,9,12,13,999)
    field_information['GGDM 3.0']['HydrographyCrv']['TRS3'] = ('Enumeration',('BI020'))
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['TRS3'] = {}
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['TRS3']['BI020']  = (-999999,8,9,12,13,999)
    field_information['GGDM 3.0']['HydrographyCrv']['UFI'] = ('StructuredText',('BH010','BH030','BH065','BH100','BH110','BH120','BH140','BH165','BH180','BI020','BI040','BI044','BI060'))
    field_information['GGDM 3.0']['HydrographyCrv']['VLM'] = ('Real',('BH100'))
    field_information['GGDM 3.0']['HydrographyCrv']['VOI'] = ('StructuredText',('BI020'))
    field_information['GGDM 3.0']['HydrographyCrv']['WCC'] = ('Enumeration',('BH140'))
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['WCC'] = {}
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['WCC']['BH140']  = (-999999,1,2,3,4,7,999)
    field_information['GGDM 3.0']['HydrographyCrv']['WD3'] = ('Real',('BH010','BH030','BH100','BH140'))
    field_information['GGDM 3.0']['HydrographyCrv']['WDAC'] = ('Enumeration',('BH010','BH030','BH140'))
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['WDAC'] = {}
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['WDAC']['BH010']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['WDAC']['BH030']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['WDAC']['BH140']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['HydrographyCrv']['WDAL'] = ('real',('BH010','BH030','BH140'))
    field_information['GGDM 3.0']['HydrographyCrv']['WDAU'] = ('real',('BH010','BH030','BH140'))
    field_information['GGDM 3.0']['HydrographyCrv']['WDH'] = ('Real',('BH010','BH030','BH140'))
    field_information['GGDM 3.0']['HydrographyCrv']['WDL'] = ('Real',('BH010','BH030','BH140'))
    field_information['GGDM 3.0']['HydrographyCrv']['WID'] = ('Real',('BH010','BH030','BH065','BH100','BH120','BH140','BH165','BH180','BI044','BI060'))
    field_information['GGDM 3.0']['HydrographyCrv']['WMT'] = ('Enumeration',('BH140'))
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['WMT'] = {}
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['WMT']['BH140']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,999)
    field_information['GGDM 3.0']['HydrographyCrv']['WOC'] = ('Real',('BI020'))
    field_information['GGDM 3.0']['HydrographyCrv']['WRT'] = ('Enumeration',('BH065'))
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['WRT'] = {}
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['WRT']['BH065']  = (-999999,1,2,3,4)
    field_information['GGDM 3.0']['HydrographyCrv']['WVA'] = ('Real',('BH010','BH030','BH140'))
    field_information['GGDM 3.0']['HydrographyCrv']['WVH'] = ('Real',('BH010','BH030','BH140'))
    field_information['GGDM 3.0']['HydrographyCrv']['WVL'] = ('Real',('BH010','BH030','BH140'))
    field_information['GGDM 3.0']['HydrographyCrv']['ZI001_SDV'] = ('StructuredText',('BH010','BH030','BH065','BH100','BH110','BH120','BH140','BH165','BH180','BI020','BI040','BI044','BI060'))
    field_information['GGDM 3.0']['HydrographyCrv']['ZI001_SRT'] = ('Enumeration',('BH010','BH030','BH065','BH100','BH110','BH120','BH140','BH165','BH180','BI020','BI040','BI044','BI060'))
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['ZI001_SRT']['BH010']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['ZI001_SRT']['BH030']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['ZI001_SRT']['BH065']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['ZI001_SRT']['BH100']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['ZI001_SRT']['BH110']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['ZI001_SRT']['BH120']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['ZI001_SRT']['BH140']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['ZI001_SRT']['BH165']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['ZI001_SRT']['BH180']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['ZI001_SRT']['BI020']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['ZI001_SRT']['BI040']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['ZI001_SRT']['BI044']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['ZI001_SRT']['BI060']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['HydrographyCrv']['ZI002_UFI'] = ('StructuredText',('BH010','BH030','BH065','BH100','BH110','BH120','BH140','BH165','BH180','BI020','BI040','BI044','BI060'))
    field_information['GGDM 3.0']['HydrographyCrv']['ZI004_RCG'] = ('Enumeration',('BH010','BH030','BH065','BH100','BH110','BH120','BH140','BH165','BH180','BI020','BI040','BI044','BI060'))
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['ZI004_RCG']['BH010']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['ZI004_RCG']['BH030']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['ZI004_RCG']['BH065']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['ZI004_RCG']['BH100']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['ZI004_RCG']['BH110']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['ZI004_RCG']['BH120']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['ZI004_RCG']['BH140']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['ZI004_RCG']['BH165']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['ZI004_RCG']['BH180']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['ZI004_RCG']['BI020']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['ZI004_RCG']['BI040']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['ZI004_RCG']['BI044']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['ZI004_RCG']['BI060']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['HydrographyCrv']['ZI005_FNA'] = ('String',('BH010','BH030','BH120','BH140','BH165','BH180','BI020','BI044','BI060'))
    field_information['GGDM 3.0']['HydrographyCrv']['ZI005_FNA2'] = ('String',('BH010','BH030','BH140','BI020'))
    field_information['GGDM 3.0']['HydrographyCrv']['ZI005_FNA3'] = ('String',('BH030','BH140','BI020'))
    field_information['GGDM 3.0']['HydrographyCrv']['ZI005_GNT'] = ('Enumeration',('BH010','BH030','BH120','BH140','BH165','BH180','BI020','BI044','BI060'))
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['ZI005_GNT']['BH010']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['ZI005_GNT']['BH030']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['ZI005_GNT']['BH120']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['ZI005_GNT']['BH140']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['ZI005_GNT']['BH165']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['ZI005_GNT']['BH180']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['ZI005_GNT']['BI020']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['ZI005_GNT']['BI044']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['ZI005_GNT']['BI060']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['HydrographyCrv']['ZI005_GNT2'] = ('Enumeration',('BH010','BH030','BH140','BI020'))
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['ZI005_GNT2'] = {}
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['ZI005_GNT2']['BH010']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['ZI005_GNT2']['BH030']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['ZI005_GNT2']['BH140']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['ZI005_GNT2']['BI020']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['HydrographyCrv']['ZI005_GNT3'] = ('Enumeration',('BH030','BH140','BI020'))
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['ZI005_GNT3'] = {}
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['ZI005_GNT3']['BH030']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['ZI005_GNT3']['BH140']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['ZI005_GNT3']['BI020']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['HydrographyCrv']['ZI005_NFN'] = ('String',('BH010','BH030','BH120','BH140','BH165','BH180','BI020','BI044','BI060'))
    field_information['GGDM 3.0']['HydrographyCrv']['ZI005_NFN2'] = ('String',('BH010','BH030','BH140','BI020'))
    field_information['GGDM 3.0']['HydrographyCrv']['ZI005_NFN3'] = ('String',('BH030','BH140','BI020'))
    field_information['GGDM 3.0']['HydrographyCrv']['ZI006_MEM'] = ('String',('BH010','BH030','BH065','BH100','BH110','BH120','BH140','BH165','BH180','BI020','BI040','BI044','BI060'))
    field_information['GGDM 3.0']['HydrographyCrv']['ZI020_GE4'] = ('CodeList',('BH010','BH030','BH065','BH100','BH110','BH120','BH140','BH165','BH180','BI020','BI040','BI044','BI060'))
    field_information['GGDM 3.0']['HydrographyCrv']['ZI024_ASE'] = ('Real',('BH010','BH030','BH065','BH100','BH140'))
    field_information['GGDM 3.0']['HydrographyCrv']['ZI024_AWO'] = ('Real',('BH010','BH030','BH140'))
    field_information['GGDM 3.0']['HydrographyCrv']['ZI024_AWOI'] = ('Real',('BH010','BH030','BH140'))
    field_information['GGDM 3.0']['HydrographyCrv']['ZI024_AWOX'] = ('Real',('BH010','BH030','BH140'))
    field_information['GGDM 3.0']['HydrographyCrv']['ZI024_CFR'] = ('Real',('BH010','BH030','BH065','BH100','BH140'))
    field_information['GGDM 3.0']['HydrographyCrv']['ZI024_CLO'] = ('Real',('BH010','BH030','BH065','BH100','BH140'))
    field_information['GGDM 3.0']['HydrographyCrv']['ZI024_CYN'] = ('Real',('BH010','BH030','BH065','BH100','BH140'))
    field_information['GGDM 3.0']['HydrographyCrv']['ZI024_FMR'] = ('Real',('BH010','BH030','BH065','BH100','BH140'))
    field_information['GGDM 3.0']['HydrographyCrv']['ZI024_FRR'] = ('Real',('BH010','BH030','BH065','BH100','BH140'))
    field_information['GGDM 3.0']['HydrographyCrv']['ZI024_HAR'] = ('Real',('BH010','BH030','BH065','BH100','BH140'))
    field_information['GGDM 3.0']['HydrographyCrv']['ZI024_HYP'] = ('Enumeration',('BH010','BH030','BH065','BH100','BH140'))
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['ZI024_HYP'] = {}
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['ZI024_HYP']['BH010']  = (-999999,1,2,4)
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['ZI024_HYP']['BH030']  = (-999999,1,2,4)
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['ZI024_HYP']['BH065']  = (-999999,1,2,4)
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['ZI024_HYP']['BH100']  = (-999999,1,2,4)
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['ZI024_HYP']['BH140']  = (-999999,1,2,4)
    field_information['GGDM 3.0']['HydrographyCrv']['ZI024_MGN'] = ('Real',('BH010','BH030','BH065','BH100','BH140'))
    field_information['GGDM 3.0']['HydrographyCrv']['ZI024_PHW'] = ('Real',('BH010','BH030','BH065','BH100','BH140'))
    field_information['GGDM 3.0']['HydrographyCrv']['ZI024_SCC'] = ('Enumeration',('BH010','BH030','BH065','BH100','BH140'))
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['ZI024_SCC'] = {}
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['ZI024_SCC']['BH010']  = (-999999,1,4,10,11,12,13,14,998)
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['ZI024_SCC']['BH030']  = (-999999,1,4,10,11,12,13,14,998,999)
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['ZI024_SCC']['BH065']  = (-999999,1,4,10,11,12,13,14,998,999)
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['ZI024_SCC']['BH100']  = (-999999,1,4,10,11,12,13,14,998)
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['ZI024_SCC']['BH140']  = (-999999,1,4,10,11,12,13,14,998,999)
    field_information['GGDM 3.0']['HydrographyCrv']['ZI024_SQN'] = ('Enumeration',('BH010','BH030','BH140'))
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['ZI024_SQN'] = {}
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['ZI024_SQN']['BH010']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['ZI024_SQN']['BH030']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['ZI024_SQN']['BH140']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['HydrographyCrv']['ZI024_SUL'] = ('Real',('BH010','BH030','BH065','BH100','BH140'))
    field_information['GGDM 3.0']['HydrographyCrv']['ZI024_TDS'] = ('Real',('BH010','BH030','BH065','BH100','BH140'))
    field_information['GGDM 3.0']['HydrographyCrv']['ZI024_TEP'] = ('Real',('BH010','BH030','BH065','BH100','BH140'))
    field_information['GGDM 3.0']['HydrographyCrv']['ZI024_TUR'] = ('Real',('BH010','BH030','BH065','BH100','BH140'))
    field_information['GGDM 3.0']['HydrographyCrv']['ZI024_WAC'] = ('Real',('BH010','BH030','BH065','BH100','BH140'))
    field_information['GGDM 3.0']['HydrographyCrv']['ZI024_WPAC'] = ('Enumeration',('BH010','BH030','BH140','BI020'))
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['ZI024_WPAC'] = {}
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['ZI024_WPAC']['BH010']  = (-999999,100,101,102,103)
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['ZI024_WPAC']['BH030']  = (-999999,100,101,102,103,104,105,106,107)
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['ZI024_WPAC']['BH140']  = (-999999,100,101,102,103,104,105,106,107)
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['ZI024_WPAC']['BI020']  = (-999999,100,101,102,103,104,105,106,107)
    field_information['GGDM 3.0']['HydrographyCrv']['ZI024_WSG'] = ('Enumeration',('BH030','BH140'))
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['ZI024_WSG'] = {}
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['ZI024_WSG']['BH030']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['ZI024_WSG']['BH140']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['HydrographyCrv']['ZI024_WTNO'] = ('Real',('BH010','BH030','BH065','BH100','BH140'))
    field_information['GGDM 3.0']['HydrographyCrv']['ZI024_WUR'] = ('Enumeration',('BH010','BH030','BH065','BH140'))
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['ZI024_WUR'] = {}
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['ZI024_WUR']['BH010']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['ZI024_WUR']['BH030']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['ZI024_WUR']['BH065']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['ZI024_WUR']['BH140']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['HydrographyCrv']['ZI024_WUR2'] = ('Enumeration',('BH010','BH030','BH065','BH140'))
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['ZI024_WUR2'] = {}
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['ZI024_WUR2']['BH010']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['ZI024_WUR2']['BH030']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['ZI024_WUR2']['BH065']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['ZI024_WUR2']['BH140']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['HydrographyCrv']['ZI024_WUR3'] = ('Enumeration',('BH010','BH030','BH065','BH140'))
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['ZI024_WUR3'] = {}
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['ZI024_WUR3']['BH010']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['ZI024_WUR3']['BH030']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['ZI024_WUR3']['BH065']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['ZI024_WUR3']['BH140']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['HydrographyCrv']['ZI024_WUR4'] = ('Enumeration',('BH010','BH030','BH065','BH140'))
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['ZI024_WUR4'] = {}
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['ZI024_WUR4']['BH010']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['ZI024_WUR4']['BH030']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['ZI024_WUR4']['BH065']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['ZI024_WUR4']['BH140']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['HydrographyCrv']['ZI024_YWQ'] = ('Enumeration',('BH010','BH030','BH065','BH100','BH140'))
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['ZI024_YWQ'] = {}
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['ZI024_YWQ']['BH010']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['ZI024_YWQ']['BH030']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['ZI024_YWQ']['BH065']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['ZI024_YWQ']['BH100']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['ZI024_YWQ']['BH140']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['HydrographyCrv']['ZI025_HDP'] = ('Real',('BH140'))
    field_information['GGDM 3.0']['HydrographyCrv']['ZI026_CTUC'] = ('Enumeration',('BH010','BH030','BH065','BH100','BH110','BH120','BH140','BH165','BH180','BI020','BI040','BI044','BI060'))
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['ZI026_CTUC']['BH010']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['ZI026_CTUC']['BH030']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['ZI026_CTUC']['BH065']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['ZI026_CTUC']['BH100']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['ZI026_CTUC']['BH110']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['ZI026_CTUC']['BH120']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['ZI026_CTUC']['BH140']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['ZI026_CTUC']['BH165']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['ZI026_CTUC']['BH180']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['ZI026_CTUC']['BI020']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['ZI026_CTUC']['BI040']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['ZI026_CTUC']['BI044']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['HydrographyCrv']['EnumeratedIndexValues']['ZI026_CTUC']['BI060']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['HydrographyCrv']['ZI026_CTUL'] = ('integer',('BH010','BH030','BH065','BH100','BH110','BH120','BH140','BH165','BH180','BI020','BI040','BI044','BI060'))
    field_information['GGDM 3.0']['HydrographyCrv']['ZI026_CTUU'] = ('integer',('BH010','BH030','BH065','BH100','BH110','BH120','BH140','BH165','BH180','BI020','BI040','BI044','BI060'))
    field_information['GGDM 3.0']['HydrographyCrv']['ZI031S_URI'] = ('StructuredText',('BH010','BH030','BH065','BH100','BH110','BH120','BH140','BH165','BH180','BI020','BI040','BI044','BI060'))
    field_information['GGDM 3.0']['HydrographyCrv']['ZI039S_UFI'] = ('StructuredText',('BH010','BH030','BH065','BH100','BH110','BH120','BH140','BH165','BH180','BI020','BI040','BI044','BI060'))
    field_information['GGDM 3.0']['HydrographyCrv']['ZSAX_RS0'] = ('CodeList',('BH010','BH030','BH065','BH100','BH110','BH120','BH140','BH165','BH180','BI020','BI040','BI044','BI060'))
    field_information['GGDM 3.0']['HydrographyCrv']['ZSAX_RX0'] = ('StructuredText',('BH010','BH030','BH065','BH100','BH110','BH120','BH140','BH165','BH180','BI020','BI040','BI044','BI060'))
    field_information['GGDM 3.0']['HydrographyCrv']['ZSAX_RX3'] = ('StructuredText',('BH010','BH030','BH065','BH100','BH110','BH120','BH140','BH165','BH180','BI020','BI040','BI044','BI060'))
    field_information['GGDM 3.0']['HydrographyCrv']['ZSAX_RX4'] = ('StructuredText',('BH010','BH030','BH065','BH100','BH110','BH120','BH140','BH165','BH180','BI020','BI040','BI044','BI060'))
    field_information['GGDM 3.0']['HydrographyCrv']['ZVH'] = ('Real',('BH010','BH030','BH100','BH110','BH140','BH180','BI020','BI044'))
    field_information['GGDM 3.0']['HydrographyCrvExt']['ARA'] = ('Real',('BB100'))
    field_information['GGDM 3.0']['HydrographyCrvExt']['BDS'] = ('Boolean',('FC165'))
    field_information['GGDM 3.0']['HydrographyCrvExt']['BEN'] = ('StructuredText',('BB100','BD120','BE010','BE015','BG012','FC021','FC041','FC100','FC165'))
    field_information['GGDM 3.0']['HydrographyCrvExt']['BRG'] = ('Real',('FC021'))
    field_information['GGDM 3.0']['HydrographyCrvExt']['BRR'] = ('StructuredText',('FC100','FC165'))
    field_information['GGDM 3.0']['HydrographyCrvExt']['BRS'] = ('Real',('FC165'))
    field_information['GGDM 3.0']['HydrographyCrvExt']['CAA'] = ('Enumeration',('FC021','FC041'))
    field_information['GGDM 3.0']['HydrographyCrvExt']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['HydrographyCrvExt']['EnumeratedIndexValues']['CAA']['FC021']  = (-999999,1,2,3,5,6,7,8,11,13,16,17,999)
    field_information['GGDM 3.0']['HydrographyCrvExt']['EnumeratedIndexValues']['CAA']['FC041']  = (-999999,1,8,16,999)
    field_information['GGDM 3.0']['HydrographyCrvExt']['CFT'] = ('Enumeration',('FC021'))
    field_information['GGDM 3.0']['HydrographyCrvExt']['EnumeratedIndexValues']['CFT'] = {}
    field_information['GGDM 3.0']['HydrographyCrvExt']['EnumeratedIndexValues']['CFT']['FC021']  = (-999999,3,6,12,13,14,16,17,18,19,20,21,22,23,24,25,27,28,29,30,999)
    field_information['GGDM 3.0']['HydrographyCrvExt']['CRV'] = ('Real',('BE010','BE015'))
    field_information['GGDM 3.0']['HydrographyCrvExt']['DAN'] = ('String',('FC165'))
    field_information['GGDM 3.0']['HydrographyCrvExt']['DMC'] = ('Boolean',('FC021'))
    field_information['GGDM 3.0']['HydrographyCrvExt']['DOF'] = ('Real',('FC041','FC165'))
    field_information['GGDM 3.0']['HydrographyCrvExt']['DPG'] = ('Enumeration',('FC021'))
    field_information['GGDM 3.0']['HydrographyCrvExt']['EnumeratedIndexValues']['DPG'] = {}
    field_information['GGDM 3.0']['HydrographyCrvExt']['EnumeratedIndexValues']['DPG']['FC021']  = (-999999,1,2,3,4,5,6,999)
    field_information['GGDM 3.0']['HydrographyCrvExt']['DPG2'] = ('Enumeration',('FC021'))
    field_information['GGDM 3.0']['HydrographyCrvExt']['EnumeratedIndexValues']['DPG2'] = {}
    field_information['GGDM 3.0']['HydrographyCrvExt']['EnumeratedIndexValues']['DPG2']['FC021']  = (-999999,1,2,3,4,5,6,999)
    field_information['GGDM 3.0']['HydrographyCrvExt']['DPG3'] = ('Enumeration',('FC021'))
    field_information['GGDM 3.0']['HydrographyCrvExt']['EnumeratedIndexValues']['DPG3'] = {}
    field_information['GGDM 3.0']['HydrographyCrvExt']['EnumeratedIndexValues']['DPG3']['FC021']  = (-999999,1,2,3,4,5,6,999)
    field_information['GGDM 3.0']['HydrographyCrvExt']['DRP'] = ('String',('FC021','FC165'))
    field_information['GGDM 3.0']['HydrographyCrvExt']['DSP'] = ('Enumeration',('FC021'))
    field_information['GGDM 3.0']['HydrographyCrvExt']['EnumeratedIndexValues']['DSP'] = {}
    field_information['GGDM 3.0']['HydrographyCrvExt']['EnumeratedIndexValues']['DSP']['FC021']  = (-999999,1,2,3,4)
    field_information['GGDM 3.0']['HydrographyCrvExt']['F_CODE'] = ('CONSTRAINED_STRING',('BB100','BD120','BE010','BE015','BG012','FC021','FC041','FC100','FC165'))
    field_information['GGDM 3.0']['HydrographyCrvExt']['FUFI'] = ('StructuredText',('BB100','BD120','BE010','BE015','BG012','FC021','FC041','FC100','FC165'))
    field_information['GGDM 3.0']['HydrographyCrvExt']['FURL'] = ('StructuredText',('BB100','BD120','BE010','BE015','BG012','FC021','FC041','FC100','FC165'))
    field_information['GGDM 3.0']['HydrographyCrvExt']['GDBV'] = ('Enumeration',('BB100','BD120','BE010','BE015','BG012','FC021','FC041','FC100','FC165'))
    field_information['GGDM 3.0']['HydrographyCrvExt']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['HydrographyCrvExt']['EnumeratedIndexValues']['GDBV']['BB100']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['HydrographyCrvExt']['EnumeratedIndexValues']['GDBV']['BD120']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['HydrographyCrvExt']['EnumeratedIndexValues']['GDBV']['BE010']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['HydrographyCrvExt']['EnumeratedIndexValues']['GDBV']['BE015']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['HydrographyCrvExt']['EnumeratedIndexValues']['GDBV']['BG012']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['HydrographyCrvExt']['EnumeratedIndexValues']['GDBV']['FC021']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['HydrographyCrvExt']['EnumeratedIndexValues']['GDBV']['FC041']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['HydrographyCrvExt']['EnumeratedIndexValues']['GDBV']['FC100']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['HydrographyCrvExt']['EnumeratedIndexValues']['GDBV']['FC165']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['HydrographyCrvExt']['HDP'] = ('Real',('FC165'))
    field_information['GGDM 3.0']['HydrographyCrvExt']['HGT'] = ('Real',('BB100'))
    field_information['GGDM 3.0']['HydrographyCrvExt']['IAS'] = ('Boolean',('FC041'))
    field_information['GGDM 3.0']['HydrographyCrvExt']['LAF'] = ('Enumeration',('FC021'))
    field_information['GGDM 3.0']['HydrographyCrvExt']['EnumeratedIndexValues']['LAF'] = {}
    field_information['GGDM 3.0']['HydrographyCrvExt']['EnumeratedIndexValues']['LAF']['FC021']  = (-999999,1,2,3,4,5,6,999)
    field_information['GGDM 3.0']['HydrographyCrvExt']['LOR'] = ('Real',('FC100'))
    field_information['GGDM 3.0']['HydrographyCrvExt']['LZN'] = ('Real',('BB100','FC021','FC041','FC165'))
    field_information['GGDM 3.0']['HydrographyCrvExt']['MAN'] = ('Boolean',('FC021','FC041','FC165'))
    field_information['GGDM 3.0']['HydrographyCrvExt']['MAS'] = ('Boolean',('FC021'))
    field_information['GGDM 3.0']['HydrographyCrvExt']['MCC'] = ('Enumeration',('BD120'))
    field_information['GGDM 3.0']['HydrographyCrvExt']['EnumeratedIndexValues']['MCC'] = {}
    field_information['GGDM 3.0']['HydrographyCrvExt']['EnumeratedIndexValues']['MCC']['BD120']  = (-999999,24,25,84,999)
    field_information['GGDM 3.0']['HydrographyCrvExt']['MCC2'] = ('Enumeration',('BD120'))
    field_information['GGDM 3.0']['HydrographyCrvExt']['EnumeratedIndexValues']['MCC2'] = {}
    field_information['GGDM 3.0']['HydrographyCrvExt']['EnumeratedIndexValues']['MCC2']['BD120']  = (-999999,24,25,84,999)
    field_information['GGDM 3.0']['HydrographyCrvExt']['MCC3'] = ('Enumeration',('BD120'))
    field_information['GGDM 3.0']['HydrographyCrvExt']['EnumeratedIndexValues']['MCC3'] = {}
    field_information['GGDM 3.0']['HydrographyCrvExt']['EnumeratedIndexValues']['MCC3']['BD120']  = (-999999,24,25,84,999)
    field_information['GGDM 3.0']['HydrographyCrvExt']['MCY'] = ('Enumeration',('FC021'))
    field_information['GGDM 3.0']['HydrographyCrvExt']['EnumeratedIndexValues']['MCY'] = {}
    field_information['GGDM 3.0']['HydrographyCrvExt']['EnumeratedIndexValues']['MCY']['FC021']  = (-999999,1,5,10,11,12,13,14,999)
    field_information['GGDM 3.0']['HydrographyCrvExt']['MCY2'] = ('Enumeration',('FC021'))
    field_information['GGDM 3.0']['HydrographyCrvExt']['EnumeratedIndexValues']['MCY2'] = {}
    field_information['GGDM 3.0']['HydrographyCrvExt']['EnumeratedIndexValues']['MCY2']['FC021']  = (-999999,1,5,10,11,12,13,14,999)
    field_information['GGDM 3.0']['HydrographyCrvExt']['MCY3'] = ('Enumeration',('FC021'))
    field_information['GGDM 3.0']['HydrographyCrvExt']['EnumeratedIndexValues']['MCY3'] = {}
    field_information['GGDM 3.0']['HydrographyCrvExt']['EnumeratedIndexValues']['MCY3']['FC021']  = (-999999,1,5,10,11,12,13,14,999)
    field_information['GGDM 3.0']['HydrographyCrvExt']['MLO'] = ('Boolean',('FC021'))
    field_information['GGDM 3.0']['HydrographyCrvExt']['MNR'] = ('Enumeration',('FC021'))
    field_information['GGDM 3.0']['HydrographyCrvExt']['EnumeratedIndexValues']['MNR'] = {}
    field_information['GGDM 3.0']['HydrographyCrvExt']['EnumeratedIndexValues']['MNR']['FC021']  = (-999999,7,8,999)
    field_information['GGDM 3.0']['HydrographyCrvExt']['MNR2'] = ('Enumeration',('FC021'))
    field_information['GGDM 3.0']['HydrographyCrvExt']['EnumeratedIndexValues']['MNR2'] = {}
    field_information['GGDM 3.0']['HydrographyCrvExt']['EnumeratedIndexValues']['MNR2']['FC021']  = (-999999,7,8,999)
    field_information['GGDM 3.0']['HydrographyCrvExt']['MNR3'] = ('Enumeration',('FC021'))
    field_information['GGDM 3.0']['HydrographyCrvExt']['EnumeratedIndexValues']['MNR3'] = {}
    field_information['GGDM 3.0']['HydrographyCrvExt']['EnumeratedIndexValues']['MNR3']['FC021']  = (-999999,7,8,999)
    field_information['GGDM 3.0']['HydrographyCrvExt']['MRR'] = ('Enumeration',('FC021'))
    field_information['GGDM 3.0']['HydrographyCrvExt']['EnumeratedIndexValues']['MRR'] = {}
    field_information['GGDM 3.0']['HydrographyCrvExt']['EnumeratedIndexValues']['MRR']['FC021']  = (-999999,3,11,16,17,18,19,20,21,24,26,27,28,32,42,999)
    field_information['GGDM 3.0']['HydrographyCrvExt']['MRR2'] = ('Enumeration',('FC021'))
    field_information['GGDM 3.0']['HydrographyCrvExt']['EnumeratedIndexValues']['MRR2'] = {}
    field_information['GGDM 3.0']['HydrographyCrvExt']['EnumeratedIndexValues']['MRR2']['FC021']  = (-999999,3,11,16,17,18,19,20,21,24,26,27,28,32,42,999)
    field_information['GGDM 3.0']['HydrographyCrvExt']['MRR3'] = ('Enumeration',('FC021'))
    field_information['GGDM 3.0']['HydrographyCrvExt']['EnumeratedIndexValues']['MRR3'] = {}
    field_information['GGDM 3.0']['HydrographyCrvExt']['EnumeratedIndexValues']['MRR3']['FC021']  = (-999999,3,11,16,17,18,19,20,21,24,26,27,28,32,42,999)
    field_information['GGDM 3.0']['HydrographyCrvExt']['NFP'] = ('Enumeration',('FC021'))
    field_information['GGDM 3.0']['HydrographyCrvExt']['EnumeratedIndexValues']['NFP'] = {}
    field_information['GGDM 3.0']['HydrographyCrvExt']['EnumeratedIndexValues']['NFP']['FC021']  = (-999999,4,6,999)
    field_information['GGDM 3.0']['HydrographyCrvExt']['NFP2'] = ('Enumeration',('FC021'))
    field_information['GGDM 3.0']['HydrographyCrvExt']['EnumeratedIndexValues']['NFP2'] = {}
    field_information['GGDM 3.0']['HydrographyCrvExt']['EnumeratedIndexValues']['NFP2']['FC021']  = (-999999,4,6,999)
    field_information['GGDM 3.0']['HydrographyCrvExt']['NFP3'] = ('Enumeration',('FC021'))
    field_information['GGDM 3.0']['HydrographyCrvExt']['EnumeratedIndexValues']['NFP3'] = {}
    field_information['GGDM 3.0']['HydrographyCrvExt']['EnumeratedIndexValues']['NFP3']['FC021']  = (-999999,4,6,999)
    field_information['GGDM 3.0']['HydrographyCrvExt']['NOA'] = ('Enumeration',('FC021'))
    field_information['GGDM 3.0']['HydrographyCrvExt']['EnumeratedIndexValues']['NOA'] = {}
    field_information['GGDM 3.0']['HydrographyCrvExt']['EnumeratedIndexValues']['NOA']['FC021']  = (-999999,14,27,999)
    field_information['GGDM 3.0']['HydrographyCrvExt']['NOA2'] = ('Enumeration',('FC021'))
    field_information['GGDM 3.0']['HydrographyCrvExt']['EnumeratedIndexValues']['NOA2'] = {}
    field_information['GGDM 3.0']['HydrographyCrvExt']['EnumeratedIndexValues']['NOA2']['FC021']  = (-999999,14,27,999)
    field_information['GGDM 3.0']['HydrographyCrvExt']['NOA3'] = ('Enumeration',('FC021'))
    field_information['GGDM 3.0']['HydrographyCrvExt']['EnumeratedIndexValues']['NOA3'] = {}
    field_information['GGDM 3.0']['HydrographyCrvExt']['EnumeratedIndexValues']['NOA3']['FC021']  = (-999999,14,27,999)
    field_information['GGDM 3.0']['HydrographyCrvExt']['OTH'] = ('StructuredText',('BB100','BD120','BE010','BE015','BG012','FC021','FC041','FC100','FC165'))
    field_information['GGDM 3.0']['HydrographyCrvExt']['PCF'] = ('Enumeration',('BB100'))
    field_information['GGDM 3.0']['HydrographyCrvExt']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['HydrographyCrvExt']['EnumeratedIndexValues']['PCF']['BB100']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['HydrographyCrvExt']['RTT'] = ('Enumeration',('FC165'))
    field_information['GGDM 3.0']['HydrographyCrvExt']['EnumeratedIndexValues']['RTT'] = {}
    field_information['GGDM 3.0']['HydrographyCrvExt']['EnumeratedIndexValues']['RTT']['FC165']  = (-999999,2,3,4,5,11,13,17,18,999)
    field_information['GGDM 3.0']['HydrographyCrvExt']['TAN'] = ('String',('FC041'))
    field_information['GGDM 3.0']['HydrographyCrvExt']['TSP'] = ('Enumeration',('FC041'))
    field_information['GGDM 3.0']['HydrographyCrvExt']['EnumeratedIndexValues']['TSP'] = {}
    field_information['GGDM 3.0']['HydrographyCrvExt']['EnumeratedIndexValues']['TSP']['FC041']  = (-999999,2,3,4,5,6,7,8,9,10,11,12,999)
    field_information['GGDM 3.0']['HydrographyCrvExt']['UFI'] = ('StructuredText',('BB100','BD120','BE010','BE015','BG012','FC021','FC041','FC100','FC165'))
    field_information['GGDM 3.0']['HydrographyCrvExt']['WID'] = ('Real',('BB100','FC041','FC165'))
    field_information['GGDM 3.0']['HydrographyCrvExt']['WTT'] = ('Enumeration',('BG012'))
    field_information['GGDM 3.0']['HydrographyCrvExt']['EnumeratedIndexValues']['WTT'] = {}
    field_information['GGDM 3.0']['HydrographyCrvExt']['EnumeratedIndexValues']['WTT']['BG012']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['HydrographyCrvExt']['ZHDP_DCR'] = ('Boolean',('FC165'))
    field_information['GGDM 3.0']['HydrographyCrvExt']['ZHDP_DKC'] = ('Enumeration',('FC165'))
    field_information['GGDM 3.0']['HydrographyCrvExt']['EnumeratedIndexValues']['ZHDP_DKC'] = {}
    field_information['GGDM 3.0']['HydrographyCrvExt']['EnumeratedIndexValues']['ZHDP_DKC']['FC165']  = (-999999,1,3,4,5,6,7,8,9,10,11,12,998,999)
    field_information['GGDM 3.0']['HydrographyCrvExt']['ZHDP_DKC2'] = ('Enumeration',('FC165'))
    field_information['GGDM 3.0']['HydrographyCrvExt']['EnumeratedIndexValues']['ZHDP_DKC2'] = {}
    field_information['GGDM 3.0']['HydrographyCrvExt']['EnumeratedIndexValues']['ZHDP_DKC2']['FC165']  = (-999999,1,3,4,5,6,7,8,9,10,11,12,998,999)
    field_information['GGDM 3.0']['HydrographyCrvExt']['ZHDP_DKC3'] = ('Enumeration',('FC165'))
    field_information['GGDM 3.0']['HydrographyCrvExt']['EnumeratedIndexValues']['ZHDP_DKC3'] = {}
    field_information['GGDM 3.0']['HydrographyCrvExt']['EnumeratedIndexValues']['ZHDP_DKC3']['FC165']  = (-999999,1,3,4,5,6,7,8,9,10,11,12,998,999)
    field_information['GGDM 3.0']['HydrographyCrvExt']['ZHDP_SVC'] = ('Enumeration',('FC165'))
    field_information['GGDM 3.0']['HydrographyCrvExt']['EnumeratedIndexValues']['ZHDP_SVC'] = {}
    field_information['GGDM 3.0']['HydrographyCrvExt']['EnumeratedIndexValues']['ZHDP_SVC']['FC165']  = (-999999,1,2,3,4,5,998,999)
    field_information['GGDM 3.0']['HydrographyCrvExt']['ZHDP_TEC'] = ('Enumeration',('FC165'))
    field_information['GGDM 3.0']['HydrographyCrvExt']['EnumeratedIndexValues']['ZHDP_TEC'] = {}
    field_information['GGDM 3.0']['HydrographyCrvExt']['EnumeratedIndexValues']['ZHDP_TEC']['FC165']  = (-999999,1,2,3,4,5,6,8,9,10,11,12,13,14,15,17,18,999)
    field_information['GGDM 3.0']['HydrographyCrvExt']['ZHDP_TEC2'] = ('Enumeration',('FC165'))
    field_information['GGDM 3.0']['HydrographyCrvExt']['EnumeratedIndexValues']['ZHDP_TEC2'] = {}
    field_information['GGDM 3.0']['HydrographyCrvExt']['EnumeratedIndexValues']['ZHDP_TEC2']['FC165']  = (-999999,1,2,3,4,5,6,8,9,10,11,12,13,14,15,17,18,999)
    field_information['GGDM 3.0']['HydrographyCrvExt']['ZHDP_TEC3'] = ('Enumeration',('FC165'))
    field_information['GGDM 3.0']['HydrographyCrvExt']['EnumeratedIndexValues']['ZHDP_TEC3'] = {}
    field_information['GGDM 3.0']['HydrographyCrvExt']['EnumeratedIndexValues']['ZHDP_TEC3']['FC165']  = (-999999,1,2,3,4,5,6,8,9,10,11,12,13,14,15,17,18,999)
    field_information['GGDM 3.0']['HydrographyCrvExt']['ZHDP_VDC'] = ('Enumeration',('FC165'))
    field_information['GGDM 3.0']['HydrographyCrvExt']['EnumeratedIndexValues']['ZHDP_VDC'] = {}
    field_information['GGDM 3.0']['HydrographyCrvExt']['EnumeratedIndexValues']['ZHDP_VDC']['FC165']  = (-999999,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,24,28,30,90,91,92,93,94,95,96,97,98,99,100,101,102,103,104,105,107,999)
    field_information['GGDM 3.0']['HydrographyCrvExt']['ZHDP_VDR'] = ('String',('FC165'))
    field_information['GGDM 3.0']['HydrographyCrvExt']['ZI001_SDV'] = ('StructuredText',('BB100','BD120','BE010','BE015','BG012','FC021','FC041','FC100','FC165'))
    field_information['GGDM 3.0']['HydrographyCrvExt']['ZI001_SRT'] = ('Enumeration',('BB100','BD120','BE010','BE015','BG012','FC021','FC041','FC100','FC165'))
    field_information['GGDM 3.0']['HydrographyCrvExt']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['HydrographyCrvExt']['EnumeratedIndexValues']['ZI001_SRT']['BB100']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['HydrographyCrvExt']['EnumeratedIndexValues']['ZI001_SRT']['BD120']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['HydrographyCrvExt']['EnumeratedIndexValues']['ZI001_SRT']['BE010']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['HydrographyCrvExt']['EnumeratedIndexValues']['ZI001_SRT']['BE015']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['HydrographyCrvExt']['EnumeratedIndexValues']['ZI001_SRT']['BG012']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['HydrographyCrvExt']['EnumeratedIndexValues']['ZI001_SRT']['FC021']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['HydrographyCrvExt']['EnumeratedIndexValues']['ZI001_SRT']['FC041']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['HydrographyCrvExt']['EnumeratedIndexValues']['ZI001_SRT']['FC100']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['HydrographyCrvExt']['EnumeratedIndexValues']['ZI001_SRT']['FC165']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['HydrographyCrvExt']['ZI002_UFI'] = ('StructuredText',('BB100','BD120','BE010','BE015','BG012','FC021','FC041','FC100','FC165'))
    field_information['GGDM 3.0']['HydrographyCrvExt']['ZI004_RCG'] = ('Enumeration',('BB100','BD120','BE010','BE015','BG012','FC021','FC041','FC100','FC165'))
    field_information['GGDM 3.0']['HydrographyCrvExt']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['HydrographyCrvExt']['EnumeratedIndexValues']['ZI004_RCG']['BB100']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['HydrographyCrvExt']['EnumeratedIndexValues']['ZI004_RCG']['BD120']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['HydrographyCrvExt']['EnumeratedIndexValues']['ZI004_RCG']['BE010']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['HydrographyCrvExt']['EnumeratedIndexValues']['ZI004_RCG']['BE015']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['HydrographyCrvExt']['EnumeratedIndexValues']['ZI004_RCG']['BG012']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['HydrographyCrvExt']['EnumeratedIndexValues']['ZI004_RCG']['FC021']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['HydrographyCrvExt']['EnumeratedIndexValues']['ZI004_RCG']['FC041']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['HydrographyCrvExt']['EnumeratedIndexValues']['ZI004_RCG']['FC100']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['HydrographyCrvExt']['EnumeratedIndexValues']['ZI004_RCG']['FC165']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['HydrographyCrvExt']['ZI005_FNA'] = ('String',('BB100','BD120','BG012','FC021','FC041','FC100','FC165'))
    field_information['GGDM 3.0']['HydrographyCrvExt']['ZI005_GNT'] = ('Enumeration',('BB100','BD120','BG012','FC021','FC041','FC100','FC165'))
    field_information['GGDM 3.0']['HydrographyCrvExt']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['HydrographyCrvExt']['EnumeratedIndexValues']['ZI005_GNT']['BB100']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['HydrographyCrvExt']['EnumeratedIndexValues']['ZI005_GNT']['BD120']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['HydrographyCrvExt']['EnumeratedIndexValues']['ZI005_GNT']['BG012']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['HydrographyCrvExt']['EnumeratedIndexValues']['ZI005_GNT']['FC021']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['HydrographyCrvExt']['EnumeratedIndexValues']['ZI005_GNT']['FC041']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['HydrographyCrvExt']['EnumeratedIndexValues']['ZI005_GNT']['FC100']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['HydrographyCrvExt']['EnumeratedIndexValues']['ZI005_GNT']['FC165']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['HydrographyCrvExt']['ZI005_NFN'] = ('String',('BB100','BD120','BG012','FC021','FC041','FC100','FC165'))
    field_information['GGDM 3.0']['HydrographyCrvExt']['ZI006_MEM'] = ('String',('BB100','BD120','BE010','BE015','BG012','FC021','FC041','FC100','FC165'))
    field_information['GGDM 3.0']['HydrographyCrvExt']['ZI012_DCR'] = ('Boolean',('BE010'))
    field_information['GGDM 3.0']['HydrographyCrvExt']['ZI012_DKC'] = ('Enumeration',('BE010'))
    field_information['GGDM 3.0']['HydrographyCrvExt']['EnumeratedIndexValues']['ZI012_DKC'] = {}
    field_information['GGDM 3.0']['HydrographyCrvExt']['EnumeratedIndexValues']['ZI012_DKC']['BE010']  = (-999999,1,3,4,5,6,7,8,9,10,11,12,998,999)
    field_information['GGDM 3.0']['HydrographyCrvExt']['ZI012_DKC2'] = ('Enumeration',('BE010'))
    field_information['GGDM 3.0']['HydrographyCrvExt']['EnumeratedIndexValues']['ZI012_DKC2'] = {}
    field_information['GGDM 3.0']['HydrographyCrvExt']['EnumeratedIndexValues']['ZI012_DKC2']['BE010']  = (-999999,1,3,4,5,6,7,8,9,10,11,12,998,999)
    field_information['GGDM 3.0']['HydrographyCrvExt']['ZI012_DKC3'] = ('Enumeration',('BE010'))
    field_information['GGDM 3.0']['HydrographyCrvExt']['EnumeratedIndexValues']['ZI012_DKC3'] = {}
    field_information['GGDM 3.0']['HydrographyCrvExt']['EnumeratedIndexValues']['ZI012_DKC3']['BE010']  = (-999999,1,3,4,5,6,7,8,9,10,11,12,998,999)
    field_information['GGDM 3.0']['HydrographyCrvExt']['ZI012_SVC'] = ('Enumeration',('BE010'))
    field_information['GGDM 3.0']['HydrographyCrvExt']['EnumeratedIndexValues']['ZI012_SVC'] = {}
    field_information['GGDM 3.0']['HydrographyCrvExt']['EnumeratedIndexValues']['ZI012_SVC']['BE010']  = (-999999,1,2,3,4,5,998,999)
    field_information['GGDM 3.0']['HydrographyCrvExt']['ZI012_TEC'] = ('Enumeration',('BE010'))
    field_information['GGDM 3.0']['HydrographyCrvExt']['EnumeratedIndexValues']['ZI012_TEC'] = {}
    field_information['GGDM 3.0']['HydrographyCrvExt']['EnumeratedIndexValues']['ZI012_TEC']['BE010']  = (-999999,1,2,3,4,5,6,8,9,10,11,12,13,14,15,17,18,999)
    field_information['GGDM 3.0']['HydrographyCrvExt']['ZI012_TEC2'] = ('Enumeration',('BE010'))
    field_information['GGDM 3.0']['HydrographyCrvExt']['EnumeratedIndexValues']['ZI012_TEC2'] = {}
    field_information['GGDM 3.0']['HydrographyCrvExt']['EnumeratedIndexValues']['ZI012_TEC2']['BE010']  = (-999999,1,2,3,4,5,6,8,9,10,11,12,13,14,15,17,18,999)
    field_information['GGDM 3.0']['HydrographyCrvExt']['ZI012_TEC3'] = ('Enumeration',('BE010'))
    field_information['GGDM 3.0']['HydrographyCrvExt']['EnumeratedIndexValues']['ZI012_TEC3'] = {}
    field_information['GGDM 3.0']['HydrographyCrvExt']['EnumeratedIndexValues']['ZI012_TEC3']['BE010']  = (-999999,1,2,3,4,5,6,8,9,10,11,12,13,14,15,17,18,999)
    field_information['GGDM 3.0']['HydrographyCrvExt']['ZI012_VDC'] = ('Enumeration',('BE010'))
    field_information['GGDM 3.0']['HydrographyCrvExt']['EnumeratedIndexValues']['ZI012_VDC'] = {}
    field_information['GGDM 3.0']['HydrographyCrvExt']['EnumeratedIndexValues']['ZI012_VDC']['BE010']  = (-999999,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,24,28,30,90,91,92,93,94,95,96,97,98,99,100,101,102,103,104,105,107,999)
    field_information['GGDM 3.0']['HydrographyCrvExt']['ZI012_VDR'] = ('String',('BE010'))
    field_information['GGDM 3.0']['HydrographyCrvExt']['ZI020_GE4'] = ('CodeList',('BB100','BD120','BE010','BE015','BG012','FC021','FC041','FC100','FC165'))
    field_information['GGDM 3.0']['HydrographyCrvExt']['ZI025_HDP'] = ('Real',('BD120'))
    field_information['GGDM 3.0']['HydrographyCrvExt']['ZI025_WLE'] = ('Enumeration',('BD120'))
    field_information['GGDM 3.0']['HydrographyCrvExt']['EnumeratedIndexValues']['ZI025_WLE'] = {}
    field_information['GGDM 3.0']['HydrographyCrvExt']['EnumeratedIndexValues']['ZI025_WLE']['BD120']  = (-999999,1,2,3,4,5,9,999)
    field_information['GGDM 3.0']['HydrographyCrvExt']['ZI026_CTUC'] = ('Enumeration',('BB100','BD120','BE010','BE015','BG012','FC021','FC041','FC100','FC165'))
    field_information['GGDM 3.0']['HydrographyCrvExt']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['HydrographyCrvExt']['EnumeratedIndexValues']['ZI026_CTUC']['BB100']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['HydrographyCrvExt']['EnumeratedIndexValues']['ZI026_CTUC']['BD120']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['HydrographyCrvExt']['EnumeratedIndexValues']['ZI026_CTUC']['BE010']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['HydrographyCrvExt']['EnumeratedIndexValues']['ZI026_CTUC']['BE015']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['HydrographyCrvExt']['EnumeratedIndexValues']['ZI026_CTUC']['BG012']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['HydrographyCrvExt']['EnumeratedIndexValues']['ZI026_CTUC']['FC021']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['HydrographyCrvExt']['EnumeratedIndexValues']['ZI026_CTUC']['FC041']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['HydrographyCrvExt']['EnumeratedIndexValues']['ZI026_CTUC']['FC100']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['HydrographyCrvExt']['EnumeratedIndexValues']['ZI026_CTUC']['FC165']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['HydrographyCrvExt']['ZI026_CTUL'] = ('integer',('BB100','BD120','BE010','BE015','BG012','FC021','FC041','FC100','FC165'))
    field_information['GGDM 3.0']['HydrographyCrvExt']['ZI026_CTUU'] = ('integer',('BB100','BD120','BE010','BE015','BG012','FC021','FC041','FC100','FC165'))
    field_information['GGDM 3.0']['HydrographyCrvExt']['ZI031S_URI'] = ('StructuredText',('BB100','BD120','BE010','BE015','BG012','FC021','FC041','FC100','FC165'))
    field_information['GGDM 3.0']['HydrographyCrvExt']['ZI039S_UFI'] = ('StructuredText',('BB100','BD120','BE010','BE015','BG012','FC021','FC041','FC100','FC165'))
    field_information['GGDM 3.0']['HydrographyCrvExt']['ZSAX_RS0'] = ('CodeList',('BB100','BD120','BE010','BE015','BG012','FC021','FC041','FC100','FC165'))
    field_information['GGDM 3.0']['HydrographyCrvExt']['ZSAX_RX0'] = ('StructuredText',('BB100','BD120','BE010','BE015','BG012','FC021','FC041','FC100','FC165'))
    field_information['GGDM 3.0']['HydrographyCrvExt']['ZSAX_RX3'] = ('StructuredText',('BB100','BD120','BE010','BE015','BG012','FC021','FC041','FC100','FC165'))
    field_information['GGDM 3.0']['HydrographyCrvExt']['ZSAX_RX4'] = ('StructuredText',('BB100','BD120','BE010','BE015','BG012','FC021','FC041','FC100','FC165'))
    field_information['GGDM 3.0']['HydrographyPnt']['AOO'] = ('Real',('BB110','BD115','BD181','BH120','BH180','BI010','BI020','BI040','BI044','BI050'))
    field_information['GGDM 3.0']['HydrographyPnt']['AQN'] = ('String',('BH170','BH230'))
    field_information['GGDM 3.0']['HydrographyPnt']['ARA'] = ('Real',('BD115','BD140','BD181','BH012','BH082','BH120','BH170','BH180','BH230','BI010','BI020','BI044','BI050'))
    field_information['GGDM 3.0']['HydrographyPnt']['AWP'] = ('Boolean',('BD115','BD181','BI020','BI050'))
    field_information['GGDM 3.0']['HydrographyPnt']['AZC'] = ('Boolean',('BH082'))
    field_information['GGDM 3.0']['HydrographyPnt']['BC034_MRT'] = ('Enumeration',('BD115'))
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['BC034_MRT'] = {}
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['BC034_MRT']['BD115']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['HydrographyPnt']['BC034_MRT2'] = ('Enumeration',('BD115'))
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['BC034_MRT2'] = {}
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['BC034_MRT2']['BD115']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['HydrographyPnt']['BC034_MRT3'] = ('Enumeration',('BD115'))
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['BC034_MRT3'] = {}
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['BC034_MRT3']['BD115']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['HydrographyPnt']['BC101_SST'] = ('Enumeration',('BD115'))
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['BC101_SST'] = {}
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['BC101_SST']['BD115']  = (-999999,1,2,3,4,6,7,8,9,10,14,15,16,98,999)
    field_information['GGDM 3.0']['HydrographyPnt']['BEN'] = ('StructuredText',('BB110','BD115','BD140','BD181','BH012','BH082','BH120','BH145','BH170','BH180','BH230','BI010','BI020','BI040','BI044','BI050','BI070','ZD070'))
    field_information['GGDM 3.0']['HydrographyPnt']['BH010_CAA'] = ('Enumeration',('BH012'))
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['BH010_CAA'] = {}
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['BH010_CAA']['BH012']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['HydrographyPnt']['BH141_AWBA'] = ('Real',('BH082'))
    field_information['GGDM 3.0']['HydrographyPnt']['BH141_AWBB'] = ('Real',('BH082'))
    field_information['GGDM 3.0']['HydrographyPnt']['BH141_IBOA'] = ('Enumeration',('BH082'))
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['BH141_IBOA'] = {}
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['BH141_IBOA']['BH082']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['HydrographyPnt']['BH141_IBOB'] = ('Enumeration',('BH082'))
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['BH141_IBOB'] = {}
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['BH141_IBOB']['BH082']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['HydrographyPnt']['BH141_SHDA'] = ('Boolean',('BH082'))
    field_information['GGDM 3.0']['HydrographyPnt']['BH141_SHDB'] = ('Boolean',('BH082'))
    field_information['GGDM 3.0']['HydrographyPnt']['BH141_SLTA'] = ('Enumeration',('BH082'))
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['BH141_SLTA'] = {}
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['BH141_SLTA']['BH082']  = (-999999,6,8,10,11,12,13,14,17,18,999)
    field_information['GGDM 3.0']['HydrographyPnt']['BH141_SLTB'] = ('Enumeration',('BH082'))
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['BH141_SLTB'] = {}
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['BH141_SLTB']['BH082']  = (-999999,6,8,10,11,12,13,14,16,17,18,999)
    field_information['GGDM 3.0']['HydrographyPnt']['BH141_WBHA'] = ('Real',('BH082'))
    field_information['GGDM 3.0']['HydrographyPnt']['BH141_WBHB'] = ('Real',('BH082'))
    field_information['GGDM 3.0']['HydrographyPnt']['BPWHAC'] = ('Enumeration',('BH082'))
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['BPWHAC'] = {}
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['BPWHAC']['BH082']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['HydrographyPnt']['BPWHAL'] = ('real',('BH082'))
    field_information['GGDM 3.0']['HydrographyPnt']['BPWHAU'] = ('real',('BH082'))
    field_information['GGDM 3.0']['HydrographyPnt']['BPWHBC'] = ('Enumeration',('BH082'))
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['BPWHBC'] = {}
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['BPWHBC']['BH082']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['HydrographyPnt']['BPWHBL'] = ('real',('BH082'))
    field_information['GGDM 3.0']['HydrographyPnt']['BPWHBU'] = ('real',('BH082'))
    field_information['GGDM 3.0']['HydrographyPnt']['BPWSAC'] = ('Enumeration',('BH082'))
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['BPWSAC'] = {}
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['BPWSAC']['BH082']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['HydrographyPnt']['BPWSAL'] = ('real',('BH082'))
    field_information['GGDM 3.0']['HydrographyPnt']['BPWSAU'] = ('real',('BH082'))
    field_information['GGDM 3.0']['HydrographyPnt']['BPWSBC'] = ('Enumeration',('BH082'))
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['BPWSBC'] = {}
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['BPWSBC']['BH082']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['HydrographyPnt']['BPWSBL'] = ('real',('BH082'))
    field_information['GGDM 3.0']['HydrographyPnt']['BPWSBU'] = ('real',('BH082'))
    field_information['GGDM 3.0']['HydrographyPnt']['BWVCAC'] = ('Enumeration',('BH082'))
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['BWVCAC'] = {}
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['BWVCAC']['BH082']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['HydrographyPnt']['BWVCAL'] = ('real',('BH082'))
    field_information['GGDM 3.0']['HydrographyPnt']['BWVCAU'] = ('real',('BH082'))
    field_information['GGDM 3.0']['HydrographyPnt']['BWVCBC'] = ('Enumeration',('BH082'))
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['BWVCBC'] = {}
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['BWVCBC']['BH082']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['HydrographyPnt']['BWVCBL'] = ('real',('BH082'))
    field_information['GGDM 3.0']['HydrographyPnt']['BWVCBU'] = ('real',('BH082'))
    field_information['GGDM 3.0']['HydrographyPnt']['CAA'] = ('Enumeration',('BB110','BD115','BD181','BH082','BH170','BH230','BI010','BI020','BI050','BI070'))
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['CAA']['BB110']  = (-999999,3,17,999)
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['CAA']['BD115']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['CAA']['BD181']  = (-999999,5,7,16,999)
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['CAA']['BH082']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['CAA']['BH170']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['CAA']['BH230']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['CAA']['BI010']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['CAA']['BI020']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['CAA']['BI050']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['CAA']['BI070']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['HydrographyPnt']['CDI'] = ('Real',('BH230'))
    field_information['GGDM 3.0']['HydrographyPnt']['CNCP'] = ('StructuredText',('BB110','BD115','BD181','BH012','BH082','BH170','BH230','BI010','BI020','BI040','BI044','BI050','BI070'))
    field_information['GGDM 3.0']['HydrographyPnt']['COS'] = ('Enumeration',('BB110','BD115','BD181','BH012','BH082','BH170','BH230','BI010','BI020','BI040','BI044','BI050','BI070'))
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['COS']['BB110']  = (-999999,2,4,6,9,13,14)
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['COS']['BD115']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['COS']['BD181']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['COS']['BH012']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['COS']['BH082']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['COS']['BH170']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['COS']['BH230']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['COS']['BI010']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['COS']['BI020']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['COS']['BI040']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['COS']['BI044']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['COS']['BI050']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['COS']['BI070']  = (-999999,4,6,8,9,13,14)
    field_information['GGDM 3.0']['HydrographyPnt']['DFT'] = ('Enumeration',('BI020'))
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['DFT'] = {}
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['DFT']['BI020']  = (-999999,1,2)
    field_information['GGDM 3.0']['HydrographyPnt']['DFU'] = ('Enumeration',('BI020'))
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['DFU'] = {}
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['DFU']['BI020']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['GGDM 3.0']['HydrographyPnt']['DFU2'] = ('Enumeration',('BI020'))
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['DFU2'] = {}
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['DFU2']['BI020']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['GGDM 3.0']['HydrographyPnt']['DFU3'] = ('Enumeration',('BI020'))
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['DFU3'] = {}
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['DFU3']['BI020']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['GGDM 3.0']['HydrographyPnt']['DMD'] = ('Boolean',('BH082'))
    field_information['GGDM 3.0']['HydrographyPnt']['DOF'] = ('Real',('BH145','BH170'))
    field_information['GGDM 3.0']['HydrographyPnt']['DOXY'] = ('Real',('BH082','ZD070'))
    field_information['GGDM 3.0']['HydrographyPnt']['DSD'] = ('Enumeration',('BI020'))
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['DSD'] = {}
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['DSD']['BI020']  = (-999999,101,102,103,104,105,106,107,999)
    field_information['GGDM 3.0']['HydrographyPnt']['DWL'] = ('Real',('BH230'))
    field_information['GGDM 3.0']['HydrographyPnt']['DZP'] = ('Real',('BH012','BH082','BH170','BH230','BI070'))
    field_information['GGDM 3.0']['HydrographyPnt']['F_CODE'] = ('CONSTRAINED_STRING',('BB110','BD115','BD140','BD181','BH012','BH082','BH120','BH145','BH170','BH180','BH230','BI010','BI020','BI040','BI044','BI050','BI070','ZD070'))
    field_information['GGDM 3.0']['HydrographyPnt']['FCS'] = ('Enumeration',('BI044'))
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['FCS'] = {}
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['FCS']['BI044']  = (-999999,1,2,3,4,5,999)
    field_information['GGDM 3.0']['HydrographyPnt']['FFN'] = ('Enumeration',('BH082'))
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['FFN'] = {}
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['FFN']['BH082']  = (-999999,30,35,351,361,440,488,505,921,955,999)
    field_information['GGDM 3.0']['HydrographyPnt']['FFN2'] = ('Enumeration',('BH082'))
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['FFN2'] = {}
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['FFN2']['BH082']  = (-999999,30,35,351,361,440,488,505,921,955,999)
    field_information['GGDM 3.0']['HydrographyPnt']['FFN3'] = ('Enumeration',('BH082'))
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['FFN3'] = {}
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['FFN3']['BH082']  = (-999999,30,35,351,361,440,488,505,921,955,999)
    field_information['GGDM 3.0']['HydrographyPnt']['FRZ'] = ('Boolean',('BH082'))
    field_information['GGDM 3.0']['HydrographyPnt']['FUFI'] = ('StructuredText',('BB110','BD115','BD140','BD181','BH012','BH082','BH120','BH145','BH170','BH180','BH230','BI010','BI020','BI040','BI044','BI050','BI070','ZD070'))
    field_information['GGDM 3.0']['HydrographyPnt']['FURL'] = ('StructuredText',('BB110','BD115','BD140','BD181','BH012','BH082','BH120','BH145','BH170','BH180','BH230','BI010','BI020','BI040','BI044','BI050','BI070','ZD070'))
    field_information['GGDM 3.0']['HydrographyPnt']['GDBV'] = ('Enumeration',('BB110','BD115','BD140','BD181','BH012','BH082','BH120','BH145','BH170','BH180','BH230','BI010','BI020','BI040','BI044','BI050','BI070','ZD070'))
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['GDBV']['BB110']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['GDBV']['BD115']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['GDBV']['BD140']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['GDBV']['BD181']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['GDBV']['BH012']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['GDBV']['BH082']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['GDBV']['BH120']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['GDBV']['BH145']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['GDBV']['BH170']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['GDBV']['BH180']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['GDBV']['BH230']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['GDBV']['BI010']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['GDBV']['BI020']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['GDBV']['BI040']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['GDBV']['BI044']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['GDBV']['BI050']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['GDBV']['BI070']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['GDBV']['ZD070']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['HydrographyPnt']['HDP'] = ('Real',('BI044'))
    field_information['GGDM 3.0']['HydrographyPnt']['HGS'] = ('Real',('BI020'))
    field_information['GGDM 3.0']['HydrographyPnt']['HGT'] = ('Real',('BD115','BD181','BH012','BH180','BH230','BI010','BI020','BI044','BI050'))
    field_information['GGDM 3.0']['HydrographyPnt']['IWT'] = ('Enumeration',('BH082'))
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['IWT'] = {}
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['IWT']['BH082']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['HydrographyPnt']['LDC'] = ('Real',('BI020'))
    field_information['GGDM 3.0']['HydrographyPnt']['LEA'] = ('Real',('ZD070'))
    field_information['GGDM 3.0']['HydrographyPnt']['LMC'] = ('Boolean',('BD115','BD181','BH012','BH082','BH120','BH180','BH230','BI010','BI020','BI040','BI050'))
    field_information['GGDM 3.0']['HydrographyPnt']['LUN'] = ('Boolean',('BH170','BI010'))
    field_information['GGDM 3.0']['HydrographyPnt']['LZN'] = ('Real',('BB110','BD115','BD140','BD181','BH012','BH082','BH120','BH170','BH180','BH230','BI010','BI040','BI044','BI050'))
    field_information['GGDM 3.0']['HydrographyPnt']['MCC'] = ('Enumeration',('BI020','BI040','BI044'))
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['MCC'] = {}
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['MCC']['BI020']  = (-999999,8,9,21,62,64,86,104,107,108,117,150,160,999)
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['MCC']['BI040']  = (-999999,21,64,77,83,107,117,150,999)
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['MCC']['BI044']  = (-999999,9,21,46,62,77,83,84,104,107,117,150,999)
    field_information['GGDM 3.0']['HydrographyPnt']['MCC2'] = ('Enumeration',('BI020','BI040','BI044'))
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['MCC2'] = {}
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['MCC2']['BI020']  = (-999999,8,9,21,62,64,86,104,107,108,117,150,160,999)
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['MCC2']['BI040']  = (-999999,21,64,77,83,107,117,150,999)
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['MCC2']['BI044']  = (-999999,9,21,46,62,77,83,84,104,107,117,150,999)
    field_information['GGDM 3.0']['HydrographyPnt']['MCC3'] = ('Enumeration',('BI020','BI040','BI044'))
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['MCC3'] = {}
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['MCC3']['BI020']  = (-999999,8,9,21,62,64,86,104,107,108,117,150,160,999)
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['MCC3']['BI040']  = (-999999,21,64,77,83,107,117,150,999)
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['MCC3']['BI044']  = (-999999,9,21,46,62,77,83,84,104,107,117,150,999)
    field_information['GGDM 3.0']['HydrographyPnt']['MNS'] = ('Boolean',('BH082'))
    field_information['GGDM 3.0']['HydrographyPnt']['OCS'] = ('Enumeration',('BD115'))
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['OCS'] = {}
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['OCS']['BD115']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['HydrographyPnt']['OTH'] = ('StructuredText',('BB110','BD115','BD140','BD181','BH012','BH082','BH120','BH145','BH170','BH180','BH230','BI010','BI020','BI040','BI044','BI050','BI070','ZD070'))
    field_information['GGDM 3.0']['HydrographyPnt']['PCF'] = ('Enumeration',('BB110','BD115','BD181','BH012','BH082','BH170','BH230','BI010','BI020','BI040','BI044','BI050','BI070'))
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['PCF']['BB110']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['PCF']['BD115']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['PCF']['BD181']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['PCF']['BH012']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['PCF']['BH082']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['PCF']['BH170']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['PCF']['BH230']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['PCF']['BI010']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['PCF']['BI020']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['PCF']['BI040']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['PCF']['BI044']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['PCF']['BI050']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['PCF']['BI070']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['HydrographyPnt']['PMPR'] = ('Boolean',('BI010'))
    field_information['GGDM 3.0']['HydrographyPnt']['PSE'] = ('StructuredText',('BB110'))
    field_information['GGDM 3.0']['HydrographyPnt']['PUD'] = ('Real',('BH230'))
    field_information['GGDM 3.0']['HydrographyPnt']['PWAC'] = ('Enumeration',('BH082','BH145','BI070','ZD070'))
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['PWAC'] = {}
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['PWAC']['BH082']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['PWAC']['BH145']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['PWAC']['BI070']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['PWAC']['ZD070']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['HydrographyPnt']['PWAL'] = ('real',('BH082','BH145','BI070','ZD070'))
    field_information['GGDM 3.0']['HydrographyPnt']['PWAU'] = ('real',('BH082','BH145','BI070','ZD070'))
    field_information['GGDM 3.0']['HydrographyPnt']['SCOG'] = ('Enumeration',('ZD070'))
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['SCOG'] = {}
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['SCOG']['ZD070']  = (-999999,1,2,3,4,998,999)
    field_information['GGDM 3.0']['HydrographyPnt']['SWT'] = ('Enumeration',('BH170'))
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['SWT'] = {}
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['SWT']['BH170']  = (-999999,4,6,7,999)
    field_information['GGDM 3.0']['HydrographyPnt']['SWW'] = ('Real',('BH230'))
    field_information['GGDM 3.0']['HydrographyPnt']['THI'] = ('Real',('BI040'))
    field_information['GGDM 3.0']['HydrographyPnt']['TID'] = ('Boolean',('BH082'))
    field_information['GGDM 3.0']['HydrographyPnt']['TRS'] = ('Enumeration',('BI020'))
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['TRS'] = {}
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['TRS']['BI020']  = (-999999,8,9,12,13,999)
    field_information['GGDM 3.0']['HydrographyPnt']['TRS2'] = ('Enumeration',('BI020'))
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['TRS2'] = {}
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['TRS2']['BI020']  = (-999999,8,9,12,13,999)
    field_information['GGDM 3.0']['HydrographyPnt']['TRS3'] = ('Enumeration',('BI020'))
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['TRS3'] = {}
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['TRS3']['BI020']  = (-999999,8,9,12,13,999)
    field_information['GGDM 3.0']['HydrographyPnt']['TSSM'] = ('Enumeration',('BH230'))
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['TSSM'] = {}
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['TSSM']['BH230']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,999)
    field_information['GGDM 3.0']['HydrographyPnt']['TSSM2'] = ('Enumeration',('BH230'))
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['TSSM2'] = {}
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['TSSM2']['BH230']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,999)
    field_information['GGDM 3.0']['HydrographyPnt']['TSSM3'] = ('Enumeration',('BH230'))
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['TSSM3'] = {}
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['TSSM3']['BH230']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,999)
    field_information['GGDM 3.0']['HydrographyPnt']['TSTE'] = ('Enumeration',('ZD070'))
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['TSTE'] = {}
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['TSTE']['ZD070']  = (-999999,1,2,3,4,998,999)
    field_information['GGDM 3.0']['HydrographyPnt']['UFI'] = ('StructuredText',('BB110','BD115','BD140','BD181','BH012','BH082','BH120','BH145','BH170','BH180','BH230','BI010','BI020','BI040','BI044','BI050','BI070','ZD070'))
    field_information['GGDM 3.0']['HydrographyPnt']['VCM'] = ('Enumeration',('BD115','BI010','BI050'))
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['VCM'] = {}
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['VCM']['BD115']  = (-999999,2,4,7,9,15,17,999)
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['VCM']['BI010']  = (-999999,3,4,7,8,9,12,13,15,16,999)
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['VCM']['BI050']  = (-999999,2,3,4,7,8,9,12,13,15,17,999)
    field_information['GGDM 3.0']['HydrographyPnt']['VCM2'] = ('Enumeration',('BD115','BI010','BI050'))
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['VCM2'] = {}
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['VCM2']['BD115']  = (-999999,2,4,7,9,15,17,999)
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['VCM2']['BI010']  = (-999999,3,4,7,8,9,12,13,15,16,999)
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['VCM2']['BI050']  = (-999999,2,3,4,7,8,9,12,13,15,17,999)
    field_information['GGDM 3.0']['HydrographyPnt']['VCM3'] = ('Enumeration',('BD115','BI010','BI050'))
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['VCM3'] = {}
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['VCM3']['BD115']  = (-999999,2,4,7,9,15,17,999)
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['VCM3']['BI010']  = (-999999,3,4,7,8,9,12,13,15,16,999)
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['VCM3']['BI050']  = (-999999,2,3,4,7,8,9,12,13,15,17,999)
    field_information['GGDM 3.0']['HydrographyPnt']['VLM'] = ('Real',('BH082','BH170','BI010'))
    field_information['GGDM 3.0']['HydrographyPnt']['VOI'] = ('StructuredText',('BD115','BD181','BI020','BI050'))
    field_information['GGDM 3.0']['HydrographyPnt']['WAD'] = ('String',('BH230'))
    field_information['GGDM 3.0']['HydrographyPnt']['WCAC'] = ('Real',('BH230','ZD070'))
    field_information['GGDM 3.0']['HydrographyPnt']['WDAC'] = ('Enumeration',('BH082','BH145','BI070','ZD070'))
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['WDAC'] = {}
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['WDAC']['BH082']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['WDAC']['BH145']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['WDAC']['BI070']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['WDAC']['ZD070']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['HydrographyPnt']['WDAL'] = ('real',('BH082','BH145','BI070','ZD070'))
    field_information['GGDM 3.0']['HydrographyPnt']['WDAU'] = ('real',('BH082','BH145','BI070','ZD070'))
    field_information['GGDM 3.0']['HydrographyPnt']['WDH'] = ('Real',('BH082','BH145','BI070','ZD070'))
    field_information['GGDM 3.0']['HydrographyPnt']['WDL'] = ('Real',('BH082','BI070','ZD070'))
    field_information['GGDM 3.0']['HydrographyPnt']['WDST'] = ('Enumeration',('BH170','BH230','BI010'))
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['WDST'] = {}
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['WDST']['BH170']  = (-999999,1,2,3,4,5,6,7,8,998,999)
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['WDST']['BH230']  = (-999999,1,2,3,4,5,6,7,8,998,999)
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['WDST']['BI010']  = (-999999,1,2,3,4,5,6,7,8,998,999)
    field_information['GGDM 3.0']['HydrographyPnt']['WFT'] = ('Enumeration',('BH230'))
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['WFT'] = {}
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['WFT']['BH230']  = (-999999,2,3,5,6,7,999)
    field_information['GGDM 3.0']['HydrographyPnt']['WHCO'] = ('Real',('BH230','ZD070'))
    field_information['GGDM 3.0']['HydrographyPnt']['WID'] = ('Real',('BD115','BD140','BD181','BH012','BH082','BH120','BH170','BH180','BH230','BI010','BI044','BI050'))
    field_information['GGDM 3.0']['HydrographyPnt']['WOC'] = ('Real',('BI020'))
    field_information['GGDM 3.0']['HydrographyPnt']['WODR'] = ('Enumeration',('ZD070'))
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['WODR'] = {}
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['WODR']['ZD070']  = (-999999,1,2,3,4,5,6,7,998,999)
    field_information['GGDM 3.0']['HydrographyPnt']['WST'] = ('Enumeration',('BH145'))
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['WST'] = {}
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['WST']['BH145']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['HydrographyPnt']['WTBB'] = ('Real',('ZD070'))
    field_information['GGDM 3.0']['HydrographyPnt']['WTCA'] = ('Real',('ZD070'))
    field_information['GGDM 3.0']['HydrographyPnt']['WTCL'] = ('String',('ZD070'))
    field_information['GGDM 3.0']['HydrographyPnt']['WTFE'] = ('Real',('ZD070'))
    field_information['GGDM 3.0']['HydrographyPnt']['WTKK'] = ('Real',('ZD070'))
    field_information['GGDM 3.0']['HydrographyPnt']['WTMN'] = ('Real',('ZD070'))
    field_information['GGDM 3.0']['HydrographyPnt']['WTNA'] = ('Real',('ZD070'))
    field_information['GGDM 3.0']['HydrographyPnt']['WTNO'] = ('Real',('ZD070'))
    field_information['GGDM 3.0']['HydrographyPnt']['WTPO'] = ('Real',('ZD070'))
    field_information['GGDM 3.0']['HydrographyPnt']['WTSI'] = ('Real',('ZD070'))
    field_information['GGDM 3.0']['HydrographyPnt']['WTST'] = ('Enumeration',('ZD070'))
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['WTST'] = {}
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['WTST']['ZD070']  = (-999999,1,2,998,999)
    field_information['GGDM 3.0']['HydrographyPnt']['WVA'] = ('Real',('BH145','BI070','ZD070'))
    field_information['GGDM 3.0']['HydrographyPnt']['WVH'] = ('Real',('BH145','BI070','ZD070'))
    field_information['GGDM 3.0']['HydrographyPnt']['WVL'] = ('Real',('BI070','ZD070'))
    field_information['GGDM 3.0']['HydrographyPnt']['WWM'] = ('Enumeration',('BH170','BH230'))
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['WWM'] = {}
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['WWM']['BH170']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,999)
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['WWM']['BH230']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,999)
    field_information['GGDM 3.0']['HydrographyPnt']['WWM2'] = ('Enumeration',('BH170','BH230'))
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['WWM2'] = {}
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['WWM2']['BH170']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,999)
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['WWM2']['BH230']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,999)
    field_information['GGDM 3.0']['HydrographyPnt']['WWM3'] = ('Enumeration',('BH170','BH230'))
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['WWM3'] = {}
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['WWM3']['BH170']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,999)
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['WWM3']['BH230']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,999)
    field_information['GGDM 3.0']['HydrographyPnt']['ZI001_SDV'] = ('StructuredText',('BB110','BD115','BD140','BD181','BH012','BH082','BH120','BH145','BH170','BH180','BH230','BI010','BI020','BI040','BI044','BI050','BI070','ZD070'))
    field_information['GGDM 3.0']['HydrographyPnt']['ZI001_SRT'] = ('Enumeration',('BB110','BD115','BD140','BD181','BH012','BH082','BH120','BH145','BH170','BH180','BH230','BI010','BI020','BI040','BI044','BI050','BI070','ZD070'))
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['ZI001_SRT']['BB110']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['ZI001_SRT']['BD115']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['ZI001_SRT']['BD140']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['ZI001_SRT']['BD181']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['ZI001_SRT']['BH012']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['ZI001_SRT']['BH082']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['ZI001_SRT']['BH120']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['ZI001_SRT']['BH145']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['ZI001_SRT']['BH170']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['ZI001_SRT']['BH180']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['ZI001_SRT']['BH230']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['ZI001_SRT']['BI010']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['ZI001_SRT']['BI020']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['ZI001_SRT']['BI040']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['ZI001_SRT']['BI044']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['ZI001_SRT']['BI050']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['ZI001_SRT']['BI070']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['ZI001_SRT']['ZD070']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['HydrographyPnt']['ZI002_UFI'] = ('StructuredText',('BB110','BD115','BD140','BD181','BH012','BH082','BH120','BH145','BH170','BH180','BH230','BI010','BI020','BI040','BI044','BI050','BI070','ZD070'))
    field_information['GGDM 3.0']['HydrographyPnt']['ZI004_RCG'] = ('Enumeration',('BB110','BD115','BD140','BD181','BH012','BH082','BH120','BH145','BH170','BH180','BH230','BI010','BI020','BI040','BI044','BI050','BI070','ZD070'))
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['ZI004_RCG']['BB110']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['ZI004_RCG']['BD115']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['ZI004_RCG']['BD140']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['ZI004_RCG']['BD181']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['ZI004_RCG']['BH012']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['ZI004_RCG']['BH082']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['ZI004_RCG']['BH120']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['ZI004_RCG']['BH145']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['ZI004_RCG']['BH170']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['ZI004_RCG']['BH180']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['ZI004_RCG']['BH230']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['ZI004_RCG']['BI010']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['ZI004_RCG']['BI020']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['ZI004_RCG']['BI040']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['ZI004_RCG']['BI044']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['ZI004_RCG']['BI050']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['ZI004_RCG']['BI070']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['ZI004_RCG']['ZD070']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['HydrographyPnt']['ZI005_FNA'] = ('String',('BB110','BD115','BD140','BD181','BH012','BH082','BH120','BH145','BH170','BH180','BH230','BI010','BI020','BI044','BI050','BI070','ZD070'))
    field_information['GGDM 3.0']['HydrographyPnt']['ZI005_FNA2'] = ('String',('BH082','BH170','BH230','BI010','BI020','BI070','ZD070'))
    field_information['GGDM 3.0']['HydrographyPnt']['ZI005_FNA3'] = ('String',('BH082','BI020','ZD070'))
    field_information['GGDM 3.0']['HydrographyPnt']['ZI005_GNT'] = ('Enumeration',('BB110','BD115','BD140','BD181','BH012','BH082','BH120','BH145','BH170','BH180','BH230','BI010','BI020','BI044','BI050','BI070','ZD070'))
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['ZI005_GNT']['BB110']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['ZI005_GNT']['BD115']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['ZI005_GNT']['BD140']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['ZI005_GNT']['BD181']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['ZI005_GNT']['BH012']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['ZI005_GNT']['BH082']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['ZI005_GNT']['BH120']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['ZI005_GNT']['BH145']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['ZI005_GNT']['BH170']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['ZI005_GNT']['BH180']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['ZI005_GNT']['BH230']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['ZI005_GNT']['BI010']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['ZI005_GNT']['BI020']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['ZI005_GNT']['BI044']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['ZI005_GNT']['BI050']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['ZI005_GNT']['BI070']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['ZI005_GNT']['ZD070']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['HydrographyPnt']['ZI005_GNT2'] = ('Enumeration',('BH082','BH170','BH230','BI010','BI020','BI070','ZD070'))
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['ZI005_GNT2'] = {}
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['ZI005_GNT2']['BH082']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['ZI005_GNT2']['BH170']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['ZI005_GNT2']['BH230']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['ZI005_GNT2']['BI010']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['ZI005_GNT2']['BI020']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['ZI005_GNT2']['BI070']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['ZI005_GNT2']['ZD070']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['HydrographyPnt']['ZI005_GNT3'] = ('Enumeration',('BH082','BI020','ZD070'))
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['ZI005_GNT3'] = {}
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['ZI005_GNT3']['BH082']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['ZI005_GNT3']['BI020']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['ZI005_GNT3']['ZD070']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['HydrographyPnt']['ZI005_NFN'] = ('String',('BB110','BD115','BD140','BD181','BH012','BH082','BH120','BH145','BH170','BH180','BH230','BI010','BI020','BI044','BI050','BI070','ZD070'))
    field_information['GGDM 3.0']['HydrographyPnt']['ZI005_NFN2'] = ('String',('BH082','BH170','BH230','BI010','BI020','BI070','ZD070'))
    field_information['GGDM 3.0']['HydrographyPnt']['ZI005_NFN3'] = ('String',('BH082','BI020','ZD070'))
    field_information['GGDM 3.0']['HydrographyPnt']['ZI006_MEM'] = ('String',('BB110','BD115','BD140','BD181','BH012','BH082','BH120','BH145','BH170','BH180','BH230','BI010','BI020','BI040','BI044','BI050','BI070','ZD070'))
    field_information['GGDM 3.0']['HydrographyPnt']['ZI020_GE4'] = ('CodeList',('BB110','BD115','BD140','BD181','BH012','BH082','BH120','BH145','BH170','BH180','BH230','BI010','BI020','BI040','BI044','BI050','BI070','ZD070'))
    field_information['GGDM 3.0']['HydrographyPnt']['ZI024_ASE'] = ('Real',('BH012','BH082','BH145','BH170','BH230','BI010','BI050','BI070','ZD070'))
    field_information['GGDM 3.0']['HydrographyPnt']['ZI024_AWO'] = ('Real',('BH170','BH230','BI070'))
    field_information['GGDM 3.0']['HydrographyPnt']['ZI024_AWOI'] = ('Real',('BH170','BH230','BI070'))
    field_information['GGDM 3.0']['HydrographyPnt']['ZI024_AWOX'] = ('Real',('BH170','BH230','BI070'))
    field_information['GGDM 3.0']['HydrographyPnt']['ZI024_CFR'] = ('Real',('BH012','BH082','BH145','BH170','BH230','BI010','BI050','BI070','ZD070'))
    field_information['GGDM 3.0']['HydrographyPnt']['ZI024_CLO'] = ('Real',('BH012','BH082','BH145','BH170','BH230','BI010','BI050','BI070','ZD070'))
    field_information['GGDM 3.0']['HydrographyPnt']['ZI024_CYN'] = ('Real',('BH012','BH082','BH145','BH170','BH230','BI010','BI050','BI070','ZD070'))
    field_information['GGDM 3.0']['HydrographyPnt']['ZI024_DRL'] = ('Enumeration',('BH230'))
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['ZI024_DRL'] = {}
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['ZI024_DRL']['BH230']  = (-999999,17,40,44,45,50,999)
    field_information['GGDM 3.0']['HydrographyPnt']['ZI024_DVPT'] = ('Enumeration',('BH230'))
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['ZI024_DVPT'] = {}
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['ZI024_DVPT']['BH230']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['HydrographyPnt']['ZI024_FMR'] = ('Real',('BH012','BH082','BH145','BH170','BH230','BI010','BI050','BI070','ZD070'))
    field_information['GGDM 3.0']['HydrographyPnt']['ZI024_FRR'] = ('Real',('BH012','BH082','BH145','BH170','BH230','BI010','BI050','BI070','ZD070'))
    field_information['GGDM 3.0']['HydrographyPnt']['ZI024_HAR'] = ('Real',('BH012','BH082','BH145','BH170','BH230','BI010','BI050','BI070','ZD070'))
    field_information['GGDM 3.0']['HydrographyPnt']['ZI024_HYP'] = ('Enumeration',('BH082','BH170','BH230','BI010','BI050','ZD070'))
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['ZI024_HYP'] = {}
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['ZI024_HYP']['BH082']  = (-999999,1,2,4)
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['ZI024_HYP']['BH170']  = (-999999,1,2,4)
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['ZI024_HYP']['BH230']  = (-999999,1,2,4)
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['ZI024_HYP']['BI010']  = (-999999,1,2,4)
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['ZI024_HYP']['BI050']  = (-999999,1,2,4)
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['ZI024_HYP']['ZD070']  = (-999999,1,2,4)
    field_information['GGDM 3.0']['HydrographyPnt']['ZI024_MGN'] = ('Real',('BH012','BH082','BH145','BH170','BH230','BI010','BI050','BI070','ZD070'))
    field_information['GGDM 3.0']['HydrographyPnt']['ZI024_PHW'] = ('Real',('BH012','BH082','BH145','BH170','BH230','BI010','BI050','BI070','ZD070'))
    field_information['GGDM 3.0']['HydrographyPnt']['ZI024_PMP'] = ('Enumeration',('BH230'))
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['ZI024_PMP'] = {}
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['ZI024_PMP']['BH230']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['GGDM 3.0']['HydrographyPnt']['ZI024_RTP'] = ('Enumeration',('BH082'))
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['ZI024_RTP'] = {}
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['ZI024_RTP']['BH082']  = (-999999,1,2,999)
    field_information['GGDM 3.0']['HydrographyPnt']['ZI024_SCC'] = ('Enumeration',('BH012','BH082','BH145','BH170','BH230','BI010','BI050','BI070','ZD070'))
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['ZI024_SCC'] = {}
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['ZI024_SCC']['BH012']  = (-999999,1,4,10,11,12,13,14,998,999)
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['ZI024_SCC']['BH082']  = (-999999,1,4,10,11,12,13,14,998)
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['ZI024_SCC']['BH145']  = (-999999,1,4,10,11,12,13,14,998,999)
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['ZI024_SCC']['BH170']  = (-999999,1,4,10,11,12,13,14,998)
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['ZI024_SCC']['BH230']  = (-999999,1,4,10,11,12,13,14,998)
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['ZI024_SCC']['BI010']  = (-999999,1,4,10,11,12,13,14,998,999)
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['ZI024_SCC']['BI050']  = (-999999,1,4,10,11,12,13,14,998,999)
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['ZI024_SCC']['BI070']  = (-999999,1,4,10,11,12,13,14,998,999)
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['ZI024_SCC']['ZD070']  = (-999999,1,4,10,11,12,13,14,998)
    field_information['GGDM 3.0']['HydrographyPnt']['ZI024_SUL'] = ('Real',('BH012','BH082','BH145','BH170','BH230','BI010','BI050','BI070','ZD070'))
    field_information['GGDM 3.0']['HydrographyPnt']['ZI024_TDS'] = ('Real',('BH012','BH082','BH145','BH170','BH230','BI010','BI050','BI070','ZD070'))
    field_information['GGDM 3.0']['HydrographyPnt']['ZI024_TEP'] = ('Real',('BH012','BH082','BH145','BH170','BH230','BI010','BI050','BI070','ZD070'))
    field_information['GGDM 3.0']['HydrographyPnt']['ZI024_TUR'] = ('Real',('BH012','BH082','BH145','BH170','BH230','BI010','BI050','BI070','ZD070'))
    field_information['GGDM 3.0']['HydrographyPnt']['ZI024_WAC'] = ('Real',('BH012','BH082','BH145','BH170','BH230','BI010','BI050','BI070','ZD070'))
    field_information['GGDM 3.0']['HydrographyPnt']['ZI024_WPAC'] = ('Enumeration',('BI020'))
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['ZI024_WPAC'] = {}
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['ZI024_WPAC']['BI020']  = (-999999,100,101,102,103,104,105,106,107)
    field_information['GGDM 3.0']['HydrographyPnt']['ZI024_WTBB'] = ('Real',('BH230'))
    field_information['GGDM 3.0']['HydrographyPnt']['ZI024_WTCA'] = ('Real',('BH230'))
    field_information['GGDM 3.0']['HydrographyPnt']['ZI024_WTFE'] = ('Real',('BH230'))
    field_information['GGDM 3.0']['HydrographyPnt']['ZI024_WTKK'] = ('Real',('BH230'))
    field_information['GGDM 3.0']['HydrographyPnt']['ZI024_WTMN'] = ('Real',('BH230'))
    field_information['GGDM 3.0']['HydrographyPnt']['ZI024_WTNA'] = ('Real',('BH230'))
    field_information['GGDM 3.0']['HydrographyPnt']['ZI024_WTNO'] = ('Real',('BH012','BH082','BH145','BH170','BH230','BI010','BI050','BI070','ZD070'))
    field_information['GGDM 3.0']['HydrographyPnt']['ZI024_WTPO'] = ('Real',('BH230'))
    field_information['GGDM 3.0']['HydrographyPnt']['ZI024_WTSI'] = ('Real',('BH230'))
    field_information['GGDM 3.0']['HydrographyPnt']['ZI024_WUR'] = ('Enumeration',('BH082','BH170','BH230','BI010'))
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['ZI024_WUR'] = {}
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['ZI024_WUR']['BH082']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['ZI024_WUR']['BH170']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['ZI024_WUR']['BH230']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['ZI024_WUR']['BI010']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['HydrographyPnt']['ZI024_WUR2'] = ('Enumeration',('BH082','BH170','BH230','BI010'))
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['ZI024_WUR2'] = {}
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['ZI024_WUR2']['BH082']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['ZI024_WUR2']['BH170']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['ZI024_WUR2']['BH230']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['ZI024_WUR2']['BI010']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['HydrographyPnt']['ZI024_WUR3'] = ('Enumeration',('BH082','BH170','BH230','BI010'))
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['ZI024_WUR3'] = {}
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['ZI024_WUR3']['BH082']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['ZI024_WUR3']['BH170']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['ZI024_WUR3']['BH230']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['ZI024_WUR3']['BI010']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['HydrographyPnt']['ZI024_WUR4'] = ('Enumeration',('BH082','BH170','BH230','BI010'))
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['ZI024_WUR4'] = {}
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['ZI024_WUR4']['BH082']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['ZI024_WUR4']['BH170']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['ZI024_WUR4']['BH230']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['ZI024_WUR4']['BI010']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['HydrographyPnt']['ZI024_YWQ'] = ('Enumeration',('BH012','BH082','BH145','BH170','BH230','BI010','BI050','ZD070'))
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['ZI024_YWQ'] = {}
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['ZI024_YWQ']['BH012']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['ZI024_YWQ']['BH082']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['ZI024_YWQ']['BH145']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['ZI024_YWQ']['BH170']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['ZI024_YWQ']['BH230']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['ZI024_YWQ']['BI010']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['ZI024_YWQ']['BI050']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['ZI024_YWQ']['ZD070']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['HydrographyPnt']['ZI025_HDP'] = ('Real',('BD115','BD140'))
    field_information['GGDM 3.0']['HydrographyPnt']['ZI025_MAN'] = ('Boolean',('BD115'))
    field_information['GGDM 3.0']['HydrographyPnt']['ZI026_CTUC'] = ('Enumeration',('BB110','BD115','BD140','BD181','BH012','BH082','BH120','BH145','BH170','BH180','BH230','BI010','BI020','BI040','BI044','BI050','BI070','ZD070'))
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['ZI026_CTUC']['BB110']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['ZI026_CTUC']['BD115']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['ZI026_CTUC']['BD140']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['ZI026_CTUC']['BD181']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['ZI026_CTUC']['BH012']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['ZI026_CTUC']['BH082']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['ZI026_CTUC']['BH120']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['ZI026_CTUC']['BH145']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['ZI026_CTUC']['BH170']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['ZI026_CTUC']['BH180']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['ZI026_CTUC']['BH230']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['ZI026_CTUC']['BI010']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['ZI026_CTUC']['BI020']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['ZI026_CTUC']['BI040']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['ZI026_CTUC']['BI044']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['ZI026_CTUC']['BI050']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['ZI026_CTUC']['BI070']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['HydrographyPnt']['EnumeratedIndexValues']['ZI026_CTUC']['ZD070']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['HydrographyPnt']['ZI026_CTUL'] = ('integer',('BB110','BD115','BD140','BD181','BH012','BH082','BH120','BH145','BH170','BH180','BH230','BI010','BI020','BI040','BI044','BI050','BI070','ZD070'))
    field_information['GGDM 3.0']['HydrographyPnt']['ZI026_CTUU'] = ('integer',('BB110','BD115','BD140','BD181','BH012','BH082','BH120','BH145','BH170','BH180','BH230','BI010','BI020','BI040','BI044','BI050','BI070','ZD070'))
    field_information['GGDM 3.0']['HydrographyPnt']['ZI031S_URI'] = ('StructuredText',('BB110','BD115','BD140','BD181','BH012','BH082','BH120','BH145','BH170','BH180','BH230','BI010','BI020','BI040','BI044','BI050','BI070','ZD070'))
    field_information['GGDM 3.0']['HydrographyPnt']['ZI039S_UFI'] = ('StructuredText',('BB110','BD115','BD140','BD181','BH012','BH082','BH120','BH145','BH170','BH180','BH230','BI010','BI020','BI040','BI044','BI050','BI070','ZD070'))
    field_information['GGDM 3.0']['HydrographyPnt']['ZSAX_RS0'] = ('CodeList',('BB110','BD115','BD140','BD181','BH012','BH082','BH120','BH145','BH170','BH180','BH230','BI010','BI020','BI040','BI044','BI050','BI070','ZD070'))
    field_information['GGDM 3.0']['HydrographyPnt']['ZSAX_RX0'] = ('StructuredText',('BB110','BD115','BD140','BD181','BH012','BH082','BH120','BH145','BH170','BH180','BH230','BI010','BI020','BI040','BI044','BI050','BI070','ZD070'))
    field_information['GGDM 3.0']['HydrographyPnt']['ZSAX_RX3'] = ('StructuredText',('BB110','BD115','BD140','BD181','BH012','BH082','BH120','BH145','BH170','BH180','BH230','BI010','BI020','BI040','BI044','BI050','BI070','ZD070'))
    field_information['GGDM 3.0']['HydrographyPnt']['ZSAX_RX4'] = ('StructuredText',('BB110','BD115','BD140','BD181','BH012','BH082','BH120','BH145','BH170','BH180','BH230','BI010','BI020','BI040','BI044','BI050','BI070','ZD070'))
    field_information['GGDM 3.0']['HydrographyPnt']['ZVH'] = ('Real',('BD115','BD181','BH012','BH082','BH180','BH230','BI010','BI020','BI044','BI050'))
    field_information['GGDM 3.0']['HydrographyPntExt']['ARA'] = ('Real',('BD030','BD050','BD061','BD130','BD180','BF010'))
    field_information['GGDM 3.0']['HydrographyPntExt']['BEN'] = ('StructuredText',('BD020','BD030','BD050','BD061','BD130','BD180','BE020','BF010','BG010','BG012','BG030','FC041'))
    field_information['GGDM 3.0']['HydrographyPntExt']['C35'] = ('Real',('BG010','BG030'))
    field_information['GGDM 3.0']['HydrographyPntExt']['C36'] = ('Real',('BG010','BG030'))
    field_information['GGDM 3.0']['HydrographyPntExt']['C37'] = ('Real',('BG010','BG030'))
    field_information['GGDM 3.0']['HydrographyPntExt']['C38'] = ('Real',('BG010','BG030'))
    field_information['GGDM 3.0']['HydrographyPntExt']['C39'] = ('Real',('BG010','BG030'))
    field_information['GGDM 3.0']['HydrographyPntExt']['C40'] = ('Real',('BG010','BG030'))
    field_information['GGDM 3.0']['HydrographyPntExt']['C41'] = ('Real',('BG010','BG030'))
    field_information['GGDM 3.0']['HydrographyPntExt']['C42'] = ('Real',('BG010','BG030'))
    field_information['GGDM 3.0']['HydrographyPntExt']['C43'] = ('Real',('BG010','BG030'))
    field_information['GGDM 3.0']['HydrographyPntExt']['C44'] = ('Real',('BG010','BG030'))
    field_information['GGDM 3.0']['HydrographyPntExt']['C45'] = ('Real',('BG010','BG030'))
    field_information['GGDM 3.0']['HydrographyPntExt']['C46'] = ('Real',('BG010','BG030'))
    field_information['GGDM 3.0']['HydrographyPntExt']['CAA'] = ('Enumeration',('FC041'))
    field_information['GGDM 3.0']['HydrographyPntExt']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['HydrographyPntExt']['EnumeratedIndexValues']['CAA']['FC041']  = (-999999,1,8,16,999)
    field_information['GGDM 3.0']['HydrographyPntExt']['CNCP'] = ('StructuredText',('BD020','BG030'))
    field_information['GGDM 3.0']['HydrographyPntExt']['COS'] = ('Enumeration',('BD020','BG030'))
    field_information['GGDM 3.0']['HydrographyPntExt']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['HydrographyPntExt']['EnumeratedIndexValues']['COS']['BD020']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['HydrographyPntExt']['EnumeratedIndexValues']['COS']['BG030']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['HydrographyPntExt']['CRN'] = ('Real',('BG010'))
    field_information['GGDM 3.0']['HydrographyPntExt']['CRS'] = ('Real',('BG010'))
    field_information['GGDM 3.0']['HydrographyPntExt']['CRX'] = ('Real',('BG010'))
    field_information['GGDM 3.0']['HydrographyPntExt']['CUR'] = ('Enumeration',('BG010'))
    field_information['GGDM 3.0']['HydrographyPntExt']['EnumeratedIndexValues']['CUR'] = {}
    field_information['GGDM 3.0']['HydrographyPntExt']['EnumeratedIndexValues']['CUR']['BG010']  = (-999999,1,2,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['HydrographyPntExt']['D35'] = ('Real',('BG010','BG030'))
    field_information['GGDM 3.0']['HydrographyPntExt']['D36'] = ('Real',('BG010','BG030'))
    field_information['GGDM 3.0']['HydrographyPntExt']['D37'] = ('Real',('BG010','BG030'))
    field_information['GGDM 3.0']['HydrographyPntExt']['D38'] = ('Real',('BG010','BG030'))
    field_information['GGDM 3.0']['HydrographyPntExt']['D39'] = ('Real',('BG010','BG030'))
    field_information['GGDM 3.0']['HydrographyPntExt']['D40'] = ('Real',('BG010','BG030'))
    field_information['GGDM 3.0']['HydrographyPntExt']['D41'] = ('Real',('BG010','BG030'))
    field_information['GGDM 3.0']['HydrographyPntExt']['D42'] = ('Real',('BG010','BG030'))
    field_information['GGDM 3.0']['HydrographyPntExt']['D43'] = ('Real',('BG010','BG030'))
    field_information['GGDM 3.0']['HydrographyPntExt']['D44'] = ('Real',('BG010','BG030'))
    field_information['GGDM 3.0']['HydrographyPntExt']['D45'] = ('Real',('BG010','BG030'))
    field_information['GGDM 3.0']['HydrographyPntExt']['D46'] = ('Real',('BG010','BG030'))
    field_information['GGDM 3.0']['HydrographyPntExt']['DKC'] = ('Enumeration',('BD180'))
    field_information['GGDM 3.0']['HydrographyPntExt']['EnumeratedIndexValues']['DKC'] = {}
    field_information['GGDM 3.0']['HydrographyPntExt']['EnumeratedIndexValues']['DKC']['BD180']  = (-999999,1,3,4,5,6,8,9,998,999)
    field_information['GGDM 3.0']['HydrographyPntExt']['DKC2'] = ('Enumeration',('BD180'))
    field_information['GGDM 3.0']['HydrographyPntExt']['EnumeratedIndexValues']['DKC2'] = {}
    field_information['GGDM 3.0']['HydrographyPntExt']['EnumeratedIndexValues']['DKC2']['BD180']  = (-999999,1,3,4,5,6,8,9,998,999)
    field_information['GGDM 3.0']['HydrographyPntExt']['DKC3'] = ('Enumeration',('BD180'))
    field_information['GGDM 3.0']['HydrographyPntExt']['EnumeratedIndexValues']['DKC3'] = {}
    field_information['GGDM 3.0']['HydrographyPntExt']['EnumeratedIndexValues']['DKC3']['BD180']  = (-999999,1,3,4,5,6,8,9,998,999)
    field_information['GGDM 3.0']['HydrographyPntExt']['DOF'] = ('Real',('BG010','FC041'))
    field_information['GGDM 3.0']['HydrographyPntExt']['DTN'] = ('Boolean',('BD050','BD061','BD180'))
    field_information['GGDM 3.0']['HydrographyPntExt']['DZP'] = ('Real',('BG010'))
    field_information['GGDM 3.0']['HydrographyPntExt']['F_CODE'] = ('CONSTRAINED_STRING',('BD020','BD030','BD050','BD061','BD130','BD180','BE020','BF010','BG010','BG012','BG030','FC041'))
    field_information['GGDM 3.0']['HydrographyPntExt']['FLO'] = ('Boolean',('BD061'))
    field_information['GGDM 3.0']['HydrographyPntExt']['FUFI'] = ('StructuredText',('BD020','BD030','BD050','BD061','BD130','BD180','BE020','BF010','BG010','BG012','BG030','FC041'))
    field_information['GGDM 3.0']['HydrographyPntExt']['FURL'] = ('StructuredText',('BD020','BD030','BD050','BD061','BD130','BD180','BE020','BF010','BG010','BG012','BG030','FC041'))
    field_information['GGDM 3.0']['HydrographyPntExt']['GDBV'] = ('Enumeration',('BD020','BD030','BD050','BD061','BD130','BD180','BE020','BF010','BG010','BG012','BG030','FC041'))
    field_information['GGDM 3.0']['HydrographyPntExt']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['HydrographyPntExt']['EnumeratedIndexValues']['GDBV']['BD020']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['HydrographyPntExt']['EnumeratedIndexValues']['GDBV']['BD030']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['HydrographyPntExt']['EnumeratedIndexValues']['GDBV']['BD050']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['HydrographyPntExt']['EnumeratedIndexValues']['GDBV']['BD061']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['HydrographyPntExt']['EnumeratedIndexValues']['GDBV']['BD130']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['HydrographyPntExt']['EnumeratedIndexValues']['GDBV']['BD180']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['HydrographyPntExt']['EnumeratedIndexValues']['GDBV']['BE020']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['HydrographyPntExt']['EnumeratedIndexValues']['GDBV']['BF010']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['HydrographyPntExt']['EnumeratedIndexValues']['GDBV']['BG010']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['HydrographyPntExt']['EnumeratedIndexValues']['GDBV']['BG012']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['HydrographyPntExt']['EnumeratedIndexValues']['GDBV']['BG030']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['HydrographyPntExt']['EnumeratedIndexValues']['GDBV']['FC041']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['HydrographyPntExt']['HDH'] = ('Real',('BE020'))
    field_information['GGDM 3.0']['HydrographyPntExt']['HDP'] = ('Real',('BE020','BG010'))
    field_information['GGDM 3.0']['HydrographyPntExt']['HSE'] = ('StructuredText',('BG010'))
    field_information['GGDM 3.0']['HydrographyPntExt']['IAS'] = ('Boolean',('FC041'))
    field_information['GGDM 3.0']['HydrographyPntExt']['LZN'] = ('Real',('BD030','BD050','BD061','BD130','BD180','BF010','FC041'))
    field_information['GGDM 3.0']['HydrographyPntExt']['MAN'] = ('Boolean',('FC041'))
    field_information['GGDM 3.0']['HydrographyPntExt']['MBC_MCC1'] = ('Enumeration',('BF010'))
    field_information['GGDM 3.0']['HydrographyPntExt']['EnumeratedIndexValues']['MBC_MCC1'] = {}
    field_information['GGDM 3.0']['HydrographyPntExt']['EnumeratedIndexValues']['MBC_MCC1']['BF010']  = (-999999,4,7,8,10,12,14,15,16,18,22,24,25,28,36,37,45,46,49,52,55,58,59,61,63,65,66,69,70,73,75,79,80,81,84,88,90,92,96,98,99,103,104,105,106,108,111,115,999)
    field_information['GGDM 3.0']['HydrographyPntExt']['MBC_MCC2'] = ('Enumeration',('BF010'))
    field_information['GGDM 3.0']['HydrographyPntExt']['EnumeratedIndexValues']['MBC_MCC2'] = {}
    field_information['GGDM 3.0']['HydrographyPntExt']['EnumeratedIndexValues']['MBC_MCC2']['BF010']  = (-999999,4,7,8,10,12,14,15,16,18,22,24,25,28,36,37,45,46,49,52,55,58,59,61,63,65,66,69,70,73,75,79,80,81,84,88,90,92,96,98,99,103,104,105,106,108,111,115,999)
    field_information['GGDM 3.0']['HydrographyPntExt']['MBC_PSC1'] = ('Enumeration',('BF010'))
    field_information['GGDM 3.0']['HydrographyPntExt']['EnumeratedIndexValues']['MBC_PSC1'] = {}
    field_information['GGDM 3.0']['HydrographyPntExt']['EnumeratedIndexValues']['MBC_PSC1']['BF010']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,17,18,19,20,21,22,23,24,25,26,27,29,999)
    field_information['GGDM 3.0']['HydrographyPntExt']['MBC_PSC2'] = ('Enumeration',('BF010'))
    field_information['GGDM 3.0']['HydrographyPntExt']['EnumeratedIndexValues']['MBC_PSC2'] = {}
    field_information['GGDM 3.0']['HydrographyPntExt']['EnumeratedIndexValues']['MBC_PSC2']['BF010']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,17,18,19,20,21,22,23,24,25,26,27,29,999)
    field_information['GGDM 3.0']['HydrographyPntExt']['MBC_SCO1'] = ('Enumeration',('BF010'))
    field_information['GGDM 3.0']['HydrographyPntExt']['EnumeratedIndexValues']['MBC_SCO1'] = {}
    field_information['GGDM 3.0']['HydrographyPntExt']['EnumeratedIndexValues']['MBC_SCO1']['BF010']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,999)
    field_information['GGDM 3.0']['HydrographyPntExt']['MBC_SCO2'] = ('Enumeration',('BF010'))
    field_information['GGDM 3.0']['HydrographyPntExt']['EnumeratedIndexValues']['MBC_SCO2'] = {}
    field_information['GGDM 3.0']['HydrographyPntExt']['EnumeratedIndexValues']['MBC_SCO2']['BF010']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,999)
    field_information['GGDM 3.0']['HydrographyPntExt']['MCC'] = ('Enumeration',('BD130'))
    field_information['GGDM 3.0']['HydrographyPntExt']['EnumeratedIndexValues']['MCC'] = {}
    field_information['GGDM 3.0']['HydrographyPntExt']['EnumeratedIndexValues']['MCC']['BD130']  = (-999999,24,25,52,84,999)
    field_information['GGDM 3.0']['HydrographyPntExt']['MCC2'] = ('Enumeration',('BD130'))
    field_information['GGDM 3.0']['HydrographyPntExt']['EnumeratedIndexValues']['MCC2'] = {}
    field_information['GGDM 3.0']['HydrographyPntExt']['EnumeratedIndexValues']['MCC2']['BD130']  = (-999999,24,25,52,84,999)
    field_information['GGDM 3.0']['HydrographyPntExt']['MCC3'] = ('Enumeration',('BD130'))
    field_information['GGDM 3.0']['HydrographyPntExt']['EnumeratedIndexValues']['MCC3'] = {}
    field_information['GGDM 3.0']['HydrographyPntExt']['EnumeratedIndexValues']['MCC3']['BD130']  = (-999999,24,25,52,84,999)
    field_information['GGDM 3.0']['HydrographyPntExt']['OTH'] = ('StructuredText',('BD020','BD030','BD050','BD061','BD130','BD180','BE020','BF010','BG010','BG012','BG030','FC041'))
    field_information['GGDM 3.0']['HydrographyPntExt']['PCF'] = ('Enumeration',('BD020','BG030'))
    field_information['GGDM 3.0']['HydrographyPntExt']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['HydrographyPntExt']['EnumeratedIndexValues']['PCF']['BD020']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['HydrographyPntExt']['EnumeratedIndexValues']['PCF']['BG030']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['HydrographyPntExt']['REW'] = ('Enumeration',('BG010','BG030'))
    field_information['GGDM 3.0']['HydrographyPntExt']['EnumeratedIndexValues']['REW'] = {}
    field_information['GGDM 3.0']['HydrographyPntExt']['EnumeratedIndexValues']['REW']['BG010']  = (-999999,1,2)
    field_information['GGDM 3.0']['HydrographyPntExt']['EnumeratedIndexValues']['REW']['BG030']  = (-999999,1,2)
    field_information['GGDM 3.0']['HydrographyPntExt']['TAN'] = ('String',('FC041'))
    field_information['GGDM 3.0']['HydrographyPntExt']['TSP'] = ('Enumeration',('FC041'))
    field_information['GGDM 3.0']['HydrographyPntExt']['EnumeratedIndexValues']['TSP'] = {}
    field_information['GGDM 3.0']['HydrographyPntExt']['EnumeratedIndexValues']['TSP']['FC041']  = (-999999,2,3,4,5,6,7,8,9,10,11,12,999)
    field_information['GGDM 3.0']['HydrographyPntExt']['UFI'] = ('StructuredText',('BD020','BD030','BD050','BD061','BD130','BD180','BE020','BF010','BG010','BG012','BG030','FC041'))
    field_information['GGDM 3.0']['HydrographyPntExt']['VEG'] = ('Enumeration',('BF010'))
    field_information['GGDM 3.0']['HydrographyPntExt']['EnumeratedIndexValues']['VEG'] = {}
    field_information['GGDM 3.0']['HydrographyPntExt']['EnumeratedIndexValues']['VEG']['BF010']  = (-999999,61,62,999)
    field_information['GGDM 3.0']['HydrographyPntExt']['VSP'] = ('Enumeration',('BD061'))
    field_information['GGDM 3.0']['HydrographyPntExt']['EnumeratedIndexValues']['VSP'] = {}
    field_information['GGDM 3.0']['HydrographyPntExt']['EnumeratedIndexValues']['VSP']['BD061']  = (-999999,17,19,22,28,29,30,31,35,36,999)
    field_information['GGDM 3.0']['HydrographyPntExt']['VSP2'] = ('Enumeration',('BD061'))
    field_information['GGDM 3.0']['HydrographyPntExt']['EnumeratedIndexValues']['VSP2'] = {}
    field_information['GGDM 3.0']['HydrographyPntExt']['EnumeratedIndexValues']['VSP2']['BD061']  = (-999999,17,19,22,28,29,30,31,35,36,999)
    field_information['GGDM 3.0']['HydrographyPntExt']['VSP3'] = ('Enumeration',('BD061'))
    field_information['GGDM 3.0']['HydrographyPntExt']['EnumeratedIndexValues']['VSP3'] = {}
    field_information['GGDM 3.0']['HydrographyPntExt']['EnumeratedIndexValues']['VSP3']['BD061']  = (-999999,17,19,22,28,29,30,31,35,36,999)
    field_information['GGDM 3.0']['HydrographyPntExt']['WID'] = ('Real',('BD030','BD050','BD061','BF010','FC041'))
    field_information['GGDM 3.0']['HydrographyPntExt']['WLO'] = ('Enumeration',('BD180'))
    field_information['GGDM 3.0']['HydrographyPntExt']['EnumeratedIndexValues']['WLO'] = {}
    field_information['GGDM 3.0']['HydrographyPntExt']['EnumeratedIndexValues']['WLO']['BD180']  = (-999999,1,2,3,4,5,6,999)
    field_information['GGDM 3.0']['HydrographyPntExt']['WTT'] = ('Enumeration',('BG012'))
    field_information['GGDM 3.0']['HydrographyPntExt']['EnumeratedIndexValues']['WTT'] = {}
    field_information['GGDM 3.0']['HydrographyPntExt']['EnumeratedIndexValues']['WTT']['BG012']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['HydrographyPntExt']['ZHBH_TEC'] = ('Enumeration',('BD020','BD130','BD180'))
    field_information['GGDM 3.0']['HydrographyPntExt']['EnumeratedIndexValues']['ZHBH_TEC'] = {}
    field_information['GGDM 3.0']['HydrographyPntExt']['EnumeratedIndexValues']['ZHBH_TEC']['BD020']  = (-999999,1,2,3,4,5,6,8,9,10,11,12,13,14,15,17,18,999)
    field_information['GGDM 3.0']['HydrographyPntExt']['EnumeratedIndexValues']['ZHBH_TEC']['BD130']  = (-999999,1,2,3,4,5,6,8,9,10,11,12,13,14,15,17,18,999)
    field_information['GGDM 3.0']['HydrographyPntExt']['EnumeratedIndexValues']['ZHBH_TEC']['BD180']  = (-999999,1,2,3,4,5,6,8,9,10,11,12,13,14,15,17,18,999)
    field_information['GGDM 3.0']['HydrographyPntExt']['ZHBH_TEC2'] = ('Enumeration',('BD020','BD130','BD180'))
    field_information['GGDM 3.0']['HydrographyPntExt']['EnumeratedIndexValues']['ZHBH_TEC2'] = {}
    field_information['GGDM 3.0']['HydrographyPntExt']['EnumeratedIndexValues']['ZHBH_TEC2']['BD020']  = (-999999,1,2,3,4,5,6,8,9,10,11,12,13,14,15,17,18,999)
    field_information['GGDM 3.0']['HydrographyPntExt']['EnumeratedIndexValues']['ZHBH_TEC2']['BD130']  = (-999999,1,2,3,4,5,6,8,9,10,11,12,13,14,15,17,18,999)
    field_information['GGDM 3.0']['HydrographyPntExt']['EnumeratedIndexValues']['ZHBH_TEC2']['BD180']  = (-999999,1,2,3,4,5,6,8,9,10,11,12,13,14,15,17,18,999)
    field_information['GGDM 3.0']['HydrographyPntExt']['ZHBH_TEC3'] = ('Enumeration',('BD020','BD130','BD180'))
    field_information['GGDM 3.0']['HydrographyPntExt']['EnumeratedIndexValues']['ZHBH_TEC3'] = {}
    field_information['GGDM 3.0']['HydrographyPntExt']['EnumeratedIndexValues']['ZHBH_TEC3']['BD020']  = (-999999,1,2,3,4,5,6,8,9,10,11,12,13,14,15,17,18,999)
    field_information['GGDM 3.0']['HydrographyPntExt']['EnumeratedIndexValues']['ZHBH_TEC3']['BD130']  = (-999999,1,2,3,4,5,6,8,9,10,11,12,13,14,15,17,18,999)
    field_information['GGDM 3.0']['HydrographyPntExt']['EnumeratedIndexValues']['ZHBH_TEC3']['BD180']  = (-999999,1,2,3,4,5,6,8,9,10,11,12,13,14,15,17,18,999)
    field_information['GGDM 3.0']['HydrographyPntExt']['ZHDP_DCR'] = ('Boolean',('BG010'))
    field_information['GGDM 3.0']['HydrographyPntExt']['ZHDP_DKC'] = ('Enumeration',('BG010'))
    field_information['GGDM 3.0']['HydrographyPntExt']['EnumeratedIndexValues']['ZHDP_DKC'] = {}
    field_information['GGDM 3.0']['HydrographyPntExt']['EnumeratedIndexValues']['ZHDP_DKC']['BG010']  = (-999999,1,3,4,5,6,7,8,9,10,11,12,998,999)
    field_information['GGDM 3.0']['HydrographyPntExt']['ZHDP_DKC2'] = ('Enumeration',('BG010'))
    field_information['GGDM 3.0']['HydrographyPntExt']['EnumeratedIndexValues']['ZHDP_DKC2'] = {}
    field_information['GGDM 3.0']['HydrographyPntExt']['EnumeratedIndexValues']['ZHDP_DKC2']['BG010']  = (-999999,1,3,4,5,6,7,8,9,10,11,12,998,999)
    field_information['GGDM 3.0']['HydrographyPntExt']['ZHDP_DKC3'] = ('Enumeration',('BG010'))
    field_information['GGDM 3.0']['HydrographyPntExt']['EnumeratedIndexValues']['ZHDP_DKC3'] = {}
    field_information['GGDM 3.0']['HydrographyPntExt']['EnumeratedIndexValues']['ZHDP_DKC3']['BG010']  = (-999999,1,3,4,5,6,7,8,9,10,11,12,998,999)
    field_information['GGDM 3.0']['HydrographyPntExt']['ZHDP_SVC'] = ('Enumeration',('BE020','BG010'))
    field_information['GGDM 3.0']['HydrographyPntExt']['EnumeratedIndexValues']['ZHDP_SVC'] = {}
    field_information['GGDM 3.0']['HydrographyPntExt']['EnumeratedIndexValues']['ZHDP_SVC']['BE020']  = (-999999,1,2,3,4,5,998,999)
    field_information['GGDM 3.0']['HydrographyPntExt']['EnumeratedIndexValues']['ZHDP_SVC']['BG010']  = (-999999,1,2,3,4,5,998,999)
    field_information['GGDM 3.0']['HydrographyPntExt']['ZHDP_TEC'] = ('Enumeration',('BE020','BG010'))
    field_information['GGDM 3.0']['HydrographyPntExt']['EnumeratedIndexValues']['ZHDP_TEC'] = {}
    field_information['GGDM 3.0']['HydrographyPntExt']['EnumeratedIndexValues']['ZHDP_TEC']['BE020']  = (-999999,1,2,3,4,5,6,8,9,10,11,12,13,14,15,17,18,999)
    field_information['GGDM 3.0']['HydrographyPntExt']['EnumeratedIndexValues']['ZHDP_TEC']['BG010']  = (-999999,1,2,3,4,5,6,8,9,10,11,12,13,14,15,17,18,999)
    field_information['GGDM 3.0']['HydrographyPntExt']['ZHDP_TEC2'] = ('Enumeration',('BE020','BG010'))
    field_information['GGDM 3.0']['HydrographyPntExt']['EnumeratedIndexValues']['ZHDP_TEC2'] = {}
    field_information['GGDM 3.0']['HydrographyPntExt']['EnumeratedIndexValues']['ZHDP_TEC2']['BE020']  = (-999999,1,2,3,4,5,6,8,9,10,11,12,13,14,15,17,18,999)
    field_information['GGDM 3.0']['HydrographyPntExt']['EnumeratedIndexValues']['ZHDP_TEC2']['BG010']  = (-999999,1,2,3,4,5,6,8,9,10,11,12,13,14,15,17,18,999)
    field_information['GGDM 3.0']['HydrographyPntExt']['ZHDP_TEC3'] = ('Enumeration',('BE020','BG010'))
    field_information['GGDM 3.0']['HydrographyPntExt']['EnumeratedIndexValues']['ZHDP_TEC3'] = {}
    field_information['GGDM 3.0']['HydrographyPntExt']['EnumeratedIndexValues']['ZHDP_TEC3']['BE020']  = (-999999,1,2,3,4,5,6,8,9,10,11,12,13,14,15,17,18,999)
    field_information['GGDM 3.0']['HydrographyPntExt']['EnumeratedIndexValues']['ZHDP_TEC3']['BG010']  = (-999999,1,2,3,4,5,6,8,9,10,11,12,13,14,15,17,18,999)
    field_information['GGDM 3.0']['HydrographyPntExt']['ZHDP_VDC'] = ('Enumeration',('BE020','BG010'))
    field_information['GGDM 3.0']['HydrographyPntExt']['EnumeratedIndexValues']['ZHDP_VDC'] = {}
    field_information['GGDM 3.0']['HydrographyPntExt']['EnumeratedIndexValues']['ZHDP_VDC']['BE020']  = (-999999,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,24,28,30,90,91,92,93,94,95,96,97,98,99,100,101,102,103,104,105,107,999)
    field_information['GGDM 3.0']['HydrographyPntExt']['EnumeratedIndexValues']['ZHDP_VDC']['BG010']  = (-999999,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,24,28,30,90,91,92,93,94,95,96,97,98,99,100,101,102,103,104,105,107,999)
    field_information['GGDM 3.0']['HydrographyPntExt']['ZHDP_VDR'] = ('String',('BE020','BG010'))
    field_information['GGDM 3.0']['HydrographyPntExt']['ZI001_SDV'] = ('StructuredText',('BD020','BD030','BD050','BD061','BD130','BD180','BE020','BF010','BG010','BG012','BG030','FC041'))
    field_information['GGDM 3.0']['HydrographyPntExt']['ZI001_SRT'] = ('Enumeration',('BD020','BD030','BD050','BD061','BD130','BD180','BE020','BF010','BG010','BG012','BG030','FC041'))
    field_information['GGDM 3.0']['HydrographyPntExt']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['HydrographyPntExt']['EnumeratedIndexValues']['ZI001_SRT']['BD020']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['HydrographyPntExt']['EnumeratedIndexValues']['ZI001_SRT']['BD030']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['HydrographyPntExt']['EnumeratedIndexValues']['ZI001_SRT']['BD050']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['HydrographyPntExt']['EnumeratedIndexValues']['ZI001_SRT']['BD061']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['HydrographyPntExt']['EnumeratedIndexValues']['ZI001_SRT']['BD130']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['HydrographyPntExt']['EnumeratedIndexValues']['ZI001_SRT']['BD180']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['HydrographyPntExt']['EnumeratedIndexValues']['ZI001_SRT']['BE020']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['HydrographyPntExt']['EnumeratedIndexValues']['ZI001_SRT']['BF010']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['HydrographyPntExt']['EnumeratedIndexValues']['ZI001_SRT']['BG010']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['HydrographyPntExt']['EnumeratedIndexValues']['ZI001_SRT']['BG012']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['HydrographyPntExt']['EnumeratedIndexValues']['ZI001_SRT']['BG030']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['HydrographyPntExt']['EnumeratedIndexValues']['ZI001_SRT']['FC041']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['HydrographyPntExt']['ZI002_UFI'] = ('StructuredText',('BD020','BD030','BD050','BD061','BD130','BD180','BE020','BF010','BG010','BG012','BG030','FC041'))
    field_information['GGDM 3.0']['HydrographyPntExt']['ZI004_RCG'] = ('Enumeration',('BD020','BD030','BD050','BD061','BD130','BD180','BE020','BF010','BG010','BG012','BG030','FC041'))
    field_information['GGDM 3.0']['HydrographyPntExt']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['HydrographyPntExt']['EnumeratedIndexValues']['ZI004_RCG']['BD020']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['HydrographyPntExt']['EnumeratedIndexValues']['ZI004_RCG']['BD030']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['HydrographyPntExt']['EnumeratedIndexValues']['ZI004_RCG']['BD050']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['HydrographyPntExt']['EnumeratedIndexValues']['ZI004_RCG']['BD061']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['HydrographyPntExt']['EnumeratedIndexValues']['ZI004_RCG']['BD130']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['HydrographyPntExt']['EnumeratedIndexValues']['ZI004_RCG']['BD180']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['HydrographyPntExt']['EnumeratedIndexValues']['ZI004_RCG']['BE020']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['HydrographyPntExt']['EnumeratedIndexValues']['ZI004_RCG']['BF010']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['HydrographyPntExt']['EnumeratedIndexValues']['ZI004_RCG']['BG010']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['HydrographyPntExt']['EnumeratedIndexValues']['ZI004_RCG']['BG012']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['HydrographyPntExt']['EnumeratedIndexValues']['ZI004_RCG']['BG030']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['HydrographyPntExt']['EnumeratedIndexValues']['ZI004_RCG']['FC041']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['HydrographyPntExt']['ZI005_FNA'] = ('String',('BD020','BD030','BD050','BD061','BD130','BD180','BF010','BG010','BG012','BG030','FC041'))
    field_information['GGDM 3.0']['HydrographyPntExt']['ZI005_GNT'] = ('Enumeration',('BD020','BD030','BD050','BD061','BD130','BD180','BF010','BG010','BG012','BG030','FC041'))
    field_information['GGDM 3.0']['HydrographyPntExt']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['HydrographyPntExt']['EnumeratedIndexValues']['ZI005_GNT']['BD020']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['HydrographyPntExt']['EnumeratedIndexValues']['ZI005_GNT']['BD030']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['HydrographyPntExt']['EnumeratedIndexValues']['ZI005_GNT']['BD050']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['HydrographyPntExt']['EnumeratedIndexValues']['ZI005_GNT']['BD061']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['HydrographyPntExt']['EnumeratedIndexValues']['ZI005_GNT']['BD130']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['HydrographyPntExt']['EnumeratedIndexValues']['ZI005_GNT']['BD180']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['HydrographyPntExt']['EnumeratedIndexValues']['ZI005_GNT']['BF010']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['HydrographyPntExt']['EnumeratedIndexValues']['ZI005_GNT']['BG010']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['HydrographyPntExt']['EnumeratedIndexValues']['ZI005_GNT']['BG012']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['HydrographyPntExt']['EnumeratedIndexValues']['ZI005_GNT']['BG030']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['HydrographyPntExt']['EnumeratedIndexValues']['ZI005_GNT']['FC041']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['HydrographyPntExt']['ZI005_NFN'] = ('String',('BD020','BD030','BD050','BD061','BD130','BD180','BF010','BG010','BG012','BG030','FC041'))
    field_information['GGDM 3.0']['HydrographyPntExt']['ZI006_MEM'] = ('String',('BD020','BD030','BD050','BD061','BD130','BD180','BE020','BF010','BG010','BG012','BG030','FC041'))
    field_information['GGDM 3.0']['HydrographyPntExt']['ZI020_GE4'] = ('CodeList',('BD020','BD030','BD050','BD061','BD130','BD180','BE020','BF010','BG010','BG012','BG030','FC041'))
    field_information['GGDM 3.0']['HydrographyPntExt']['ZI025_HDP'] = ('Real',('BD020','BD130','BD180'))
    field_information['GGDM 3.0']['HydrographyPntExt']['ZI025_UHS'] = ('Boolean',('BD130'))
    field_information['GGDM 3.0']['HydrographyPntExt']['ZI025_WLE'] = ('Enumeration',('BD020','BD130','BD180'))
    field_information['GGDM 3.0']['HydrographyPntExt']['EnumeratedIndexValues']['ZI025_WLE'] = {}
    field_information['GGDM 3.0']['HydrographyPntExt']['EnumeratedIndexValues']['ZI025_WLE']['BD020']  = (-999999,1,2,3,4,5,9,999)
    field_information['GGDM 3.0']['HydrographyPntExt']['EnumeratedIndexValues']['ZI025_WLE']['BD130']  = (-999999,1,2,3,4,5,9,999)
    field_information['GGDM 3.0']['HydrographyPntExt']['EnumeratedIndexValues']['ZI025_WLE']['BD180']  = (-999999,1,2,3,4,5,9,999)
    field_information['GGDM 3.0']['HydrographyPntExt']['ZI026_CTUC'] = ('Enumeration',('BD020','BD030','BD050','BD061','BD130','BD180','BE020','BF010','BG010','BG012','BG030','FC041'))
    field_information['GGDM 3.0']['HydrographyPntExt']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['HydrographyPntExt']['EnumeratedIndexValues']['ZI026_CTUC']['BD020']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['HydrographyPntExt']['EnumeratedIndexValues']['ZI026_CTUC']['BD030']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['HydrographyPntExt']['EnumeratedIndexValues']['ZI026_CTUC']['BD050']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['HydrographyPntExt']['EnumeratedIndexValues']['ZI026_CTUC']['BD061']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['HydrographyPntExt']['EnumeratedIndexValues']['ZI026_CTUC']['BD130']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['HydrographyPntExt']['EnumeratedIndexValues']['ZI026_CTUC']['BD180']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['HydrographyPntExt']['EnumeratedIndexValues']['ZI026_CTUC']['BE020']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['HydrographyPntExt']['EnumeratedIndexValues']['ZI026_CTUC']['BF010']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['HydrographyPntExt']['EnumeratedIndexValues']['ZI026_CTUC']['BG010']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['HydrographyPntExt']['EnumeratedIndexValues']['ZI026_CTUC']['BG012']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['HydrographyPntExt']['EnumeratedIndexValues']['ZI026_CTUC']['BG030']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['HydrographyPntExt']['EnumeratedIndexValues']['ZI026_CTUC']['FC041']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['HydrographyPntExt']['ZI026_CTUL'] = ('integer',('BD020','BD030','BD050','BD061','BD130','BD180','BE020','BF010','BG010','BG012','BG030','FC041'))
    field_information['GGDM 3.0']['HydrographyPntExt']['ZI026_CTUU'] = ('integer',('BD020','BD030','BD050','BD061','BD130','BD180','BE020','BF010','BG010','BG012','BG030','FC041'))
    field_information['GGDM 3.0']['HydrographyPntExt']['ZI031S_URI'] = ('StructuredText',('BD020','BD030','BD050','BD061','BD130','BD180','BE020','BF010','BG010','BG012','BG030','FC041'))
    field_information['GGDM 3.0']['HydrographyPntExt']['ZI039S_UFI'] = ('StructuredText',('BD020','BD030','BD050','BD061','BD130','BD180','BE020','BF010','BG010','BG012','BG030','FC041'))
    field_information['GGDM 3.0']['HydrographyPntExt']['ZSAX_RS0'] = ('CodeList',('BD020','BD030','BD050','BD061','BD130','BD180','BE020','BF010','BG010','BG012','BG030','FC041'))
    field_information['GGDM 3.0']['HydrographyPntExt']['ZSAX_RX0'] = ('StructuredText',('BD020','BD030','BD050','BD061','BD130','BD180','BE020','BF010','BG010','BG012','BG030','FC041'))
    field_information['GGDM 3.0']['HydrographyPntExt']['ZSAX_RX3'] = ('StructuredText',('BD020','BD030','BD050','BD061','BD130','BD180','BE020','BF010','BG010','BG012','BG030','FC041'))
    field_information['GGDM 3.0']['HydrographyPntExt']['ZSAX_RX4'] = ('StructuredText',('BD020','BD030','BD050','BD061','BD130','BD180','BE020','BF010','BG010','BG012','BG030','FC041'))
    field_information['GGDM 3.0']['HydrographySrf']['AOO'] = ('Real',('BB110','BD115','BH120','BI020','BI044','BI050'))
    field_information['GGDM 3.0']['HydrographySrf']['AQN'] = ('String',('BH170','BH230'))
    field_information['GGDM 3.0']['HydrographySrf']['ARA'] = ('Real',('BA040','BD115','BD140','BH010','BH030','BH082','BH090','BH100','BH120','BH140','BH165','BH170','BH230','BI020','BI044','BI050'))
    field_information['GGDM 3.0']['HydrographySrf']['ATC'] = ('Enumeration',('BH010'))
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['ATC'] = {}
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['ATC']['BH010']  = (-999999,3,4,5,6)
    field_information['GGDM 3.0']['HydrographySrf']['AWP'] = ('Boolean',('BD115','BI020','BI050'))
    field_information['GGDM 3.0']['HydrographySrf']['AZC'] = ('Boolean',('BH082'))
    field_information['GGDM 3.0']['HydrographySrf']['BBMCA'] = ('Enumeration',('BH030','BH140'))
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['BBMCA'] = {}
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['BBMCA']['BH030']  = (-999999,1,2,3,4,5,6,7,8,9,11,14,15,16,17,18,999)
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['BBMCA']['BH140']  = (-999999,1,2,3,4,5,6,7,8,9,11,14,15,16,17,18,999)
    field_information['GGDM 3.0']['HydrographySrf']['BBMCA2'] = ('Enumeration',('BH030','BH140'))
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['BBMCA2'] = {}
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['BBMCA2']['BH030']  = (-999999,1,2,3,4,5,6,7,8,9,11,14,15,16,17,18,999)
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['BBMCA2']['BH140']  = (-999999,1,2,3,4,5,6,7,8,9,11,14,15,16,17,18,999)
    field_information['GGDM 3.0']['HydrographySrf']['BBMCA3'] = ('Enumeration',('BH030','BH140'))
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['BBMCA3'] = {}
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['BBMCA3']['BH030']  = (-999999,1,2,3,4,5,6,7,8,9,11,14,15,16,17,18,999)
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['BBMCA3']['BH140']  = (-999999,1,2,3,4,5,6,7,8,9,11,14,15,16,17,18,999)
    field_information['GGDM 3.0']['HydrographySrf']['BBMCB'] = ('Enumeration',('BH030','BH140'))
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['BBMCB'] = {}
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['BBMCB']['BH030']  = (-999999,1,2,3,4,5,6,7,8,9,11,14,15,16,17,18,999)
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['BBMCB']['BH140']  = (-999999,1,2,3,4,5,6,7,8,9,11,14,15,16,17,18,999)
    field_information['GGDM 3.0']['HydrographySrf']['BBMCB2'] = ('Enumeration',('BH030','BH140'))
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['BBMCB2'] = {}
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['BBMCB2']['BH030']  = (-999999,1,2,3,4,5,6,7,8,9,11,14,15,16,17,18,999)
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['BBMCB2']['BH140']  = (-999999,1,2,3,4,5,6,7,8,9,11,14,15,16,17,18,999)
    field_information['GGDM 3.0']['HydrographySrf']['BBMCB3'] = ('Enumeration',('BH030','BH140'))
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['BBMCB3'] = {}
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['BBMCB3']['BH030']  = (-999999,1,2,3,4,5,6,7,8,9,11,14,15,16,17,18,999)
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['BBMCB3']['BH140']  = (-999999,1,2,3,4,5,6,7,8,9,11,14,15,16,17,18,999)
    field_information['GGDM 3.0']['HydrographySrf']['BC034_MRT'] = ('Enumeration',('BD115'))
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['BC034_MRT'] = {}
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['BC034_MRT']['BD115']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['HydrographySrf']['BC034_MRT2'] = ('Enumeration',('BD115'))
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['BC034_MRT2'] = {}
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['BC034_MRT2']['BD115']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['HydrographySrf']['BC034_MRT3'] = ('Enumeration',('BD115'))
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['BC034_MRT3'] = {}
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['BC034_MRT3']['BD115']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['HydrographySrf']['BC101_SST'] = ('Enumeration',('BD115'))
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['BC101_SST'] = {}
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['BC101_SST']['BD115']  = (-999999,1,2,3,4,6,7,8,9,10,14,15,16,98,999)
    field_information['GGDM 3.0']['HydrographySrf']['BEN'] = ('StructuredText',('BA040','BB110','BD115','BD140','BH010','BH030','BH082','BH090','BH100','BH120','BH140','BH165','BH170','BH230','BI020','BI044','BI050','ZD070'))
    field_information['GGDM 3.0']['HydrographySrf']['BH141_AWBA'] = ('Real',('BH010','BH030','BH082','BH140'))
    field_information['GGDM 3.0']['HydrographySrf']['BH141_AWBB'] = ('Real',('BH010','BH030','BH082','BH140'))
    field_information['GGDM 3.0']['HydrographySrf']['BH141_IBOA'] = ('Enumeration',('BH010','BH030','BH082','BH140'))
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['BH141_IBOA'] = {}
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['BH141_IBOA']['BH010']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['BH141_IBOA']['BH030']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['BH141_IBOA']['BH082']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['BH141_IBOA']['BH140']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['HydrographySrf']['BH141_IBOB'] = ('Enumeration',('BH010','BH030','BH082','BH140'))
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['BH141_IBOB'] = {}
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['BH141_IBOB']['BH010']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['BH141_IBOB']['BH030']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['BH141_IBOB']['BH082']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['BH141_IBOB']['BH140']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['HydrographySrf']['BH141_SHDA'] = ('Boolean',('BH010','BH030','BH082','BH140'))
    field_information['GGDM 3.0']['HydrographySrf']['BH141_SHDB'] = ('Boolean',('BH010','BH030','BH082','BH140'))
    field_information['GGDM 3.0']['HydrographySrf']['BH141_SLTA'] = ('Enumeration',('BH010','BH030','BH082','BH140'))
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['BH141_SLTA'] = {}
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['BH141_SLTA']['BH010']  = (-999999,6,8,10,11,12,13,14,16,17,18,999)
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['BH141_SLTA']['BH030']  = (-999999,6,8,10,11,12,13,14,16,17,18,999)
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['BH141_SLTA']['BH082']  = (-999999,6,8,10,11,12,13,14,17,18,999)
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['BH141_SLTA']['BH140']  = (-999999,6,8,10,11,12,13,14,16,17,18,999)
    field_information['GGDM 3.0']['HydrographySrf']['BH141_SLTB'] = ('Enumeration',('BH010','BH030','BH082','BH140'))
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['BH141_SLTB'] = {}
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['BH141_SLTB']['BH010']  = (-999999,6,8,10,11,12,13,14,17,18,999)
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['BH141_SLTB']['BH030']  = (-999999,6,8,10,11,12,13,14,17,18,999)
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['BH141_SLTB']['BH082']  = (-999999,6,8,10,11,12,13,14,16,17,18,999)
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['BH141_SLTB']['BH140']  = (-999999,6,8,10,11,12,13,14,17,18,999)
    field_information['GGDM 3.0']['HydrographySrf']['BH141_WBHA'] = ('Real',('BH010','BH030','BH082','BH140'))
    field_information['GGDM 3.0']['HydrographySrf']['BH141_WBHB'] = ('Real',('BH010','BH030','BH082','BH140'))
    field_information['GGDM 3.0']['HydrographySrf']['BMC'] = ('Enumeration',('BA040','BH030','BH140'))
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['BMC'] = {}
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['BMC']['BA040']  = (-999999,1,2,3,4,5,6,7,8,9,11,14,15,16,17,18,999)
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['BMC']['BH030']  = (-999999,1,2,3,4,5,6,7,8,9,14,15,16,17,18,999)
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['BMC']['BH140']  = (-999999,1,2,3,4,5,6,7,9,14,15,18,999)
    field_information['GGDM 3.0']['HydrographySrf']['BMC2'] = ('Enumeration',('BA040','BH030','BH140'))
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['BMC2'] = {}
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['BMC2']['BA040']  = (-999999,1,2,3,4,5,6,7,8,9,11,14,15,16,17,18,999)
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['BMC2']['BH030']  = (-999999,1,2,3,4,5,6,7,8,9,14,15,16,17,18,999)
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['BMC2']['BH140']  = (-999999,1,2,3,4,5,6,7,9,14,15,18,999)
    field_information['GGDM 3.0']['HydrographySrf']['BMC3'] = ('Enumeration',('BA040','BH030','BH140'))
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['BMC3'] = {}
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['BMC3']['BA040']  = (-999999,1,2,3,4,5,6,7,8,9,11,14,15,16,17,18,999)
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['BMC3']['BH030']  = (-999999,1,2,3,4,5,6,7,8,9,14,15,16,17,18,999)
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['BMC3']['BH140']  = (-999999,1,2,3,4,5,6,7,9,14,15,18,999)
    field_information['GGDM 3.0']['HydrographySrf']['BPWHAC'] = ('Enumeration',('BH010','BH030','BH082','BH140'))
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['BPWHAC'] = {}
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['BPWHAC']['BH010']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['BPWHAC']['BH030']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['BPWHAC']['BH082']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['BPWHAC']['BH140']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['HydrographySrf']['BPWHAL'] = ('real',('BH010','BH030','BH082','BH140'))
    field_information['GGDM 3.0']['HydrographySrf']['BPWHAU'] = ('real',('BH010','BH030','BH082','BH140'))
    field_information['GGDM 3.0']['HydrographySrf']['BPWHBC'] = ('Enumeration',('BH010','BH030','BH082','BH140'))
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['BPWHBC'] = {}
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['BPWHBC']['BH010']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['BPWHBC']['BH030']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['BPWHBC']['BH082']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['BPWHBC']['BH140']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['HydrographySrf']['BPWHBL'] = ('real',('BH010','BH030','BH082','BH140'))
    field_information['GGDM 3.0']['HydrographySrf']['BPWHBU'] = ('real',('BH010','BH030','BH082','BH140'))
    field_information['GGDM 3.0']['HydrographySrf']['BPWSAC'] = ('Enumeration',('BH010','BH030','BH082','BH140'))
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['BPWSAC'] = {}
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['BPWSAC']['BH010']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['BPWSAC']['BH030']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['BPWSAC']['BH082']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['BPWSAC']['BH140']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['HydrographySrf']['BPWSAL'] = ('real',('BH010','BH030','BH082','BH140'))
    field_information['GGDM 3.0']['HydrographySrf']['BPWSAU'] = ('real',('BH010','BH030','BH082','BH140'))
    field_information['GGDM 3.0']['HydrographySrf']['BPWSBC'] = ('Enumeration',('BH010','BH030','BH082','BH140'))
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['BPWSBC'] = {}
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['BPWSBC']['BH010']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['BPWSBC']['BH030']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['BPWSBC']['BH082']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['BPWSBC']['BH140']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['HydrographySrf']['BPWSBL'] = ('real',('BH010','BH030','BH082','BH140'))
    field_information['GGDM 3.0']['HydrographySrf']['BPWSBU'] = ('real',('BH010','BH030','BH082','BH140'))
    field_information['GGDM 3.0']['HydrographySrf']['BWVCAC'] = ('Enumeration',('BH010','BH030','BH082','BH140'))
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['BWVCAC'] = {}
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['BWVCAC']['BH010']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['BWVCAC']['BH030']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['BWVCAC']['BH082']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['BWVCAC']['BH140']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['HydrographySrf']['BWVCAL'] = ('real',('BH010','BH030','BH082','BH140'))
    field_information['GGDM 3.0']['HydrographySrf']['BWVCAU'] = ('real',('BH010','BH030','BH082','BH140'))
    field_information['GGDM 3.0']['HydrographySrf']['BWVCBC'] = ('Enumeration',('BH010','BH030','BH082','BH140'))
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['BWVCBC'] = {}
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['BWVCBC']['BH010']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['BWVCBC']['BH030']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['BWVCBC']['BH082']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['BWVCBC']['BH140']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['HydrographySrf']['BWVCBL'] = ('real',('BH010','BH030','BH082','BH140'))
    field_information['GGDM 3.0']['HydrographySrf']['BWVCBU'] = ('real',('BH010','BH030','BH082','BH140'))
    field_information['GGDM 3.0']['HydrographySrf']['CAA'] = ('Enumeration',('BB110','BD115','BH010','BH030','BH082','BH140','BH170','BH230','BI020','BI050'))
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['CAA']['BB110']  = (-999999,3,17,999)
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['CAA']['BD115']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['CAA']['BH010']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['CAA']['BH030']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['CAA']['BH082']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['CAA']['BH140']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['CAA']['BH170']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['CAA']['BH230']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['CAA']['BI020']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['CAA']['BI050']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['HydrographySrf']['CDA'] = ('Boolean',('BH010','BH030','BH140'))
    field_information['GGDM 3.0']['HydrographySrf']['CDI'] = ('Real',('BH230'))
    field_information['GGDM 3.0']['HydrographySrf']['CDL'] = ('Real',('BH010','BH030','BH140'))
    field_information['GGDM 3.0']['HydrographySrf']['CNCP'] = ('StructuredText',('BB110','BD115','BH010','BH030','BH082','BH100','BH165','BH170','BH230','BI020','BI044','BI050'))
    field_information['GGDM 3.0']['HydrographySrf']['COS'] = ('Enumeration',('BB110','BD115','BH010','BH030','BH082','BH100','BH165','BH170','BH230','BI020','BI044','BI050'))
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['COS']['BB110']  = (-999999,2,4,6,9,13,14)
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['COS']['BD115']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['COS']['BH010']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['COS']['BH030']  = (-999999,2,4,6,9,13,14)
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['COS']['BH082']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['COS']['BH100']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['COS']['BH165']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['COS']['BH170']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['COS']['BH230']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['COS']['BI020']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['COS']['BI044']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['COS']['BI050']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['HydrographySrf']['CWT'] = ('Boolean',('BH010','BH030'))
    field_information['GGDM 3.0']['HydrographySrf']['DEV'] = ('Integer',('BH010','BH030'))
    field_information['GGDM 3.0']['HydrographySrf']['DFT'] = ('Enumeration',('BI020'))
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['DFT'] = {}
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['DFT']['BI020']  = (-999999,1,2)
    field_information['GGDM 3.0']['HydrographySrf']['DFU'] = ('Enumeration',('BI020'))
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['DFU'] = {}
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['DFU']['BI020']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['GGDM 3.0']['HydrographySrf']['DFU2'] = ('Enumeration',('BI020'))
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['DFU2'] = {}
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['DFU2']['BI020']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['GGDM 3.0']['HydrographySrf']['DFU3'] = ('Enumeration',('BI020'))
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['DFU3'] = {}
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['DFU3']['BI020']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['GGDM 3.0']['HydrographySrf']['DIT'] = ('Enumeration',('BH030'))
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['DIT'] = {}
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['DIT']['BH030']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['HydrographySrf']['DMD'] = ('Boolean',('BH082'))
    field_information['GGDM 3.0']['HydrographySrf']['DOF'] = ('Real',('BH170'))
    field_information['GGDM 3.0']['HydrographySrf']['DOXY'] = ('Real',('BA040','BH010','BH030','BH082','BH140','ZD070'))
    field_information['GGDM 3.0']['HydrographySrf']['DSD'] = ('Enumeration',('BI020'))
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['DSD'] = {}
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['DSD']['BI020']  = (-999999,101,102,103,104,105,106,107,999)
    field_information['GGDM 3.0']['HydrographySrf']['DWL'] = ('Real',('BH230'))
    field_information['GGDM 3.0']['HydrographySrf']['DZP'] = ('Real',('BH010','BH030','BH082','BH090','BH100','BH140','BH170','BH230'))
    field_information['GGDM 3.0']['HydrographySrf']['F_CODE'] = ('CONSTRAINED_STRING',('BA040','BB110','BD115','BD140','BH010','BH030','BH082','BH090','BH100','BH120','BH140','BH165','BH170','BH230','BI020','BI044','BI050','ZD070'))
    field_information['GGDM 3.0']['HydrographySrf']['FCS'] = ('Enumeration',('BI044'))
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['FCS'] = {}
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['FCS']['BI044']  = (-999999,1,2,3,4,5,999)
    field_information['GGDM 3.0']['HydrographySrf']['FFN'] = ('Enumeration',('BH082'))
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['FFN'] = {}
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['FFN']['BH082']  = (-999999,30,35,351,361,440,488,505,921,955,999)
    field_information['GGDM 3.0']['HydrographySrf']['FFN2'] = ('Enumeration',('BH082'))
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['FFN2'] = {}
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['FFN2']['BH082']  = (-999999,30,35,351,361,440,488,505,921,955,999)
    field_information['GGDM 3.0']['HydrographySrf']['FFN3'] = ('Enumeration',('BH082'))
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['FFN3'] = {}
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['FFN3']['BH082']  = (-999999,30,35,351,361,440,488,505,921,955,999)
    field_information['GGDM 3.0']['HydrographySrf']['FRZ'] = ('Boolean',('BH010','BH030','BH082','BH140'))
    field_information['GGDM 3.0']['HydrographySrf']['FUFI'] = ('StructuredText',('BA040','BB110','BD115','BD140','BH010','BH030','BH082','BH090','BH100','BH120','BH140','BH165','BH170','BH230','BI020','BI044','BI050','ZD070'))
    field_information['GGDM 3.0']['HydrographySrf']['FURL'] = ('StructuredText',('BA040','BB110','BD115','BD140','BH010','BH030','BH082','BH090','BH100','BH120','BH140','BH165','BH170','BH230','BI020','BI044','BI050','ZD070'))
    field_information['GGDM 3.0']['HydrographySrf']['GDBV'] = ('Enumeration',('BA040','BB110','BD115','BD140','BH010','BH030','BH082','BH090','BH100','BH120','BH140','BH165','BH170','BH230','BI020','BI044','BI050','ZD070'))
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['GDBV']['BA040']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['GDBV']['BB110']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['GDBV']['BD115']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['GDBV']['BD140']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['GDBV']['BH010']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['GDBV']['BH030']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['GDBV']['BH082']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['GDBV']['BH090']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['GDBV']['BH100']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['GDBV']['BH120']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['GDBV']['BH140']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['GDBV']['BH165']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['GDBV']['BH170']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['GDBV']['BH230']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['GDBV']['BI020']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['GDBV']['BI044']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['GDBV']['BI050']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['GDBV']['ZD070']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['HydrographySrf']['HDP'] = ('Real',('BH030','BI044'))
    field_information['GGDM 3.0']['HydrographySrf']['HGS'] = ('Real',('BI020'))
    field_information['GGDM 3.0']['HydrographySrf']['HGT'] = ('Real',('BD115','BH010','BH030','BH230','BI020','BI044','BI050'))
    field_information['GGDM 3.0']['HydrographySrf']['INU'] = ('Enumeration',('BH090'))
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['INU'] = {}
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['INU']['BH090']  = (-999999,1,2)
    field_information['GGDM 3.0']['HydrographySrf']['IWT'] = ('Enumeration',('BH082'))
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['IWT'] = {}
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['IWT']['BH082']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['HydrographySrf']['LDC'] = ('Real',('BI020'))
    field_information['GGDM 3.0']['HydrographySrf']['LEA'] = ('Real',('BH010','BH030','BH140','ZD070'))
    field_information['GGDM 3.0']['HydrographySrf']['LMC'] = ('Boolean',('BD115','BH010','BH030','BH082','BH120','BH140','BH230','BI020','BI050'))
    field_information['GGDM 3.0']['HydrographySrf']['LOC'] = ('Enumeration',('BH030','BH140'))
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['LOC'] = {}
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['LOC']['BH030']  = (-999999,40,44)
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['LOC']['BH140']  = (-999999,40,44)
    field_information['GGDM 3.0']['HydrographySrf']['LUN'] = ('Boolean',('BH010','BH170'))
    field_information['GGDM 3.0']['HydrographySrf']['LZN'] = ('Real',('BA040','BB110','BD115','BD140','BH010','BH030','BH082','BH090','BH100','BH120','BH140','BH165','BH170','BH230','BI044','BI050'))
    field_information['GGDM 3.0']['HydrographySrf']['MCC'] = ('Enumeration',('BH165','BI020','BI044'))
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['MCC'] = {}
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['MCC']['BH165']  = (-999999,5,9,21,62,77,83,84,104,108,999)
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['MCC']['BI020']  = (-999999,8,9,21,62,64,86,104,107,108,117,150,160,999)
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['MCC']['BI044']  = (-999999,9,21,46,62,77,83,84,104,107,117,150,999)
    field_information['GGDM 3.0']['HydrographySrf']['MCC2'] = ('Enumeration',('BH165','BI020','BI044'))
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['MCC2'] = {}
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['MCC2']['BH165']  = (-999999,5,9,21,62,77,83,84,104,108,999)
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['MCC2']['BI020']  = (-999999,8,9,21,62,64,86,104,107,108,117,150,160,999)
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['MCC2']['BI044']  = (-999999,9,21,46,62,77,83,84,104,107,117,150,999)
    field_information['GGDM 3.0']['HydrographySrf']['MCC3'] = ('Enumeration',('BH165','BI020','BI044'))
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['MCC3'] = {}
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['MCC3']['BH165']  = (-999999,5,9,21,62,77,83,84,104,108,999)
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['MCC3']['BI020']  = (-999999,8,9,21,62,64,86,104,107,108,117,150,160,999)
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['MCC3']['BI044']  = (-999999,9,21,46,62,77,83,84,104,107,117,150,999)
    field_information['GGDM 3.0']['HydrographySrf']['MNS'] = ('Boolean',('BH082'))
    field_information['GGDM 3.0']['HydrographySrf']['MWD'] = ('Real',('BH010','BH030','BH100'))
    field_information['GGDM 3.0']['HydrographySrf']['NVS'] = ('Enumeration',('BH140'))
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['NVS'] = {}
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['NVS']['BH140']  = (-999999,1,2,3,4,5,999)
    field_information['GGDM 3.0']['HydrographySrf']['OCS'] = ('Enumeration',('BD115'))
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['OCS'] = {}
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['OCS']['BD115']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['HydrographySrf']['OTH'] = ('StructuredText',('BA040','BB110','BD115','BD140','BH010','BH030','BH082','BH090','BH100','BH120','BH140','BH165','BH170','BH230','BI020','BI044','BI050','ZD070'))
    field_information['GGDM 3.0']['HydrographySrf']['PCF'] = ('Enumeration',('BB110','BD115','BH010','BH030','BH082','BH100','BH165','BH170','BH230','BI020','BI044','BI050'))
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['PCF']['BB110']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['PCF']['BD115']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['PCF']['BH010']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['PCF']['BH030']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['PCF']['BH082']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['PCF']['BH100']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['PCF']['BH165']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['PCF']['BH170']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['PCF']['BH230']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['PCF']['BI020']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['PCF']['BI044']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['PCF']['BI050']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['HydrographySrf']['PSE'] = ('StructuredText',('BB110'))
    field_information['GGDM 3.0']['HydrographySrf']['PUD'] = ('Real',('BH230'))
    field_information['GGDM 3.0']['HydrographySrf']['PWA'] = ('Real',('BH030','BH140'))
    field_information['GGDM 3.0']['HydrographySrf']['PWAC'] = ('Enumeration',('BH010','BH082','ZD070'))
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['PWAC'] = {}
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['PWAC']['BH010']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['PWAC']['BH082']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['PWAC']['ZD070']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['HydrographySrf']['PWAL'] = ('real',('BH010','BH082','ZD070'))
    field_information['GGDM 3.0']['HydrographySrf']['PWAU'] = ('real',('BH010','BH082','ZD070'))
    field_information['GGDM 3.0']['HydrographySrf']['RLE'] = ('Enumeration',('BH010','BH030'))
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['RLE'] = {}
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['RLE']['BH010']  = (-999999,1,2,3,998)
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['RLE']['BH030']  = (-999999,1,2,3,998)
    field_information['GGDM 3.0']['HydrographySrf']['SBB'] = ('Boolean',('BH010','BH030'))
    field_information['GGDM 3.0']['HydrographySrf']['SCOG'] = ('Enumeration',('ZD070'))
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['SCOG'] = {}
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['SCOG']['ZD070']  = (-999999,1,2,3,4,998,999)
    field_information['GGDM 3.0']['HydrographySrf']['STNB'] = ('Integer',('BH140'))
    field_information['GGDM 3.0']['HydrographySrf']['SWT'] = ('Enumeration',('BH170'))
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['SWT'] = {}
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['SWT']['BH170']  = (-999999,4,6,7,999)
    field_information['GGDM 3.0']['HydrographySrf']['SWW'] = ('Real',('BH230'))
    field_information['GGDM 3.0']['HydrographySrf']['TID'] = ('Boolean',('BH082','BH140'))
    field_information['GGDM 3.0']['HydrographySrf']['TRS'] = ('Enumeration',('BI020'))
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['TRS'] = {}
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['TRS']['BI020']  = (-999999,8,9,12,13,999)
    field_information['GGDM 3.0']['HydrographySrf']['TRS2'] = ('Enumeration',('BI020'))
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['TRS2'] = {}
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['TRS2']['BI020']  = (-999999,8,9,12,13,999)
    field_information['GGDM 3.0']['HydrographySrf']['TRS3'] = ('Enumeration',('BI020'))
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['TRS3'] = {}
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['TRS3']['BI020']  = (-999999,8,9,12,13,999)
    field_information['GGDM 3.0']['HydrographySrf']['TSSM'] = ('Enumeration',('BH230'))
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['TSSM'] = {}
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['TSSM']['BH230']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,999)
    field_information['GGDM 3.0']['HydrographySrf']['TSSM2'] = ('Enumeration',('BH230'))
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['TSSM2'] = {}
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['TSSM2']['BH230']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,999)
    field_information['GGDM 3.0']['HydrographySrf']['TSSM3'] = ('Enumeration',('BH230'))
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['TSSM3'] = {}
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['TSSM3']['BH230']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,999)
    field_information['GGDM 3.0']['HydrographySrf']['TSTE'] = ('Enumeration',('ZD070'))
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['TSTE'] = {}
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['TSTE']['ZD070']  = (-999999,1,2,3,4,998,999)
    field_information['GGDM 3.0']['HydrographySrf']['UFI'] = ('StructuredText',('BA040','BB110','BD115','BD140','BH010','BH030','BH082','BH090','BH100','BH120','BH140','BH165','BH170','BH230','BI020','BI044','BI050','ZD070'))
    field_information['GGDM 3.0']['HydrographySrf']['VCM'] = ('Enumeration',('BD115','BI050'))
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['VCM'] = {}
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['VCM']['BD115']  = (-999999,2,4,7,9,15,17,999)
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['VCM']['BI050']  = (-999999,2,3,4,7,8,9,12,13,15,17,999)
    field_information['GGDM 3.0']['HydrographySrf']['VCM2'] = ('Enumeration',('BD115','BI050'))
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['VCM2'] = {}
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['VCM2']['BD115']  = (-999999,2,4,7,9,15,17,999)
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['VCM2']['BI050']  = (-999999,2,3,4,7,8,9,12,13,15,17,999)
    field_information['GGDM 3.0']['HydrographySrf']['VCM3'] = ('Enumeration',('BD115','BI050'))
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['VCM3'] = {}
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['VCM3']['BD115']  = (-999999,2,4,7,9,15,17,999)
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['VCM3']['BI050']  = (-999999,2,3,4,7,8,9,12,13,15,17,999)
    field_information['GGDM 3.0']['HydrographySrf']['VLM'] = ('Real',('BH082','BH100','BH170'))
    field_information['GGDM 3.0']['HydrographySrf']['VOI'] = ('StructuredText',('BD115','BI020','BI050'))
    field_information['GGDM 3.0']['HydrographySrf']['WAD'] = ('String',('BH230'))
    field_information['GGDM 3.0']['HydrographySrf']['WCAC'] = ('Real',('BH230','ZD070'))
    field_information['GGDM 3.0']['HydrographySrf']['WCC'] = ('Enumeration',('BH140'))
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['WCC'] = {}
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['WCC']['BH140']  = (-999999,1,2,3,4,7,999)
    field_information['GGDM 3.0']['HydrographySrf']['WD3'] = ('Real',('BH010','BH030','BH100','BH140'))
    field_information['GGDM 3.0']['HydrographySrf']['WDAC'] = ('Enumeration',('BH010','BH030','BH082','BH140','ZD070'))
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['WDAC'] = {}
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['WDAC']['BH010']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['WDAC']['BH030']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['WDAC']['BH082']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['WDAC']['BH140']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['WDAC']['ZD070']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['HydrographySrf']['WDAL'] = ('real',('BH010','BH030','BH082','BH140','ZD070'))
    field_information['GGDM 3.0']['HydrographySrf']['WDAU'] = ('real',('BH010','BH030','BH082','BH140','ZD070'))
    field_information['GGDM 3.0']['HydrographySrf']['WDH'] = ('Real',('BH010','BH030','BH082','BH140','ZD070'))
    field_information['GGDM 3.0']['HydrographySrf']['WDL'] = ('Real',('BH010','BH030','BH082','BH140','ZD070'))
    field_information['GGDM 3.0']['HydrographySrf']['WDST'] = ('Enumeration',('BH170','BH230'))
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['WDST'] = {}
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['WDST']['BH170']  = (-999999,1,2,3,4,5,6,7,8,998,999)
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['WDST']['BH230']  = (-999999,1,2,3,4,5,6,7,8,998,999)
    field_information['GGDM 3.0']['HydrographySrf']['WFT'] = ('Enumeration',('BH230'))
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['WFT'] = {}
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['WFT']['BH230']  = (-999999,2,3,5,6,7,999)
    field_information['GGDM 3.0']['HydrographySrf']['WHCO'] = ('Real',('BH230','ZD070'))
    field_information['GGDM 3.0']['HydrographySrf']['WID'] = ('Real',('BA040','BD115','BD140','BH010','BH030','BH082','BH090','BH100','BH120','BH140','BH165','BH170','BH230','BI044','BI050'))
    field_information['GGDM 3.0']['HydrographySrf']['WMT'] = ('Enumeration',('BH140'))
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['WMT'] = {}
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['WMT']['BH140']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,999)
    field_information['GGDM 3.0']['HydrographySrf']['WOC'] = ('Real',('BI020'))
    field_information['GGDM 3.0']['HydrographySrf']['WODR'] = ('Enumeration',('ZD070'))
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['WODR'] = {}
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['WODR']['ZD070']  = (-999999,1,2,3,4,5,6,7,998,999)
    field_information['GGDM 3.0']['HydrographySrf']['WTBB'] = ('Real',('ZD070'))
    field_information['GGDM 3.0']['HydrographySrf']['WTCA'] = ('Real',('ZD070'))
    field_information['GGDM 3.0']['HydrographySrf']['WTCL'] = ('String',('ZD070'))
    field_information['GGDM 3.0']['HydrographySrf']['WTFE'] = ('Real',('ZD070'))
    field_information['GGDM 3.0']['HydrographySrf']['WTKK'] = ('Real',('ZD070'))
    field_information['GGDM 3.0']['HydrographySrf']['WTMN'] = ('Real',('ZD070'))
    field_information['GGDM 3.0']['HydrographySrf']['WTNA'] = ('Real',('ZD070'))
    field_information['GGDM 3.0']['HydrographySrf']['WTNO'] = ('Real',('ZD070'))
    field_information['GGDM 3.0']['HydrographySrf']['WTPO'] = ('Real',('ZD070'))
    field_information['GGDM 3.0']['HydrographySrf']['WTSI'] = ('Real',('ZD070'))
    field_information['GGDM 3.0']['HydrographySrf']['WTST'] = ('Enumeration',('ZD070'))
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['WTST'] = {}
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['WTST']['ZD070']  = (-999999,1,2,998,999)
    field_information['GGDM 3.0']['HydrographySrf']['WVA'] = ('Real',('BH010','BH030','BH140','ZD070'))
    field_information['GGDM 3.0']['HydrographySrf']['WVH'] = ('Real',('BH010','BH030','BH140','ZD070'))
    field_information['GGDM 3.0']['HydrographySrf']['WVL'] = ('Real',('BH010','BH030','BH140','ZD070'))
    field_information['GGDM 3.0']['HydrographySrf']['WWM'] = ('Enumeration',('BH170','BH230'))
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['WWM'] = {}
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['WWM']['BH170']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,999)
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['WWM']['BH230']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,999)
    field_information['GGDM 3.0']['HydrographySrf']['WWM2'] = ('Enumeration',('BH170','BH230'))
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['WWM2'] = {}
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['WWM2']['BH170']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,999)
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['WWM2']['BH230']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,999)
    field_information['GGDM 3.0']['HydrographySrf']['WWM3'] = ('Enumeration',('BH170','BH230'))
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['WWM3'] = {}
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['WWM3']['BH170']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,999)
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['WWM3']['BH230']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,999)
    field_information['GGDM 3.0']['HydrographySrf']['ZI001_SDV'] = ('StructuredText',('BA040','BB110','BD115','BD140','BH010','BH030','BH082','BH090','BH100','BH120','BH140','BH165','BH170','BH230','BI020','BI044','BI050','ZD070'))
    field_information['GGDM 3.0']['HydrographySrf']['ZI001_SRT'] = ('Enumeration',('BA040','BB110','BD115','BD140','BH010','BH030','BH082','BH090','BH100','BH120','BH140','BH165','BH170','BH230','BI020','BI044','BI050','ZD070'))
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['ZI001_SRT']['BA040']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['ZI001_SRT']['BB110']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['ZI001_SRT']['BD115']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['ZI001_SRT']['BD140']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['ZI001_SRT']['BH010']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['ZI001_SRT']['BH030']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['ZI001_SRT']['BH082']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['ZI001_SRT']['BH090']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['ZI001_SRT']['BH100']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['ZI001_SRT']['BH120']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['ZI001_SRT']['BH140']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['ZI001_SRT']['BH165']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['ZI001_SRT']['BH170']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['ZI001_SRT']['BH230']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['ZI001_SRT']['BI020']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['ZI001_SRT']['BI044']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['ZI001_SRT']['BI050']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['ZI001_SRT']['ZD070']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['HydrographySrf']['ZI002_UFI'] = ('StructuredText',('BA040','BB110','BD115','BD140','BH010','BH030','BH082','BH090','BH100','BH120','BH140','BH165','BH170','BH230','BI020','BI044','BI050','ZD070'))
    field_information['GGDM 3.0']['HydrographySrf']['ZI004_RCG'] = ('Enumeration',('BA040','BB110','BD115','BD140','BH010','BH030','BH082','BH090','BH100','BH120','BH140','BH165','BH170','BH230','BI020','BI044','BI050','ZD070'))
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['ZI004_RCG']['BA040']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['ZI004_RCG']['BB110']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['ZI004_RCG']['BD115']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['ZI004_RCG']['BD140']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['ZI004_RCG']['BH010']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['ZI004_RCG']['BH030']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['ZI004_RCG']['BH082']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['ZI004_RCG']['BH090']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['ZI004_RCG']['BH100']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['ZI004_RCG']['BH120']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['ZI004_RCG']['BH140']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['ZI004_RCG']['BH165']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['ZI004_RCG']['BH170']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['ZI004_RCG']['BH230']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['ZI004_RCG']['BI020']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['ZI004_RCG']['BI044']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['ZI004_RCG']['BI050']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['ZI004_RCG']['ZD070']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['HydrographySrf']['ZI005_FNA'] = ('String',('BA040','BB110','BD115','BD140','BH010','BH030','BH082','BH090','BH120','BH140','BH165','BH170','BH230','BI020','BI044','BI050','ZD070'))
    field_information['GGDM 3.0']['HydrographySrf']['ZI005_FNA2'] = ('String',('BH010','BH030','BH082','BH140','BH170','BH230','BI020','ZD070'))
    field_information['GGDM 3.0']['HydrographySrf']['ZI005_FNA3'] = ('String',('BH030','BH082','BH140','BI020','ZD070'))
    field_information['GGDM 3.0']['HydrographySrf']['ZI005_GNT'] = ('Enumeration',('BA040','BB110','BD115','BD140','BH010','BH030','BH082','BH090','BH120','BH140','BH165','BH170','BH230','BI020','BI044','BI050','ZD070'))
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['ZI005_GNT']['BA040']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['ZI005_GNT']['BB110']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['ZI005_GNT']['BD115']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['ZI005_GNT']['BD140']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['ZI005_GNT']['BH010']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['ZI005_GNT']['BH030']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['ZI005_GNT']['BH082']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['ZI005_GNT']['BH090']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['ZI005_GNT']['BH120']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['ZI005_GNT']['BH140']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['ZI005_GNT']['BH165']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['ZI005_GNT']['BH170']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['ZI005_GNT']['BH230']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['ZI005_GNT']['BI020']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['ZI005_GNT']['BI044']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['ZI005_GNT']['BI050']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['ZI005_GNT']['ZD070']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['HydrographySrf']['ZI005_GNT2'] = ('Enumeration',('BH010','BH030','BH082','BH140','BH170','BH230','BI020','ZD070'))
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['ZI005_GNT2'] = {}
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['ZI005_GNT2']['BH010']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['ZI005_GNT2']['BH030']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['ZI005_GNT2']['BH082']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['ZI005_GNT2']['BH140']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['ZI005_GNT2']['BH170']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['ZI005_GNT2']['BH230']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['ZI005_GNT2']['BI020']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['ZI005_GNT2']['ZD070']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['HydrographySrf']['ZI005_GNT3'] = ('Enumeration',('BH030','BH082','BH140','BI020','ZD070'))
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['ZI005_GNT3'] = {}
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['ZI005_GNT3']['BH030']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['ZI005_GNT3']['BH082']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['ZI005_GNT3']['BH140']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['ZI005_GNT3']['BI020']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['ZI005_GNT3']['ZD070']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['HydrographySrf']['ZI005_NFN'] = ('String',('BA040','BB110','BD115','BD140','BH010','BH030','BH082','BH090','BH120','BH140','BH165','BH170','BH230','BI020','BI044','BI050','ZD070'))
    field_information['GGDM 3.0']['HydrographySrf']['ZI005_NFN2'] = ('String',('BH010','BH030','BH082','BH140','BH170','BH230','BI020','ZD070'))
    field_information['GGDM 3.0']['HydrographySrf']['ZI005_NFN3'] = ('String',('BH030','BH082','BH140','BI020','ZD070'))
    field_information['GGDM 3.0']['HydrographySrf']['ZI006_MEM'] = ('String',('BA040','BB110','BD115','BD140','BH010','BH030','BH082','BH090','BH100','BH120','BH140','BH165','BH170','BH230','BI020','BI044','BI050','ZD070'))
    field_information['GGDM 3.0']['HydrographySrf']['ZI020_GE4'] = ('CodeList',('BA040','BB110','BD115','BD140','BH010','BH030','BH082','BH090','BH100','BH120','BH140','BH165','BH170','BH230','BI020','BI044','BI050','ZD070'))
    field_information['GGDM 3.0']['HydrographySrf']['ZI024_ASE'] = ('Real',('BA040','BH010','BH030','BH082','BH100','BH140','BH170','BH230','BI050','ZD070'))
    field_information['GGDM 3.0']['HydrographySrf']['ZI024_AWO'] = ('Real',('BH010','BH030','BH140','BH170','BH230'))
    field_information['GGDM 3.0']['HydrographySrf']['ZI024_AWOI'] = ('Real',('BH010','BH030','BH140','BH170','BH230'))
    field_information['GGDM 3.0']['HydrographySrf']['ZI024_AWOX'] = ('Real',('BH010','BH030','BH140','BH170','BH230'))
    field_information['GGDM 3.0']['HydrographySrf']['ZI024_CFR'] = ('Real',('BA040','BH010','BH030','BH082','BH100','BH140','BH170','BH230','BI050','ZD070'))
    field_information['GGDM 3.0']['HydrographySrf']['ZI024_CLO'] = ('Real',('BA040','BH010','BH030','BH082','BH100','BH140','BH170','BH230','BI050','ZD070'))
    field_information['GGDM 3.0']['HydrographySrf']['ZI024_CYN'] = ('Real',('BA040','BH010','BH030','BH082','BH100','BH140','BH170','BH230','BI050','ZD070'))
    field_information['GGDM 3.0']['HydrographySrf']['ZI024_DRL'] = ('Enumeration',('BH230'))
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['ZI024_DRL'] = {}
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['ZI024_DRL']['BH230']  = (-999999,17,40,44,45,50,999)
    field_information['GGDM 3.0']['HydrographySrf']['ZI024_DVPT'] = ('Enumeration',('BH230'))
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['ZI024_DVPT'] = {}
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['ZI024_DVPT']['BH230']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['HydrographySrf']['ZI024_FMR'] = ('Real',('BA040','BH010','BH030','BH082','BH100','BH140','BH170','BH230','BI050','ZD070'))
    field_information['GGDM 3.0']['HydrographySrf']['ZI024_FRR'] = ('Real',('BA040','BH010','BH030','BH082','BH100','BH140','BH170','BH230','BI050','ZD070'))
    field_information['GGDM 3.0']['HydrographySrf']['ZI024_HAR'] = ('Real',('BA040','BH010','BH030','BH082','BH100','BH140','BH170','BH230','BI050','ZD070'))
    field_information['GGDM 3.0']['HydrographySrf']['ZI024_HYP'] = ('Enumeration',('BH010','BH030','BH082','BH090','BH100','BH140','BH170','BH230','BI050','ZD070'))
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['ZI024_HYP'] = {}
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['ZI024_HYP']['BH010']  = (-999999,1,2,4)
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['ZI024_HYP']['BH030']  = (-999999,1,2,4)
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['ZI024_HYP']['BH082']  = (-999999,1,2,4)
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['ZI024_HYP']['BH090']  = (-999999,1,2,4)
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['ZI024_HYP']['BH100']  = (-999999,1,2,4)
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['ZI024_HYP']['BH140']  = (-999999,1,2,4)
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['ZI024_HYP']['BH170']  = (-999999,1,2,4)
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['ZI024_HYP']['BH230']  = (-999999,1,2,4)
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['ZI024_HYP']['BI050']  = (-999999,1,2,4)
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['ZI024_HYP']['ZD070']  = (-999999,1,2,4)
    field_information['GGDM 3.0']['HydrographySrf']['ZI024_MGN'] = ('Real',('BA040','BH010','BH030','BH082','BH100','BH140','BH170','BH230','BI050','ZD070'))
    field_information['GGDM 3.0']['HydrographySrf']['ZI024_PHW'] = ('Real',('BA040','BH010','BH030','BH082','BH100','BH140','BH170','BH230','BI050','ZD070'))
    field_information['GGDM 3.0']['HydrographySrf']['ZI024_PMP'] = ('Enumeration',('BH230'))
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['ZI024_PMP'] = {}
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['ZI024_PMP']['BH230']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['GGDM 3.0']['HydrographySrf']['ZI024_RTP'] = ('Enumeration',('BH082'))
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['ZI024_RTP'] = {}
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['ZI024_RTP']['BH082']  = (-999999,1,2,999)
    field_information['GGDM 3.0']['HydrographySrf']['ZI024_SCC'] = ('Enumeration',('BA040','BH010','BH030','BH082','BH100','BH140','BH170','BH230','BI050','ZD070'))
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['ZI024_SCC'] = {}
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['ZI024_SCC']['BA040']  = (-999999,1,4,10,11,12,13,14,998,999)
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['ZI024_SCC']['BH010']  = (-999999,1,4,10,11,12,13,14,998)
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['ZI024_SCC']['BH030']  = (-999999,1,4,10,11,12,13,14,998,999)
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['ZI024_SCC']['BH082']  = (-999999,1,4,10,11,12,13,14,998)
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['ZI024_SCC']['BH100']  = (-999999,1,4,10,11,12,13,14,998)
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['ZI024_SCC']['BH140']  = (-999999,1,4,10,11,12,13,14,998,999)
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['ZI024_SCC']['BH170']  = (-999999,1,4,10,11,12,13,14,998)
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['ZI024_SCC']['BH230']  = (-999999,1,4,10,11,12,13,14,998)
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['ZI024_SCC']['BI050']  = (-999999,1,4,10,11,12,13,14,998,999)
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['ZI024_SCC']['ZD070']  = (-999999,1,4,10,11,12,13,14,998)
    field_information['GGDM 3.0']['HydrographySrf']['ZI024_SQN'] = ('Enumeration',('BH010','BH030','BH140'))
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['ZI024_SQN'] = {}
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['ZI024_SQN']['BH010']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['ZI024_SQN']['BH030']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['ZI024_SQN']['BH140']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['HydrographySrf']['ZI024_SUL'] = ('Real',('BA040','BH010','BH030','BH082','BH100','BH140','BH170','BH230','BI050','ZD070'))
    field_information['GGDM 3.0']['HydrographySrf']['ZI024_TDS'] = ('Real',('BA040','BH010','BH030','BH082','BH100','BH140','BH170','BH230','BI050','ZD070'))
    field_information['GGDM 3.0']['HydrographySrf']['ZI024_TEP'] = ('Real',('BA040','BH010','BH030','BH082','BH100','BH140','BH170','BH230','BI050','ZD070'))
    field_information['GGDM 3.0']['HydrographySrf']['ZI024_TUR'] = ('Real',('BA040','BH010','BH030','BH082','BH100','BH140','BH170','BH230','BI050','ZD070'))
    field_information['GGDM 3.0']['HydrographySrf']['ZI024_WAC'] = ('Real',('BA040','BH010','BH030','BH082','BH100','BH140','BH170','BH230','BI050','ZD070'))
    field_information['GGDM 3.0']['HydrographySrf']['ZI024_WPAC'] = ('Enumeration',('BH010','BH030','BH140','BI020'))
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['ZI024_WPAC'] = {}
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['ZI024_WPAC']['BH010']  = (-999999,100,101,102,103)
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['ZI024_WPAC']['BH030']  = (-999999,100,101,102,103,104,105,106,107)
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['ZI024_WPAC']['BH140']  = (-999999,100,101,102,103,104,105,106,107)
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['ZI024_WPAC']['BI020']  = (-999999,100,101,102,103,104,105,106,107)
    field_information['GGDM 3.0']['HydrographySrf']['ZI024_WSG'] = ('Enumeration',('BH030','BH140'))
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['ZI024_WSG'] = {}
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['ZI024_WSG']['BH030']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['ZI024_WSG']['BH140']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['HydrographySrf']['ZI024_WTBB'] = ('Real',('BH230'))
    field_information['GGDM 3.0']['HydrographySrf']['ZI024_WTCA'] = ('Real',('BH230'))
    field_information['GGDM 3.0']['HydrographySrf']['ZI024_WTFE'] = ('Real',('BH230'))
    field_information['GGDM 3.0']['HydrographySrf']['ZI024_WTKK'] = ('Real',('BH230'))
    field_information['GGDM 3.0']['HydrographySrf']['ZI024_WTMN'] = ('Real',('BH230'))
    field_information['GGDM 3.0']['HydrographySrf']['ZI024_WTNA'] = ('Real',('BH230'))
    field_information['GGDM 3.0']['HydrographySrf']['ZI024_WTNO'] = ('Real',('BA040','BH010','BH030','BH082','BH100','BH140','BH170','BH230','BI050','ZD070'))
    field_information['GGDM 3.0']['HydrographySrf']['ZI024_WTPO'] = ('Real',('BH230'))
    field_information['GGDM 3.0']['HydrographySrf']['ZI024_WTSI'] = ('Real',('BH230'))
    field_information['GGDM 3.0']['HydrographySrf']['ZI024_WUR'] = ('Enumeration',('BH010','BH030','BH082','BH140','BH170','BH230'))
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['ZI024_WUR'] = {}
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['ZI024_WUR']['BH010']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['ZI024_WUR']['BH030']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['ZI024_WUR']['BH082']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['ZI024_WUR']['BH140']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['ZI024_WUR']['BH170']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['ZI024_WUR']['BH230']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['HydrographySrf']['ZI024_WUR2'] = ('Enumeration',('BH010','BH030','BH082','BH140','BH170','BH230'))
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['ZI024_WUR2'] = {}
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['ZI024_WUR2']['BH010']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['ZI024_WUR2']['BH030']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['ZI024_WUR2']['BH082']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['ZI024_WUR2']['BH140']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['ZI024_WUR2']['BH170']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['ZI024_WUR2']['BH230']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['HydrographySrf']['ZI024_WUR3'] = ('Enumeration',('BH010','BH030','BH082','BH140','BH170','BH230'))
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['ZI024_WUR3'] = {}
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['ZI024_WUR3']['BH010']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['ZI024_WUR3']['BH030']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['ZI024_WUR3']['BH082']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['ZI024_WUR3']['BH140']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['ZI024_WUR3']['BH170']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['ZI024_WUR3']['BH230']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['HydrographySrf']['ZI024_WUR4'] = ('Enumeration',('BH010','BH030','BH082','BH140','BH170','BH230'))
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['ZI024_WUR4'] = {}
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['ZI024_WUR4']['BH010']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['ZI024_WUR4']['BH030']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['ZI024_WUR4']['BH082']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['ZI024_WUR4']['BH140']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['ZI024_WUR4']['BH170']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['ZI024_WUR4']['BH230']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['HydrographySrf']['ZI024_YWQ'] = ('Enumeration',('BH010','BH030','BH082','BH100','BH140','BH170','BH230','BI050','ZD070'))
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['ZI024_YWQ'] = {}
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['ZI024_YWQ']['BH010']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['ZI024_YWQ']['BH030']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['ZI024_YWQ']['BH082']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['ZI024_YWQ']['BH100']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['ZI024_YWQ']['BH140']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['ZI024_YWQ']['BH170']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['ZI024_YWQ']['BH230']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['ZI024_YWQ']['BI050']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['ZI024_YWQ']['ZD070']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['HydrographySrf']['ZI025_HDP'] = ('Real',('BD115','BD140','BH140'))
    field_information['GGDM 3.0']['HydrographySrf']['ZI025_MAN'] = ('Boolean',('BD115'))
    field_information['GGDM 3.0']['HydrographySrf']['ZI026_CTUC'] = ('Enumeration',('BA040','BB110','BD115','BD140','BH010','BH030','BH082','BH090','BH100','BH120','BH140','BH165','BH170','BH230','BI020','BI044','BI050','ZD070'))
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['ZI026_CTUC']['BA040']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['ZI026_CTUC']['BB110']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['ZI026_CTUC']['BD115']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['ZI026_CTUC']['BD140']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['ZI026_CTUC']['BH010']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['ZI026_CTUC']['BH030']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['ZI026_CTUC']['BH082']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['ZI026_CTUC']['BH090']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['ZI026_CTUC']['BH100']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['ZI026_CTUC']['BH120']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['ZI026_CTUC']['BH140']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['ZI026_CTUC']['BH165']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['ZI026_CTUC']['BH170']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['ZI026_CTUC']['BH230']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['ZI026_CTUC']['BI020']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['ZI026_CTUC']['BI044']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['ZI026_CTUC']['BI050']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['HydrographySrf']['EnumeratedIndexValues']['ZI026_CTUC']['ZD070']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['HydrographySrf']['ZI026_CTUL'] = ('integer',('BA040','BB110','BD115','BD140','BH010','BH030','BH082','BH090','BH100','BH120','BH140','BH165','BH170','BH230','BI020','BI044','BI050','ZD070'))
    field_information['GGDM 3.0']['HydrographySrf']['ZI026_CTUU'] = ('integer',('BA040','BB110','BD115','BD140','BH010','BH030','BH082','BH090','BH100','BH120','BH140','BH165','BH170','BH230','BI020','BI044','BI050','ZD070'))
    field_information['GGDM 3.0']['HydrographySrf']['ZI031S_URI'] = ('StructuredText',('BA040','BB110','BD115','BD140','BH010','BH030','BH082','BH090','BH100','BH120','BH140','BH165','BH170','BH230','BI020','BI044','BI050','ZD070'))
    field_information['GGDM 3.0']['HydrographySrf']['ZI039S_UFI'] = ('StructuredText',('BA040','BB110','BD115','BD140','BH010','BH030','BH082','BH090','BH100','BH120','BH140','BH165','BH170','BH230','BI020','BI044','BI050','ZD070'))
    field_information['GGDM 3.0']['HydrographySrf']['ZSAX_RS0'] = ('CodeList',('BA040','BB110','BD115','BD140','BH010','BH030','BH082','BH090','BH100','BH120','BH140','BH165','BH170','BH230','BI020','BI044','BI050','ZD070'))
    field_information['GGDM 3.0']['HydrographySrf']['ZSAX_RX0'] = ('StructuredText',('BA040','BB110','BD115','BD140','BH010','BH030','BH082','BH090','BH100','BH120','BH140','BH165','BH170','BH230','BI020','BI044','BI050','ZD070'))
    field_information['GGDM 3.0']['HydrographySrf']['ZSAX_RX3'] = ('StructuredText',('BA040','BB110','BD115','BD140','BH010','BH030','BH082','BH090','BH100','BH120','BH140','BH165','BH170','BH230','BI020','BI044','BI050','ZD070'))
    field_information['GGDM 3.0']['HydrographySrf']['ZSAX_RX4'] = ('StructuredText',('BA040','BB110','BD115','BD140','BH010','BH030','BH082','BH090','BH100','BH120','BH140','BH165','BH170','BH230','BI020','BI044','BI050','ZD070'))
    field_information['GGDM 3.0']['HydrographySrf']['ZVH'] = ('Real',('BD115','BH010','BH030','BH082','BH100','BH140','BH230','BI020','BI044','BI050'))
    field_information['GGDM 3.0']['HydrographySrfExt']['AQF'] = ('Enumeration',('BH050'))
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['AQF'] = {}
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['AQF']['BH050']  = (-999999,1,2,3,4,8)
    field_information['GGDM 3.0']['HydrographySrfExt']['ARA'] = ('Real',('BB008','BD030','BD050','BD061','BD180','BF010','BH050','FC034','FC035','FC037','FC177'))
    field_information['GGDM 3.0']['HydrographySrfExt']['BDS'] = ('Boolean',('FC165'))
    field_information['GGDM 3.0']['HydrographySrfExt']['BEN'] = ('StructuredText',('BB008','BD020','BD030','BD050','BD061','BD120','BD180','BE019','BF010','BG012','BH050','BH190','FC034','FC035','FC037','FC041','FC165','FC177'))
    field_information['GGDM 3.0']['HydrographySrfExt']['BMC'] = ('Enumeration',('BH190'))
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['BMC'] = {}
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['BMC']['BH190']  = (-999999,1,2,3,4,5,6,7,8,9,11,14,999)
    field_information['GGDM 3.0']['HydrographySrfExt']['BMC2'] = ('Enumeration',('BH190'))
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['BMC2'] = {}
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['BMC2']['BH190']  = (-999999,1,2,3,4,5,6,7,8,9,11,14,999)
    field_information['GGDM 3.0']['HydrographySrfExt']['BMC3'] = ('Enumeration',('BH190'))
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['BMC3'] = {}
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['BMC3']['BH190']  = (-999999,1,2,3,4,5,6,7,8,9,11,14,999)
    field_information['GGDM 3.0']['HydrographySrfExt']['BRR'] = ('StructuredText',('FC165'))
    field_information['GGDM 3.0']['HydrographySrfExt']['BRS'] = ('Real',('FC165'))
    field_information['GGDM 3.0']['HydrographySrfExt']['CAA'] = ('Enumeration',('BB008','FC034','FC041'))
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['CAA']['BB008']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['CAA']['FC034']  = (-999999,1,2,5,6,7,11,16,999)
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['CAA']['FC041']  = (-999999,1,8,16,999)
    field_information['GGDM 3.0']['HydrographySrfExt']['CAB'] = ('Enumeration',('FC037'))
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['CAB'] = {}
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['CAB']['FC037']  = (-999999,2,3,4,7,8,9,999)
    field_information['GGDM 3.0']['HydrographySrfExt']['CNCP'] = ('StructuredText',('BD020','BH050'))
    field_information['GGDM 3.0']['HydrographySrfExt']['COA'] = ('Enumeration',('BH050'))
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['COA'] = {}
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['COA']['BH050']  = (-999999,2,4)
    field_information['GGDM 3.0']['HydrographySrfExt']['COC'] = ('Enumeration',('BH050'))
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['COC'] = {}
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['COC']['BH050']  = (-999999,1,2,3,4)
    field_information['GGDM 3.0']['HydrographySrfExt']['COG'] = ('Enumeration',('BH050'))
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['COG'] = {}
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['COG']['BH050']  = (-999999,2,4)
    field_information['GGDM 3.0']['HydrographySrfExt']['COS'] = ('Enumeration',('BD020','BH050'))
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['COS']['BD020']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['COS']['BH050']  = (-999999,2,4,6,9,13,14)
    field_information['GGDM 3.0']['HydrographySrfExt']['DAN'] = ('String',('FC034','FC037','FC165'))
    field_information['GGDM 3.0']['HydrographySrfExt']['DKC'] = ('Enumeration',('BD180'))
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['DKC'] = {}
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['DKC']['BD180']  = (-999999,1,3,4,5,6,8,9,998,999)
    field_information['GGDM 3.0']['HydrographySrfExt']['DKC2'] = ('Enumeration',('BD180'))
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['DKC2'] = {}
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['DKC2']['BD180']  = (-999999,1,3,4,5,6,8,9,998,999)
    field_information['GGDM 3.0']['HydrographySrfExt']['DKC3'] = ('Enumeration',('BD180'))
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['DKC3'] = {}
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['DKC3']['BD180']  = (-999999,1,3,4,5,6,8,9,998,999)
    field_information['GGDM 3.0']['HydrographySrfExt']['DOF'] = ('Real',('FC041','FC165'))
    field_information['GGDM 3.0']['HydrographySrfExt']['DOXY'] = ('Real',('BB008'))
    field_information['GGDM 3.0']['HydrographySrfExt']['DRP'] = ('String',('FC165'))
    field_information['GGDM 3.0']['HydrographySrfExt']['DTN'] = ('Boolean',('BD050','BD061','BD180'))
    field_information['GGDM 3.0']['HydrographySrfExt']['F_CODE'] = ('CONSTRAINED_STRING',('BB008','BD020','BD030','BD050','BD061','BD120','BD180','BE019','BF010','BG012','BH050','BH190','FC034','FC035','FC037','FC041','FC165','FC177'))
    field_information['GGDM 3.0']['HydrographySrfExt']['FLO'] = ('Boolean',('BD061'))
    field_information['GGDM 3.0']['HydrographySrfExt']['FUFI'] = ('StructuredText',('BB008','BD020','BD030','BD050','BD061','BD120','BD180','BE019','BF010','BG012','BH050','BH190','FC034','FC035','FC037','FC041','FC165','FC177'))
    field_information['GGDM 3.0']['HydrographySrfExt']['FURL'] = ('StructuredText',('BB008','BD020','BD030','BD050','BD061','BD120','BD180','BE019','BF010','BG012','BH050','BH190','FC034','FC035','FC037','FC041','FC165','FC177'))
    field_information['GGDM 3.0']['HydrographySrfExt']['GDBV'] = ('Enumeration',('BB008','BD020','BD030','BD050','BD061','BD120','BD180','BE019','BF010','BG012','BH050','BH190','FC034','FC035','FC037','FC041','FC165','FC177'))
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['GDBV']['BB008']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['GDBV']['BD020']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['GDBV']['BD030']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['GDBV']['BD050']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['GDBV']['BD061']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['GDBV']['BD120']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['GDBV']['BD180']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['GDBV']['BE019']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['GDBV']['BF010']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['GDBV']['BG012']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['GDBV']['BH050']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['GDBV']['BH190']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['GDBV']['FC034']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['GDBV']['FC035']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['GDBV']['FC037']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['GDBV']['FC041']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['GDBV']['FC165']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['GDBV']['FC177']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['HydrographySrfExt']['HDP'] = ('Real',('FC034','FC165','FC177'))
    field_information['GGDM 3.0']['HydrographySrfExt']['IAS'] = ('Boolean',('FC041'))
    field_information['GGDM 3.0']['HydrographySrfExt']['LMC'] = ('Boolean',('BH050'))
    field_information['GGDM 3.0']['HydrographySrfExt']['LZN'] = ('Real',('BB008','BD030','BD050','BD061','BD180','BF010','BH050','FC034','FC035','FC037','FC041','FC165','FC177'))
    field_information['GGDM 3.0']['HydrographySrfExt']['MAN'] = ('Boolean',('FC034','FC037','FC041','FC165'))
    field_information['GGDM 3.0']['HydrographySrfExt']['MAS'] = ('Boolean',('FC034'))
    field_information['GGDM 3.0']['HydrographySrfExt']['MBC_MCC1'] = ('Enumeration',('BF010'))
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['MBC_MCC1'] = {}
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['MBC_MCC1']['BF010']  = (-999999,4,7,8,10,12,14,15,16,18,22,24,25,28,36,37,45,46,49,52,55,58,59,61,63,65,66,69,70,73,75,79,80,81,84,88,90,92,96,98,99,103,104,105,106,108,111,115,999)
    field_information['GGDM 3.0']['HydrographySrfExt']['MBC_MCC2'] = ('Enumeration',('BF010'))
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['MBC_MCC2'] = {}
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['MBC_MCC2']['BF010']  = (-999999,4,7,8,10,12,14,15,16,18,22,24,25,28,36,37,45,46,49,52,55,58,59,61,63,65,66,69,70,73,75,79,80,81,84,88,90,92,96,98,99,103,104,105,106,108,111,115,999)
    field_information['GGDM 3.0']['HydrographySrfExt']['MBC_PSC1'] = ('Enumeration',('BF010'))
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['MBC_PSC1'] = {}
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['MBC_PSC1']['BF010']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,17,18,19,20,21,22,23,24,25,26,27,29,999)
    field_information['GGDM 3.0']['HydrographySrfExt']['MBC_PSC2'] = ('Enumeration',('BF010'))
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['MBC_PSC2'] = {}
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['MBC_PSC2']['BF010']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,17,18,19,20,21,22,23,24,25,26,27,29,999)
    field_information['GGDM 3.0']['HydrographySrfExt']['MBC_SCO1'] = ('Enumeration',('BF010'))
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['MBC_SCO1'] = {}
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['MBC_SCO1']['BF010']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,999)
    field_information['GGDM 3.0']['HydrographySrfExt']['MBC_SCO2'] = ('Enumeration',('BF010'))
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['MBC_SCO2'] = {}
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['MBC_SCO2']['BF010']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,999)
    field_information['GGDM 3.0']['HydrographySrfExt']['MCC'] = ('Enumeration',('BD120'))
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['MCC'] = {}
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['MCC']['BD120']  = (-999999,24,25,84,999)
    field_information['GGDM 3.0']['HydrographySrfExt']['MCC2'] = ('Enumeration',('BD120'))
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['MCC2'] = {}
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['MCC2']['BD120']  = (-999999,24,25,84,999)
    field_information['GGDM 3.0']['HydrographySrfExt']['MCC3'] = ('Enumeration',('BD120'))
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['MCC3'] = {}
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['MCC3']['BD120']  = (-999999,24,25,84,999)
    field_information['GGDM 3.0']['HydrographySrfExt']['MCY'] = ('Enumeration',('FC037'))
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['MCY'] = {}
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['MCY']['FC037']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,14,15,999)
    field_information['GGDM 3.0']['HydrographySrfExt']['MCY2'] = ('Enumeration',('FC037'))
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['MCY2'] = {}
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['MCY2']['FC037']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,14,15,999)
    field_information['GGDM 3.0']['HydrographySrfExt']['MCY3'] = ('Enumeration',('FC037'))
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['MCY3'] = {}
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['MCY3']['FC037']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,14,15,999)
    field_information['GGDM 3.0']['HydrographySrfExt']['MFE'] = ('Enumeration',('BH050'))
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['MFE'] = {}
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['MFE']['BH050']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['HydrographySrfExt']['MLO'] = ('Boolean',('FC037'))
    field_information['GGDM 3.0']['HydrographySrfExt']['MNR'] = ('Enumeration',('FC037'))
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['MNR'] = {}
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['MNR']['FC037']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,999)
    field_information['GGDM 3.0']['HydrographySrfExt']['MNR2'] = ('Enumeration',('FC037'))
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['MNR2'] = {}
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['MNR2']['FC037']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,999)
    field_information['GGDM 3.0']['HydrographySrfExt']['MNR3'] = ('Enumeration',('FC037'))
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['MNR3'] = {}
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['MNR3']['FC037']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,999)
    field_information['GGDM 3.0']['HydrographySrfExt']['MRR'] = ('Enumeration',('FC037'))
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['MRR'] = {}
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['MRR']['FC037']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,45,46,47,52,999)
    field_information['GGDM 3.0']['HydrographySrfExt']['MRR2'] = ('Enumeration',('FC037'))
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['MRR2'] = {}
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['MRR2']['FC037']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,45,46,47,52,999)
    field_information['GGDM 3.0']['HydrographySrfExt']['MRR3'] = ('Enumeration',('FC037'))
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['MRR3'] = {}
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['MRR3']['FC037']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,45,46,47,52,999)
    field_information['GGDM 3.0']['HydrographySrfExt']['OPT'] = ('Enumeration',('FC037'))
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['OPT'] = {}
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['OPT']['FC037']  = (-999999,1,2,3,4,5,999)
    field_information['GGDM 3.0']['HydrographySrfExt']['ORS'] = ('Enumeration',('FC037'))
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['ORS'] = {}
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['ORS']['FC037']  = (-999999,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['HydrographySrfExt']['ORS2'] = ('Enumeration',('FC037'))
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['ORS2'] = {}
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['ORS2']['FC037']  = (-999999,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['HydrographySrfExt']['ORS3'] = ('Enumeration',('FC037'))
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['ORS3'] = {}
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['ORS3']['FC037']  = (-999999,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['HydrographySrfExt']['OTH'] = ('StructuredText',('BB008','BD020','BD030','BD050','BD061','BD120','BD180','BE019','BF010','BG012','BH050','BH190','FC034','FC035','FC037','FC041','FC165','FC177'))
    field_information['GGDM 3.0']['HydrographySrfExt']['PCF'] = ('Enumeration',('BD020','BH050'))
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['PCF']['BD020']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['PCF']['BH050']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['HydrographySrfExt']['PPO'] = ('Enumeration',('BH050'))
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['PPO'] = {}
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['PPO']['BH050']  = (-999999,11,29,30,39,72,77,999)
    field_information['GGDM 3.0']['HydrographySrfExt']['PPO2'] = ('Enumeration',('BH050'))
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['PPO2'] = {}
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['PPO2']['BH050']  = (-999999,11,29,30,39,72,77,999)
    field_information['GGDM 3.0']['HydrographySrfExt']['PPO3'] = ('Enumeration',('BH050'))
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['PPO3'] = {}
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['PPO3']['BH050']  = (-999999,11,29,30,39,72,77,999)
    field_information['GGDM 3.0']['HydrographySrfExt']['PWAC'] = ('Enumeration',('BH190'))
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['PWAC'] = {}
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['PWAC']['BH190']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['HydrographySrfExt']['PWAL'] = ('real',('BH190'))
    field_information['GGDM 3.0']['HydrographySrfExt']['PWAU'] = ('real',('BH190'))
    field_information['GGDM 3.0']['HydrographySrfExt']['RTT'] = ('Enumeration',('FC165'))
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['RTT'] = {}
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['RTT']['FC165']  = (-999999,2,3,4,5,11,13,17,18,999)
    field_information['GGDM 3.0']['HydrographySrfExt']['TAN'] = ('String',('FC041'))
    field_information['GGDM 3.0']['HydrographySrfExt']['TSP'] = ('Enumeration',('FC041'))
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['TSP'] = {}
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['TSP']['FC041']  = (-999999,2,3,4,5,6,7,8,9,10,11,12,999)
    field_information['GGDM 3.0']['HydrographySrfExt']['UFI'] = ('StructuredText',('BB008','BD020','BD030','BD050','BD061','BD120','BD180','BE019','BF010','BG012','BH050','BH190','FC034','FC035','FC037','FC041','FC165','FC177'))
    field_information['GGDM 3.0']['HydrographySrfExt']['VEG'] = ('Enumeration',('BF010'))
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['VEG'] = {}
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['VEG']['BF010']  = (-999999,61,62,999)
    field_information['GGDM 3.0']['HydrographySrfExt']['VSP'] = ('Enumeration',('BD061'))
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['VSP'] = {}
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['VSP']['BD061']  = (-999999,17,19,22,28,29,30,31,35,36,999)
    field_information['GGDM 3.0']['HydrographySrfExt']['VSP2'] = ('Enumeration',('BD061'))
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['VSP2'] = {}
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['VSP2']['BD061']  = (-999999,17,19,22,28,29,30,31,35,36,999)
    field_information['GGDM 3.0']['HydrographySrfExt']['VSP3'] = ('Enumeration',('BD061'))
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['VSP3'] = {}
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['VSP3']['BD061']  = (-999999,17,19,22,28,29,30,31,35,36,999)
    field_information['GGDM 3.0']['HydrographySrfExt']['WDAC'] = ('Enumeration',('BH190'))
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['WDAC'] = {}
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['WDAC']['BH190']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['HydrographySrfExt']['WDAL'] = ('real',('BH190'))
    field_information['GGDM 3.0']['HydrographySrfExt']['WDAU'] = ('real',('BH190'))
    field_information['GGDM 3.0']['HydrographySrfExt']['WDH'] = ('Real',('BH190'))
    field_information['GGDM 3.0']['HydrographySrfExt']['WDL'] = ('Real',('BH190'))
    field_information['GGDM 3.0']['HydrographySrfExt']['WID'] = ('Real',('BB008','BD030','BD050','BD061','BF010','BH050','FC034','FC035','FC037','FC041','FC165','FC177'))
    field_information['GGDM 3.0']['HydrographySrfExt']['WLO'] = ('Enumeration',('BD180'))
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['WLO'] = {}
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['WLO']['BD180']  = (-999999,1,2,3,4,5,6,999)
    field_information['GGDM 3.0']['HydrographySrfExt']['WPC'] = ('Enumeration',('FC037'))
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['WPC'] = {}
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['WPC']['FC037']  = (-999999,1,2,999)
    field_information['GGDM 3.0']['HydrographySrfExt']['WPC2'] = ('Enumeration',('FC037'))
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['WPC2'] = {}
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['WPC2']['FC037']  = (-999999,1,2,999)
    field_information['GGDM 3.0']['HydrographySrfExt']['WPC3'] = ('Enumeration',('FC037'))
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['WPC3'] = {}
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['WPC3']['FC037']  = (-999999,1,2,999)
    field_information['GGDM 3.0']['HydrographySrfExt']['WTT'] = ('Enumeration',('BG012'))
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['WTT'] = {}
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['WTT']['BG012']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['HydrographySrfExt']['ZHBH_TEC'] = ('Enumeration',('BD020','BD180'))
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['ZHBH_TEC'] = {}
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['ZHBH_TEC']['BD020']  = (-999999,1,2,3,4,5,6,8,9,10,11,12,13,14,15,17,18,999)
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['ZHBH_TEC']['BD180']  = (-999999,1,2,3,4,5,6,8,9,10,11,12,13,14,15,17,18,999)
    field_information['GGDM 3.0']['HydrographySrfExt']['ZHBH_TEC2'] = ('Enumeration',('BD020','BD180'))
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['ZHBH_TEC2'] = {}
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['ZHBH_TEC2']['BD020']  = (-999999,1,2,3,4,5,6,8,9,10,11,12,13,14,15,17,18,999)
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['ZHBH_TEC2']['BD180']  = (-999999,1,2,3,4,5,6,8,9,10,11,12,13,14,15,17,18,999)
    field_information['GGDM 3.0']['HydrographySrfExt']['ZHBH_TEC3'] = ('Enumeration',('BD020','BD180'))
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['ZHBH_TEC3'] = {}
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['ZHBH_TEC3']['BD020']  = (-999999,1,2,3,4,5,6,8,9,10,11,12,13,14,15,17,18,999)
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['ZHBH_TEC3']['BD180']  = (-999999,1,2,3,4,5,6,8,9,10,11,12,13,14,15,17,18,999)
    field_information['GGDM 3.0']['HydrographySrfExt']['ZHDP_DCR'] = ('Boolean',('FC034','FC165','FC177'))
    field_information['GGDM 3.0']['HydrographySrfExt']['ZHDP_DKC'] = ('Enumeration',('FC034','FC165','FC177'))
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['ZHDP_DKC'] = {}
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['ZHDP_DKC']['FC034']  = (-999999,1,3,4,5,6,7,8,9,10,11,12,998,999)
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['ZHDP_DKC']['FC165']  = (-999999,1,3,4,5,6,7,8,9,10,11,12,998,999)
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['ZHDP_DKC']['FC177']  = (-999999,1,3,4,5,6,7,8,9,10,11,12,998,999)
    field_information['GGDM 3.0']['HydrographySrfExt']['ZHDP_DKC2'] = ('Enumeration',('FC034','FC165','FC177'))
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['ZHDP_DKC2'] = {}
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['ZHDP_DKC2']['FC034']  = (-999999,1,3,4,5,6,7,8,9,10,11,12,998,999)
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['ZHDP_DKC2']['FC165']  = (-999999,1,3,4,5,6,7,8,9,10,11,12,998,999)
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['ZHDP_DKC2']['FC177']  = (-999999,1,3,4,5,6,7,8,9,10,11,12,998,999)
    field_information['GGDM 3.0']['HydrographySrfExt']['ZHDP_DKC3'] = ('Enumeration',('FC034','FC165','FC177'))
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['ZHDP_DKC3'] = {}
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['ZHDP_DKC3']['FC034']  = (-999999,1,3,4,5,6,7,8,9,10,11,12,998,999)
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['ZHDP_DKC3']['FC165']  = (-999999,1,3,4,5,6,7,8,9,10,11,12,998,999)
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['ZHDP_DKC3']['FC177']  = (-999999,1,3,4,5,6,7,8,9,10,11,12,998,999)
    field_information['GGDM 3.0']['HydrographySrfExt']['ZHDP_SVC'] = ('Enumeration',('FC034','FC165','FC177'))
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['ZHDP_SVC'] = {}
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['ZHDP_SVC']['FC034']  = (-999999,1,2,3,4,5,998,999)
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['ZHDP_SVC']['FC165']  = (-999999,1,2,3,4,5,998,999)
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['ZHDP_SVC']['FC177']  = (-999999,1,2,3,4,5,998,999)
    field_information['GGDM 3.0']['HydrographySrfExt']['ZHDP_TEC'] = ('Enumeration',('FC034','FC165','FC177'))
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['ZHDP_TEC'] = {}
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['ZHDP_TEC']['FC034']  = (-999999,1,2,3,4,5,6,8,9,10,11,12,13,14,15,17,18,999)
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['ZHDP_TEC']['FC165']  = (-999999,1,2,3,4,5,6,8,9,10,11,12,13,14,15,17,18,999)
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['ZHDP_TEC']['FC177']  = (-999999,1,2,3,4,5,6,8,9,10,11,12,13,14,15,17,18,999)
    field_information['GGDM 3.0']['HydrographySrfExt']['ZHDP_TEC2'] = ('Enumeration',('FC034','FC165','FC177'))
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['ZHDP_TEC2'] = {}
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['ZHDP_TEC2']['FC034']  = (-999999,1,2,3,4,5,6,8,9,10,11,12,13,14,15,17,18,999)
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['ZHDP_TEC2']['FC165']  = (-999999,1,2,3,4,5,6,8,9,10,11,12,13,14,15,17,18,999)
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['ZHDP_TEC2']['FC177']  = (-999999,1,2,3,4,5,6,8,9,10,11,12,13,14,15,17,18,999)
    field_information['GGDM 3.0']['HydrographySrfExt']['ZHDP_TEC3'] = ('Enumeration',('FC034','FC165','FC177'))
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['ZHDP_TEC3'] = {}
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['ZHDP_TEC3']['FC034']  = (-999999,1,2,3,4,5,6,8,9,10,11,12,13,14,15,17,18,999)
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['ZHDP_TEC3']['FC165']  = (-999999,1,2,3,4,5,6,8,9,10,11,12,13,14,15,17,18,999)
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['ZHDP_TEC3']['FC177']  = (-999999,1,2,3,4,5,6,8,9,10,11,12,13,14,15,17,18,999)
    field_information['GGDM 3.0']['HydrographySrfExt']['ZHDP_VDC'] = ('Enumeration',('FC034','FC165','FC177'))
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['ZHDP_VDC'] = {}
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['ZHDP_VDC']['FC034']  = (-999999,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,24,28,30,90,91,92,93,94,95,96,97,98,99,100,101,102,103,104,105,107,999)
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['ZHDP_VDC']['FC165']  = (-999999,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,24,28,30,90,91,92,93,94,95,96,97,98,99,100,101,102,103,104,105,107,999)
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['ZHDP_VDC']['FC177']  = (-999999,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,24,28,30,90,91,92,93,94,95,96,97,98,99,100,101,102,103,104,105,107,999)
    field_information['GGDM 3.0']['HydrographySrfExt']['ZHDP_VDR'] = ('String',('FC034','FC165','FC177'))
    field_information['GGDM 3.0']['HydrographySrfExt']['ZI001_SDV'] = ('StructuredText',('BB008','BD020','BD030','BD050','BD061','BD120','BD180','BE019','BF010','BG012','BH050','BH190','FC034','FC035','FC037','FC041','FC165','FC177'))
    field_information['GGDM 3.0']['HydrographySrfExt']['ZI001_SRT'] = ('Enumeration',('BB008','BD020','BD030','BD050','BD061','BD120','BD180','BE019','BF010','BG012','BH050','BH190','FC034','FC035','FC037','FC041','FC165','FC177'))
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['ZI001_SRT']['BB008']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['ZI001_SRT']['BD020']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['ZI001_SRT']['BD030']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['ZI001_SRT']['BD050']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['ZI001_SRT']['BD061']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['ZI001_SRT']['BD120']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['ZI001_SRT']['BD180']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['ZI001_SRT']['BE019']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['ZI001_SRT']['BF010']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['ZI001_SRT']['BG012']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['ZI001_SRT']['BH050']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['ZI001_SRT']['BH190']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['ZI001_SRT']['FC034']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['ZI001_SRT']['FC035']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['ZI001_SRT']['FC037']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['ZI001_SRT']['FC041']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['ZI001_SRT']['FC165']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['ZI001_SRT']['FC177']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['HydrographySrfExt']['ZI002_UFI'] = ('StructuredText',('BB008','BD020','BD030','BD050','BD061','BD120','BD180','BE019','BF010','BG012','BH050','BH190','FC034','FC035','FC037','FC041','FC165','FC177'))
    field_information['GGDM 3.0']['HydrographySrfExt']['ZI004_RCG'] = ('Enumeration',('BB008','BD020','BD030','BD050','BD061','BD120','BD180','BE019','BF010','BG012','BH050','BH190','FC034','FC035','FC037','FC041','FC165','FC177'))
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['ZI004_RCG']['BB008']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['ZI004_RCG']['BD020']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['ZI004_RCG']['BD030']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['ZI004_RCG']['BD050']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['ZI004_RCG']['BD061']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['ZI004_RCG']['BD120']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['ZI004_RCG']['BD180']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['ZI004_RCG']['BE019']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['ZI004_RCG']['BF010']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['ZI004_RCG']['BG012']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['ZI004_RCG']['BH050']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['ZI004_RCG']['BH190']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['ZI004_RCG']['FC034']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['ZI004_RCG']['FC035']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['ZI004_RCG']['FC037']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['ZI004_RCG']['FC041']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['ZI004_RCG']['FC165']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['ZI004_RCG']['FC177']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['HydrographySrfExt']['ZI005_FNA'] = ('String',('BD020','BD030','BD050','BD061','BD120','BD180','BF010','BG012','BH050','BH190','FC034','FC035','FC037','FC041','FC165','FC177'))
    field_information['GGDM 3.0']['HydrographySrfExt']['ZI005_FNA2'] = ('String',('BH190'))
    field_information['GGDM 3.0']['HydrographySrfExt']['ZI005_FNA3'] = ('String',('BH190'))
    field_information['GGDM 3.0']['HydrographySrfExt']['ZI005_GNT'] = ('Enumeration',('BD020','BD030','BD050','BD061','BD120','BD180','BF010','BG012','BH050','BH190','FC034','FC035','FC037','FC041','FC165','FC177'))
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['ZI005_GNT']['BD020']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['ZI005_GNT']['BD030']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['ZI005_GNT']['BD050']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['ZI005_GNT']['BD061']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['ZI005_GNT']['BD120']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['ZI005_GNT']['BD180']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['ZI005_GNT']['BF010']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['ZI005_GNT']['BG012']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['ZI005_GNT']['BH050']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['ZI005_GNT']['BH190']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['ZI005_GNT']['FC034']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['ZI005_GNT']['FC035']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['ZI005_GNT']['FC037']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['ZI005_GNT']['FC041']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['ZI005_GNT']['FC165']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['ZI005_GNT']['FC177']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['HydrographySrfExt']['ZI005_GNT2'] = ('Enumeration',('BH190'))
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['ZI005_GNT2'] = {}
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['ZI005_GNT2']['BH190']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['HydrographySrfExt']['ZI005_GNT3'] = ('Enumeration',('BH190'))
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['ZI005_GNT3'] = {}
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['ZI005_GNT3']['BH190']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['HydrographySrfExt']['ZI005_NFN'] = ('String',('BD020','BD030','BD050','BD061','BD120','BD180','BF010','BG012','BH050','BH190','FC034','FC035','FC037','FC041','FC165','FC177'))
    field_information['GGDM 3.0']['HydrographySrfExt']['ZI005_NFN2'] = ('String',('BH190'))
    field_information['GGDM 3.0']['HydrographySrfExt']['ZI005_NFN3'] = ('String',('BH190'))
    field_information['GGDM 3.0']['HydrographySrfExt']['ZI006_MEM'] = ('String',('BB008','BD020','BD030','BD050','BD061','BD120','BD180','BE019','BF010','BG012','BH050','BH190','FC034','FC035','FC037','FC041','FC165','FC177'))
    field_information['GGDM 3.0']['HydrographySrfExt']['ZI020_GE4'] = ('CodeList',('BB008','BD020','BD030','BD050','BD061','BD120','BD180','BE019','BF010','BG012','BH050','BH190','FC034','FC035','FC037','FC041','FC165','FC177'))
    field_information['GGDM 3.0']['HydrographySrfExt']['ZI024_ASE'] = ('Real',('BB008','BH190'))
    field_information['GGDM 3.0']['HydrographySrfExt']['ZI024_CFR'] = ('Real',('BB008','BH190'))
    field_information['GGDM 3.0']['HydrographySrfExt']['ZI024_CLO'] = ('Real',('BB008','BH190'))
    field_information['GGDM 3.0']['HydrographySrfExt']['ZI024_CYN'] = ('Real',('BB008','BH190'))
    field_information['GGDM 3.0']['HydrographySrfExt']['ZI024_FMR'] = ('Real',('BB008','BH190'))
    field_information['GGDM 3.0']['HydrographySrfExt']['ZI024_FRR'] = ('Real',('BB008','BH190'))
    field_information['GGDM 3.0']['HydrographySrfExt']['ZI024_HAR'] = ('Real',('BB008','BH190'))
    field_information['GGDM 3.0']['HydrographySrfExt']['ZI024_HYP'] = ('Enumeration',('BB008','BH190'))
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['ZI024_HYP'] = {}
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['ZI024_HYP']['BB008']  = (-999999,1,2,4)
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['ZI024_HYP']['BH190']  = (-999999,1,2,4)
    field_information['GGDM 3.0']['HydrographySrfExt']['ZI024_MGN'] = ('Real',('BB008','BH190'))
    field_information['GGDM 3.0']['HydrographySrfExt']['ZI024_PHW'] = ('Real',('BB008','BH190'))
    field_information['GGDM 3.0']['HydrographySrfExt']['ZI024_SCC'] = ('Enumeration',('BB008','BH190'))
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['ZI024_SCC'] = {}
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['ZI024_SCC']['BB008']  = (-999999,1,4,10,11,12,13,14,998,999)
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['ZI024_SCC']['BH190']  = (-999999,1,4,10,11,12,13,14,998,999)
    field_information['GGDM 3.0']['HydrographySrfExt']['ZI024_SUL'] = ('Real',('BB008','BH190'))
    field_information['GGDM 3.0']['HydrographySrfExt']['ZI024_TDS'] = ('Real',('BB008','BH190'))
    field_information['GGDM 3.0']['HydrographySrfExt']['ZI024_TEP'] = ('Real',('BB008','BH190'))
    field_information['GGDM 3.0']['HydrographySrfExt']['ZI024_TUR'] = ('Real',('BB008','BH190'))
    field_information['GGDM 3.0']['HydrographySrfExt']['ZI024_WAC'] = ('Real',('BB008','BH190'))
    field_information['GGDM 3.0']['HydrographySrfExt']['ZI024_WTNO'] = ('Real',('BB008','BH190'))
    field_information['GGDM 3.0']['HydrographySrfExt']['ZI025_HDP'] = ('Real',('BD020','BD120','BD180','BH190'))
    field_information['GGDM 3.0']['HydrographySrfExt']['ZI025_WLE'] = ('Enumeration',('BD020','BD120','BD180','BH190'))
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['ZI025_WLE'] = {}
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['ZI025_WLE']['BD020']  = (-999999,1,2,3,4,5,9,999)
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['ZI025_WLE']['BD120']  = (-999999,1,2,3,4,5,9,999)
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['ZI025_WLE']['BD180']  = (-999999,1,2,3,4,5,9,999)
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['ZI025_WLE']['BH190']  = (-999999,1,2,3,4,5,9,999)
    field_information['GGDM 3.0']['HydrographySrfExt']['ZI026_CTUC'] = ('Enumeration',('BB008','BD020','BD030','BD050','BD061','BD120','BD180','BE019','BF010','BG012','BH050','BH190','FC034','FC035','FC037','FC041','FC165','FC177'))
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['ZI026_CTUC']['BB008']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['ZI026_CTUC']['BD020']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['ZI026_CTUC']['BD030']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['ZI026_CTUC']['BD050']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['ZI026_CTUC']['BD061']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['ZI026_CTUC']['BD120']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['ZI026_CTUC']['BD180']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['ZI026_CTUC']['BE019']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['ZI026_CTUC']['BF010']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['ZI026_CTUC']['BG012']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['ZI026_CTUC']['BH050']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['ZI026_CTUC']['BH190']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['ZI026_CTUC']['FC034']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['ZI026_CTUC']['FC035']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['ZI026_CTUC']['FC037']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['ZI026_CTUC']['FC041']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['ZI026_CTUC']['FC165']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['HydrographySrfExt']['EnumeratedIndexValues']['ZI026_CTUC']['FC177']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['HydrographySrfExt']['ZI026_CTUL'] = ('integer',('BB008','BD020','BD030','BD050','BD061','BD120','BD180','BE019','BF010','BG012','BH050','BH190','FC034','FC035','FC037','FC041','FC165','FC177'))
    field_information['GGDM 3.0']['HydrographySrfExt']['ZI026_CTUU'] = ('integer',('BB008','BD020','BD030','BD050','BD061','BD120','BD180','BE019','BF010','BG012','BH050','BH190','FC034','FC035','FC037','FC041','FC165','FC177'))
    field_information['GGDM 3.0']['HydrographySrfExt']['ZI031S_URI'] = ('StructuredText',('BB008','BD020','BD030','BD050','BD061','BD120','BD180','BE019','BF010','BG012','BH050','BH190','FC034','FC035','FC037','FC041','FC165','FC177'))
    field_information['GGDM 3.0']['HydrographySrfExt']['ZI039S_UFI'] = ('StructuredText',('BB008','BD020','BD030','BD050','BD061','BD120','BD180','BE019','BF010','BG012','BH050','BH190','FC034','FC035','FC037','FC041','FC165','FC177'))
    field_information['GGDM 3.0']['HydrographySrfExt']['ZSAX_RS0'] = ('CodeList',('BB008','BD020','BD030','BD050','BD061','BD120','BD180','BE019','BF010','BG012','BH050','BH190','FC034','FC035','FC037','FC041','FC165','FC177'))
    field_information['GGDM 3.0']['HydrographySrfExt']['ZSAX_RX0'] = ('StructuredText',('BB008','BD020','BD030','BD050','BD061','BD120','BD180','BE019','BF010','BG012','BH050','BH190','FC034','FC035','FC037','FC041','FC165','FC177'))
    field_information['GGDM 3.0']['HydrographySrfExt']['ZSAX_RX3'] = ('StructuredText',('BB008','BD020','BD030','BD050','BD061','BD120','BD180','BE019','BF010','BG012','BH050','BH190','FC034','FC035','FC037','FC041','FC165','FC177'))
    field_information['GGDM 3.0']['HydrographySrfExt']['ZSAX_RX4'] = ('StructuredText',('BB008','BD020','BD030','BD050','BD061','BD120','BD180','BE019','BF010','BG012','BH050','BH190','FC034','FC035','FC037','FC041','FC165','FC177'))
    field_information['GGDM 3.0']['HypsographyCrv']['BEN'] = ('StructuredText',('CA010'))
    field_information['GGDM 3.0']['HypsographyCrv']['ESC'] = ('Enumeration',('CA010'))
    field_information['GGDM 3.0']['HypsographyCrv']['EnumeratedIndexValues']['ESC'] = {}
    field_information['GGDM 3.0']['HypsographyCrv']['EnumeratedIndexValues']['ESC']['CA010']  = (-999999,1,2,4,5,6)
    field_information['GGDM 3.0']['HypsographyCrv']['F_CODE'] = ('CONSTRAINED_STRING',('CA010'))
    field_information['GGDM 3.0']['HypsographyCrv']['FUFI'] = ('StructuredText',('CA010'))
    field_information['GGDM 3.0']['HypsographyCrv']['FURL'] = ('StructuredText',('CA010'))
    field_information['GGDM 3.0']['HypsographyCrv']['GDBV'] = ('Enumeration',('CA010'))
    field_information['GGDM 3.0']['HypsographyCrv']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['HypsographyCrv']['EnumeratedIndexValues']['GDBV']['CA010']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['HypsographyCrv']['HQC'] = ('Enumeration',('CA010'))
    field_information['GGDM 3.0']['HypsographyCrv']['EnumeratedIndexValues']['HQC'] = {}
    field_information['GGDM 3.0']['HypsographyCrv']['EnumeratedIndexValues']['HQC']['CA010']  = (-999999,1,2,3,4,5,6,7,8,9,12,13,14,15,16,18,19,20,21,22,23,98,99,999)
    field_information['GGDM 3.0']['HypsographyCrv']['OTH'] = ('StructuredText',('CA010'))
    field_information['GGDM 3.0']['HypsographyCrv']['UFI'] = ('StructuredText',('CA010'))
    field_information['GGDM 3.0']['HypsographyCrv']['ZI001_SDV'] = ('StructuredText',('CA010'))
    field_information['GGDM 3.0']['HypsographyCrv']['ZI001_SRT'] = ('Enumeration',('CA010'))
    field_information['GGDM 3.0']['HypsographyCrv']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['HypsographyCrv']['EnumeratedIndexValues']['ZI001_SRT']['CA010']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['HypsographyCrv']['ZI002_UFI'] = ('StructuredText',('CA010'))
    field_information['GGDM 3.0']['HypsographyCrv']['ZI004_RCG'] = ('Enumeration',('CA010'))
    field_information['GGDM 3.0']['HypsographyCrv']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['HypsographyCrv']['EnumeratedIndexValues']['ZI004_RCG']['CA010']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['HypsographyCrv']['ZI006_MEM'] = ('String',('CA010'))
    field_information['GGDM 3.0']['HypsographyCrv']['ZI020_GE4'] = ('CodeList',('CA010'))
    field_information['GGDM 3.0']['HypsographyCrv']['ZI026_CTUC'] = ('Enumeration',('CA010'))
    field_information['GGDM 3.0']['HypsographyCrv']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['HypsographyCrv']['EnumeratedIndexValues']['ZI026_CTUC']['CA010']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['HypsographyCrv']['ZI026_CTUL'] = ('integer',('CA010'))
    field_information['GGDM 3.0']['HypsographyCrv']['ZI026_CTUU'] = ('integer',('CA010'))
    field_information['GGDM 3.0']['HypsographyCrv']['ZI031S_URI'] = ('StructuredText',('CA010'))
    field_information['GGDM 3.0']['HypsographyCrv']['ZI039S_UFI'] = ('StructuredText',('CA010'))
    field_information['GGDM 3.0']['HypsographyCrv']['ZSAX_RS0'] = ('CodeList',('CA010'))
    field_information['GGDM 3.0']['HypsographyCrv']['ZSAX_RX0'] = ('StructuredText',('CA010'))
    field_information['GGDM 3.0']['HypsographyCrv']['ZSAX_RX3'] = ('StructuredText',('CA010'))
    field_information['GGDM 3.0']['HypsographyCrv']['ZSAX_RX4'] = ('StructuredText',('CA010'))
    field_information['GGDM 3.0']['HypsographyCrv']['ZVH'] = ('Real',('CA010'))
    field_information['GGDM 3.0']['HypsographyPnt']['BEL'] = ('Real',('ZB050'))
    field_information['GGDM 3.0']['HypsographyPnt']['BEN'] = ('StructuredText',('CA030','ZB050'))
    field_information['GGDM 3.0']['HypsographyPnt']['CAA'] = ('Enumeration',('ZB050'))
    field_information['GGDM 3.0']['HypsographyPnt']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['HypsographyPnt']['EnumeratedIndexValues']['CAA']['ZB050']  = (-999999,3,5,7,17,999)
    field_information['GGDM 3.0']['HypsographyPnt']['ESC'] = ('Enumeration',('CA030'))
    field_information['GGDM 3.0']['HypsographyPnt']['EnumeratedIndexValues']['ESC'] = {}
    field_information['GGDM 3.0']['HypsographyPnt']['EnumeratedIndexValues']['ESC']['CA030']  = (-999999,1,2,4,5,6)
    field_information['GGDM 3.0']['HypsographyPnt']['F_CODE'] = ('CONSTRAINED_STRING',('CA030','ZB050'))
    field_information['GGDM 3.0']['HypsographyPnt']['FUFI'] = ('StructuredText',('CA030','ZB050'))
    field_information['GGDM 3.0']['HypsographyPnt']['FURL'] = ('StructuredText',('CA030','ZB050'))
    field_information['GGDM 3.0']['HypsographyPnt']['GDBV'] = ('Enumeration',('CA030','ZB050'))
    field_information['GGDM 3.0']['HypsographyPnt']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['HypsographyPnt']['EnumeratedIndexValues']['GDBV']['CA030']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['HypsographyPnt']['EnumeratedIndexValues']['GDBV']['ZB050']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['HypsographyPnt']['OTH'] = ('StructuredText',('CA030','ZB050'))
    field_information['GGDM 3.0']['HypsographyPnt']['PCF'] = ('Enumeration',('ZB050'))
    field_information['GGDM 3.0']['HypsographyPnt']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['HypsographyPnt']['EnumeratedIndexValues']['PCF']['ZB050']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['HypsographyPnt']['SUY'] = ('Enumeration',('ZB050'))
    field_information['GGDM 3.0']['HypsographyPnt']['EnumeratedIndexValues']['SUY'] = {}
    field_information['GGDM 3.0']['HypsographyPnt']['EnumeratedIndexValues']['SUY']['ZB050']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['HypsographyPnt']['UFI'] = ('StructuredText',('CA030','ZB050'))
    field_information['GGDM 3.0']['HypsographyPnt']['ZI001_SDV'] = ('StructuredText',('CA030','ZB050'))
    field_information['GGDM 3.0']['HypsographyPnt']['ZI001_SRT'] = ('Enumeration',('CA030','ZB050'))
    field_information['GGDM 3.0']['HypsographyPnt']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['HypsographyPnt']['EnumeratedIndexValues']['ZI001_SRT']['CA030']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['HypsographyPnt']['EnumeratedIndexValues']['ZI001_SRT']['ZB050']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['HypsographyPnt']['ZI002_UFI'] = ('StructuredText',('CA030','ZB050'))
    field_information['GGDM 3.0']['HypsographyPnt']['ZI004_RCG'] = ('Enumeration',('CA030','ZB050'))
    field_information['GGDM 3.0']['HypsographyPnt']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['HypsographyPnt']['EnumeratedIndexValues']['ZI004_RCG']['CA030']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['HypsographyPnt']['EnumeratedIndexValues']['ZI004_RCG']['ZB050']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['HypsographyPnt']['ZI005_FNA'] = ('String',('ZB050'))
    field_information['GGDM 3.0']['HypsographyPnt']['ZI005_GNT'] = ('Enumeration',('ZB050'))
    field_information['GGDM 3.0']['HypsographyPnt']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['HypsographyPnt']['EnumeratedIndexValues']['ZI005_GNT']['ZB050']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['HypsographyPnt']['ZI005_NFN'] = ('String',('ZB050'))
    field_information['GGDM 3.0']['HypsographyPnt']['ZI006_MEM'] = ('String',('CA030','ZB050'))
    field_information['GGDM 3.0']['HypsographyPnt']['ZI020_GE4'] = ('CodeList',('CA030','ZB050'))
    field_information['GGDM 3.0']['HypsographyPnt']['ZI026_CTUC'] = ('Enumeration',('CA030','ZB050'))
    field_information['GGDM 3.0']['HypsographyPnt']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['HypsographyPnt']['EnumeratedIndexValues']['ZI026_CTUC']['CA030']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['HypsographyPnt']['EnumeratedIndexValues']['ZI026_CTUC']['ZB050']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['HypsographyPnt']['ZI026_CTUL'] = ('integer',('CA030','ZB050'))
    field_information['GGDM 3.0']['HypsographyPnt']['ZI026_CTUU'] = ('integer',('CA030','ZB050'))
    field_information['GGDM 3.0']['HypsographyPnt']['ZI031S_URI'] = ('StructuredText',('CA030','ZB050'))
    field_information['GGDM 3.0']['HypsographyPnt']['ZI039S_UFI'] = ('StructuredText',('CA030','ZB050'))
    field_information['GGDM 3.0']['HypsographyPnt']['ZSAX_RS0'] = ('CodeList',('CA030','ZB050'))
    field_information['GGDM 3.0']['HypsographyPnt']['ZSAX_RX0'] = ('StructuredText',('CA030','ZB050'))
    field_information['GGDM 3.0']['HypsographyPnt']['ZSAX_RX3'] = ('StructuredText',('CA030','ZB050'))
    field_information['GGDM 3.0']['HypsographyPnt']['ZSAX_RX4'] = ('StructuredText',('CA030','ZB050'))
    field_information['GGDM 3.0']['HypsographyPnt']['ZVH'] = ('Real',('CA030','ZB050'))
    field_information['GGDM 3.0']['HypsographyPnt']['ZVH_AVA'] = ('Real',('CA030'))
    field_information['GGDM 3.0']['HypsographyPnt']['ZVH_VDT'] = ('Enumeration',('CA030'))
    field_information['GGDM 3.0']['HypsographyPnt']['EnumeratedIndexValues']['ZVH_VDT'] = {}
    field_information['GGDM 3.0']['HypsographyPnt']['EnumeratedIndexValues']['ZVH_VDT']['CA030']  = (-999999,1,2,3,4,5,6,7,998,999)
    field_information['GGDM 3.0']['HypsographyPntExt']['BEN'] = ('StructuredText',('ZB020','ZB060'))
    field_information['GGDM 3.0']['HypsographyPntExt']['CPA'] = ('Enumeration',('ZB020','ZB060'))
    field_information['GGDM 3.0']['HypsographyPntExt']['EnumeratedIndexValues']['CPA'] = {}
    field_information['GGDM 3.0']['HypsographyPntExt']['EnumeratedIndexValues']['CPA']['ZB020']  = (-999999,1,2,3,5)
    field_information['GGDM 3.0']['HypsographyPntExt']['EnumeratedIndexValues']['CPA']['ZB060']  = (-999999,1,2,3,5)
    field_information['GGDM 3.0']['HypsographyPntExt']['F_CODE'] = ('CONSTRAINED_STRING',('ZB020','ZB060'))
    field_information['GGDM 3.0']['HypsographyPntExt']['FUFI'] = ('StructuredText',('ZB020','ZB060'))
    field_information['GGDM 3.0']['HypsographyPntExt']['FURL'] = ('StructuredText',('ZB020','ZB060'))
    field_information['GGDM 3.0']['HypsographyPntExt']['GDBV'] = ('Enumeration',('ZB020','ZB060'))
    field_information['GGDM 3.0']['HypsographyPntExt']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['HypsographyPntExt']['EnumeratedIndexValues']['GDBV']['ZB020']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['HypsographyPntExt']['EnumeratedIndexValues']['GDBV']['ZB060']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['HypsographyPntExt']['OTH'] = ('StructuredText',('ZB020','ZB060'))
    field_information['GGDM 3.0']['HypsographyPntExt']['PCF'] = ('Enumeration',('ZB020'))
    field_information['GGDM 3.0']['HypsographyPntExt']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['HypsographyPntExt']['EnumeratedIndexValues']['PCF']['ZB020']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['HypsographyPntExt']['UFI'] = ('StructuredText',('ZB020','ZB060'))
    field_information['GGDM 3.0']['HypsographyPntExt']['ZI001_SDV'] = ('StructuredText',('ZB020','ZB060'))
    field_information['GGDM 3.0']['HypsographyPntExt']['ZI001_SRT'] = ('Enumeration',('ZB020','ZB060'))
    field_information['GGDM 3.0']['HypsographyPntExt']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['HypsographyPntExt']['EnumeratedIndexValues']['ZI001_SRT']['ZB020']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['HypsographyPntExt']['EnumeratedIndexValues']['ZI001_SRT']['ZB060']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['HypsographyPntExt']['ZI002_UFI'] = ('StructuredText',('ZB020','ZB060'))
    field_information['GGDM 3.0']['HypsographyPntExt']['ZI004_RCG'] = ('Enumeration',('ZB020','ZB060'))
    field_information['GGDM 3.0']['HypsographyPntExt']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['HypsographyPntExt']['EnumeratedIndexValues']['ZI004_RCG']['ZB020']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['HypsographyPntExt']['EnumeratedIndexValues']['ZI004_RCG']['ZB060']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['HypsographyPntExt']['ZI005_FNA'] = ('String',('ZB020','ZB060'))
    field_information['GGDM 3.0']['HypsographyPntExt']['ZI005_GNT'] = ('Enumeration',('ZB020','ZB060'))
    field_information['GGDM 3.0']['HypsographyPntExt']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['HypsographyPntExt']['EnumeratedIndexValues']['ZI005_GNT']['ZB020']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['HypsographyPntExt']['EnumeratedIndexValues']['ZI005_GNT']['ZB060']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['HypsographyPntExt']['ZI005_NFN'] = ('String',('ZB020','ZB060'))
    field_information['GGDM 3.0']['HypsographyPntExt']['ZI006_MEM'] = ('String',('ZB020','ZB060'))
    field_information['GGDM 3.0']['HypsographyPntExt']['ZI020_GE4'] = ('CodeList',('ZB020','ZB060'))
    field_information['GGDM 3.0']['HypsographyPntExt']['ZI026_CTUC'] = ('Enumeration',('ZB020','ZB060'))
    field_information['GGDM 3.0']['HypsographyPntExt']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['HypsographyPntExt']['EnumeratedIndexValues']['ZI026_CTUC']['ZB020']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['HypsographyPntExt']['EnumeratedIndexValues']['ZI026_CTUC']['ZB060']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['HypsographyPntExt']['ZI026_CTUL'] = ('integer',('ZB020','ZB060'))
    field_information['GGDM 3.0']['HypsographyPntExt']['ZI026_CTUU'] = ('integer',('ZB020','ZB060'))
    field_information['GGDM 3.0']['HypsographyPntExt']['ZI031S_URI'] = ('StructuredText',('ZB020','ZB060'))
    field_information['GGDM 3.0']['HypsographyPntExt']['ZI039S_UFI'] = ('StructuredText',('ZB020','ZB060'))
    field_information['GGDM 3.0']['HypsographyPntExt']['ZSAX_RS0'] = ('CodeList',('ZB020','ZB060'))
    field_information['GGDM 3.0']['HypsographyPntExt']['ZSAX_RX0'] = ('StructuredText',('ZB020','ZB060'))
    field_information['GGDM 3.0']['HypsographyPntExt']['ZSAX_RX3'] = ('StructuredText',('ZB020','ZB060'))
    field_information['GGDM 3.0']['HypsographyPntExt']['ZSAX_RX4'] = ('StructuredText',('ZB020','ZB060'))
    field_information['GGDM 3.0']['HypsographyPntExt']['ZVH'] = ('Real',('ZB020','ZB060'))
    field_information['GGDM 3.0']['IndustryCrv']['AOO'] = ('Real',('AF020','AF050'))
    field_information['GGDM 3.0']['IndustryCrv']['ARA'] = ('Real',('AF020','AF050'))
    field_information['GGDM 3.0']['IndustryCrv']['AWP'] = ('Boolean',('AF020','AF050'))
    field_information['GGDM 3.0']['IndustryCrv']['BEN'] = ('StructuredText',('AA011','AF020','AF050'))
    field_information['GGDM 3.0']['IndustryCrv']['CAA'] = ('Enumeration',('AF020','AF050'))
    field_information['GGDM 3.0']['IndustryCrv']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['IndustryCrv']['EnumeratedIndexValues']['CAA']['AF020']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['IndustryCrv']['EnumeratedIndexValues']['CAA']['AF050']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['IndustryCrv']['CNCP'] = ('StructuredText',('AF020','AF050'))
    field_information['GGDM 3.0']['IndustryCrv']['COS'] = ('Enumeration',('AF020','AF050'))
    field_information['GGDM 3.0']['IndustryCrv']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['IndustryCrv']['EnumeratedIndexValues']['COS']['AF020']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['IndustryCrv']['EnumeratedIndexValues']['COS']['AF050']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['IndustryCrv']['CVT'] = ('Enumeration',('AF020'))
    field_information['GGDM 3.0']['IndustryCrv']['EnumeratedIndexValues']['CVT'] = {}
    field_information['GGDM 3.0']['IndustryCrv']['EnumeratedIndexValues']['CVT']['AF020']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['IndustryCrv']['CVT2'] = ('Enumeration',('AF020'))
    field_information['GGDM 3.0']['IndustryCrv']['EnumeratedIndexValues']['CVT2'] = {}
    field_information['GGDM 3.0']['IndustryCrv']['EnumeratedIndexValues']['CVT2']['AF020']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['IndustryCrv']['CVT3'] = ('Enumeration',('AF020'))
    field_information['GGDM 3.0']['IndustryCrv']['EnumeratedIndexValues']['CVT3'] = {}
    field_information['GGDM 3.0']['IndustryCrv']['EnumeratedIndexValues']['CVT3']['AF020']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['IndustryCrv']['DZP'] = ('Real',('AA011'))
    field_information['GGDM 3.0']['IndustryCrv']['F_CODE'] = ('CONSTRAINED_STRING',('AA011','AF020','AF050'))
    field_information['GGDM 3.0']['IndustryCrv']['FUFI'] = ('StructuredText',('AA011','AF020','AF050'))
    field_information['GGDM 3.0']['IndustryCrv']['FURL'] = ('StructuredText',('AA011','AF020','AF050'))
    field_information['GGDM 3.0']['IndustryCrv']['GDBV'] = ('Enumeration',('AA011','AF020','AF050'))
    field_information['GGDM 3.0']['IndustryCrv']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['IndustryCrv']['EnumeratedIndexValues']['GDBV']['AA011']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['IndustryCrv']['EnumeratedIndexValues']['GDBV']['AF020']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['IndustryCrv']['EnumeratedIndexValues']['GDBV']['AF050']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['IndustryCrv']['HGT'] = ('Real',('AA011','AF020','AF050'))
    field_information['GGDM 3.0']['IndustryCrv']['LMC'] = ('Boolean',('AF020','AF050'))
    field_information['GGDM 3.0']['IndustryCrv']['LZN'] = ('Real',('AA011','AF020','AF050'))
    field_information['GGDM 3.0']['IndustryCrv']['OTH'] = ('StructuredText',('AA011','AF020','AF050'))
    field_information['GGDM 3.0']['IndustryCrv']['PCF'] = ('Enumeration',('AF020','AF050'))
    field_information['GGDM 3.0']['IndustryCrv']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['IndustryCrv']['EnumeratedIndexValues']['PCF']['AF020']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['IndustryCrv']['EnumeratedIndexValues']['PCF']['AF050']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['IndustryCrv']['PFH'] = ('Real',('AA011'))
    field_information['GGDM 3.0']['IndustryCrv']['UFI'] = ('StructuredText',('AA011','AF020','AF050'))
    field_information['GGDM 3.0']['IndustryCrv']['VCM'] = ('Enumeration',('AF020'))
    field_information['GGDM 3.0']['IndustryCrv']['EnumeratedIndexValues']['VCM'] = {}
    field_information['GGDM 3.0']['IndustryCrv']['EnumeratedIndexValues']['VCM']['AF020']  = (-999999,4,7,8,9,15,18,999)
    field_information['GGDM 3.0']['IndustryCrv']['VCM2'] = ('Enumeration',('AF020'))
    field_information['GGDM 3.0']['IndustryCrv']['EnumeratedIndexValues']['VCM2'] = {}
    field_information['GGDM 3.0']['IndustryCrv']['EnumeratedIndexValues']['VCM2']['AF020']  = (-999999,4,7,8,9,15,18,999)
    field_information['GGDM 3.0']['IndustryCrv']['VCM3'] = ('Enumeration',('AF020'))
    field_information['GGDM 3.0']['IndustryCrv']['EnumeratedIndexValues']['VCM3'] = {}
    field_information['GGDM 3.0']['IndustryCrv']['EnumeratedIndexValues']['VCM3']['AF020']  = (-999999,4,7,8,9,15,18,999)
    field_information['GGDM 3.0']['IndustryCrv']['VOI'] = ('StructuredText',('AF020','AF050'))
    field_information['GGDM 3.0']['IndustryCrv']['WID'] = ('Real',('AF020','AF050'))
    field_information['GGDM 3.0']['IndustryCrv']['ZI001_SDV'] = ('StructuredText',('AA011','AF020','AF050'))
    field_information['GGDM 3.0']['IndustryCrv']['ZI001_SRT'] = ('Enumeration',('AA011','AF020','AF050'))
    field_information['GGDM 3.0']['IndustryCrv']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['IndustryCrv']['EnumeratedIndexValues']['ZI001_SRT']['AA011']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['IndustryCrv']['EnumeratedIndexValues']['ZI001_SRT']['AF020']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['IndustryCrv']['EnumeratedIndexValues']['ZI001_SRT']['AF050']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['IndustryCrv']['ZI002_UFI'] = ('StructuredText',('AA011','AF020','AF050'))
    field_information['GGDM 3.0']['IndustryCrv']['ZI004_RCG'] = ('Enumeration',('AA011','AF020','AF050'))
    field_information['GGDM 3.0']['IndustryCrv']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['IndustryCrv']['EnumeratedIndexValues']['ZI004_RCG']['AA011']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['IndustryCrv']['EnumeratedIndexValues']['ZI004_RCG']['AF020']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['IndustryCrv']['EnumeratedIndexValues']['ZI004_RCG']['AF050']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['IndustryCrv']['ZI005_FNA'] = ('String',('AA011','AF020','AF050'))
    field_information['GGDM 3.0']['IndustryCrv']['ZI005_GNT'] = ('Enumeration',('AA011','AF020','AF050'))
    field_information['GGDM 3.0']['IndustryCrv']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['IndustryCrv']['EnumeratedIndexValues']['ZI005_GNT']['AA011']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['IndustryCrv']['EnumeratedIndexValues']['ZI005_GNT']['AF020']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['IndustryCrv']['EnumeratedIndexValues']['ZI005_GNT']['AF050']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['IndustryCrv']['ZI005_NFN'] = ('String',('AA011','AF020','AF050'))
    field_information['GGDM 3.0']['IndustryCrv']['ZI006_MEM'] = ('String',('AA011','AF020','AF050'))
    field_information['GGDM 3.0']['IndustryCrv']['ZI020_GE4'] = ('CodeList',('AA011','AF020','AF050'))
    field_information['GGDM 3.0']['IndustryCrv']['ZI026_CTUC'] = ('Enumeration',('AA011','AF020','AF050'))
    field_information['GGDM 3.0']['IndustryCrv']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['IndustryCrv']['EnumeratedIndexValues']['ZI026_CTUC']['AA011']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['IndustryCrv']['EnumeratedIndexValues']['ZI026_CTUC']['AF020']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['IndustryCrv']['EnumeratedIndexValues']['ZI026_CTUC']['AF050']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['IndustryCrv']['ZI026_CTUL'] = ('integer',('AA011','AF020','AF050'))
    field_information['GGDM 3.0']['IndustryCrv']['ZI026_CTUU'] = ('integer',('AA011','AF020','AF050'))
    field_information['GGDM 3.0']['IndustryCrv']['ZI031S_URI'] = ('StructuredText',('AA011','AF020','AF050'))
    field_information['GGDM 3.0']['IndustryCrv']['ZI039S_UFI'] = ('StructuredText',('AA011','AF020','AF050'))
    field_information['GGDM 3.0']['IndustryCrv']['ZSAX_RS0'] = ('CodeList',('AA011','AF020','AF050'))
    field_information['GGDM 3.0']['IndustryCrv']['ZSAX_RX0'] = ('StructuredText',('AA011','AF020','AF050'))
    field_information['GGDM 3.0']['IndustryCrv']['ZSAX_RX3'] = ('StructuredText',('AA011','AF020','AF050'))
    field_information['GGDM 3.0']['IndustryCrv']['ZSAX_RX4'] = ('StructuredText',('AA011','AF020','AF050'))
    field_information['GGDM 3.0']['IndustryCrv']['ZVH'] = ('Real',('AA011','AF020','AF050'))
    field_information['GGDM 3.0']['IndustryPnt']['ADR'] = ('String',('AC040','AJ055'))
    field_information['GGDM 3.0']['IndustryPnt']['AOO'] = ('Real',('AA010','AA020','AA040','AB000','AC010','AC020','AC040','AC060','AF020','AF040','AF050','AF070','AF080','AJ055','AM040'))
    field_information['GGDM 3.0']['IndustryPnt']['ARA'] = ('Real',('AA010','AA020','AA040','AA054','AB000','AB507','AC010','AC020','AC040','AC060','AF020','AF040','AF050','AF080','AJ055','AM040','BH155'))
    field_information['GGDM 3.0']['IndustryPnt']['AWP'] = ('Boolean',('AA020','AA040','AB000','AC010','AC020','AF020','AF040','AF050','AF070','AF080','AJ055','AM040'))
    field_information['GGDM 3.0']['IndustryPnt']['AZC'] = ('Boolean',('BH155'))
    field_information['GGDM 3.0']['IndustryPnt']['BEN'] = ('StructuredText',('AA010','AA020','AA040','AA045','AA054','AB000','AB507','AC010','AC020','AC040','AC060','AF020','AF040','AF050','AF070','AF080','AJ055','AM040','BH155'))
    field_information['GGDM 3.0']['IndustryPnt']['BNF'] = ('Integer',('AJ055'))
    field_information['GGDM 3.0']['IndustryPnt']['CAA'] = ('Enumeration',('AA020','AA040','AC010','AC020','AC040','AC060','AF020','AF040','AF050','AF070','AF080','AJ055','AM040'))
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['CAA']['AA020']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['CAA']['AA040']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['CAA']['AC010']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['CAA']['AC020']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['CAA']['AC040']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['CAA']['AC060']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['CAA']['AF020']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['CAA']['AF040']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['CAA']['AF050']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['CAA']['AF070']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['CAA']['AF080']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['CAA']['AJ055']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['CAA']['AM040']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['IndustryPnt']['CNCP'] = ('StructuredText',('AA010','AA020','AA040','AA045','AA054','AB000','AC010','AC020','AC040','AC060','AF020','AF040','AF050','AF070','AF080','AJ055','AM040','BH155'))
    field_information['GGDM 3.0']['IndustryPnt']['COS'] = ('Enumeration',('AA010','AA020','AA040','AA045','AA054','AB000','AC010','AC020','AC040','AC060','AF020','AF040','AF050','AF070','AF080','AJ055','AM040','BH155'))
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['COS']['AA010']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['COS']['AA020']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['COS']['AA040']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['COS']['AA045']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['COS']['AA054']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['COS']['AB000']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['COS']['AC010']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['COS']['AC020']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['COS']['AC040']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['COS']['AC060']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['COS']['AF020']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['COS']['AF040']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['COS']['AF050']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['COS']['AF070']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['COS']['AF080']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['COS']['AJ055']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['COS']['AM040']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['COS']['BH155']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['IndustryPnt']['CRA'] = ('Enumeration',('AF040'))
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['CRA'] = {}
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['CRA']['AF040']  = (-999999,2,3,7,8,9,10,99,999)
    field_information['GGDM 3.0']['IndustryPnt']['CRM'] = ('Enumeration',('AF040'))
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['CRM'] = {}
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['CRM']['AF040']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['IndustryPnt']['CVT'] = ('Enumeration',('AF020'))
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['CVT'] = {}
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['CVT']['AF020']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['IndustryPnt']['CVT2'] = ('Enumeration',('AF020'))
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['CVT2'] = {}
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['CVT2']['AF020']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['IndustryPnt']['CVT3'] = ('Enumeration',('AF020'))
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['CVT3'] = {}
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['CVT3']['AF020']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['IndustryPnt']['DZP'] = ('Real',('AA010','AA045'))
    field_information['GGDM 3.0']['IndustryPnt']['F_CODE'] = ('CONSTRAINED_STRING',('AA010','AA020','AA040','AA045','AA054','AB000','AB507','AC010','AC020','AC040','AC060','AF020','AF040','AF050','AF070','AF080','AJ055','AM040','BH155'))
    field_information['GGDM 3.0']['IndustryPnt']['FFN'] = ('Enumeration',('AA010','AC040','AJ055'))
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['FFN'] = {}
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['FFN']['AA010']  = (-999999,40,50,70,83,84,85,87,999)
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['FFN']['AC040']  = (-999999,91,192,481,484,500,999)
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['FFN']['AJ055']  = (-999999,105,107,161,351,501,999)
    field_information['GGDM 3.0']['IndustryPnt']['FFN2'] = ('Enumeration',('AA010','AC040','AJ055'))
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['FFN2'] = {}
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['FFN2']['AA010']  = (-999999,40,50,70,83,84,85,87,999)
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['FFN2']['AC040']  = (-999999,91,192,481,484,500,999)
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['FFN2']['AJ055']  = (-999999,105,107,161,351,501,999)
    field_information['GGDM 3.0']['IndustryPnt']['FFN3'] = ('Enumeration',('AA010','AC040','AJ055'))
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['FFN3'] = {}
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['FFN3']['AA010']  = (-999999,40,50,70,83,84,85,87,999)
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['FFN3']['AC040']  = (-999999,91,192,481,484,500,999)
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['FFN3']['AJ055']  = (-999999,105,107,161,351,501,999)
    field_information['GGDM 3.0']['IndustryPnt']['FUFI'] = ('StructuredText',('AA010','AA020','AA040','AA045','AA054','AB000','AB507','AC010','AC020','AC040','AC060','AF020','AF040','AF050','AF070','AF080','AJ055','AM040','BH155'))
    field_information['GGDM 3.0']['IndustryPnt']['FURL'] = ('StructuredText',('AA010','AA020','AA040','AA045','AA054','AB000','AB507','AC010','AC020','AC040','AC060','AF020','AF040','AF050','AF070','AF080','AJ055','AM040','BH155'))
    field_information['GGDM 3.0']['IndustryPnt']['GDBV'] = ('Enumeration',('AA010','AA020','AA040','AA045','AA054','AB000','AB507','AC010','AC020','AC040','AC060','AF020','AF040','AF050','AF070','AF080','AJ055','AM040','BH155'))
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['GDBV']['AA010']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['GDBV']['AA020']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['GDBV']['AA040']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['GDBV']['AA045']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['GDBV']['AA054']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['GDBV']['AB000']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['GDBV']['AB507']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['GDBV']['AC010']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['GDBV']['AC020']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['GDBV']['AC040']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['GDBV']['AC060']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['GDBV']['AF020']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['GDBV']['AF040']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['GDBV']['AF050']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['GDBV']['AF070']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['GDBV']['AF080']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['GDBV']['AJ055']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['GDBV']['AM040']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['GDBV']['BH155']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['IndustryPnt']['GUG'] = ('Boolean',('AF070'))
    field_information['GGDM 3.0']['IndustryPnt']['HGT'] = ('Real',('AA010','AA020','AA040','AA054','AB000','AB507','AC010','AC020','AC040','AC060','AF020','AF040','AF050','AF070','AF080','AJ055','AM040'))
    field_information['GGDM 3.0']['IndustryPnt']['HST'] = ('Enumeration',('AA010'))
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['HST'] = {}
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['HST']['AA010']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['IndustryPnt']['HST2'] = ('Enumeration',('AA010'))
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['HST2'] = {}
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['HST2']['AA010']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['IndustryPnt']['HST3'] = ('Enumeration',('AA010'))
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['HST3'] = {}
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['HST3']['AA010']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['IndustryPnt']['LCA'] = ('Real',('AF040'))
    field_information['GGDM 3.0']['IndustryPnt']['LEA'] = ('Real',('AA010'))
    field_information['GGDM 3.0']['IndustryPnt']['LMC'] = ('Boolean',('AA010','AA020','AA040','AA045','AA054','AB000','AB507','AC010','AC020','AC040','AC060','AF020','AF040','AF050','AF070','AF080','AJ055','AM040','BH155'))
    field_information['GGDM 3.0']['IndustryPnt']['LOC'] = ('Enumeration',('AA010'))
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['LOC'] = {}
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['LOC']['AA010']  = (-999999,40,44)
    field_information['GGDM 3.0']['IndustryPnt']['LZN'] = ('Real',('AA010','AA020','AA040','AA054','AB000','AB507','AC010','AC020','AC040','AC060','AF020','AF040','AF050','AF070','AF080','AJ055','AM040','BH155'))
    field_information['GGDM 3.0']['IndustryPnt']['MZN'] = ('Enumeration',('AA010'))
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['MZN'] = {}
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['MZN']['AA010']  = (-999999,1,3,4,5,6,8,9,10,11,13,999)
    field_information['GGDM 3.0']['IndustryPnt']['OTH'] = ('StructuredText',('AA010','AA020','AA040','AA045','AA054','AB000','AB507','AC010','AC020','AC040','AC060','AF020','AF040','AF050','AF070','AF080','AJ055','AM040','BH155'))
    field_information['GGDM 3.0']['IndustryPnt']['PBY'] = ('Enumeration',('AB000'))
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['PBY'] = {}
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['PBY']['AB000']  = (-999999,8,15,16,17,999)
    field_information['GGDM 3.0']['IndustryPnt']['PBY2'] = ('Enumeration',('AB000'))
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['PBY2'] = {}
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['PBY2']['AB000']  = (-999999,8,15,16,17,999)
    field_information['GGDM 3.0']['IndustryPnt']['PBY3'] = ('Enumeration',('AB000'))
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['PBY3'] = {}
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['PBY3']['AB000']  = (-999999,8,15,16,17,999)
    field_information['GGDM 3.0']['IndustryPnt']['PCF'] = ('Enumeration',('AA010','AA020','AA040','AA045','AA054','AB000','AC010','AC020','AC040','AC060','AF020','AF040','AF050','AF070','AF080','AJ055','BH155'))
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['PCF']['AA010']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['PCF']['AA020']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['PCF']['AA040']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['PCF']['AA045']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['PCF']['AA054']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['PCF']['AB000']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['PCF']['AC010']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['PCF']['AC020']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['PCF']['AC040']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['PCF']['AC060']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['PCF']['AF020']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['PCF']['AF040']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['PCF']['AF050']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['PCF']['AF070']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['PCF']['AF080']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['PCF']['AJ055']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['PCF']['BH155']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['IndustryPnt']['PPO'] = ('Enumeration',('AA010','AA020','AA040','AA054','AC060'))
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['PPO'] = {}
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['PPO']['AA010']  = (-999999,8,9,17,18,26,33,34,35,48,50,53,58,59,65,66,85,88,89,93,95,96,97,105,110,118,120,126,130,151,152,153,173,204,224,283,339,999)
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['PPO']['AA020']  = (-999999,18,26,33,48,58,59,65,95,105,120,126,151,152,153,999)
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['PPO']['AA040']  = (-999999,45,83,122,149,999)
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['PPO']['AA054']  = (-999999,45,62,83,149,161,162,163,164,999)
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['PPO']['AC060']  = (-999999,13,15,60,63,158,159,999)
    field_information['GGDM 3.0']['IndustryPnt']['PPO2'] = ('Enumeration',('AA010','AA020','AA040','AA054','AC060'))
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['PPO2'] = {}
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['PPO2']['AA010']  = (-999999,8,9,17,18,26,33,34,35,48,50,53,58,59,65,66,85,88,89,93,95,96,97,105,110,118,120,126,130,151,152,153,173,204,224,283,339,999)
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['PPO2']['AA020']  = (-999999,18,26,33,48,58,59,65,95,105,120,126,151,152,153,999)
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['PPO2']['AA040']  = (-999999,45,83,122,149,999)
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['PPO2']['AA054']  = (-999999,45,62,83,149,161,162,163,164,999)
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['PPO2']['AC060']  = (-999999,13,15,60,63,158,159,999)
    field_information['GGDM 3.0']['IndustryPnt']['PPO3'] = ('Enumeration',('AA010','AA020','AA040','AA054','AC060'))
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['PPO3'] = {}
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['PPO3']['AA010']  = (-999999,8,9,17,18,26,33,34,35,48,50,53,58,59,65,66,85,88,89,93,95,96,97,105,110,118,120,126,130,151,152,153,173,204,224,283,339,999)
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['PPO3']['AA020']  = (-999999,18,26,33,48,58,59,65,95,105,120,126,151,152,153,999)
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['PPO3']['AA040']  = (-999999,45,83,122,149,999)
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['PPO3']['AA054']  = (-999999,45,62,83,149,161,162,163,164,999)
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['PPO3']['AC060']  = (-999999,13,15,60,63,158,159,999)
    field_information['GGDM 3.0']['IndustryPnt']['PRW'] = ('Enumeration',('AM040'))
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['PRW'] = {}
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['PRW']['AM040']  = (-999999,12,14,34,54,67,68,84,154,999)
    field_information['GGDM 3.0']['IndustryPnt']['PRW2'] = ('Enumeration',('AM040'))
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['PRW2'] = {}
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['PRW2']['AM040']  = (-999999,12,14,34,54,67,68,84,154,999)
    field_information['GGDM 3.0']['IndustryPnt']['PRW3'] = ('Enumeration',('AM040'))
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['PRW3'] = {}
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['PRW3']['AM040']  = (-999999,12,14,34,54,67,68,84,154,999)
    field_information['GGDM 3.0']['IndustryPnt']['RIP'] = ('Boolean',('AA045','AA054'))
    field_information['GGDM 3.0']['IndustryPnt']['SRL'] = ('Enumeration',('AA040','AF040','AF070'))
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['SRL'] = {}
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['SRL']['AA040']  = (-999999,1,2,3)
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['SRL']['AF040']  = (-999999,1,2,3)
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['SRL']['AF070']  = (-999999,1,2,3)
    field_information['GGDM 3.0']['IndustryPnt']['TRS'] = ('Enumeration',('AF040'))
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['TRS'] = {}
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['TRS']['AF040']  = (-999999,7,8,12,13,999)
    field_information['GGDM 3.0']['IndustryPnt']['TRS2'] = ('Enumeration',('AF040'))
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['TRS2'] = {}
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['TRS2']['AF040']  = (-999999,7,8,12,13,999)
    field_information['GGDM 3.0']['IndustryPnt']['TRS3'] = ('Enumeration',('AF040'))
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['TRS3'] = {}
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['TRS3']['AF040']  = (-999999,7,8,12,13,999)
    field_information['GGDM 3.0']['IndustryPnt']['UFI'] = ('StructuredText',('AA010','AA020','AA040','AA045','AA054','AB000','AB507','AC010','AC020','AC040','AC060','AF020','AF040','AF050','AF070','AF080','AJ055','AM040','BH155'))
    field_information['GGDM 3.0']['IndustryPnt']['UMA'] = ('Enumeration',('AA010'))
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['UMA'] = {}
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['UMA']['AA010']  = (-999999,1,2,3,998)
    field_information['GGDM 3.0']['IndustryPnt']['VCM'] = ('Enumeration',('AA040','AC020','AF020','AF040','AF070'))
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['VCM'] = {}
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['VCM']['AA040']  = (-999999,2,7,9,15,18,999)
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['VCM']['AC020']  = (-999999,3,4,7,8,9,12,13,15,999)
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['VCM']['AF020']  = (-999999,4,7,8,9,15,18,999)
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['VCM']['AF040']  = (-999999,2,7,9,15,999)
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['VCM']['AF070']  = (-999999,4,8,9,15,999)
    field_information['GGDM 3.0']['IndustryPnt']['VCM2'] = ('Enumeration',('AA040','AC020','AF020','AF040','AF070'))
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['VCM2'] = {}
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['VCM2']['AA040']  = (-999999,2,7,9,15,18,999)
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['VCM2']['AC020']  = (-999999,3,4,7,8,9,12,13,15,999)
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['VCM2']['AF020']  = (-999999,4,7,8,9,15,18,999)
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['VCM2']['AF040']  = (-999999,2,7,9,15,999)
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['VCM2']['AF070']  = (-999999,4,8,9,15,999)
    field_information['GGDM 3.0']['IndustryPnt']['VCM3'] = ('Enumeration',('AA040','AC020','AF020','AF040','AF070'))
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['VCM3'] = {}
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['VCM3']['AA040']  = (-999999,2,7,9,15,18,999)
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['VCM3']['AC020']  = (-999999,3,4,7,8,9,12,13,15,999)
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['VCM3']['AF020']  = (-999999,4,7,8,9,15,18,999)
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['VCM3']['AF040']  = (-999999,2,7,9,15,999)
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['VCM3']['AF070']  = (-999999,4,8,9,15,999)
    field_information['GGDM 3.0']['IndustryPnt']['VOI'] = ('StructuredText',('AA020','AA040','AB000','AB507','AC010','AC020','AF020','AF040','AF050','AF070','AF080','AJ055','AM040'))
    field_information['GGDM 3.0']['IndustryPnt']['WEQ'] = ('Enumeration',('AA054'))
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['WEQ'] = {}
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['WEQ']['AA054']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['IndustryPnt']['WEQ2'] = ('Enumeration',('AA054'))
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['WEQ2'] = {}
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['WEQ2']['AA054']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['IndustryPnt']['WEQ3'] = ('Enumeration',('AA054'))
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['WEQ3'] = {}
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['WEQ3']['AA054']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['IndustryPnt']['WID'] = ('Real',('AA010','AA020','AA040','AA054','AB000','AB507','AC010','AC020','AC040','AC060','AF020','AF040','AF050','AF070','AF080','AJ055','AM040','BH155'))
    field_information['GGDM 3.0']['IndustryPnt']['ZI001_SDV'] = ('StructuredText',('AA010','AA020','AA040','AA045','AA054','AB000','AB507','AC010','AC020','AC040','AC060','AF020','AF040','AF050','AF070','AF080','AJ055','AM040','BH155'))
    field_information['GGDM 3.0']['IndustryPnt']['ZI001_SRT'] = ('Enumeration',('AA010','AA020','AA040','AA045','AA054','AB000','AB507','AC010','AC020','AC040','AC060','AF020','AF040','AF050','AF070','AF080','AJ055','AM040','BH155'))
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['ZI001_SRT']['AA010']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['ZI001_SRT']['AA020']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['ZI001_SRT']['AA040']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['ZI001_SRT']['AA045']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['ZI001_SRT']['AA054']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['ZI001_SRT']['AB000']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['ZI001_SRT']['AB507']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['ZI001_SRT']['AC010']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['ZI001_SRT']['AC020']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['ZI001_SRT']['AC040']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['ZI001_SRT']['AC060']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['ZI001_SRT']['AF020']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['ZI001_SRT']['AF040']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['ZI001_SRT']['AF050']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['ZI001_SRT']['AF070']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['ZI001_SRT']['AF080']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['ZI001_SRT']['AJ055']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['ZI001_SRT']['AM040']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['ZI001_SRT']['BH155']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['IndustryPnt']['ZI002_UFI'] = ('StructuredText',('AA010','AA020','AA040','AA045','AA054','AB000','AB507','AC010','AC020','AC040','AC060','AF020','AF040','AF050','AF070','AF080','AJ055','AM040','BH155'))
    field_information['GGDM 3.0']['IndustryPnt']['ZI004_RCG'] = ('Enumeration',('AA010','AA020','AA040','AA045','AA054','AB000','AB507','AC010','AC020','AC040','AC060','AF020','AF040','AF050','AF070','AF080','AJ055','AM040','BH155'))
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['ZI004_RCG']['AA010']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['ZI004_RCG']['AA020']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['ZI004_RCG']['AA040']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['ZI004_RCG']['AA045']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['ZI004_RCG']['AA054']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['ZI004_RCG']['AB000']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['ZI004_RCG']['AB507']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['ZI004_RCG']['AC010']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['ZI004_RCG']['AC020']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['ZI004_RCG']['AC040']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['ZI004_RCG']['AC060']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['ZI004_RCG']['AF020']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['ZI004_RCG']['AF040']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['ZI004_RCG']['AF050']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['ZI004_RCG']['AF070']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['ZI004_RCG']['AF080']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['ZI004_RCG']['AJ055']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['ZI004_RCG']['AM040']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['ZI004_RCG']['BH155']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['IndustryPnt']['ZI005_FNA'] = ('String',('AA010','AA040','AA045','AA054','AB000','AB507','AC010','AC020','AC040','AC060','AF020','AF040','AF050','AF080','AJ055','BH155'))
    field_information['GGDM 3.0']['IndustryPnt']['ZI005_GNT'] = ('Enumeration',('AA010','AA040','AA045','AA054','AB000','AB507','AC010','AC020','AC040','AC060','AF020','AF040','AF050','AF080','AJ055','BH155'))
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['ZI005_GNT']['AA010']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['ZI005_GNT']['AA040']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['ZI005_GNT']['AA045']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['ZI005_GNT']['AA054']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['ZI005_GNT']['AB000']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['ZI005_GNT']['AB507']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['ZI005_GNT']['AC010']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['ZI005_GNT']['AC020']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['ZI005_GNT']['AC040']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['ZI005_GNT']['AC060']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['ZI005_GNT']['AF020']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['ZI005_GNT']['AF040']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['ZI005_GNT']['AF050']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['ZI005_GNT']['AF080']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['ZI005_GNT']['AJ055']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['ZI005_GNT']['BH155']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['IndustryPnt']['ZI005_NFN'] = ('String',('AA010','AA040','AA045','AA054','AB000','AB507','AC010','AC020','AC040','AC060','AF020','AF040','AF050','AF080','AJ055','BH155'))
    field_information['GGDM 3.0']['IndustryPnt']['ZI006_MEM'] = ('String',('AA010','AA020','AA040','AA045','AA054','AB000','AB507','AC010','AC020','AC040','AC060','AF020','AF040','AF050','AF070','AF080','AJ055','AM040','BH155'))
    field_information['GGDM 3.0']['IndustryPnt']['ZI014_PPO'] = ('Enumeration',('AC040','AJ055'))
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['ZI014_PPO'] = {}
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['ZI014_PPO']['AC040']  = (-999999,4,16,45,46,61,62,74,83,84,137,150,157,214,999)
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['ZI014_PPO']['AJ055']  = (-999999,20,28,63,73,111,155,160,999)
    field_information['GGDM 3.0']['IndustryPnt']['ZI014_PPO2'] = ('Enumeration',('AC040','AJ055'))
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['ZI014_PPO2'] = {}
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['ZI014_PPO2']['AC040']  = (-999999,4,16,45,46,61,62,74,83,84,137,150,157,214,999)
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['ZI014_PPO2']['AJ055']  = (-999999,20,28,63,73,111,155,160,999)
    field_information['GGDM 3.0']['IndustryPnt']['ZI014_PPO3'] = ('Enumeration',('AC040','AJ055'))
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['ZI014_PPO3'] = {}
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['ZI014_PPO3']['AC040']  = (-999999,4,16,45,46,61,62,74,83,84,137,150,157,214,999)
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['ZI014_PPO3']['AJ055']  = (-999999,20,28,63,73,111,155,160,999)
    field_information['GGDM 3.0']['IndustryPnt']['ZI020_GE4'] = ('CodeList',('AA010','AA020','AA040','AA045','AA054','AB000','AB507','AC010','AC020','AC040','AC060','AF020','AF040','AF050','AF070','AF080','AJ055','AM040','BH155'))
    field_information['GGDM 3.0']['IndustryPnt']['ZI025_HDP'] = ('Real',('AA054'))
    field_information['GGDM 3.0']['IndustryPnt']['ZI026_CTUC'] = ('Enumeration',('AA010','AA020','AA040','AA045','AA054','AB000','AB507','AC010','AC020','AC040','AC060','AF020','AF040','AF050','AF070','AF080','AJ055','AM040','BH155'))
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['ZI026_CTUC']['AA010']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['ZI026_CTUC']['AA020']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['ZI026_CTUC']['AA040']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['ZI026_CTUC']['AA045']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['ZI026_CTUC']['AA054']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['ZI026_CTUC']['AB000']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['ZI026_CTUC']['AB507']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['ZI026_CTUC']['AC010']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['ZI026_CTUC']['AC020']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['ZI026_CTUC']['AC040']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['ZI026_CTUC']['AC060']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['ZI026_CTUC']['AF020']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['ZI026_CTUC']['AF040']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['ZI026_CTUC']['AF050']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['ZI026_CTUC']['AF070']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['ZI026_CTUC']['AF080']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['ZI026_CTUC']['AJ055']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['ZI026_CTUC']['AM040']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['IndustryPnt']['EnumeratedIndexValues']['ZI026_CTUC']['BH155']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['IndustryPnt']['ZI026_CTUL'] = ('integer',('AA010','AA020','AA040','AA045','AA054','AB000','AB507','AC010','AC020','AC040','AC060','AF020','AF040','AF050','AF070','AF080','AJ055','AM040','BH155'))
    field_information['GGDM 3.0']['IndustryPnt']['ZI026_CTUU'] = ('integer',('AA010','AA020','AA040','AA045','AA054','AB000','AB507','AC010','AC020','AC040','AC060','AF020','AF040','AF050','AF070','AF080','AJ055','AM040','BH155'))
    field_information['GGDM 3.0']['IndustryPnt']['ZI031S_URI'] = ('StructuredText',('AA010','AA020','AA040','AA045','AA054','AB000','AB507','AC010','AC020','AC040','AC060','AF020','AF040','AF050','AF070','AF080','AJ055','AM040','BH155'))
    field_information['GGDM 3.0']['IndustryPnt']['ZI039S_UFI'] = ('StructuredText',('AA010','AA020','AA040','AA045','AA054','AB000','AB507','AC010','AC020','AC040','AC060','AF020','AF040','AF050','AF070','AF080','AJ055','AM040','BH155'))
    field_information['GGDM 3.0']['IndustryPnt']['ZSAX_RS0'] = ('CodeList',('AA010','AA020','AA040','AA045','AA054','AB000','AB507','AC010','AC020','AC040','AC060','AF020','AF040','AF050','AF070','AF080','AJ055','AM040','BH155'))
    field_information['GGDM 3.0']['IndustryPnt']['ZSAX_RX0'] = ('StructuredText',('AA010','AA020','AA040','AA045','AA054','AB000','AB507','AC010','AC020','AC040','AC060','AF020','AF040','AF050','AF070','AF080','AJ055','AM040','BH155'))
    field_information['GGDM 3.0']['IndustryPnt']['ZSAX_RX3'] = ('StructuredText',('AA010','AA020','AA040','AA045','AA054','AB000','AB507','AC010','AC020','AC040','AC060','AF020','AF040','AF050','AF070','AF080','AJ055','AM040','BH155'))
    field_information['GGDM 3.0']['IndustryPnt']['ZSAX_RX4'] = ('StructuredText',('AA010','AA020','AA040','AA045','AA054','AB000','AB507','AC010','AC020','AC040','AC060','AF020','AF040','AF050','AF070','AF080','AJ055','AM040','BH155'))
    field_information['GGDM 3.0']['IndustryPnt']['ZVH'] = ('Real',('AA010','AA020','AA040','AA045','AA054','AB000','AB507','AC010','AC020','AC040','AC060','AF020','AF040','AF050','AF070','AF080','AJ055','AM040'))
    field_information['GGDM 3.0']['IndustryPntExt']['ARA'] = ('Real',('AA052'))
    field_information['GGDM 3.0']['IndustryPntExt']['BEN'] = ('StructuredText',('AA052'))
    field_information['GGDM 3.0']['IndustryPntExt']['F_CODE'] = ('CONSTRAINED_STRING',('AA052'))
    field_information['GGDM 3.0']['IndustryPntExt']['FUFI'] = ('StructuredText',('AA052'))
    field_information['GGDM 3.0']['IndustryPntExt']['FURL'] = ('StructuredText',('AA052'))
    field_information['GGDM 3.0']['IndustryPntExt']['GDBV'] = ('Enumeration',('AA052'))
    field_information['GGDM 3.0']['IndustryPntExt']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['IndustryPntExt']['EnumeratedIndexValues']['GDBV']['AA052']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['IndustryPntExt']['LZN'] = ('Real',('AA052'))
    field_information['GGDM 3.0']['IndustryPntExt']['OTH'] = ('StructuredText',('AA052'))
    field_information['GGDM 3.0']['IndustryPntExt']['PPO'] = ('Enumeration',('AA052'))
    field_information['GGDM 3.0']['IndustryPntExt']['EnumeratedIndexValues']['PPO'] = {}
    field_information['GGDM 3.0']['IndustryPntExt']['EnumeratedIndexValues']['PPO']['AA052']  = (-999999,45,83,999)
    field_information['GGDM 3.0']['IndustryPntExt']['PPO2'] = ('Enumeration',('AA052'))
    field_information['GGDM 3.0']['IndustryPntExt']['EnumeratedIndexValues']['PPO2'] = {}
    field_information['GGDM 3.0']['IndustryPntExt']['EnumeratedIndexValues']['PPO2']['AA052']  = (-999999,45,83,999)
    field_information['GGDM 3.0']['IndustryPntExt']['PPO3'] = ('Enumeration',('AA052'))
    field_information['GGDM 3.0']['IndustryPntExt']['EnumeratedIndexValues']['PPO3'] = {}
    field_information['GGDM 3.0']['IndustryPntExt']['EnumeratedIndexValues']['PPO3']['AA052']  = (-999999,45,83,999)
    field_information['GGDM 3.0']['IndustryPntExt']['UFI'] = ('StructuredText',('AA052'))
    field_information['GGDM 3.0']['IndustryPntExt']['WID'] = ('Real',('AA052'))
    field_information['GGDM 3.0']['IndustryPntExt']['ZI001_SDV'] = ('StructuredText',('AA052'))
    field_information['GGDM 3.0']['IndustryPntExt']['ZI001_SRT'] = ('Enumeration',('AA052'))
    field_information['GGDM 3.0']['IndustryPntExt']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['IndustryPntExt']['EnumeratedIndexValues']['ZI001_SRT']['AA052']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['IndustryPntExt']['ZI002_UFI'] = ('StructuredText',('AA052'))
    field_information['GGDM 3.0']['IndustryPntExt']['ZI004_RCG'] = ('Enumeration',('AA052'))
    field_information['GGDM 3.0']['IndustryPntExt']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['IndustryPntExt']['EnumeratedIndexValues']['ZI004_RCG']['AA052']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['IndustryPntExt']['ZI005_FNA'] = ('String',('AA052'))
    field_information['GGDM 3.0']['IndustryPntExt']['ZI005_GNT'] = ('Enumeration',('AA052'))
    field_information['GGDM 3.0']['IndustryPntExt']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['IndustryPntExt']['EnumeratedIndexValues']['ZI005_GNT']['AA052']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['IndustryPntExt']['ZI005_NFN'] = ('String',('AA052'))
    field_information['GGDM 3.0']['IndustryPntExt']['ZI006_MEM'] = ('String',('AA052'))
    field_information['GGDM 3.0']['IndustryPntExt']['ZI020_GE4'] = ('CodeList',('AA052'))
    field_information['GGDM 3.0']['IndustryPntExt']['ZI026_CTUC'] = ('Enumeration',('AA052'))
    field_information['GGDM 3.0']['IndustryPntExt']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['IndustryPntExt']['EnumeratedIndexValues']['ZI026_CTUC']['AA052']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['IndustryPntExt']['ZI026_CTUL'] = ('integer',('AA052'))
    field_information['GGDM 3.0']['IndustryPntExt']['ZI026_CTUU'] = ('integer',('AA052'))
    field_information['GGDM 3.0']['IndustryPntExt']['ZI031S_URI'] = ('StructuredText',('AA052'))
    field_information['GGDM 3.0']['IndustryPntExt']['ZI039S_UFI'] = ('StructuredText',('AA052'))
    field_information['GGDM 3.0']['IndustryPntExt']['ZSAX_RS0'] = ('CodeList',('AA052'))
    field_information['GGDM 3.0']['IndustryPntExt']['ZSAX_RX0'] = ('StructuredText',('AA052'))
    field_information['GGDM 3.0']['IndustryPntExt']['ZSAX_RX3'] = ('StructuredText',('AA052'))
    field_information['GGDM 3.0']['IndustryPntExt']['ZSAX_RX4'] = ('StructuredText',('AA052'))
    field_information['GGDM 3.0']['IndustrySrf']['ADR'] = ('String',('AC040','AJ055'))
    field_information['GGDM 3.0']['IndustrySrf']['AOO'] = ('Real',('AA010','AA020','AA040','AB000','AB010','AC010','AC020','AC040','AC060','AF040','AJ055','AM040'))
    field_information['GGDM 3.0']['IndustrySrf']['ARA'] = ('Real',('AA010','AA020','AA040','AA052','AB000','AB010','AB040','AB507','AC010','AC020','AC030','AC040','AC060','AF040','AJ055','AM040','BH040','BH155'))
    field_information['GGDM 3.0']['IndustrySrf']['AWP'] = ('Boolean',('AA020','AA040','AB000','AC010','AC020','AF040','AJ055','AM040'))
    field_information['GGDM 3.0']['IndustrySrf']['AZC'] = ('Boolean',('BH155'))
    field_information['GGDM 3.0']['IndustrySrf']['BEN'] = ('StructuredText',('AA010','AA020','AA040','AA052','AB000','AB010','AB040','AB507','AC010','AC020','AC030','AC040','AC060','AF040','AJ055','AM040','BH040','BH155'))
    field_information['GGDM 3.0']['IndustrySrf']['BNF'] = ('Integer',('AJ055'))
    field_information['GGDM 3.0']['IndustrySrf']['CAA'] = ('Enumeration',('AA020','AA040','AB010','AC010','AC020','AC040','AC060','AF040','AJ055','AM040'))
    field_information['GGDM 3.0']['IndustrySrf']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['IndustrySrf']['EnumeratedIndexValues']['CAA']['AA020']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['IndustrySrf']['EnumeratedIndexValues']['CAA']['AA040']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['IndustrySrf']['EnumeratedIndexValues']['CAA']['AB010']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['IndustrySrf']['EnumeratedIndexValues']['CAA']['AC010']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['IndustrySrf']['EnumeratedIndexValues']['CAA']['AC020']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['IndustrySrf']['EnumeratedIndexValues']['CAA']['AC040']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['IndustrySrf']['EnumeratedIndexValues']['CAA']['AC060']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['IndustrySrf']['EnumeratedIndexValues']['CAA']['AF040']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['IndustrySrf']['EnumeratedIndexValues']['CAA']['AJ055']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['IndustrySrf']['EnumeratedIndexValues']['CAA']['AM040']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['IndustrySrf']['CNCP'] = ('StructuredText',('AA010','AA020','AA040','AB000','AB010','AB040','AC010','AC020','AC030','AC040','AC060','AF040','AJ055','AM040','BH040','BH155'))
    field_information['GGDM 3.0']['IndustrySrf']['COS'] = ('Enumeration',('AA010','AA020','AA040','AB000','AB010','AB040','AC010','AC020','AC030','AC040','AC060','AF040','AJ055','AM040','BH040','BH155'))
    field_information['GGDM 3.0']['IndustrySrf']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['IndustrySrf']['EnumeratedIndexValues']['COS']['AA010']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['IndustrySrf']['EnumeratedIndexValues']['COS']['AA020']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['IndustrySrf']['EnumeratedIndexValues']['COS']['AA040']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['IndustrySrf']['EnumeratedIndexValues']['COS']['AB000']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['IndustrySrf']['EnumeratedIndexValues']['COS']['AB010']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['IndustrySrf']['EnumeratedIndexValues']['COS']['AB040']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['IndustrySrf']['EnumeratedIndexValues']['COS']['AC010']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['IndustrySrf']['EnumeratedIndexValues']['COS']['AC020']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['IndustrySrf']['EnumeratedIndexValues']['COS']['AC030']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['IndustrySrf']['EnumeratedIndexValues']['COS']['AC040']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['IndustrySrf']['EnumeratedIndexValues']['COS']['AC060']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['IndustrySrf']['EnumeratedIndexValues']['COS']['AF040']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['IndustrySrf']['EnumeratedIndexValues']['COS']['AJ055']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['IndustrySrf']['EnumeratedIndexValues']['COS']['AM040']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['IndustrySrf']['EnumeratedIndexValues']['COS']['BH040']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['IndustrySrf']['EnumeratedIndexValues']['COS']['BH155']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['IndustrySrf']['CRA'] = ('Enumeration',('AF040'))
    field_information['GGDM 3.0']['IndustrySrf']['EnumeratedIndexValues']['CRA'] = {}
    field_information['GGDM 3.0']['IndustrySrf']['EnumeratedIndexValues']['CRA']['AF040']  = (-999999,2,3,7,8,9,10,99,999)
    field_information['GGDM 3.0']['IndustrySrf']['CRM'] = ('Enumeration',('AF040'))
    field_information['GGDM 3.0']['IndustrySrf']['EnumeratedIndexValues']['CRM'] = {}
    field_information['GGDM 3.0']['IndustrySrf']['EnumeratedIndexValues']['CRM']['AF040']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['IndustrySrf']['DZP'] = ('Real',('AA010','AC030','BH040'))
    field_information['GGDM 3.0']['IndustrySrf']['F_CODE'] = ('CONSTRAINED_STRING',('AA010','AA020','AA040','AA052','AB000','AB010','AB040','AB507','AC010','AC020','AC030','AC040','AC060','AF040','AJ055','AM040','BH040','BH155'))
    field_information['GGDM 3.0']['IndustrySrf']['FFN'] = ('Enumeration',('AA010','AC040','AJ055'))
    field_information['GGDM 3.0']['IndustrySrf']['EnumeratedIndexValues']['FFN'] = {}
    field_information['GGDM 3.0']['IndustrySrf']['EnumeratedIndexValues']['FFN']['AA010']  = (-999999,40,50,70,83,84,85,87,999)
    field_information['GGDM 3.0']['IndustrySrf']['EnumeratedIndexValues']['FFN']['AC040']  = (-999999,91,192,481,484,500,999)
    field_information['GGDM 3.0']['IndustrySrf']['EnumeratedIndexValues']['FFN']['AJ055']  = (-999999,105,107,161,351,501,999)
    field_information['GGDM 3.0']['IndustrySrf']['FFN2'] = ('Enumeration',('AA010','AC040','AJ055'))
    field_information['GGDM 3.0']['IndustrySrf']['EnumeratedIndexValues']['FFN2'] = {}
    field_information['GGDM 3.0']['IndustrySrf']['EnumeratedIndexValues']['FFN2']['AA010']  = (-999999,40,50,70,83,84,85,87,999)
    field_information['GGDM 3.0']['IndustrySrf']['EnumeratedIndexValues']['FFN2']['AC040']  = (-999999,91,192,481,484,500,999)
    field_information['GGDM 3.0']['IndustrySrf']['EnumeratedIndexValues']['FFN2']['AJ055']  = (-999999,105,107,161,351,501,999)
    field_information['GGDM 3.0']['IndustrySrf']['FFN3'] = ('Enumeration',('AA010','AC040','AJ055'))
    field_information['GGDM 3.0']['IndustrySrf']['EnumeratedIndexValues']['FFN3'] = {}
    field_information['GGDM 3.0']['IndustrySrf']['EnumeratedIndexValues']['FFN3']['AA010']  = (-999999,40,50,70,83,84,85,87,999)
    field_information['GGDM 3.0']['IndustrySrf']['EnumeratedIndexValues']['FFN3']['AC040']  = (-999999,91,192,481,484,500,999)
    field_information['GGDM 3.0']['IndustrySrf']['EnumeratedIndexValues']['FFN3']['AJ055']  = (-999999,105,107,161,351,501,999)
    field_information['GGDM 3.0']['IndustrySrf']['FUFI'] = ('StructuredText',('AA010','AA020','AA040','AA052','AB000','AB010','AB040','AB507','AC010','AC020','AC030','AC040','AC060','AF040','AJ055','AM040','BH040','BH155'))
    field_information['GGDM 3.0']['IndustrySrf']['FURL'] = ('StructuredText',('AA010','AA020','AA040','AA052','AB000','AB010','AB040','AB507','AC010','AC020','AC030','AC040','AC060','AF040','AJ055','AM040','BH040','BH155'))
    field_information['GGDM 3.0']['IndustrySrf']['GDBV'] = ('Enumeration',('AA010','AA020','AA040','AA052','AB000','AB010','AB040','AB507','AC010','AC020','AC030','AC040','AC060','AF040','AJ055','AM040','BH040','BH155'))
    field_information['GGDM 3.0']['IndustrySrf']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['IndustrySrf']['EnumeratedIndexValues']['GDBV']['AA010']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['IndustrySrf']['EnumeratedIndexValues']['GDBV']['AA020']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['IndustrySrf']['EnumeratedIndexValues']['GDBV']['AA040']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['IndustrySrf']['EnumeratedIndexValues']['GDBV']['AA052']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['IndustrySrf']['EnumeratedIndexValues']['GDBV']['AB000']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['IndustrySrf']['EnumeratedIndexValues']['GDBV']['AB010']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['IndustrySrf']['EnumeratedIndexValues']['GDBV']['AB040']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['IndustrySrf']['EnumeratedIndexValues']['GDBV']['AB507']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['IndustrySrf']['EnumeratedIndexValues']['GDBV']['AC010']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['IndustrySrf']['EnumeratedIndexValues']['GDBV']['AC020']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['IndustrySrf']['EnumeratedIndexValues']['GDBV']['AC030']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['IndustrySrf']['EnumeratedIndexValues']['GDBV']['AC040']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['IndustrySrf']['EnumeratedIndexValues']['GDBV']['AC060']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['IndustrySrf']['EnumeratedIndexValues']['GDBV']['AF040']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['IndustrySrf']['EnumeratedIndexValues']['GDBV']['AJ055']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['IndustrySrf']['EnumeratedIndexValues']['GDBV']['AM040']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['IndustrySrf']['EnumeratedIndexValues']['GDBV']['BH040']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['IndustrySrf']['EnumeratedIndexValues']['GDBV']['BH155']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['IndustrySrf']['HGT'] = ('Real',('AA010','AA020','AA040','AB000','AB010','AB507','AC010','AC020','AC040','AC060','AF040','AJ055','AM040'))
    field_information['GGDM 3.0']['IndustrySrf']['HST'] = ('Enumeration',('AA010'))
    field_information['GGDM 3.0']['IndustrySrf']['EnumeratedIndexValues']['HST'] = {}
    field_information['GGDM 3.0']['IndustrySrf']['EnumeratedIndexValues']['HST']['AA010']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['IndustrySrf']['HST2'] = ('Enumeration',('AA010'))
    field_information['GGDM 3.0']['IndustrySrf']['EnumeratedIndexValues']['HST2'] = {}
    field_information['GGDM 3.0']['IndustrySrf']['EnumeratedIndexValues']['HST2']['AA010']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['IndustrySrf']['HST3'] = ('Enumeration',('AA010'))
    field_information['GGDM 3.0']['IndustrySrf']['EnumeratedIndexValues']['HST3'] = {}
    field_information['GGDM 3.0']['IndustrySrf']['EnumeratedIndexValues']['HST3']['AA010']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['IndustrySrf']['LCA'] = ('Real',('AF040'))
    field_information['GGDM 3.0']['IndustrySrf']['LEA'] = ('Real',('AA010'))
    field_information['GGDM 3.0']['IndustrySrf']['LMC'] = ('Boolean',('AA010','AA020','AA040','AB000','AB010','AB040','AB507','AC010','AC020','AC030','AC040','AC060','AF040','AJ055','AM040','BH040','BH155'))
    field_information['GGDM 3.0']['IndustrySrf']['LOC'] = ('Enumeration',('AA010'))
    field_information['GGDM 3.0']['IndustrySrf']['EnumeratedIndexValues']['LOC'] = {}
    field_information['GGDM 3.0']['IndustrySrf']['EnumeratedIndexValues']['LOC']['AA010']  = (-999999,40,44)
    field_information['GGDM 3.0']['IndustrySrf']['LZN'] = ('Real',('AA010','AA020','AA040','AA052','AB000','AB010','AB040','AB507','AC010','AC020','AC030','AC040','AC060','AF040','AJ055','AM040','BH040','BH155'))
    field_information['GGDM 3.0']['IndustrySrf']['MZN'] = ('Enumeration',('AA010'))
    field_information['GGDM 3.0']['IndustrySrf']['EnumeratedIndexValues']['MZN'] = {}
    field_information['GGDM 3.0']['IndustrySrf']['EnumeratedIndexValues']['MZN']['AA010']  = (-999999,1,3,4,5,6,8,9,10,11,13,999)
    field_information['GGDM 3.0']['IndustrySrf']['OTH'] = ('StructuredText',('AA010','AA020','AA040','AA052','AB000','AB010','AB040','AB507','AC010','AC020','AC030','AC040','AC060','AF040','AJ055','AM040','BH040','BH155'))
    field_information['GGDM 3.0']['IndustrySrf']['PBY'] = ('Enumeration',('AB000'))
    field_information['GGDM 3.0']['IndustrySrf']['EnumeratedIndexValues']['PBY'] = {}
    field_information['GGDM 3.0']['IndustrySrf']['EnumeratedIndexValues']['PBY']['AB000']  = (-999999,8,15,16,17,999)
    field_information['GGDM 3.0']['IndustrySrf']['PBY2'] = ('Enumeration',('AB000'))
    field_information['GGDM 3.0']['IndustrySrf']['EnumeratedIndexValues']['PBY2'] = {}
    field_information['GGDM 3.0']['IndustrySrf']['EnumeratedIndexValues']['PBY2']['AB000']  = (-999999,8,15,16,17,999)
    field_information['GGDM 3.0']['IndustrySrf']['PBY3'] = ('Enumeration',('AB000'))
    field_information['GGDM 3.0']['IndustrySrf']['EnumeratedIndexValues']['PBY3'] = {}
    field_information['GGDM 3.0']['IndustrySrf']['EnumeratedIndexValues']['PBY3']['AB000']  = (-999999,8,15,16,17,999)
    field_information['GGDM 3.0']['IndustrySrf']['PCF'] = ('Enumeration',('AA010','AA020','AA040','AB000','AB010','AB040','AC010','AC020','AC030','AC040','AC060','AF040','AJ055','BH040','BH155'))
    field_information['GGDM 3.0']['IndustrySrf']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['IndustrySrf']['EnumeratedIndexValues']['PCF']['AA010']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['IndustrySrf']['EnumeratedIndexValues']['PCF']['AA020']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['IndustrySrf']['EnumeratedIndexValues']['PCF']['AA040']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['IndustrySrf']['EnumeratedIndexValues']['PCF']['AB000']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['IndustrySrf']['EnumeratedIndexValues']['PCF']['AB010']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['IndustrySrf']['EnumeratedIndexValues']['PCF']['AB040']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['IndustrySrf']['EnumeratedIndexValues']['PCF']['AC010']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['IndustrySrf']['EnumeratedIndexValues']['PCF']['AC020']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['IndustrySrf']['EnumeratedIndexValues']['PCF']['AC030']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['IndustrySrf']['EnumeratedIndexValues']['PCF']['AC040']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['IndustrySrf']['EnumeratedIndexValues']['PCF']['AC060']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['IndustrySrf']['EnumeratedIndexValues']['PCF']['AF040']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['IndustrySrf']['EnumeratedIndexValues']['PCF']['AJ055']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['IndustrySrf']['EnumeratedIndexValues']['PCF']['BH040']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['IndustrySrf']['EnumeratedIndexValues']['PCF']['BH155']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['IndustrySrf']['PPO'] = ('Enumeration',('AA010','AA020','AA040','AA052','AC060'))
    field_information['GGDM 3.0']['IndustrySrf']['EnumeratedIndexValues']['PPO'] = {}
    field_information['GGDM 3.0']['IndustrySrf']['EnumeratedIndexValues']['PPO']['AA010']  = (-999999,8,9,17,18,26,33,34,35,48,50,53,58,59,65,66,85,88,89,93,95,96,97,105,110,118,120,126,130,151,152,153,173,204,224,283,339,999)
    field_information['GGDM 3.0']['IndustrySrf']['EnumeratedIndexValues']['PPO']['AA020']  = (-999999,18,26,33,48,58,59,65,95,105,120,126,151,152,153,999)
    field_information['GGDM 3.0']['IndustrySrf']['EnumeratedIndexValues']['PPO']['AA040']  = (-999999,45,83,122,149,999)
    field_information['GGDM 3.0']['IndustrySrf']['EnumeratedIndexValues']['PPO']['AA052']  = (-999999,45,83,999)
    field_information['GGDM 3.0']['IndustrySrf']['EnumeratedIndexValues']['PPO']['AC060']  = (-999999,13,15,60,63,158,159,999)
    field_information['GGDM 3.0']['IndustrySrf']['PPO2'] = ('Enumeration',('AA010','AA020','AA040','AA052','AC060'))
    field_information['GGDM 3.0']['IndustrySrf']['EnumeratedIndexValues']['PPO2'] = {}
    field_information['GGDM 3.0']['IndustrySrf']['EnumeratedIndexValues']['PPO2']['AA010']  = (-999999,8,9,17,18,26,33,34,35,48,50,53,58,59,65,66,85,88,89,93,95,96,97,105,110,118,120,126,130,151,152,153,173,204,224,283,339,999)
    field_information['GGDM 3.0']['IndustrySrf']['EnumeratedIndexValues']['PPO2']['AA020']  = (-999999,18,26,33,48,58,59,65,95,105,120,126,151,152,153,999)
    field_information['GGDM 3.0']['IndustrySrf']['EnumeratedIndexValues']['PPO2']['AA040']  = (-999999,45,83,122,149,999)
    field_information['GGDM 3.0']['IndustrySrf']['EnumeratedIndexValues']['PPO2']['AA052']  = (-999999,45,83,999)
    field_information['GGDM 3.0']['IndustrySrf']['EnumeratedIndexValues']['PPO2']['AC060']  = (-999999,13,15,60,63,158,159,999)
    field_information['GGDM 3.0']['IndustrySrf']['PPO3'] = ('Enumeration',('AA010','AA020','AA040','AA052','AC060'))
    field_information['GGDM 3.0']['IndustrySrf']['EnumeratedIndexValues']['PPO3'] = {}
    field_information['GGDM 3.0']['IndustrySrf']['EnumeratedIndexValues']['PPO3']['AA010']  = (-999999,8,9,17,18,26,33,34,35,48,50,53,58,59,65,66,85,88,89,93,95,96,97,105,110,118,120,126,130,151,152,153,173,204,224,283,339,999)
    field_information['GGDM 3.0']['IndustrySrf']['EnumeratedIndexValues']['PPO3']['AA020']  = (-999999,18,26,33,48,58,59,65,95,105,120,126,151,152,153,999)
    field_information['GGDM 3.0']['IndustrySrf']['EnumeratedIndexValues']['PPO3']['AA040']  = (-999999,45,83,122,149,999)
    field_information['GGDM 3.0']['IndustrySrf']['EnumeratedIndexValues']['PPO3']['AA052']  = (-999999,45,83,999)
    field_information['GGDM 3.0']['IndustrySrf']['EnumeratedIndexValues']['PPO3']['AC060']  = (-999999,13,15,60,63,158,159,999)
    field_information['GGDM 3.0']['IndustrySrf']['PRW'] = ('Enumeration',('AM040'))
    field_information['GGDM 3.0']['IndustrySrf']['EnumeratedIndexValues']['PRW'] = {}
    field_information['GGDM 3.0']['IndustrySrf']['EnumeratedIndexValues']['PRW']['AM040']  = (-999999,12,14,34,54,67,68,84,154,999)
    field_information['GGDM 3.0']['IndustrySrf']['PRW2'] = ('Enumeration',('AM040'))
    field_information['GGDM 3.0']['IndustrySrf']['EnumeratedIndexValues']['PRW2'] = {}
    field_information['GGDM 3.0']['IndustrySrf']['EnumeratedIndexValues']['PRW2']['AM040']  = (-999999,12,14,34,54,67,68,84,154,999)
    field_information['GGDM 3.0']['IndustrySrf']['PRW3'] = ('Enumeration',('AM040'))
    field_information['GGDM 3.0']['IndustrySrf']['EnumeratedIndexValues']['PRW3'] = {}
    field_information['GGDM 3.0']['IndustrySrf']['EnumeratedIndexValues']['PRW3']['AM040']  = (-999999,12,14,34,54,67,68,84,154,999)
    field_information['GGDM 3.0']['IndustrySrf']['SRL'] = ('Enumeration',('AA040','AF040'))
    field_information['GGDM 3.0']['IndustrySrf']['EnumeratedIndexValues']['SRL'] = {}
    field_information['GGDM 3.0']['IndustrySrf']['EnumeratedIndexValues']['SRL']['AA040']  = (-999999,1,2,3)
    field_information['GGDM 3.0']['IndustrySrf']['EnumeratedIndexValues']['SRL']['AF040']  = (-999999,1,2,3)
    field_information['GGDM 3.0']['IndustrySrf']['TRS'] = ('Enumeration',('AF040'))
    field_information['GGDM 3.0']['IndustrySrf']['EnumeratedIndexValues']['TRS'] = {}
    field_information['GGDM 3.0']['IndustrySrf']['EnumeratedIndexValues']['TRS']['AF040']  = (-999999,7,8,12,13,999)
    field_information['GGDM 3.0']['IndustrySrf']['TRS2'] = ('Enumeration',('AF040'))
    field_information['GGDM 3.0']['IndustrySrf']['EnumeratedIndexValues']['TRS2'] = {}
    field_information['GGDM 3.0']['IndustrySrf']['EnumeratedIndexValues']['TRS2']['AF040']  = (-999999,7,8,12,13,999)
    field_information['GGDM 3.0']['IndustrySrf']['TRS3'] = ('Enumeration',('AF040'))
    field_information['GGDM 3.0']['IndustrySrf']['EnumeratedIndexValues']['TRS3'] = {}
    field_information['GGDM 3.0']['IndustrySrf']['EnumeratedIndexValues']['TRS3']['AF040']  = (-999999,7,8,12,13,999)
    field_information['GGDM 3.0']['IndustrySrf']['UFI'] = ('StructuredText',('AA010','AA020','AA040','AA052','AB000','AB010','AB040','AB507','AC010','AC020','AC030','AC040','AC060','AF040','AJ055','AM040','BH040','BH155'))
    field_information['GGDM 3.0']['IndustrySrf']['UMA'] = ('Enumeration',('AA010'))
    field_information['GGDM 3.0']['IndustrySrf']['EnumeratedIndexValues']['UMA'] = {}
    field_information['GGDM 3.0']['IndustrySrf']['EnumeratedIndexValues']['UMA']['AA010']  = (-999999,1,2,3,998)
    field_information['GGDM 3.0']['IndustrySrf']['VCM'] = ('Enumeration',('AA040','AC020','AF040'))
    field_information['GGDM 3.0']['IndustrySrf']['EnumeratedIndexValues']['VCM'] = {}
    field_information['GGDM 3.0']['IndustrySrf']['EnumeratedIndexValues']['VCM']['AA040']  = (-999999,2,7,9,15,18,999)
    field_information['GGDM 3.0']['IndustrySrf']['EnumeratedIndexValues']['VCM']['AC020']  = (-999999,3,4,7,8,9,12,13,15,999)
    field_information['GGDM 3.0']['IndustrySrf']['EnumeratedIndexValues']['VCM']['AF040']  = (-999999,2,7,9,15,999)
    field_information['GGDM 3.0']['IndustrySrf']['VCM2'] = ('Enumeration',('AA040','AC020','AF040'))
    field_information['GGDM 3.0']['IndustrySrf']['EnumeratedIndexValues']['VCM2'] = {}
    field_information['GGDM 3.0']['IndustrySrf']['EnumeratedIndexValues']['VCM2']['AA040']  = (-999999,2,7,9,15,18,999)
    field_information['GGDM 3.0']['IndustrySrf']['EnumeratedIndexValues']['VCM2']['AC020']  = (-999999,3,4,7,8,9,12,13,15,999)
    field_information['GGDM 3.0']['IndustrySrf']['EnumeratedIndexValues']['VCM2']['AF040']  = (-999999,2,7,9,15,999)
    field_information['GGDM 3.0']['IndustrySrf']['VCM3'] = ('Enumeration',('AA040','AC020','AF040'))
    field_information['GGDM 3.0']['IndustrySrf']['EnumeratedIndexValues']['VCM3'] = {}
    field_information['GGDM 3.0']['IndustrySrf']['EnumeratedIndexValues']['VCM3']['AA040']  = (-999999,2,7,9,15,18,999)
    field_information['GGDM 3.0']['IndustrySrf']['EnumeratedIndexValues']['VCM3']['AC020']  = (-999999,3,4,7,8,9,12,13,15,999)
    field_information['GGDM 3.0']['IndustrySrf']['EnumeratedIndexValues']['VCM3']['AF040']  = (-999999,2,7,9,15,999)
    field_information['GGDM 3.0']['IndustrySrf']['VLM'] = ('Real',('AB040','AC030','BH040'))
    field_information['GGDM 3.0']['IndustrySrf']['VOI'] = ('StructuredText',('AA020','AA040','AB000','AB507','AC010','AC020','AF040','AJ055','AM040'))
    field_information['GGDM 3.0']['IndustrySrf']['WDAC'] = ('Enumeration',('AC030'))
    field_information['GGDM 3.0']['IndustrySrf']['EnumeratedIndexValues']['WDAC'] = {}
    field_information['GGDM 3.0']['IndustrySrf']['EnumeratedIndexValues']['WDAC']['AC030']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['IndustrySrf']['WDAL'] = ('real',('AC030'))
    field_information['GGDM 3.0']['IndustrySrf']['WDAU'] = ('real',('AC030'))
    field_information['GGDM 3.0']['IndustrySrf']['WID'] = ('Real',('AA010','AA020','AA040','AA052','AB000','AB010','AB040','AB507','AC010','AC020','AC030','AC040','AC060','AF040','AJ055','AM040','BH040','BH155'))
    field_information['GGDM 3.0']['IndustrySrf']['ZI001_SDV'] = ('StructuredText',('AA010','AA020','AA040','AA052','AB000','AB010','AB040','AB507','AC010','AC020','AC030','AC040','AC060','AF040','AJ055','AM040','BH040','BH155'))
    field_information['GGDM 3.0']['IndustrySrf']['ZI001_SRT'] = ('Enumeration',('AA010','AA020','AA040','AA052','AB000','AB010','AB040','AB507','AC010','AC020','AC030','AC040','AC060','AF040','AJ055','AM040','BH040','BH155'))
    field_information['GGDM 3.0']['IndustrySrf']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['IndustrySrf']['EnumeratedIndexValues']['ZI001_SRT']['AA010']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['IndustrySrf']['EnumeratedIndexValues']['ZI001_SRT']['AA020']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['IndustrySrf']['EnumeratedIndexValues']['ZI001_SRT']['AA040']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['IndustrySrf']['EnumeratedIndexValues']['ZI001_SRT']['AA052']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['IndustrySrf']['EnumeratedIndexValues']['ZI001_SRT']['AB000']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['IndustrySrf']['EnumeratedIndexValues']['ZI001_SRT']['AB010']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['IndustrySrf']['EnumeratedIndexValues']['ZI001_SRT']['AB040']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['IndustrySrf']['EnumeratedIndexValues']['ZI001_SRT']['AB507']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['IndustrySrf']['EnumeratedIndexValues']['ZI001_SRT']['AC010']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['IndustrySrf']['EnumeratedIndexValues']['ZI001_SRT']['AC020']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['IndustrySrf']['EnumeratedIndexValues']['ZI001_SRT']['AC030']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['IndustrySrf']['EnumeratedIndexValues']['ZI001_SRT']['AC040']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['IndustrySrf']['EnumeratedIndexValues']['ZI001_SRT']['AC060']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['IndustrySrf']['EnumeratedIndexValues']['ZI001_SRT']['AF040']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['IndustrySrf']['EnumeratedIndexValues']['ZI001_SRT']['AJ055']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['IndustrySrf']['EnumeratedIndexValues']['ZI001_SRT']['AM040']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['IndustrySrf']['EnumeratedIndexValues']['ZI001_SRT']['BH040']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['IndustrySrf']['EnumeratedIndexValues']['ZI001_SRT']['BH155']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['IndustrySrf']['ZI002_UFI'] = ('StructuredText',('AA010','AA020','AA040','AA052','AB000','AB010','AB040','AB507','AC010','AC020','AC030','AC040','AC060','AF040','AJ055','AM040','BH040','BH155'))
    field_information['GGDM 3.0']['IndustrySrf']['ZI004_RCG'] = ('Enumeration',('AA010','AA020','AA040','AA052','AB000','AB010','AB040','AB507','AC010','AC020','AC030','AC040','AC060','AF040','AJ055','AM040','BH040','BH155'))
    field_information['GGDM 3.0']['IndustrySrf']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['IndustrySrf']['EnumeratedIndexValues']['ZI004_RCG']['AA010']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['IndustrySrf']['EnumeratedIndexValues']['ZI004_RCG']['AA020']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['IndustrySrf']['EnumeratedIndexValues']['ZI004_RCG']['AA040']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['IndustrySrf']['EnumeratedIndexValues']['ZI004_RCG']['AA052']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['IndustrySrf']['EnumeratedIndexValues']['ZI004_RCG']['AB000']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['IndustrySrf']['EnumeratedIndexValues']['ZI004_RCG']['AB010']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['IndustrySrf']['EnumeratedIndexValues']['ZI004_RCG']['AB040']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['IndustrySrf']['EnumeratedIndexValues']['ZI004_RCG']['AB507']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['IndustrySrf']['EnumeratedIndexValues']['ZI004_RCG']['AC010']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['IndustrySrf']['EnumeratedIndexValues']['ZI004_RCG']['AC020']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['IndustrySrf']['EnumeratedIndexValues']['ZI004_RCG']['AC030']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['IndustrySrf']['EnumeratedIndexValues']['ZI004_RCG']['AC040']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['IndustrySrf']['EnumeratedIndexValues']['ZI004_RCG']['AC060']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['IndustrySrf']['EnumeratedIndexValues']['ZI004_RCG']['AF040']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['IndustrySrf']['EnumeratedIndexValues']['ZI004_RCG']['AJ055']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['IndustrySrf']['EnumeratedIndexValues']['ZI004_RCG']['AM040']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['IndustrySrf']['EnumeratedIndexValues']['ZI004_RCG']['BH040']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['IndustrySrf']['EnumeratedIndexValues']['ZI004_RCG']['BH155']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['IndustrySrf']['ZI005_FNA'] = ('String',('AA010','AA040','AA052','AB000','AB010','AB040','AB507','AC010','AC020','AC030','AC040','AC060','AF040','AJ055','BH040','BH155'))
    field_information['GGDM 3.0']['IndustrySrf']['ZI005_GNT'] = ('Enumeration',('AA010','AA040','AA052','AB000','AB010','AB040','AB507','AC010','AC020','AC030','AC040','AC060','AF040','AJ055','BH040','BH155'))
    field_information['GGDM 3.0']['IndustrySrf']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['IndustrySrf']['EnumeratedIndexValues']['ZI005_GNT']['AA010']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['IndustrySrf']['EnumeratedIndexValues']['ZI005_GNT']['AA040']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['IndustrySrf']['EnumeratedIndexValues']['ZI005_GNT']['AA052']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['IndustrySrf']['EnumeratedIndexValues']['ZI005_GNT']['AB000']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['IndustrySrf']['EnumeratedIndexValues']['ZI005_GNT']['AB010']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['IndustrySrf']['EnumeratedIndexValues']['ZI005_GNT']['AB040']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['IndustrySrf']['EnumeratedIndexValues']['ZI005_GNT']['AB507']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['IndustrySrf']['EnumeratedIndexValues']['ZI005_GNT']['AC010']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['IndustrySrf']['EnumeratedIndexValues']['ZI005_GNT']['AC020']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['IndustrySrf']['EnumeratedIndexValues']['ZI005_GNT']['AC030']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['IndustrySrf']['EnumeratedIndexValues']['ZI005_GNT']['AC040']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['IndustrySrf']['EnumeratedIndexValues']['ZI005_GNT']['AC060']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['IndustrySrf']['EnumeratedIndexValues']['ZI005_GNT']['AF040']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['IndustrySrf']['EnumeratedIndexValues']['ZI005_GNT']['AJ055']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['IndustrySrf']['EnumeratedIndexValues']['ZI005_GNT']['BH040']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['IndustrySrf']['EnumeratedIndexValues']['ZI005_GNT']['BH155']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['IndustrySrf']['ZI005_NFN'] = ('String',('AA010','AA040','AA052','AB000','AB010','AB040','AB507','AC010','AC020','AC030','AC040','AC060','AF040','AJ055','BH040','BH155'))
    field_information['GGDM 3.0']['IndustrySrf']['ZI006_MEM'] = ('String',('AA010','AA020','AA040','AA052','AB000','AB010','AB040','AB507','AC010','AC020','AC030','AC040','AC060','AF040','AJ055','AM040','BH040','BH155'))
    field_information['GGDM 3.0']['IndustrySrf']['ZI014_PPO'] = ('Enumeration',('AC040','AJ055'))
    field_information['GGDM 3.0']['IndustrySrf']['EnumeratedIndexValues']['ZI014_PPO'] = {}
    field_information['GGDM 3.0']['IndustrySrf']['EnumeratedIndexValues']['ZI014_PPO']['AC040']  = (-999999,4,16,45,46,61,62,74,83,84,137,150,157,214,999)
    field_information['GGDM 3.0']['IndustrySrf']['EnumeratedIndexValues']['ZI014_PPO']['AJ055']  = (-999999,20,28,63,73,111,155,160,999)
    field_information['GGDM 3.0']['IndustrySrf']['ZI014_PPO2'] = ('Enumeration',('AC040','AJ055'))
    field_information['GGDM 3.0']['IndustrySrf']['EnumeratedIndexValues']['ZI014_PPO2'] = {}
    field_information['GGDM 3.0']['IndustrySrf']['EnumeratedIndexValues']['ZI014_PPO2']['AC040']  = (-999999,4,16,45,46,61,62,74,83,84,137,150,157,214,999)
    field_information['GGDM 3.0']['IndustrySrf']['EnumeratedIndexValues']['ZI014_PPO2']['AJ055']  = (-999999,20,28,63,73,111,155,160,999)
    field_information['GGDM 3.0']['IndustrySrf']['ZI014_PPO3'] = ('Enumeration',('AC040','AJ055'))
    field_information['GGDM 3.0']['IndustrySrf']['EnumeratedIndexValues']['ZI014_PPO3'] = {}
    field_information['GGDM 3.0']['IndustrySrf']['EnumeratedIndexValues']['ZI014_PPO3']['AC040']  = (-999999,4,16,45,46,61,62,74,83,84,137,150,157,214,999)
    field_information['GGDM 3.0']['IndustrySrf']['EnumeratedIndexValues']['ZI014_PPO3']['AJ055']  = (-999999,20,28,63,73,111,155,160,999)
    field_information['GGDM 3.0']['IndustrySrf']['ZI020_GE4'] = ('CodeList',('AA010','AA020','AA040','AA052','AB000','AB010','AB040','AB507','AC010','AC020','AC030','AC040','AC060','AF040','AJ055','AM040','BH040','BH155'))
    field_information['GGDM 3.0']['IndustrySrf']['ZI024_ASE'] = ('Real',('AB040','BH040'))
    field_information['GGDM 3.0']['IndustrySrf']['ZI024_CFR'] = ('Real',('AB040','BH040'))
    field_information['GGDM 3.0']['IndustrySrf']['ZI024_CLO'] = ('Real',('AB040','BH040'))
    field_information['GGDM 3.0']['IndustrySrf']['ZI024_CYN'] = ('Real',('AB040','BH040'))
    field_information['GGDM 3.0']['IndustrySrf']['ZI024_FMR'] = ('Real',('AB040','BH040'))
    field_information['GGDM 3.0']['IndustrySrf']['ZI024_FRR'] = ('Real',('AB040','BH040'))
    field_information['GGDM 3.0']['IndustrySrf']['ZI024_HAR'] = ('Real',('AB040','BH040'))
    field_information['GGDM 3.0']['IndustrySrf']['ZI024_MGN'] = ('Real',('AB040','BH040'))
    field_information['GGDM 3.0']['IndustrySrf']['ZI024_PHW'] = ('Real',('AB040','BH040'))
    field_information['GGDM 3.0']['IndustrySrf']['ZI024_SCC'] = ('Enumeration',('AB040','BH040'))
    field_information['GGDM 3.0']['IndustrySrf']['EnumeratedIndexValues']['ZI024_SCC'] = {}
    field_information['GGDM 3.0']['IndustrySrf']['EnumeratedIndexValues']['ZI024_SCC']['AB040']  = (-999999,1,4,10,11,12,13,14,998,999)
    field_information['GGDM 3.0']['IndustrySrf']['EnumeratedIndexValues']['ZI024_SCC']['BH040']  = (-999999,1,4,10,11,12,13,14,998,999)
    field_information['GGDM 3.0']['IndustrySrf']['ZI024_SUL'] = ('Real',('AB040','BH040'))
    field_information['GGDM 3.0']['IndustrySrf']['ZI024_TDS'] = ('Real',('AB040','BH040'))
    field_information['GGDM 3.0']['IndustrySrf']['ZI024_TEP'] = ('Real',('AB040','BH040'))
    field_information['GGDM 3.0']['IndustrySrf']['ZI024_TUR'] = ('Real',('AB040','BH040'))
    field_information['GGDM 3.0']['IndustrySrf']['ZI024_WAC'] = ('Real',('AB040','BH040'))
    field_information['GGDM 3.0']['IndustrySrf']['ZI024_WTNO'] = ('Real',('AB040','BH040'))
    field_information['GGDM 3.0']['IndustrySrf']['ZI026_CTUC'] = ('Enumeration',('AA010','AA020','AA040','AA052','AB000','AB010','AB040','AB507','AC010','AC020','AC030','AC040','AC060','AF040','AJ055','AM040','BH040','BH155'))
    field_information['GGDM 3.0']['IndustrySrf']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['IndustrySrf']['EnumeratedIndexValues']['ZI026_CTUC']['AA010']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['IndustrySrf']['EnumeratedIndexValues']['ZI026_CTUC']['AA020']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['IndustrySrf']['EnumeratedIndexValues']['ZI026_CTUC']['AA040']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['IndustrySrf']['EnumeratedIndexValues']['ZI026_CTUC']['AA052']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['IndustrySrf']['EnumeratedIndexValues']['ZI026_CTUC']['AB000']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['IndustrySrf']['EnumeratedIndexValues']['ZI026_CTUC']['AB010']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['IndustrySrf']['EnumeratedIndexValues']['ZI026_CTUC']['AB040']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['IndustrySrf']['EnumeratedIndexValues']['ZI026_CTUC']['AB507']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['IndustrySrf']['EnumeratedIndexValues']['ZI026_CTUC']['AC010']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['IndustrySrf']['EnumeratedIndexValues']['ZI026_CTUC']['AC020']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['IndustrySrf']['EnumeratedIndexValues']['ZI026_CTUC']['AC030']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['IndustrySrf']['EnumeratedIndexValues']['ZI026_CTUC']['AC040']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['IndustrySrf']['EnumeratedIndexValues']['ZI026_CTUC']['AC060']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['IndustrySrf']['EnumeratedIndexValues']['ZI026_CTUC']['AF040']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['IndustrySrf']['EnumeratedIndexValues']['ZI026_CTUC']['AJ055']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['IndustrySrf']['EnumeratedIndexValues']['ZI026_CTUC']['AM040']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['IndustrySrf']['EnumeratedIndexValues']['ZI026_CTUC']['BH040']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['IndustrySrf']['EnumeratedIndexValues']['ZI026_CTUC']['BH155']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['IndustrySrf']['ZI026_CTUL'] = ('integer',('AA010','AA020','AA040','AA052','AB000','AB010','AB040','AB507','AC010','AC020','AC030','AC040','AC060','AF040','AJ055','AM040','BH040','BH155'))
    field_information['GGDM 3.0']['IndustrySrf']['ZI026_CTUU'] = ('integer',('AA010','AA020','AA040','AA052','AB000','AB010','AB040','AB507','AC010','AC020','AC030','AC040','AC060','AF040','AJ055','AM040','BH040','BH155'))
    field_information['GGDM 3.0']['IndustrySrf']['ZI031S_URI'] = ('StructuredText',('AA010','AA020','AA040','AA052','AB000','AB010','AB040','AB507','AC010','AC020','AC030','AC040','AC060','AF040','AJ055','AM040','BH040','BH155'))
    field_information['GGDM 3.0']['IndustrySrf']['ZI039S_UFI'] = ('StructuredText',('AA010','AA020','AA040','AA052','AB000','AB010','AB040','AB507','AC010','AC020','AC030','AC040','AC060','AF040','AJ055','AM040','BH040','BH155'))
    field_information['GGDM 3.0']['IndustrySrf']['ZSAX_RS0'] = ('CodeList',('AA010','AA020','AA040','AA052','AB000','AB010','AB040','AB507','AC010','AC020','AC030','AC040','AC060','AF040','AJ055','AM040','BH040','BH155'))
    field_information['GGDM 3.0']['IndustrySrf']['ZSAX_RX0'] = ('StructuredText',('AA010','AA020','AA040','AA052','AB000','AB010','AB040','AB507','AC010','AC020','AC030','AC040','AC060','AF040','AJ055','AM040','BH040','BH155'))
    field_information['GGDM 3.0']['IndustrySrf']['ZSAX_RX3'] = ('StructuredText',('AA010','AA020','AA040','AA052','AB000','AB010','AB040','AB507','AC010','AC020','AC030','AC040','AC060','AF040','AJ055','AM040','BH040','BH155'))
    field_information['GGDM 3.0']['IndustrySrf']['ZSAX_RX4'] = ('StructuredText',('AA010','AA020','AA040','AA052','AB000','AB010','AB040','AB507','AC010','AC020','AC030','AC040','AC060','AF040','AJ055','AM040','BH040','BH155'))
    field_information['GGDM 3.0']['IndustrySrf']['ZVH'] = ('Real',('AA010','AA020','AA040','AB000','AB010','AB507','AC010','AC020','AC040','AC060','AF040','AJ055','AM040'))
    field_information['GGDM 3.0']['InformationCrv']['BEN'] = ('StructuredText',('ZD045'))
    field_information['GGDM 3.0']['InformationCrv']['F_CODE'] = ('CONSTRAINED_STRING',('ZD045'))
    field_information['GGDM 3.0']['InformationCrv']['FUFI'] = ('StructuredText',('ZD045'))
    field_information['GGDM 3.0']['InformationCrv']['FURL'] = ('StructuredText',('ZD045'))
    field_information['GGDM 3.0']['InformationCrv']['GDBV'] = ('Enumeration',('ZD045'))
    field_information['GGDM 3.0']['InformationCrv']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['InformationCrv']['EnumeratedIndexValues']['GDBV']['ZD045']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['InformationCrv']['OTH'] = ('StructuredText',('ZD045'))
    field_information['GGDM 3.0']['InformationCrv']['UFI'] = ('StructuredText',('ZD045'))
    field_information['GGDM 3.0']['InformationCrv']['ZI001_SDV'] = ('StructuredText',('ZD045'))
    field_information['GGDM 3.0']['InformationCrv']['ZI001_SRT'] = ('Enumeration',('ZD045'))
    field_information['GGDM 3.0']['InformationCrv']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['InformationCrv']['EnumeratedIndexValues']['ZI001_SRT']['ZD045']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['InformationCrv']['ZI002_UFI'] = ('StructuredText',('ZD045'))
    field_information['GGDM 3.0']['InformationCrv']['ZI004_RCG'] = ('Enumeration',('ZD045'))
    field_information['GGDM 3.0']['InformationCrv']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['InformationCrv']['EnumeratedIndexValues']['ZI004_RCG']['ZD045']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['InformationCrv']['ZI005_FNA'] = ('String',('ZD045'))
    field_information['GGDM 3.0']['InformationCrv']['ZI005_FNA2'] = ('String',('ZD045'))
    field_information['GGDM 3.0']['InformationCrv']['ZI005_FNA3'] = ('String',('ZD045'))
    field_information['GGDM 3.0']['InformationCrv']['ZI005_GNR'] = ('Integer',('ZD045'))
    field_information['GGDM 3.0']['InformationCrv']['ZI005_GNR2'] = ('Integer',('ZD045'))
    field_information['GGDM 3.0']['InformationCrv']['ZI005_GNR3'] = ('Integer',('ZD045'))
    field_information['GGDM 3.0']['InformationCrv']['ZI005_GNT'] = ('Enumeration',('ZD045'))
    field_information['GGDM 3.0']['InformationCrv']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['InformationCrv']['EnumeratedIndexValues']['ZI005_GNT']['ZD045']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['InformationCrv']['ZI005_GNT2'] = ('Enumeration',('ZD045'))
    field_information['GGDM 3.0']['InformationCrv']['EnumeratedIndexValues']['ZI005_GNT2'] = {}
    field_information['GGDM 3.0']['InformationCrv']['EnumeratedIndexValues']['ZI005_GNT2']['ZD045']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['InformationCrv']['ZI005_GNT3'] = ('Enumeration',('ZD045'))
    field_information['GGDM 3.0']['InformationCrv']['EnumeratedIndexValues']['ZI005_GNT3'] = {}
    field_information['GGDM 3.0']['InformationCrv']['EnumeratedIndexValues']['ZI005_GNT3']['ZD045']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['InformationCrv']['ZI005_NFN'] = ('String',('ZD045'))
    field_information['GGDM 3.0']['InformationCrv']['ZI005_NFN2'] = ('String',('ZD045'))
    field_information['GGDM 3.0']['InformationCrv']['ZI005_NFN3'] = ('String',('ZD045'))
    field_information['GGDM 3.0']['InformationCrv']['ZI006_MEM'] = ('String',('ZD045'))
    field_information['GGDM 3.0']['InformationCrv']['ZI015_GCUC'] = ('Enumeration',('ZD045'))
    field_information['GGDM 3.0']['InformationCrv']['EnumeratedIndexValues']['ZI015_GCUC'] = {}
    field_information['GGDM 3.0']['InformationCrv']['EnumeratedIndexValues']['ZI015_GCUC']['ZD045']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['InformationCrv']['ZI015_GCUL'] = ('integer',('ZD045'))
    field_information['GGDM 3.0']['InformationCrv']['ZI015_GCUU'] = ('integer',('ZD045'))
    field_information['GGDM 3.0']['InformationCrv']['ZI020_GE4'] = ('CodeList',('ZD045'))
    field_information['GGDM 3.0']['InformationCrv']['ZI026_CTUC'] = ('Enumeration',('ZD045'))
    field_information['GGDM 3.0']['InformationCrv']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['InformationCrv']['EnumeratedIndexValues']['ZI026_CTUC']['ZD045']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['InformationCrv']['ZI026_CTUL'] = ('integer',('ZD045'))
    field_information['GGDM 3.0']['InformationCrv']['ZI026_CTUU'] = ('integer',('ZD045'))
    field_information['GGDM 3.0']['InformationCrv']['ZI031S_URI'] = ('StructuredText',('ZD045'))
    field_information['GGDM 3.0']['InformationCrv']['ZI039S_UFI'] = ('StructuredText',('ZD045'))
    field_information['GGDM 3.0']['InformationCrv']['ZSAX_RS0'] = ('CodeList',('ZD045'))
    field_information['GGDM 3.0']['InformationCrv']['ZSAX_RX0'] = ('StructuredText',('ZD045'))
    field_information['GGDM 3.0']['InformationCrv']['ZSAX_RX3'] = ('StructuredText',('ZD045'))
    field_information['GGDM 3.0']['InformationCrv']['ZSAX_RX4'] = ('StructuredText',('ZD045'))
    field_information['GGDM 3.0']['InformationCrvExt']['BEN'] = ('StructuredText',('ZD040'))
    field_information['GGDM 3.0']['InformationCrvExt']['F_CODE'] = ('CONSTRAINED_STRING',('ZD040'))
    field_information['GGDM 3.0']['InformationCrvExt']['FUFI'] = ('StructuredText',('ZD040'))
    field_information['GGDM 3.0']['InformationCrvExt']['FURL'] = ('StructuredText',('ZD040'))
    field_information['GGDM 3.0']['InformationCrvExt']['GDBV'] = ('Enumeration',('ZD040'))
    field_information['GGDM 3.0']['InformationCrvExt']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['InformationCrvExt']['EnumeratedIndexValues']['GDBV']['ZD040']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['InformationCrvExt']['NLT'] = ('Enumeration',('ZD040'))
    field_information['GGDM 3.0']['InformationCrvExt']['EnumeratedIndexValues']['NLT'] = {}
    field_information['GGDM 3.0']['InformationCrvExt']['EnumeratedIndexValues']['NLT']['ZD040']  = (-999999,1,2,3,4,5,999)
    field_information['GGDM 3.0']['InformationCrvExt']['OTH'] = ('StructuredText',('ZD040'))
    field_information['GGDM 3.0']['InformationCrvExt']['UFI'] = ('StructuredText',('ZD040'))
    field_information['GGDM 3.0']['InformationCrvExt']['ZI001_SDV'] = ('StructuredText',('ZD040'))
    field_information['GGDM 3.0']['InformationCrvExt']['ZI001_SRT'] = ('Enumeration',('ZD040'))
    field_information['GGDM 3.0']['InformationCrvExt']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['InformationCrvExt']['EnumeratedIndexValues']['ZI001_SRT']['ZD040']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['InformationCrvExt']['ZI002_UFI'] = ('StructuredText',('ZD040'))
    field_information['GGDM 3.0']['InformationCrvExt']['ZI004_RCG'] = ('Enumeration',('ZD040'))
    field_information['GGDM 3.0']['InformationCrvExt']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['InformationCrvExt']['EnumeratedIndexValues']['ZI004_RCG']['ZD040']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['InformationCrvExt']['ZI005_FNA'] = ('String',('ZD040'))
    field_information['GGDM 3.0']['InformationCrvExt']['ZI005_FNA2'] = ('String',('ZD040'))
    field_information['GGDM 3.0']['InformationCrvExt']['ZI005_FNA3'] = ('String',('ZD040'))
    field_information['GGDM 3.0']['InformationCrvExt']['ZI005_GNR'] = ('Integer',('ZD040'))
    field_information['GGDM 3.0']['InformationCrvExt']['ZI005_GNR2'] = ('Integer',('ZD040'))
    field_information['GGDM 3.0']['InformationCrvExt']['ZI005_GNR3'] = ('Integer',('ZD040'))
    field_information['GGDM 3.0']['InformationCrvExt']['ZI005_GNT'] = ('Enumeration',('ZD040'))
    field_information['GGDM 3.0']['InformationCrvExt']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['InformationCrvExt']['EnumeratedIndexValues']['ZI005_GNT']['ZD040']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['InformationCrvExt']['ZI005_GNT2'] = ('Enumeration',('ZD040'))
    field_information['GGDM 3.0']['InformationCrvExt']['EnumeratedIndexValues']['ZI005_GNT2'] = {}
    field_information['GGDM 3.0']['InformationCrvExt']['EnumeratedIndexValues']['ZI005_GNT2']['ZD040']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['InformationCrvExt']['ZI005_GNT3'] = ('Enumeration',('ZD040'))
    field_information['GGDM 3.0']['InformationCrvExt']['EnumeratedIndexValues']['ZI005_GNT3'] = {}
    field_information['GGDM 3.0']['InformationCrvExt']['EnumeratedIndexValues']['ZI005_GNT3']['ZD040']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['InformationCrvExt']['ZI005_NFN'] = ('String',('ZD040'))
    field_information['GGDM 3.0']['InformationCrvExt']['ZI005_NFN2'] = ('String',('ZD040'))
    field_information['GGDM 3.0']['InformationCrvExt']['ZI005_NFN3'] = ('String',('ZD040'))
    field_information['GGDM 3.0']['InformationCrvExt']['ZI006_MEM'] = ('String',('ZD040'))
    field_information['GGDM 3.0']['InformationCrvExt']['ZI015_GCUC'] = ('Enumeration',('ZD040'))
    field_information['GGDM 3.0']['InformationCrvExt']['EnumeratedIndexValues']['ZI015_GCUC'] = {}
    field_information['GGDM 3.0']['InformationCrvExt']['EnumeratedIndexValues']['ZI015_GCUC']['ZD040']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['InformationCrvExt']['ZI015_GCUL'] = ('integer',('ZD040'))
    field_information['GGDM 3.0']['InformationCrvExt']['ZI015_GCUU'] = ('integer',('ZD040'))
    field_information['GGDM 3.0']['InformationCrvExt']['ZI020_GE4'] = ('CodeList',('ZD040'))
    field_information['GGDM 3.0']['InformationCrvExt']['ZI026_CTUC'] = ('Enumeration',('ZD040'))
    field_information['GGDM 3.0']['InformationCrvExt']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['InformationCrvExt']['EnumeratedIndexValues']['ZI026_CTUC']['ZD040']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['InformationCrvExt']['ZI026_CTUL'] = ('integer',('ZD040'))
    field_information['GGDM 3.0']['InformationCrvExt']['ZI026_CTUU'] = ('integer',('ZD040'))
    field_information['GGDM 3.0']['InformationCrvExt']['ZI031S_URI'] = ('StructuredText',('ZD040'))
    field_information['GGDM 3.0']['InformationCrvExt']['ZI039S_UFI'] = ('StructuredText',('ZD040'))
    field_information['GGDM 3.0']['InformationCrvExt']['ZSAX_RS0'] = ('CodeList',('ZD040'))
    field_information['GGDM 3.0']['InformationCrvExt']['ZSAX_RX0'] = ('StructuredText',('ZD040'))
    field_information['GGDM 3.0']['InformationCrvExt']['ZSAX_RX3'] = ('StructuredText',('ZD040'))
    field_information['GGDM 3.0']['InformationCrvExt']['ZSAX_RX4'] = ('StructuredText',('ZD040'))
    field_information['GGDM 3.0']['InformationPnt']['BEN'] = ('StructuredText',('ZD040','ZD045'))
    field_information['GGDM 3.0']['InformationPnt']['F_CODE'] = ('CONSTRAINED_STRING',('ZD040','ZD045'))
    field_information['GGDM 3.0']['InformationPnt']['FUFI'] = ('StructuredText',('ZD040','ZD045'))
    field_information['GGDM 3.0']['InformationPnt']['FURL'] = ('StructuredText',('ZD040','ZD045'))
    field_information['GGDM 3.0']['InformationPnt']['GDBV'] = ('Enumeration',('ZD040','ZD045'))
    field_information['GGDM 3.0']['InformationPnt']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['InformationPnt']['EnumeratedIndexValues']['GDBV']['ZD040']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['InformationPnt']['EnumeratedIndexValues']['GDBV']['ZD045']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['InformationPnt']['NLT'] = ('Enumeration',('ZD040'))
    field_information['GGDM 3.0']['InformationPnt']['EnumeratedIndexValues']['NLT'] = {}
    field_information['GGDM 3.0']['InformationPnt']['EnumeratedIndexValues']['NLT']['ZD040']  = (-999999,1,2,3,4,5,999)
    field_information['GGDM 3.0']['InformationPnt']['OTH'] = ('StructuredText',('ZD040','ZD045'))
    field_information['GGDM 3.0']['InformationPnt']['UFI'] = ('StructuredText',('ZD040','ZD045'))
    field_information['GGDM 3.0']['InformationPnt']['ZI001_SDV'] = ('StructuredText',('ZD040','ZD045'))
    field_information['GGDM 3.0']['InformationPnt']['ZI001_SRT'] = ('Enumeration',('ZD040','ZD045'))
    field_information['GGDM 3.0']['InformationPnt']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['InformationPnt']['EnumeratedIndexValues']['ZI001_SRT']['ZD040']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['InformationPnt']['EnumeratedIndexValues']['ZI001_SRT']['ZD045']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['InformationPnt']['ZI002_UFI'] = ('StructuredText',('ZD040','ZD045'))
    field_information['GGDM 3.0']['InformationPnt']['ZI004_RCG'] = ('Enumeration',('ZD040','ZD045'))
    field_information['GGDM 3.0']['InformationPnt']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['InformationPnt']['EnumeratedIndexValues']['ZI004_RCG']['ZD040']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['InformationPnt']['EnumeratedIndexValues']['ZI004_RCG']['ZD045']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['InformationPnt']['ZI005_FNA'] = ('String',('ZD040','ZD045'))
    field_information['GGDM 3.0']['InformationPnt']['ZI005_FNA2'] = ('String',('ZD040','ZD045'))
    field_information['GGDM 3.0']['InformationPnt']['ZI005_FNA3'] = ('String',('ZD040','ZD045'))
    field_information['GGDM 3.0']['InformationPnt']['ZI005_GNR'] = ('Integer',('ZD040','ZD045'))
    field_information['GGDM 3.0']['InformationPnt']['ZI005_GNR2'] = ('Integer',('ZD040','ZD045'))
    field_information['GGDM 3.0']['InformationPnt']['ZI005_GNR3'] = ('Integer',('ZD040','ZD045'))
    field_information['GGDM 3.0']['InformationPnt']['ZI005_GNT'] = ('Enumeration',('ZD040','ZD045'))
    field_information['GGDM 3.0']['InformationPnt']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['InformationPnt']['EnumeratedIndexValues']['ZI005_GNT']['ZD040']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['InformationPnt']['EnumeratedIndexValues']['ZI005_GNT']['ZD045']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['InformationPnt']['ZI005_GNT2'] = ('Enumeration',('ZD040','ZD045'))
    field_information['GGDM 3.0']['InformationPnt']['EnumeratedIndexValues']['ZI005_GNT2'] = {}
    field_information['GGDM 3.0']['InformationPnt']['EnumeratedIndexValues']['ZI005_GNT2']['ZD040']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['InformationPnt']['EnumeratedIndexValues']['ZI005_GNT2']['ZD045']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['InformationPnt']['ZI005_GNT3'] = ('Enumeration',('ZD040','ZD045'))
    field_information['GGDM 3.0']['InformationPnt']['EnumeratedIndexValues']['ZI005_GNT3'] = {}
    field_information['GGDM 3.0']['InformationPnt']['EnumeratedIndexValues']['ZI005_GNT3']['ZD040']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['InformationPnt']['EnumeratedIndexValues']['ZI005_GNT3']['ZD045']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['InformationPnt']['ZI005_NFN'] = ('String',('ZD040','ZD045'))
    field_information['GGDM 3.0']['InformationPnt']['ZI005_NFN2'] = ('String',('ZD040','ZD045'))
    field_information['GGDM 3.0']['InformationPnt']['ZI005_NFN3'] = ('String',('ZD040','ZD045'))
    field_information['GGDM 3.0']['InformationPnt']['ZI006_MEM'] = ('String',('ZD040','ZD045'))
    field_information['GGDM 3.0']['InformationPnt']['ZI015_GCUC'] = ('Enumeration',('ZD040','ZD045'))
    field_information['GGDM 3.0']['InformationPnt']['EnumeratedIndexValues']['ZI015_GCUC'] = {}
    field_information['GGDM 3.0']['InformationPnt']['EnumeratedIndexValues']['ZI015_GCUC']['ZD040']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['InformationPnt']['EnumeratedIndexValues']['ZI015_GCUC']['ZD045']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['InformationPnt']['ZI015_GCUL'] = ('integer',('ZD040','ZD045'))
    field_information['GGDM 3.0']['InformationPnt']['ZI015_GCUU'] = ('integer',('ZD040','ZD045'))
    field_information['GGDM 3.0']['InformationPnt']['ZI020_GE4'] = ('CodeList',('ZD040','ZD045'))
    field_information['GGDM 3.0']['InformationPnt']['ZI026_CTUC'] = ('Enumeration',('ZD040','ZD045'))
    field_information['GGDM 3.0']['InformationPnt']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['InformationPnt']['EnumeratedIndexValues']['ZI026_CTUC']['ZD040']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['InformationPnt']['EnumeratedIndexValues']['ZI026_CTUC']['ZD045']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['InformationPnt']['ZI026_CTUL'] = ('integer',('ZD040','ZD045'))
    field_information['GGDM 3.0']['InformationPnt']['ZI026_CTUU'] = ('integer',('ZD040','ZD045'))
    field_information['GGDM 3.0']['InformationPnt']['ZI031S_URI'] = ('StructuredText',('ZD040','ZD045'))
    field_information['GGDM 3.0']['InformationPnt']['ZI039S_UFI'] = ('StructuredText',('ZD040','ZD045'))
    field_information['GGDM 3.0']['InformationPnt']['ZSAX_RS0'] = ('CodeList',('ZD040','ZD045'))
    field_information['GGDM 3.0']['InformationPnt']['ZSAX_RX0'] = ('StructuredText',('ZD040','ZD045'))
    field_information['GGDM 3.0']['InformationPnt']['ZSAX_RX3'] = ('StructuredText',('ZD040','ZD045'))
    field_information['GGDM 3.0']['InformationPnt']['ZSAX_RX4'] = ('StructuredText',('ZD040','ZD045'))
    field_information['GGDM 3.0']['InformationSrf']['ARA'] = ('Real',('ZD020'))
    field_information['GGDM 3.0']['InformationSrf']['BEN'] = ('StructuredText',('ZD020','ZD045'))
    field_information['GGDM 3.0']['InformationSrf']['F_CODE'] = ('CONSTRAINED_STRING',('ZD020','ZD045'))
    field_information['GGDM 3.0']['InformationSrf']['FUFI'] = ('StructuredText',('ZD020','ZD045'))
    field_information['GGDM 3.0']['InformationSrf']['FURL'] = ('StructuredText',('ZD020','ZD045'))
    field_information['GGDM 3.0']['InformationSrf']['GDBV'] = ('Enumeration',('ZD020','ZD045'))
    field_information['GGDM 3.0']['InformationSrf']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['InformationSrf']['EnumeratedIndexValues']['GDBV']['ZD020']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['InformationSrf']['EnumeratedIndexValues']['GDBV']['ZD045']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['InformationSrf']['LZN'] = ('Real',('ZD020'))
    field_information['GGDM 3.0']['InformationSrf']['OTH'] = ('StructuredText',('ZD020','ZD045'))
    field_information['GGDM 3.0']['InformationSrf']['UFI'] = ('StructuredText',('ZD020','ZD045'))
    field_information['GGDM 3.0']['InformationSrf']['VCA'] = ('Enumeration',('ZD020'))
    field_information['GGDM 3.0']['InformationSrf']['EnumeratedIndexValues']['VCA'] = {}
    field_information['GGDM 3.0']['InformationSrf']['EnumeratedIndexValues']['VCA']['ZD020']  = (-999999,1,2,3,6,7,8,9,10,11,12,13,16,999)
    field_information['GGDM 3.0']['InformationSrf']['VCA2'] = ('Enumeration',('ZD020'))
    field_information['GGDM 3.0']['InformationSrf']['EnumeratedIndexValues']['VCA2'] = {}
    field_information['GGDM 3.0']['InformationSrf']['EnumeratedIndexValues']['VCA2']['ZD020']  = (-999999,1,2,3,6,7,8,9,10,11,12,13,16,999)
    field_information['GGDM 3.0']['InformationSrf']['VCA3'] = ('Enumeration',('ZD020'))
    field_information['GGDM 3.0']['InformationSrf']['EnumeratedIndexValues']['VCA3'] = {}
    field_information['GGDM 3.0']['InformationSrf']['EnumeratedIndexValues']['VCA3']['ZD020']  = (-999999,1,2,3,6,7,8,9,10,11,12,13,16,999)
    field_information['GGDM 3.0']['InformationSrf']['VCT'] = ('Enumeration',('ZD020'))
    field_information['GGDM 3.0']['InformationSrf']['EnumeratedIndexValues']['VCT'] = {}
    field_information['GGDM 3.0']['InformationSrf']['EnumeratedIndexValues']['VCT']['ZD020']  = (-999999,1,3,4,999)
    field_information['GGDM 3.0']['InformationSrf']['VCT2'] = ('Enumeration',('ZD020'))
    field_information['GGDM 3.0']['InformationSrf']['EnumeratedIndexValues']['VCT2'] = {}
    field_information['GGDM 3.0']['InformationSrf']['EnumeratedIndexValues']['VCT2']['ZD020']  = (-999999,1,3,4,999)
    field_information['GGDM 3.0']['InformationSrf']['VCT3'] = ('Enumeration',('ZD020'))
    field_information['GGDM 3.0']['InformationSrf']['EnumeratedIndexValues']['VCT3'] = {}
    field_information['GGDM 3.0']['InformationSrf']['EnumeratedIndexValues']['VCT3']['ZD020']  = (-999999,1,3,4,999)
    field_information['GGDM 3.0']['InformationSrf']['WID'] = ('Real',('ZD020'))
    field_information['GGDM 3.0']['InformationSrf']['ZI001_SDV'] = ('StructuredText',('ZD020','ZD045'))
    field_information['GGDM 3.0']['InformationSrf']['ZI001_SRT'] = ('Enumeration',('ZD020','ZD045'))
    field_information['GGDM 3.0']['InformationSrf']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['InformationSrf']['EnumeratedIndexValues']['ZI001_SRT']['ZD020']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['InformationSrf']['EnumeratedIndexValues']['ZI001_SRT']['ZD045']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['InformationSrf']['ZI002_UFI'] = ('StructuredText',('ZD020','ZD045'))
    field_information['GGDM 3.0']['InformationSrf']['ZI004_RCG'] = ('Enumeration',('ZD020','ZD045'))
    field_information['GGDM 3.0']['InformationSrf']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['InformationSrf']['EnumeratedIndexValues']['ZI004_RCG']['ZD020']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['InformationSrf']['EnumeratedIndexValues']['ZI004_RCG']['ZD045']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['InformationSrf']['ZI005_FNA'] = ('String',('ZD045'))
    field_information['GGDM 3.0']['InformationSrf']['ZI005_FNA2'] = ('String',('ZD045'))
    field_information['GGDM 3.0']['InformationSrf']['ZI005_FNA3'] = ('String',('ZD045'))
    field_information['GGDM 3.0']['InformationSrf']['ZI005_GNR'] = ('Integer',('ZD045'))
    field_information['GGDM 3.0']['InformationSrf']['ZI005_GNR2'] = ('Integer',('ZD045'))
    field_information['GGDM 3.0']['InformationSrf']['ZI005_GNR3'] = ('Integer',('ZD045'))
    field_information['GGDM 3.0']['InformationSrf']['ZI005_GNT'] = ('Enumeration',('ZD045'))
    field_information['GGDM 3.0']['InformationSrf']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['InformationSrf']['EnumeratedIndexValues']['ZI005_GNT']['ZD045']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['InformationSrf']['ZI005_GNT2'] = ('Enumeration',('ZD045'))
    field_information['GGDM 3.0']['InformationSrf']['EnumeratedIndexValues']['ZI005_GNT2'] = {}
    field_information['GGDM 3.0']['InformationSrf']['EnumeratedIndexValues']['ZI005_GNT2']['ZD045']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['InformationSrf']['ZI005_GNT3'] = ('Enumeration',('ZD045'))
    field_information['GGDM 3.0']['InformationSrf']['EnumeratedIndexValues']['ZI005_GNT3'] = {}
    field_information['GGDM 3.0']['InformationSrf']['EnumeratedIndexValues']['ZI005_GNT3']['ZD045']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['InformationSrf']['ZI005_NFN'] = ('String',('ZD045'))
    field_information['GGDM 3.0']['InformationSrf']['ZI005_NFN2'] = ('String',('ZD045'))
    field_information['GGDM 3.0']['InformationSrf']['ZI005_NFN3'] = ('String',('ZD045'))
    field_information['GGDM 3.0']['InformationSrf']['ZI006_MEM'] = ('String',('ZD020','ZD045'))
    field_information['GGDM 3.0']['InformationSrf']['ZI015_GCUC'] = ('Enumeration',('ZD045'))
    field_information['GGDM 3.0']['InformationSrf']['EnumeratedIndexValues']['ZI015_GCUC'] = {}
    field_information['GGDM 3.0']['InformationSrf']['EnumeratedIndexValues']['ZI015_GCUC']['ZD045']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['InformationSrf']['ZI015_GCUL'] = ('integer',('ZD045'))
    field_information['GGDM 3.0']['InformationSrf']['ZI015_GCUU'] = ('integer',('ZD045'))
    field_information['GGDM 3.0']['InformationSrf']['ZI020_GE4'] = ('CodeList',('ZD020','ZD045'))
    field_information['GGDM 3.0']['InformationSrf']['ZI026_CTUC'] = ('Enumeration',('ZD020','ZD045'))
    field_information['GGDM 3.0']['InformationSrf']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['InformationSrf']['EnumeratedIndexValues']['ZI026_CTUC']['ZD020']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['InformationSrf']['EnumeratedIndexValues']['ZI026_CTUC']['ZD045']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['InformationSrf']['ZI026_CTUL'] = ('integer',('ZD020','ZD045'))
    field_information['GGDM 3.0']['InformationSrf']['ZI026_CTUU'] = ('integer',('ZD020','ZD045'))
    field_information['GGDM 3.0']['InformationSrf']['ZI031S_URI'] = ('StructuredText',('ZD020','ZD045'))
    field_information['GGDM 3.0']['InformationSrf']['ZI039S_UFI'] = ('StructuredText',('ZD020','ZD045'))
    field_information['GGDM 3.0']['InformationSrf']['ZSAX_RS0'] = ('CodeList',('ZD020','ZD045'))
    field_information['GGDM 3.0']['InformationSrf']['ZSAX_RX0'] = ('StructuredText',('ZD020','ZD045'))
    field_information['GGDM 3.0']['InformationSrf']['ZSAX_RX3'] = ('StructuredText',('ZD020','ZD045'))
    field_information['GGDM 3.0']['InformationSrf']['ZSAX_RX4'] = ('StructuredText',('ZD020','ZD045'))
    field_information['GGDM 3.0']['InformationSrfExt']['BEN'] = ('StructuredText',('ZC040','ZD040'))
    field_information['GGDM 3.0']['InformationSrfExt']['F_CODE'] = ('CONSTRAINED_STRING',('ZC040','ZD040'))
    field_information['GGDM 3.0']['InformationSrfExt']['FUFI'] = ('StructuredText',('ZC040','ZD040'))
    field_information['GGDM 3.0']['InformationSrfExt']['FURL'] = ('StructuredText',('ZC040','ZD040'))
    field_information['GGDM 3.0']['InformationSrfExt']['GDBV'] = ('Enumeration',('ZC040','ZD040'))
    field_information['GGDM 3.0']['InformationSrfExt']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['InformationSrfExt']['EnumeratedIndexValues']['GDBV']['ZC040']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['InformationSrfExt']['EnumeratedIndexValues']['GDBV']['ZD040']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['InformationSrfExt']['NLT'] = ('Enumeration',('ZD040'))
    field_information['GGDM 3.0']['InformationSrfExt']['EnumeratedIndexValues']['NLT'] = {}
    field_information['GGDM 3.0']['InformationSrfExt']['EnumeratedIndexValues']['NLT']['ZD040']  = (-999999,1,2,3,4,5,999)
    field_information['GGDM 3.0']['InformationSrfExt']['OTH'] = ('StructuredText',('ZC040','ZD040'))
    field_information['GGDM 3.0']['InformationSrfExt']['UFI'] = ('StructuredText',('ZC040','ZD040'))
    field_information['GGDM 3.0']['InformationSrfExt']['VAVC'] = ('Enumeration',('ZC040'))
    field_information['GGDM 3.0']['InformationSrfExt']['EnumeratedIndexValues']['VAVC'] = {}
    field_information['GGDM 3.0']['InformationSrfExt']['EnumeratedIndexValues']['VAVC']['ZC040']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['InformationSrfExt']['VAVL'] = ('real',('ZC040'))
    field_information['GGDM 3.0']['InformationSrfExt']['VAVU'] = ('real',('ZC040'))
    field_information['GGDM 3.0']['InformationSrfExt']['ZI001_SDV'] = ('StructuredText',('ZC040','ZD040'))
    field_information['GGDM 3.0']['InformationSrfExt']['ZI001_SRT'] = ('Enumeration',('ZC040','ZD040'))
    field_information['GGDM 3.0']['InformationSrfExt']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['InformationSrfExt']['EnumeratedIndexValues']['ZI001_SRT']['ZC040']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['InformationSrfExt']['EnumeratedIndexValues']['ZI001_SRT']['ZD040']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['InformationSrfExt']['ZI002_UFI'] = ('StructuredText',('ZC040','ZD040'))
    field_information['GGDM 3.0']['InformationSrfExt']['ZI004_RCG'] = ('Enumeration',('ZC040','ZD040'))
    field_information['GGDM 3.0']['InformationSrfExt']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['InformationSrfExt']['EnumeratedIndexValues']['ZI004_RCG']['ZC040']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['InformationSrfExt']['EnumeratedIndexValues']['ZI004_RCG']['ZD040']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['InformationSrfExt']['ZI005_FNA'] = ('String',('ZD040'))
    field_information['GGDM 3.0']['InformationSrfExt']['ZI005_FNA2'] = ('String',('ZD040'))
    field_information['GGDM 3.0']['InformationSrfExt']['ZI005_FNA3'] = ('String',('ZD040'))
    field_information['GGDM 3.0']['InformationSrfExt']['ZI005_GNR'] = ('Integer',('ZD040'))
    field_information['GGDM 3.0']['InformationSrfExt']['ZI005_GNR2'] = ('Integer',('ZD040'))
    field_information['GGDM 3.0']['InformationSrfExt']['ZI005_GNR3'] = ('Integer',('ZD040'))
    field_information['GGDM 3.0']['InformationSrfExt']['ZI005_GNT'] = ('Enumeration',('ZD040'))
    field_information['GGDM 3.0']['InformationSrfExt']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['InformationSrfExt']['EnumeratedIndexValues']['ZI005_GNT']['ZD040']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['InformationSrfExt']['ZI005_GNT2'] = ('Enumeration',('ZD040'))
    field_information['GGDM 3.0']['InformationSrfExt']['EnumeratedIndexValues']['ZI005_GNT2'] = {}
    field_information['GGDM 3.0']['InformationSrfExt']['EnumeratedIndexValues']['ZI005_GNT2']['ZD040']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['InformationSrfExt']['ZI005_GNT3'] = ('Enumeration',('ZD040'))
    field_information['GGDM 3.0']['InformationSrfExt']['EnumeratedIndexValues']['ZI005_GNT3'] = {}
    field_information['GGDM 3.0']['InformationSrfExt']['EnumeratedIndexValues']['ZI005_GNT3']['ZD040']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['InformationSrfExt']['ZI005_NFN'] = ('String',('ZD040'))
    field_information['GGDM 3.0']['InformationSrfExt']['ZI005_NFN2'] = ('String',('ZD040'))
    field_information['GGDM 3.0']['InformationSrfExt']['ZI005_NFN3'] = ('String',('ZD040'))
    field_information['GGDM 3.0']['InformationSrfExt']['ZI006_MEM'] = ('String',('ZC040','ZD040'))
    field_information['GGDM 3.0']['InformationSrfExt']['ZI015_GCUC'] = ('Enumeration',('ZD040'))
    field_information['GGDM 3.0']['InformationSrfExt']['EnumeratedIndexValues']['ZI015_GCUC'] = {}
    field_information['GGDM 3.0']['InformationSrfExt']['EnumeratedIndexValues']['ZI015_GCUC']['ZD040']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['InformationSrfExt']['ZI015_GCUL'] = ('integer',('ZD040'))
    field_information['GGDM 3.0']['InformationSrfExt']['ZI015_GCUU'] = ('integer',('ZD040'))
    field_information['GGDM 3.0']['InformationSrfExt']['ZI020_GE4'] = ('CodeList',('ZC040','ZD040'))
    field_information['GGDM 3.0']['InformationSrfExt']['ZI026_CTUC'] = ('Enumeration',('ZC040','ZD040'))
    field_information['GGDM 3.0']['InformationSrfExt']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['InformationSrfExt']['EnumeratedIndexValues']['ZI026_CTUC']['ZC040']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['InformationSrfExt']['EnumeratedIndexValues']['ZI026_CTUC']['ZD040']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['InformationSrfExt']['ZI026_CTUL'] = ('integer',('ZC040','ZD040'))
    field_information['GGDM 3.0']['InformationSrfExt']['ZI026_CTUU'] = ('integer',('ZC040','ZD040'))
    field_information['GGDM 3.0']['InformationSrfExt']['ZI031S_URI'] = ('StructuredText',('ZC040','ZD040'))
    field_information['GGDM 3.0']['InformationSrfExt']['ZI039S_UFI'] = ('StructuredText',('ZC040','ZD040'))
    field_information['GGDM 3.0']['InformationSrfExt']['ZSAX_RS0'] = ('CodeList',('ZC040','ZD040'))
    field_information['GGDM 3.0']['InformationSrfExt']['ZSAX_RX0'] = ('StructuredText',('ZC040','ZD040'))
    field_information['GGDM 3.0']['InformationSrfExt']['ZSAX_RX3'] = ('StructuredText',('ZC040','ZD040'))
    field_information['GGDM 3.0']['InformationSrfExt']['ZSAX_RX4'] = ('StructuredText',('ZC040','ZD040'))
    field_information['GGDM 3.0']['MetadataSrf']['AHA'] = ('Real',('ZI039'))
    field_information['GGDM 3.0']['MetadataSrf']['AVA'] = ('Real',('ZI039'))
    field_information['GGDM 3.0']['MetadataSrf']['DQS'] = ('String',('ZI039'))
    field_information['GGDM 3.0']['MetadataSrf']['EQS'] = ('Integer',('ZI039'))
    field_information['GGDM 3.0']['MetadataSrf']['EVA'] = ('Real',('ZI039'))
    field_information['GGDM 3.0']['MetadataSrf']['F_CODE'] = ('CONSTRAINED_STRING',('ZI039'))
    field_information['GGDM 3.0']['MetadataSrf']['HVA'] = ('Real',('ZI039'))
    field_information['GGDM 3.0']['MetadataSrf']['MDE'] = ('StructuredText',('ZI039'))
    field_information['GGDM 3.0']['MetadataSrf']['OTH'] = ('StructuredText',('ZI039'))
    field_information['GGDM 3.0']['MetadataSrf']['RCG'] = ('Enumeration',('ZI039'))
    field_information['GGDM 3.0']['MetadataSrf']['EnumeratedIndexValues']['RCG'] = {}
    field_information['GGDM 3.0']['MetadataSrf']['EnumeratedIndexValues']['RCG']['ZI039']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['MetadataSrf']['SCVN'] = ('StructuredText',('ZI039'))
    field_information['GGDM 3.0']['MetadataSrf']['UFI'] = ('StructuredText',('ZI039'))
    field_information['GGDM 3.0']['MetadataSrf']['ZI001_SDP'] = ('String',('ZI039'))
    # field_information['GGDM 3.0']['MetadataSrf']['ZI001_SDV'] = ('StructuredText',('ZI039'))
    field_information['GGDM 3.0']['MetadataSrf']['ZI001_SPS'] = ('Boolean',('ZI039'))
    # field_information['GGDM 3.0']['MetadataSrf']['ZI001_SRT'] = ('Enumeration',('ZI039'))
    # field_information['GGDM 3.0']['MetadataSrf']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    # field_information['GGDM 3.0']['MetadataSrf']['EnumeratedIndexValues']['ZI001_SRT']['ZI039']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['MetadataSrf']['ZI001_VSC'] = ('Enumeration',('ZI039'))
    field_information['GGDM 3.0']['MetadataSrf']['EnumeratedIndexValues']['ZI001_VSC'] = {}
    field_information['GGDM 3.0']['MetadataSrf']['EnumeratedIndexValues']['ZI001_VSC']['ZI039']  = (-999999,1,2,3,4,5,6,998,999)
    field_information['GGDM 3.0']['MetadataSrf']['ZI001_VSD'] = ('StructuredText',('ZI039'))
    field_information['GGDM 3.0']['MetadataSrf']['ZI001_VSN'] = ('String',('ZI039'))
    field_information['GGDM 3.0']['MetadataSrf']['ZI004_PRE'] = ('String',('ZI039'))
    field_information['GGDM 3.0']['ENTITY_COLLECTION_METADATA_T']['AHA'] = ('Real',('ZI039'))
    field_information['GGDM 3.0']['ENTITY_COLLECTION_METADATA_T']['AVA'] = ('Real',('ZI039'))
    field_information['GGDM 3.0']['ENTITY_COLLECTION_METADATA_T']['DQS'] = ('String',('ZI039'))
    field_information['GGDM 3.0']['ENTITY_COLLECTION_METADATA_T']['EQS'] = ('Integer',('ZI039'))
    field_information['GGDM 3.0']['ENTITY_COLLECTION_METADATA_T']['EVA'] = ('Real',('ZI039'))
    field_information['GGDM 3.0']['ENTITY_COLLECTION_METADATA_T']['F_CODE'] = ('CONSTRAINED_STRING',('ZI039'))
    field_information['GGDM 3.0']['ENTITY_COLLECTION_METADATA_T']['HVA'] = ('Real',('ZI039'))
    field_information['GGDM 3.0']['ENTITY_COLLECTION_METADATA_T']['MDE'] = ('StructuredText',('ZI039'))
    field_information['GGDM 3.0']['ENTITY_COLLECTION_METADATA_T']['OTH'] = ('StructuredText',('ZI039'))
    field_information['GGDM 3.0']['ENTITY_COLLECTION_METADATA_T']['RCG'] = ('Enumeration',('ZI039'))
    field_information['GGDM 3.0']['ENTITY_COLLECTION_METADATA_T']['EnumeratedIndexValues']['RCG'] = {}
    field_information['GGDM 3.0']['ENTITY_COLLECTION_METADATA_T']['EnumeratedIndexValues']['RCG']['ZI039']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['ENTITY_COLLECTION_METADATA_T']['SCVN'] = ('StructuredText',('ZI039'))
    field_information['GGDM 3.0']['ENTITY_COLLECTION_METADATA_T']['UFI'] = ('StructuredText',('ZI039'))
    field_information['GGDM 3.0']['ENTITY_COLLECTION_METADATA_T']['ZI001_SDP'] = ('String',('ZI039'))
    # field_information['GGDM 3.0']['ENTITY_COLLECTION_METADATA_T']['ZI001_SDV'] = ('StructuredText',('ZI039'))
    field_information['GGDM 3.0']['ENTITY_COLLECTION_METADATA_T']['ZI001_SPS'] = ('Boolean',('ZI039'))
    # field_information['GGDM 3.0']['ENTITY_COLLECTION_METADATA_T']['ZI001_SRT'] = ('Enumeration',('ZI039'))
    # field_information['GGDM 3.0']['ENTITY_COLLECTION_METADATA_T']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    # field_information['GGDM 3.0']['ENTITY_COLLECTION_METADATA_T']['EnumeratedIndexValues']['ZI001_SRT']['ZI039']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['ENTITY_COLLECTION_METADATA_T']['ZI001_VSC'] = ('Enumeration',('ZI039'))
    field_information['GGDM 3.0']['ENTITY_COLLECTION_METADATA_T']['EnumeratedIndexValues']['ZI001_VSC'] = {}
    field_information['GGDM 3.0']['ENTITY_COLLECTION_METADATA_T']['EnumeratedIndexValues']['ZI001_VSC']['ZI039']  = (-999999,1,2,3,4,5,6,998,999)
    field_information['GGDM 3.0']['ENTITY_COLLECTION_METADATA_T']['ZI001_VSD'] = ('StructuredText',('ZI039'))
    field_information['GGDM 3.0']['ENTITY_COLLECTION_METADATA_T']['ZI001_VSN'] = ('String',('ZI039'))
    field_information['GGDM 3.0']['ENTITY_COLLECTION_METADATA_T']['ZI004_PRE'] = ('String',('ZI039'))
    field_information['GGDM 3.0']['MilitaryCrv']['ARA'] = ('Real',('AH025','AL060','GB050'))
    field_information['GGDM 3.0']['MilitaryCrv']['BEN'] = ('StructuredText',('AH025','AL060','GB050','SU030'))
    field_information['GGDM 3.0']['MilitaryCrv']['CNCP'] = ('StructuredText',('AH025','AL060','GB050'))
    field_information['GGDM 3.0']['MilitaryCrv']['COS'] = ('Enumeration',('AH025','AL060','GB050'))
    field_information['GGDM 3.0']['MilitaryCrv']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['MilitaryCrv']['EnumeratedIndexValues']['COS']['AH025']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['MilitaryCrv']['EnumeratedIndexValues']['COS']['AL060']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['MilitaryCrv']['EnumeratedIndexValues']['COS']['GB050']  = (-999999,4,6,8,9,13,14)
    field_information['GGDM 3.0']['MilitaryCrv']['DZP'] = ('Real',('AH025'))
    field_information['GGDM 3.0']['MilitaryCrv']['EET'] = ('Enumeration',('AH025'))
    field_information['GGDM 3.0']['MilitaryCrv']['EnumeratedIndexValues']['EET'] = {}
    field_information['GGDM 3.0']['MilitaryCrv']['EnumeratedIndexValues']['EET']['AH025']  = (-999999,1,2,3,4,5,999)
    field_information['GGDM 3.0']['MilitaryCrv']['F_CODE'] = ('CONSTRAINED_STRING',('AH025','AL060','GB050','SU030'))
    field_information['GGDM 3.0']['MilitaryCrv']['FUFI'] = ('StructuredText',('AH025','AL060','GB050','SU030'))
    field_information['GGDM 3.0']['MilitaryCrv']['FURL'] = ('StructuredText',('AH025','AL060','GB050','SU030'))
    field_information['GGDM 3.0']['MilitaryCrv']['GDBV'] = ('Enumeration',('AH025','AL060','GB050','SU030'))
    field_information['GGDM 3.0']['MilitaryCrv']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['MilitaryCrv']['EnumeratedIndexValues']['GDBV']['AH025']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['MilitaryCrv']['EnumeratedIndexValues']['GDBV']['AL060']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['MilitaryCrv']['EnumeratedIndexValues']['GDBV']['GB050']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['MilitaryCrv']['EnumeratedIndexValues']['GDBV']['SU030']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['MilitaryCrv']['HGT'] = ('Real',('AL060','GB050'))
    field_information['GGDM 3.0']['MilitaryCrv']['HST'] = ('Enumeration',('AH025'))
    field_information['GGDM 3.0']['MilitaryCrv']['EnumeratedIndexValues']['HST'] = {}
    field_information['GGDM 3.0']['MilitaryCrv']['EnumeratedIndexValues']['HST']['AH025']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['MilitaryCrv']['HST2'] = ('Enumeration',('AH025'))
    field_information['GGDM 3.0']['MilitaryCrv']['EnumeratedIndexValues']['HST2'] = {}
    field_information['GGDM 3.0']['MilitaryCrv']['EnumeratedIndexValues']['HST2']['AH025']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['MilitaryCrv']['HST3'] = ('Enumeration',('AH025'))
    field_information['GGDM 3.0']['MilitaryCrv']['EnumeratedIndexValues']['HST3'] = {}
    field_information['GGDM 3.0']['MilitaryCrv']['EnumeratedIndexValues']['HST3']['AH025']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['MilitaryCrv']['LMC'] = ('Boolean',('AH025'))
    field_information['GGDM 3.0']['MilitaryCrv']['LNU'] = ('Real',('GB050'))
    field_information['GGDM 3.0']['MilitaryCrv']['LZN'] = ('Real',('AH025','AL060','GB050','SU030'))
    field_information['GGDM 3.0']['MilitaryCrv']['MCC'] = ('Enumeration',('AL060','GB050'))
    field_information['GGDM 3.0']['MilitaryCrv']['EnumeratedIndexValues']['MCC'] = {}
    field_information['GGDM 3.0']['MilitaryCrv']['EnumeratedIndexValues']['MCC']['AL060']  = (-999999,21,107,108,999)
    field_information['GGDM 3.0']['MilitaryCrv']['EnumeratedIndexValues']['MCC']['GB050']  = (-999999,5,8,9,21,62,64,83,86,88,104,117,999)
    field_information['GGDM 3.0']['MilitaryCrv']['MCC2'] = ('Enumeration',('AL060','GB050'))
    field_information['GGDM 3.0']['MilitaryCrv']['EnumeratedIndexValues']['MCC2'] = {}
    field_information['GGDM 3.0']['MilitaryCrv']['EnumeratedIndexValues']['MCC2']['AL060']  = (-999999,21,107,108,999)
    field_information['GGDM 3.0']['MilitaryCrv']['EnumeratedIndexValues']['MCC2']['GB050']  = (-999999,5,8,9,21,62,64,83,86,88,104,117,999)
    field_information['GGDM 3.0']['MilitaryCrv']['MCC3'] = ('Enumeration',('AL060','GB050'))
    field_information['GGDM 3.0']['MilitaryCrv']['EnumeratedIndexValues']['MCC3'] = {}
    field_information['GGDM 3.0']['MilitaryCrv']['EnumeratedIndexValues']['MCC3']['AL060']  = (-999999,21,107,108,999)
    field_information['GGDM 3.0']['MilitaryCrv']['EnumeratedIndexValues']['MCC3']['GB050']  = (-999999,5,8,9,21,62,64,83,86,88,104,117,999)
    field_information['GGDM 3.0']['MilitaryCrv']['OTH'] = ('StructuredText',('AH025','AL060','GB050','SU030'))
    field_information['GGDM 3.0']['MilitaryCrv']['PCF'] = ('Enumeration',('AH025','AL060','GB050'))
    field_information['GGDM 3.0']['MilitaryCrv']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['MilitaryCrv']['EnumeratedIndexValues']['PCF']['AH025']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['MilitaryCrv']['EnumeratedIndexValues']['PCF']['AL060']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['MilitaryCrv']['EnumeratedIndexValues']['PCF']['GB050']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['MilitaryCrv']['PFHC'] = ('Enumeration',('AH025'))
    field_information['GGDM 3.0']['MilitaryCrv']['EnumeratedIndexValues']['PFHC'] = {}
    field_information['GGDM 3.0']['MilitaryCrv']['EnumeratedIndexValues']['PFHC']['AH025']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['MilitaryCrv']['PFHL'] = ('real',('AH025'))
    field_information['GGDM 3.0']['MilitaryCrv']['PFHU'] = ('real',('AH025'))
    field_information['GGDM 3.0']['MilitaryCrv']['UFI'] = ('StructuredText',('AH025','AL060','GB050','SU030'))
    field_information['GGDM 3.0']['MilitaryCrv']['VOI'] = ('StructuredText',('SU030'))
    field_information['GGDM 3.0']['MilitaryCrv']['WD3'] = ('Real',('AH025'))
    field_information['GGDM 3.0']['MilitaryCrv']['WID'] = ('Real',('AH025','AL060','GB050'))
    field_information['GGDM 3.0']['MilitaryCrv']['YSU'] = ('Enumeration',('AH025'))
    field_information['GGDM 3.0']['MilitaryCrv']['EnumeratedIndexValues']['YSU'] = {}
    field_information['GGDM 3.0']['MilitaryCrv']['EnumeratedIndexValues']['YSU']['AH025']  = (-999999,1,2,3,4,5,7,8,9,999)
    field_information['GGDM 3.0']['MilitaryCrv']['ZI001_SDV'] = ('StructuredText',('AH025','AL060','GB050','SU030'))
    field_information['GGDM 3.0']['MilitaryCrv']['ZI001_SRT'] = ('Enumeration',('AH025','AL060','GB050','SU030'))
    field_information['GGDM 3.0']['MilitaryCrv']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['MilitaryCrv']['EnumeratedIndexValues']['ZI001_SRT']['AH025']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['MilitaryCrv']['EnumeratedIndexValues']['ZI001_SRT']['AL060']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['MilitaryCrv']['EnumeratedIndexValues']['ZI001_SRT']['GB050']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['MilitaryCrv']['EnumeratedIndexValues']['ZI001_SRT']['SU030']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['MilitaryCrv']['ZI002_UFI'] = ('StructuredText',('AH025','AL060','GB050','SU030'))
    field_information['GGDM 3.0']['MilitaryCrv']['ZI004_RCG'] = ('Enumeration',('AH025','AL060','GB050','SU030'))
    field_information['GGDM 3.0']['MilitaryCrv']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['MilitaryCrv']['EnumeratedIndexValues']['ZI004_RCG']['AH025']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['MilitaryCrv']['EnumeratedIndexValues']['ZI004_RCG']['AL060']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['MilitaryCrv']['EnumeratedIndexValues']['ZI004_RCG']['GB050']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['MilitaryCrv']['EnumeratedIndexValues']['ZI004_RCG']['SU030']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['MilitaryCrv']['ZI005_FNA'] = ('String',('AH025','GB050','SU030'))
    field_information['GGDM 3.0']['MilitaryCrv']['ZI005_GNT'] = ('Enumeration',('AH025','GB050','SU030'))
    field_information['GGDM 3.0']['MilitaryCrv']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['MilitaryCrv']['EnumeratedIndexValues']['ZI005_GNT']['AH025']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['MilitaryCrv']['EnumeratedIndexValues']['ZI005_GNT']['GB050']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['MilitaryCrv']['EnumeratedIndexValues']['ZI005_GNT']['SU030']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['MilitaryCrv']['ZI005_NFN'] = ('String',('AH025','GB050','SU030'))
    field_information['GGDM 3.0']['MilitaryCrv']['ZI006_MEM'] = ('String',('AH025','AL060','GB050','SU030'))
    field_information['GGDM 3.0']['MilitaryCrv']['ZI020_GE4'] = ('CodeList',('AH025','AL060','GB050','SU030'))
    field_information['GGDM 3.0']['MilitaryCrv']['ZI026_CTUC'] = ('Enumeration',('AH025','AL060','GB050','SU030'))
    field_information['GGDM 3.0']['MilitaryCrv']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['MilitaryCrv']['EnumeratedIndexValues']['ZI026_CTUC']['AH025']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['MilitaryCrv']['EnumeratedIndexValues']['ZI026_CTUC']['AL060']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['MilitaryCrv']['EnumeratedIndexValues']['ZI026_CTUC']['GB050']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['MilitaryCrv']['EnumeratedIndexValues']['ZI026_CTUC']['SU030']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['MilitaryCrv']['ZI026_CTUL'] = ('integer',('AH025','AL060','GB050','SU030'))
    field_information['GGDM 3.0']['MilitaryCrv']['ZI026_CTUU'] = ('integer',('AH025','AL060','GB050','SU030'))
    field_information['GGDM 3.0']['MilitaryCrv']['ZI031S_URI'] = ('StructuredText',('AH025','AL060','GB050','SU030'))
    field_information['GGDM 3.0']['MilitaryCrv']['ZI039S_UFI'] = ('StructuredText',('AH025','AL060','GB050','SU030'))
    field_information['GGDM 3.0']['MilitaryCrv']['ZSAX_RS0'] = ('CodeList',('AH025','AL060','GB050','SU030'))
    field_information['GGDM 3.0']['MilitaryCrv']['ZSAX_RX0'] = ('StructuredText',('AH025','AL060','GB050','SU030'))
    field_information['GGDM 3.0']['MilitaryCrv']['ZSAX_RX3'] = ('StructuredText',('AH025','AL060','GB050','SU030'))
    field_information['GGDM 3.0']['MilitaryCrv']['ZSAX_RX4'] = ('StructuredText',('AH025','AL060','GB050','SU030'))
    field_information['GGDM 3.0']['MilitaryCrv']['ZVH'] = ('Real',('GB050'))
    field_information['GGDM 3.0']['MilitaryCrvExt']['BEN'] = ('StructuredText',('STBM1'))
    field_information['GGDM 3.0']['MilitaryCrvExt']['CAA'] = ('Enumeration',('STBM1'))
    field_information['GGDM 3.0']['MilitaryCrvExt']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['MilitaryCrvExt']['EnumeratedIndexValues']['CAA']['STBM1']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['MilitaryCrvExt']['DSP'] = ('Enumeration',('STBM1'))
    field_information['GGDM 3.0']['MilitaryCrvExt']['EnumeratedIndexValues']['DSP'] = {}
    field_information['GGDM 3.0']['MilitaryCrvExt']['EnumeratedIndexValues']['DSP']['STBM1']  = (-999999,1,2,3,4)
    field_information['GGDM 3.0']['MilitaryCrvExt']['F_CODE'] = ('CONSTRAINED_STRING',('STBM1'))
    field_information['GGDM 3.0']['MilitaryCrvExt']['FUFI'] = ('StructuredText',('STBM1'))
    field_information['GGDM 3.0']['MilitaryCrvExt']['FURL'] = ('StructuredText',('STBM1'))
    field_information['GGDM 3.0']['MilitaryCrvExt']['GDBV'] = ('Enumeration',('STBM1'))
    field_information['GGDM 3.0']['MilitaryCrvExt']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['MilitaryCrvExt']['EnumeratedIndexValues']['GDBV']['STBM1']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['MilitaryCrvExt']['LZN'] = ('Real',('STBM1'))
    field_information['GGDM 3.0']['MilitaryCrvExt']['MLUS'] = ('Enumeration',('STBM1'))
    field_information['GGDM 3.0']['MilitaryCrvExt']['EnumeratedIndexValues']['MLUS'] = {}
    field_information['GGDM 3.0']['MilitaryCrvExt']['EnumeratedIndexValues']['MLUS']['STBM1']  = (-999999,11,12,13,14,15,16,17,18,19,999)
    field_information['GGDM 3.0']['MilitaryCrvExt']['OTH'] = ('StructuredText',('STBM1'))
    field_information['GGDM 3.0']['MilitaryCrvExt']['UFI'] = ('StructuredText',('STBM1'))
    field_information['GGDM 3.0']['MilitaryCrvExt']['ZI001_SDV'] = ('StructuredText',('STBM1'))
    field_information['GGDM 3.0']['MilitaryCrvExt']['ZI001_SRT'] = ('Enumeration',('STBM1'))
    field_information['GGDM 3.0']['MilitaryCrvExt']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['MilitaryCrvExt']['EnumeratedIndexValues']['ZI001_SRT']['STBM1']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['MilitaryCrvExt']['ZI002_UFI'] = ('StructuredText',('STBM1'))
    field_information['GGDM 3.0']['MilitaryCrvExt']['ZI004_RCG'] = ('Enumeration',('STBM1'))
    field_information['GGDM 3.0']['MilitaryCrvExt']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['MilitaryCrvExt']['EnumeratedIndexValues']['ZI004_RCG']['STBM1']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['MilitaryCrvExt']['ZI005_FNAA'] = ('String',('STBM1'))
    field_information['GGDM 3.0']['MilitaryCrvExt']['ZI005_FNAB'] = ('String',('STBM1'))
    field_information['GGDM 3.0']['MilitaryCrvExt']['ZI005_GNTA'] = ('Enumeration',('STBM1'))
    field_information['GGDM 3.0']['MilitaryCrvExt']['EnumeratedIndexValues']['ZI005_GNTA'] = {}
    field_information['GGDM 3.0']['MilitaryCrvExt']['EnumeratedIndexValues']['ZI005_GNTA']['STBM1']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['MilitaryCrvExt']['ZI005_GNTB'] = ('Enumeration',('STBM1'))
    field_information['GGDM 3.0']['MilitaryCrvExt']['EnumeratedIndexValues']['ZI005_GNTB'] = {}
    field_information['GGDM 3.0']['MilitaryCrvExt']['EnumeratedIndexValues']['ZI005_GNTB']['STBM1']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['MilitaryCrvExt']['ZI005_NFNA'] = ('String',('STBM1'))
    field_information['GGDM 3.0']['MilitaryCrvExt']['ZI005_NFNB'] = ('String',('STBM1'))
    field_information['GGDM 3.0']['MilitaryCrvExt']['ZI006_MEM'] = ('String',('STBM1'))
    field_information['GGDM 3.0']['MilitaryCrvExt']['ZI020_FI2A'] = ('String',('STBM1'))
    field_information['GGDM 3.0']['MilitaryCrvExt']['ZI020_FI2B'] = ('String',('STBM1'))
    field_information['GGDM 3.0']['MilitaryCrvExt']['ZI020_GE4'] = ('CodeList',('STBM1'))
    field_information['GGDM 3.0']['MilitaryCrvExt']['ZI020_GE4A'] = ('CodeList',('STBM1'))
    field_information['GGDM 3.0']['MilitaryCrvExt']['ZI020_GE4B'] = ('CodeList',('STBM1'))
    field_information['GGDM 3.0']['MilitaryCrvExt']['ZI026_CTUC'] = ('Enumeration',('STBM1'))
    field_information['GGDM 3.0']['MilitaryCrvExt']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['MilitaryCrvExt']['EnumeratedIndexValues']['ZI026_CTUC']['STBM1']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['MilitaryCrvExt']['ZI026_CTUL'] = ('integer',('STBM1'))
    field_information['GGDM 3.0']['MilitaryCrvExt']['ZI026_CTUU'] = ('integer',('STBM1'))
    field_information['GGDM 3.0']['MilitaryCrvExt']['ZI031S_URI'] = ('StructuredText',('STBM1'))
    field_information['GGDM 3.0']['MilitaryCrvExt']['ZI039S_UFI'] = ('StructuredText',('STBM1'))
    field_information['GGDM 3.0']['MilitaryCrvExt']['ZSAX_RS0'] = ('CodeList',('STBM1'))
    field_information['GGDM 3.0']['MilitaryCrvExt']['ZSAX_RX0'] = ('StructuredText',('STBM1'))
    field_information['GGDM 3.0']['MilitaryCrvExt']['ZSAX_RX3'] = ('StructuredText',('STBM1'))
    field_information['GGDM 3.0']['MilitaryCrvExt']['ZSAX_RX4'] = ('StructuredText',('STBM1'))
    field_information['GGDM 3.0']['MilitaryPnt']['ADR'] = ('String',('AH055','AL375','AL376','AM060','FA165','SU001'))
    field_information['GGDM 3.0']['MilitaryPnt']['AOO'] = ('Real',('AH055','AL120','AL375','AL376','AM060','FA015','FA165','SU001'))
    field_information['GGDM 3.0']['MilitaryPnt']['ARA'] = ('Real',('AH055','AH060','AL120','AL375','AL376','AM060','FA015','FA165','SU001'))
    field_information['GGDM 3.0']['MilitaryPnt']['ATB'] = ('Boolean',('AH055'))
    field_information['GGDM 3.0']['MilitaryPnt']['AWP'] = ('Boolean',('AH055','AL375'))
    field_information['GGDM 3.0']['MilitaryPnt']['BEN'] = ('StructuredText',('AH055','AH060','AL120','AL375','AL376','AM060','FA015','FA165','SU001'))
    field_information['GGDM 3.0']['MilitaryPnt']['BNF'] = ('Integer',('AH055','AL375'))
    field_information['GGDM 3.0']['MilitaryPnt']['CAA'] = ('Enumeration',('AH055','AH060','AL120','AL375','AL376','AM060','FA015','FA165','SU001'))
    field_information['GGDM 3.0']['MilitaryPnt']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['MilitaryPnt']['EnumeratedIndexValues']['CAA']['AH055']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['MilitaryPnt']['EnumeratedIndexValues']['CAA']['AH060']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['MilitaryPnt']['EnumeratedIndexValues']['CAA']['AL120']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['MilitaryPnt']['EnumeratedIndexValues']['CAA']['AL375']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['MilitaryPnt']['EnumeratedIndexValues']['CAA']['AL376']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['MilitaryPnt']['EnumeratedIndexValues']['CAA']['AM060']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['MilitaryPnt']['EnumeratedIndexValues']['CAA']['FA015']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['MilitaryPnt']['EnumeratedIndexValues']['CAA']['FA165']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['MilitaryPnt']['EnumeratedIndexValues']['CAA']['SU001']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['MilitaryPnt']['CNCP'] = ('StructuredText',('AH055','AH060','AL120','AL375','AL376','AM060','FA015','FA165','SU001'))
    field_information['GGDM 3.0']['MilitaryPnt']['COS'] = ('Enumeration',('AH055','AH060','AL120','AL375','AL376','AM060','FA015','FA165','SU001'))
    field_information['GGDM 3.0']['MilitaryPnt']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['MilitaryPnt']['EnumeratedIndexValues']['COS']['AH055']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['MilitaryPnt']['EnumeratedIndexValues']['COS']['AH060']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['MilitaryPnt']['EnumeratedIndexValues']['COS']['AL120']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['MilitaryPnt']['EnumeratedIndexValues']['COS']['AL375']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['MilitaryPnt']['EnumeratedIndexValues']['COS']['AL376']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['MilitaryPnt']['EnumeratedIndexValues']['COS']['AM060']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['MilitaryPnt']['EnumeratedIndexValues']['COS']['FA015']  = (-999999,2,4,6,9,13,14)
    field_information['GGDM 3.0']['MilitaryPnt']['EnumeratedIndexValues']['COS']['FA165']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['MilitaryPnt']['EnumeratedIndexValues']['COS']['SU001']  = (-999999,2,4,6,9,13,14)
    field_information['GGDM 3.0']['MilitaryPnt']['DZP'] = ('Real',('AH060'))
    field_information['GGDM 3.0']['MilitaryPnt']['F_CODE'] = ('CONSTRAINED_STRING',('AH055','AH060','AL120','AL375','AL376','AM060','FA015','FA165','SU001'))
    field_information['GGDM 3.0']['MilitaryPnt']['FFN'] = ('Enumeration',('AH055','AL375','AL376','FA015','FA165'))
    field_information['GGDM 3.0']['MilitaryPnt']['EnumeratedIndexValues']['FFN'] = {}
    field_information['GGDM 3.0']['MilitaryPnt']['EnumeratedIndexValues']['FFN']['AH055']  = (-999999,2,3,9,14,15,19,20,21,27,30,35,40,50,60,70,83,87,91,95,99,100,101,102,103,104,105,106,107,110,111,112,113,114,115,116,118,119,120,121,122,123,124,125,129,130,140,150,155,160,161,165,171,181,190,191,192,195,210,221,225,230,231,232,233,234,235,236,237,240,241,242,243,250,251,255,257,260,270,272,280,289,290,301,304,305,306,310,320,321,322,323,324,325,330,331,332,333,334,340,341,342,343,350,351,352,355,356,360,361,362,363,370,372,382,383,385,440,459,460,464,465,466,470,473,474,475,476,477,478,480,481,482,483,484,486,487,488,489,490,491,494,495,496,497,500,501,505,507,508,510,511,512,513,520,525,529,530,535,536,537,538,539,540,541,545,548,549,550,551,552,553,554,555,556,557,558,559,563,570,572,573,574,578,579,580,582,594,601,604,610,612,614,615,616,617,620,621,622,625,626,632,633,640,642,643,651,662,663,671,680,681,691,696,701,706,711,714,717,720,721,722,725,730,741,752,757,760,761,770,775,780,781,791,795,801,807,808,809,810,811,812,813,814,815,817,818,819,821,822,825,826,827,828,829,830,831,832,833,835,836,837,838,839,840,841,842,843,844,845,846,847,848,850,851,852,855,857,860,861,862,863,864,865,866,871,873,875,881,882,883,884,885,887,888,890,891,892,893,894,895,900,902,905,906,907,909,912,913,914,919,921,922,923,930,931,950,954,955,961,962,963,964,965,966,967,970,980,999)
    field_information['GGDM 3.0']['MilitaryPnt']['EnumeratedIndexValues']['FFN']['AL375']  = (-999999,551,563,570,572,578,809,810,811,815,822,835,836,843,847,905,922,930,970,999)
    field_information['GGDM 3.0']['MilitaryPnt']['EnumeratedIndexValues']['FFN']['AL376']  = (-999999,551,563,570,572,578,809,810,811,815,822,835,836,843,847,905,922,930,970,999)
    field_information['GGDM 3.0']['MilitaryPnt']['EnumeratedIndexValues']['FFN']['FA015']  = (-999999,835,841,921,999)
    field_information['GGDM 3.0']['MilitaryPnt']['EnumeratedIndexValues']['FFN']['FA165']  = (-999999,811,831,832,835,839,841,845,846,847,848,857,888,912,914,954,970,999)
    field_information['GGDM 3.0']['MilitaryPnt']['FFN2'] = ('Enumeration',('AH055','AL375','AL376','FA015','FA165'))
    field_information['GGDM 3.0']['MilitaryPnt']['EnumeratedIndexValues']['FFN2'] = {}
    field_information['GGDM 3.0']['MilitaryPnt']['EnumeratedIndexValues']['FFN2']['AH055']  = (-999999,2,3,9,14,15,19,20,21,27,30,35,40,50,60,70,83,87,91,95,99,100,101,102,103,104,105,106,107,110,111,112,113,114,115,116,118,119,120,121,122,123,124,125,129,130,140,150,155,160,161,165,171,181,190,191,192,195,210,221,225,230,231,232,233,234,235,236,237,240,241,242,243,250,251,255,257,260,270,272,280,289,290,301,304,305,306,310,320,321,322,323,324,325,330,331,332,333,334,340,341,342,343,350,351,352,355,356,360,361,362,363,370,372,382,383,385,440,459,460,464,465,466,470,473,474,475,476,477,478,480,481,482,483,484,486,487,488,489,490,491,494,495,496,497,500,501,505,507,508,510,511,512,513,520,525,529,530,535,536,537,538,539,540,541,545,548,549,550,551,552,553,554,555,556,557,558,559,563,570,572,573,574,578,579,580,582,594,601,604,610,612,614,615,616,617,620,621,622,625,626,632,633,640,642,643,651,662,663,671,680,681,691,696,701,706,711,714,717,720,721,722,725,730,741,752,757,760,761,770,775,780,781,791,795,801,807,808,809,810,811,812,813,814,815,817,818,819,821,822,825,826,827,828,829,830,831,832,833,835,836,837,838,839,840,841,842,843,844,845,846,847,848,850,851,852,855,857,860,861,862,863,864,865,866,871,873,875,881,882,883,884,885,887,888,890,891,892,893,894,895,900,902,905,906,907,909,912,913,914,919,921,922,923,930,931,950,954,955,961,962,963,964,965,966,967,970,980,999)
    field_information['GGDM 3.0']['MilitaryPnt']['EnumeratedIndexValues']['FFN2']['AL375']  = (-999999,551,563,570,572,578,809,810,811,815,822,835,836,843,847,905,922,930,970,999)
    field_information['GGDM 3.0']['MilitaryPnt']['EnumeratedIndexValues']['FFN2']['AL376']  = (-999999,551,563,570,572,578,809,810,811,815,822,835,836,843,847,905,922,930,970,999)
    field_information['GGDM 3.0']['MilitaryPnt']['EnumeratedIndexValues']['FFN2']['FA015']  = (-999999,835,841,921,999)
    field_information['GGDM 3.0']['MilitaryPnt']['EnumeratedIndexValues']['FFN2']['FA165']  = (-999999,811,831,832,835,839,841,845,846,847,848,857,888,912,914,954,970,999)
    field_information['GGDM 3.0']['MilitaryPnt']['FFN3'] = ('Enumeration',('AH055','AL375','AL376','FA015','FA165'))
    field_information['GGDM 3.0']['MilitaryPnt']['EnumeratedIndexValues']['FFN3'] = {}
    field_information['GGDM 3.0']['MilitaryPnt']['EnumeratedIndexValues']['FFN3']['AH055']  = (-999999,2,3,9,14,15,19,20,21,27,30,35,40,50,60,70,83,87,91,95,99,100,101,102,103,104,105,106,107,110,111,112,113,114,115,116,118,119,120,121,122,123,124,125,129,130,140,150,155,160,161,165,171,181,190,191,192,195,210,221,225,230,231,232,233,234,235,236,237,240,241,242,243,250,251,255,257,260,270,272,280,289,290,301,304,305,306,310,320,321,322,323,324,325,330,331,332,333,334,340,341,342,343,350,351,352,355,356,360,361,362,363,370,372,382,383,385,440,459,460,464,465,466,470,473,474,475,476,477,478,480,481,482,483,484,486,487,488,489,490,491,494,495,496,497,500,501,505,507,508,510,511,512,513,520,525,529,530,535,536,537,538,539,540,541,545,548,549,550,551,552,553,554,555,556,557,558,559,563,570,572,573,574,578,579,580,582,594,601,604,610,612,614,615,616,617,620,621,622,625,626,632,633,640,642,643,651,662,663,671,680,681,691,696,701,706,711,714,717,720,721,722,725,730,741,752,757,760,761,770,775,780,781,791,795,801,807,808,809,810,811,812,813,814,815,817,818,819,821,822,825,826,827,828,829,830,831,832,833,835,836,837,838,839,840,841,842,843,844,845,846,847,848,850,851,852,855,857,860,861,862,863,864,865,866,871,873,875,881,882,883,884,885,887,888,890,891,892,893,894,895,900,902,905,906,907,909,912,913,914,919,921,922,923,930,931,950,954,955,961,962,963,964,965,966,967,970,980,999)
    field_information['GGDM 3.0']['MilitaryPnt']['EnumeratedIndexValues']['FFN3']['AL375']  = (-999999,551,563,570,572,578,809,810,811,815,822,835,836,843,847,905,922,930,970,999)
    field_information['GGDM 3.0']['MilitaryPnt']['EnumeratedIndexValues']['FFN3']['AL376']  = (-999999,551,563,570,572,578,809,810,811,815,822,835,836,843,847,905,922,930,970,999)
    field_information['GGDM 3.0']['MilitaryPnt']['EnumeratedIndexValues']['FFN3']['FA015']  = (-999999,835,841,921,999)
    field_information['GGDM 3.0']['MilitaryPnt']['EnumeratedIndexValues']['FFN3']['FA165']  = (-999999,811,831,832,835,839,841,845,846,847,848,857,888,912,914,954,970,999)
    field_information['GGDM 3.0']['MilitaryPnt']['FRT'] = ('Enumeration',('FA015'))
    field_information['GGDM 3.0']['MilitaryPnt']['EnumeratedIndexValues']['FRT'] = {}
    field_information['GGDM 3.0']['MilitaryPnt']['EnumeratedIndexValues']['FRT']['FA015']  = (-999999,1,2,3,4,5,6,999)
    field_information['GGDM 3.0']['MilitaryPnt']['FRT2'] = ('Enumeration',('FA015'))
    field_information['GGDM 3.0']['MilitaryPnt']['EnumeratedIndexValues']['FRT2'] = {}
    field_information['GGDM 3.0']['MilitaryPnt']['EnumeratedIndexValues']['FRT2']['FA015']  = (-999999,1,2,3,4,5,6,999)
    field_information['GGDM 3.0']['MilitaryPnt']['FRT3'] = ('Enumeration',('FA015'))
    field_information['GGDM 3.0']['MilitaryPnt']['EnumeratedIndexValues']['FRT3'] = {}
    field_information['GGDM 3.0']['MilitaryPnt']['EnumeratedIndexValues']['FRT3']['FA015']  = (-999999,1,2,3,4,5,6,999)
    field_information['GGDM 3.0']['MilitaryPnt']['FUFI'] = ('StructuredText',('AH055','AH060','AL120','AL375','AL376','AM060','FA015','FA165','SU001'))
    field_information['GGDM 3.0']['MilitaryPnt']['FURL'] = ('StructuredText',('AH055','AH060','AL120','AL375','AL376','AM060','FA015','FA165','SU001'))
    field_information['GGDM 3.0']['MilitaryPnt']['FZR'] = ('Enumeration',('AH055'))
    field_information['GGDM 3.0']['MilitaryPnt']['EnumeratedIndexValues']['FZR'] = {}
    field_information['GGDM 3.0']['MilitaryPnt']['EnumeratedIndexValues']['FZR']['AH055']  = (-999999,1,2,3,4,5,6,999)
    field_information['GGDM 3.0']['MilitaryPnt']['GDBV'] = ('Enumeration',('AH055','AH060','AL120','AL375','AL376','AM060','FA015','FA165','SU001'))
    field_information['GGDM 3.0']['MilitaryPnt']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['MilitaryPnt']['EnumeratedIndexValues']['GDBV']['AH055']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['MilitaryPnt']['EnumeratedIndexValues']['GDBV']['AH060']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['MilitaryPnt']['EnumeratedIndexValues']['GDBV']['AL120']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['MilitaryPnt']['EnumeratedIndexValues']['GDBV']['AL375']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['MilitaryPnt']['EnumeratedIndexValues']['GDBV']['AL376']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['MilitaryPnt']['EnumeratedIndexValues']['GDBV']['AM060']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['MilitaryPnt']['EnumeratedIndexValues']['GDBV']['FA015']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['MilitaryPnt']['EnumeratedIndexValues']['GDBV']['FA165']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['MilitaryPnt']['EnumeratedIndexValues']['GDBV']['SU001']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['MilitaryPnt']['HGT'] = ('Real',('AH055','AL375','AL376','AM060','FA015','FA165'))
    field_information['GGDM 3.0']['MilitaryPnt']['HST'] = ('Enumeration',('AH055','AH060','AL375','AM060'))
    field_information['GGDM 3.0']['MilitaryPnt']['EnumeratedIndexValues']['HST'] = {}
    field_information['GGDM 3.0']['MilitaryPnt']['EnumeratedIndexValues']['HST']['AH055']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['MilitaryPnt']['EnumeratedIndexValues']['HST']['AH060']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['MilitaryPnt']['EnumeratedIndexValues']['HST']['AL375']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['MilitaryPnt']['EnumeratedIndexValues']['HST']['AM060']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['MilitaryPnt']['HST2'] = ('Enumeration',('AH055','AH060','AL375','AM060'))
    field_information['GGDM 3.0']['MilitaryPnt']['EnumeratedIndexValues']['HST2'] = {}
    field_information['GGDM 3.0']['MilitaryPnt']['EnumeratedIndexValues']['HST2']['AH055']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['MilitaryPnt']['EnumeratedIndexValues']['HST2']['AH060']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['MilitaryPnt']['EnumeratedIndexValues']['HST2']['AL375']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['MilitaryPnt']['EnumeratedIndexValues']['HST2']['AM060']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['MilitaryPnt']['HST3'] = ('Enumeration',('AH055','AH060','AL375','AM060'))
    field_information['GGDM 3.0']['MilitaryPnt']['EnumeratedIndexValues']['HST3'] = {}
    field_information['GGDM 3.0']['MilitaryPnt']['EnumeratedIndexValues']['HST3']['AH055']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['MilitaryPnt']['EnumeratedIndexValues']['HST3']['AH060']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['MilitaryPnt']['EnumeratedIndexValues']['HST3']['AL375']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['MilitaryPnt']['EnumeratedIndexValues']['HST3']['AM060']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['MilitaryPnt']['LEA'] = ('Real',('AH060'))
    field_information['GGDM 3.0']['MilitaryPnt']['LMC'] = ('Boolean',('AH055','AL120','AL375','AL376','FA165','SU001'))
    field_information['GGDM 3.0']['MilitaryPnt']['LUN'] = ('Boolean',('AL120','SU001'))
    field_information['GGDM 3.0']['MilitaryPnt']['LZN'] = ('Real',('AH055','AH060','AL120','AL375','AL376','AM060','FA015','FA165','SU001'))
    field_information['GGDM 3.0']['MilitaryPnt']['MCC'] = ('Enumeration',('AH060'))
    field_information['GGDM 3.0']['MilitaryPnt']['EnumeratedIndexValues']['MCC'] = {}
    field_information['GGDM 3.0']['MilitaryPnt']['EnumeratedIndexValues']['MCC']['AH060']  = (-999999,7,9,21,62,77,83,104,999)
    field_information['GGDM 3.0']['MilitaryPnt']['MCC2'] = ('Enumeration',('AH060'))
    field_information['GGDM 3.0']['MilitaryPnt']['EnumeratedIndexValues']['MCC2'] = {}
    field_information['GGDM 3.0']['MilitaryPnt']['EnumeratedIndexValues']['MCC2']['AH060']  = (-999999,7,9,21,62,77,83,104,999)
    field_information['GGDM 3.0']['MilitaryPnt']['MCC3'] = ('Enumeration',('AH060'))
    field_information['GGDM 3.0']['MilitaryPnt']['EnumeratedIndexValues']['MCC3'] = {}
    field_information['GGDM 3.0']['MilitaryPnt']['EnumeratedIndexValues']['MCC3']['AH060']  = (-999999,7,9,21,62,77,83,104,999)
    field_information['GGDM 3.0']['MilitaryPnt']['MLOP'] = ('Enumeration',('SU001'))
    field_information['GGDM 3.0']['MilitaryPnt']['EnumeratedIndexValues']['MLOP'] = {}
    field_information['GGDM 3.0']['MilitaryPnt']['EnumeratedIndexValues']['MLOP']['SU001']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,999)
    field_information['GGDM 3.0']['MilitaryPnt']['MLUS'] = ('Enumeration',('SU001'))
    field_information['GGDM 3.0']['MilitaryPnt']['EnumeratedIndexValues']['MLUS'] = {}
    field_information['GGDM 3.0']['MilitaryPnt']['EnumeratedIndexValues']['MLUS']['SU001']  = (-999999,1,2,3,4,5,6,7,8,9,10,18,19,999)
    field_information['GGDM 3.0']['MilitaryPnt']['MST'] = ('Enumeration',('AL120'))
    field_information['GGDM 3.0']['MilitaryPnt']['EnumeratedIndexValues']['MST'] = {}
    field_information['GGDM 3.0']['MilitaryPnt']['EnumeratedIndexValues']['MST']['AL120']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,17,18,19,20,21,22,23,24,25,26,999)
    field_information['GGDM 3.0']['MilitaryPnt']['MST2'] = ('Enumeration',('AL120'))
    field_information['GGDM 3.0']['MilitaryPnt']['EnumeratedIndexValues']['MST2'] = {}
    field_information['GGDM 3.0']['MilitaryPnt']['EnumeratedIndexValues']['MST2']['AL120']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,17,18,19,20,21,22,23,24,25,26,999)
    field_information['GGDM 3.0']['MilitaryPnt']['MST3'] = ('Enumeration',('AL120'))
    field_information['GGDM 3.0']['MilitaryPnt']['EnumeratedIndexValues']['MST3'] = {}
    field_information['GGDM 3.0']['MilitaryPnt']['EnumeratedIndexValues']['MST3']['AL120']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,17,18,19,20,21,22,23,24,25,26,999)
    field_information['GGDM 3.0']['MilitaryPnt']['MUB'] = ('Boolean',('AH055','AL375'))
    field_information['GGDM 3.0']['MilitaryPnt']['OTH'] = ('StructuredText',('AH055','AH060','AL120','AL375','AL376','AM060','FA015','FA165','SU001'))
    field_information['GGDM 3.0']['MilitaryPnt']['PCF'] = ('Enumeration',('AH055','AH060','AL120','AL375','AL376','AM060','FA015','FA165','SU001'))
    field_information['GGDM 3.0']['MilitaryPnt']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['MilitaryPnt']['EnumeratedIndexValues']['PCF']['AH055']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['MilitaryPnt']['EnumeratedIndexValues']['PCF']['AH060']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['MilitaryPnt']['EnumeratedIndexValues']['PCF']['AL120']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['MilitaryPnt']['EnumeratedIndexValues']['PCF']['AL375']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['MilitaryPnt']['EnumeratedIndexValues']['PCF']['AL376']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['MilitaryPnt']['EnumeratedIndexValues']['PCF']['AM060']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['MilitaryPnt']['EnumeratedIndexValues']['PCF']['FA015']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['MilitaryPnt']['EnumeratedIndexValues']['PCF']['FA165']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['MilitaryPnt']['EnumeratedIndexValues']['PCF']['SU001']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['MilitaryPnt']['PPO'] = ('Enumeration',('AM060'))
    field_information['GGDM 3.0']['MilitaryPnt']['EnumeratedIndexValues']['PPO'] = {}
    field_information['GGDM 3.0']['MilitaryPnt']['EnumeratedIndexValues']['PPO']['AM060']  = (-999999,3,16,38,46,90,120,999)
    field_information['GGDM 3.0']['MilitaryPnt']['PPO2'] = ('Enumeration',('AM060'))
    field_information['GGDM 3.0']['MilitaryPnt']['EnumeratedIndexValues']['PPO2'] = {}
    field_information['GGDM 3.0']['MilitaryPnt']['EnumeratedIndexValues']['PPO2']['AM060']  = (-999999,3,16,38,46,90,120,999)
    field_information['GGDM 3.0']['MilitaryPnt']['PPO3'] = ('Enumeration',('AM060'))
    field_information['GGDM 3.0']['MilitaryPnt']['EnumeratedIndexValues']['PPO3'] = {}
    field_information['GGDM 3.0']['MilitaryPnt']['EnumeratedIndexValues']['PPO3']['AM060']  = (-999999,3,16,38,46,90,120,999)
    field_information['GGDM 3.0']['MilitaryPnt']['PRM'] = ('Boolean',('AH060','AL120','FA015'))
    field_information['GGDM 3.0']['MilitaryPnt']['RLE'] = ('Enumeration',('AH055'))
    field_information['GGDM 3.0']['MilitaryPnt']['EnumeratedIndexValues']['RLE'] = {}
    field_information['GGDM 3.0']['MilitaryPnt']['EnumeratedIndexValues']['RLE']['AH055']  = (-999999,1,2,3)
    field_information['GGDM 3.0']['MilitaryPnt']['SSR'] = ('Enumeration',('AH055'))
    field_information['GGDM 3.0']['MilitaryPnt']['EnumeratedIndexValues']['SSR'] = {}
    field_information['GGDM 3.0']['MilitaryPnt']['EnumeratedIndexValues']['SSR']['AH055']  = (-999999,6,7,38,40,41,42,47,50,55,64,999)
    field_information['GGDM 3.0']['MilitaryPnt']['SSR2'] = ('Enumeration',('AH055'))
    field_information['GGDM 3.0']['MilitaryPnt']['EnumeratedIndexValues']['SSR2'] = {}
    field_information['GGDM 3.0']['MilitaryPnt']['EnumeratedIndexValues']['SSR2']['AH055']  = (-999999,6,7,38,40,41,42,47,50,55,64,999)
    field_information['GGDM 3.0']['MilitaryPnt']['SSR3'] = ('Enumeration',('AH055'))
    field_information['GGDM 3.0']['MilitaryPnt']['EnumeratedIndexValues']['SSR3'] = {}
    field_information['GGDM 3.0']['MilitaryPnt']['EnumeratedIndexValues']['SSR3']['AH055']  = (-999999,6,7,38,40,41,42,47,50,55,64,999)
    field_information['GGDM 3.0']['MilitaryPnt']['UFI'] = ('StructuredText',('AH055','AH060','AL120','AL375','AL376','AM060','FA015','FA165','SU001'))
    field_information['GGDM 3.0']['MilitaryPnt']['VCM'] = ('Enumeration',('AH055','AL120'))
    field_information['GGDM 3.0']['MilitaryPnt']['EnumeratedIndexValues']['VCM'] = {}
    field_information['GGDM 3.0']['MilitaryPnt']['EnumeratedIndexValues']['VCM']['AH055']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,999)
    field_information['GGDM 3.0']['MilitaryPnt']['EnumeratedIndexValues']['VCM']['AL120']  = (-999999,3,4,6,7,8,9,12,13,15,16,18,999)
    field_information['GGDM 3.0']['MilitaryPnt']['VCM2'] = ('Enumeration',('AH055','AL120'))
    field_information['GGDM 3.0']['MilitaryPnt']['EnumeratedIndexValues']['VCM2'] = {}
    field_information['GGDM 3.0']['MilitaryPnt']['EnumeratedIndexValues']['VCM2']['AH055']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,999)
    field_information['GGDM 3.0']['MilitaryPnt']['EnumeratedIndexValues']['VCM2']['AL120']  = (-999999,3,4,6,7,8,9,12,13,15,16,18,999)
    field_information['GGDM 3.0']['MilitaryPnt']['VCM3'] = ('Enumeration',('AH055','AL120'))
    field_information['GGDM 3.0']['MilitaryPnt']['EnumeratedIndexValues']['VCM3'] = {}
    field_information['GGDM 3.0']['MilitaryPnt']['EnumeratedIndexValues']['VCM3']['AH055']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,999)
    field_information['GGDM 3.0']['MilitaryPnt']['EnumeratedIndexValues']['VCM3']['AL120']  = (-999999,3,4,6,7,8,9,12,13,15,16,18,999)
    field_information['GGDM 3.0']['MilitaryPnt']['VOI'] = ('StructuredText',('AH055','AL375'))
    field_information['GGDM 3.0']['MilitaryPnt']['WID'] = ('Real',('AH055','AH060','AL120','AL375','AL376','AM060','FA015','FA165','SU001'))
    field_information['GGDM 3.0']['MilitaryPnt']['WPST'] = ('Integer',('AH055'))
    field_information['GGDM 3.0']['MilitaryPnt']['WTYP'] = ('Enumeration',('AH055'))
    field_information['GGDM 3.0']['MilitaryPnt']['EnumeratedIndexValues']['WTYP'] = {}
    field_information['GGDM 3.0']['MilitaryPnt']['EnumeratedIndexValues']['WTYP']['AH055']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['MilitaryPnt']['YSU'] = ('Enumeration',('AH055','AH060','AL120','FA015','SU001'))
    field_information['GGDM 3.0']['MilitaryPnt']['EnumeratedIndexValues']['YSU'] = {}
    field_information['GGDM 3.0']['MilitaryPnt']['EnumeratedIndexValues']['YSU']['AH055']  = (-999999,1,2,3,4,5,7,999)
    field_information['GGDM 3.0']['MilitaryPnt']['EnumeratedIndexValues']['YSU']['AH060']  = (-999999,1,2,3,4,5,7,999)
    field_information['GGDM 3.0']['MilitaryPnt']['EnumeratedIndexValues']['YSU']['AL120']  = (-999999,1,2,3,4,5,7,999)
    field_information['GGDM 3.0']['MilitaryPnt']['EnumeratedIndexValues']['YSU']['FA015']  = (-999999,1,2,3,4,5,7,8,9,998,999)
    field_information['GGDM 3.0']['MilitaryPnt']['EnumeratedIndexValues']['YSU']['SU001']  = (-999999,1,2,3,4,5,7,8,9,999)
    field_information['GGDM 3.0']['MilitaryPnt']['ZI001_SDV'] = ('StructuredText',('AH055','AH060','AL120','AL375','AL376','AM060','FA015','FA165','SU001'))
    field_information['GGDM 3.0']['MilitaryPnt']['ZI001_SRT'] = ('Enumeration',('AH055','AH060','AL120','AL375','AL376','AM060','FA015','FA165','SU001'))
    field_information['GGDM 3.0']['MilitaryPnt']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['MilitaryPnt']['EnumeratedIndexValues']['ZI001_SRT']['AH055']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['MilitaryPnt']['EnumeratedIndexValues']['ZI001_SRT']['AH060']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['MilitaryPnt']['EnumeratedIndexValues']['ZI001_SRT']['AL120']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['MilitaryPnt']['EnumeratedIndexValues']['ZI001_SRT']['AL375']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['MilitaryPnt']['EnumeratedIndexValues']['ZI001_SRT']['AL376']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['MilitaryPnt']['EnumeratedIndexValues']['ZI001_SRT']['AM060']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['MilitaryPnt']['EnumeratedIndexValues']['ZI001_SRT']['FA015']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['MilitaryPnt']['EnumeratedIndexValues']['ZI001_SRT']['FA165']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['MilitaryPnt']['EnumeratedIndexValues']['ZI001_SRT']['SU001']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['MilitaryPnt']['ZI002_UFI'] = ('StructuredText',('AH055','AH060','AL120','AL375','AL376','AM060','FA015','FA165','SU001'))
    field_information['GGDM 3.0']['MilitaryPnt']['ZI004_RCG'] = ('Enumeration',('AH055','AH060','AL120','AL375','AL376','AM060','FA015','FA165','SU001'))
    field_information['GGDM 3.0']['MilitaryPnt']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['MilitaryPnt']['EnumeratedIndexValues']['ZI004_RCG']['AH055']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['MilitaryPnt']['EnumeratedIndexValues']['ZI004_RCG']['AH060']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['MilitaryPnt']['EnumeratedIndexValues']['ZI004_RCG']['AL120']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['MilitaryPnt']['EnumeratedIndexValues']['ZI004_RCG']['AL375']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['MilitaryPnt']['EnumeratedIndexValues']['ZI004_RCG']['AL376']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['MilitaryPnt']['EnumeratedIndexValues']['ZI004_RCG']['AM060']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['MilitaryPnt']['EnumeratedIndexValues']['ZI004_RCG']['FA015']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['MilitaryPnt']['EnumeratedIndexValues']['ZI004_RCG']['FA165']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['MilitaryPnt']['EnumeratedIndexValues']['ZI004_RCG']['SU001']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['MilitaryPnt']['ZI005_FNA'] = ('String',('AH055','AH060','AL120','AL375','AL376','AM060','FA015','FA165','SU001'))
    field_information['GGDM 3.0']['MilitaryPnt']['ZI005_GNT'] = ('Enumeration',('AH055','AH060','AL120','AL375','AL376','AM060','FA015','FA165','SU001'))
    field_information['GGDM 3.0']['MilitaryPnt']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['MilitaryPnt']['EnumeratedIndexValues']['ZI005_GNT']['AH055']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['MilitaryPnt']['EnumeratedIndexValues']['ZI005_GNT']['AH060']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['MilitaryPnt']['EnumeratedIndexValues']['ZI005_GNT']['AL120']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['MilitaryPnt']['EnumeratedIndexValues']['ZI005_GNT']['AL375']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['MilitaryPnt']['EnumeratedIndexValues']['ZI005_GNT']['AL376']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['MilitaryPnt']['EnumeratedIndexValues']['ZI005_GNT']['AM060']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['MilitaryPnt']['EnumeratedIndexValues']['ZI005_GNT']['FA015']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['MilitaryPnt']['EnumeratedIndexValues']['ZI005_GNT']['FA165']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['MilitaryPnt']['EnumeratedIndexValues']['ZI005_GNT']['SU001']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['MilitaryPnt']['ZI005_NFN'] = ('String',('AH055','AH060','AL120','AL375','AL376','AM060','FA015','FA165','SU001'))
    field_information['GGDM 3.0']['MilitaryPnt']['ZI006_MEM'] = ('String',('AH055','AH060','AL120','AL375','AL376','AM060','FA015','FA165','SU001'))
    field_information['GGDM 3.0']['MilitaryPnt']['ZI014_PBY'] = ('Enumeration',('AH055'))
    field_information['GGDM 3.0']['MilitaryPnt']['EnumeratedIndexValues']['ZI014_PBY'] = {}
    field_information['GGDM 3.0']['MilitaryPnt']['EnumeratedIndexValues']['ZI014_PBY']['AH055']  = (-999999,1,2,6,7,8,12,13,15,89,999)
    field_information['GGDM 3.0']['MilitaryPnt']['ZI014_PBY2'] = ('Enumeration',('AH055'))
    field_information['GGDM 3.0']['MilitaryPnt']['EnumeratedIndexValues']['ZI014_PBY2'] = {}
    field_information['GGDM 3.0']['MilitaryPnt']['EnumeratedIndexValues']['ZI014_PBY2']['AH055']  = (-999999,1,2,6,7,8,12,13,15,89,999)
    field_information['GGDM 3.0']['MilitaryPnt']['ZI014_PBY3'] = ('Enumeration',('AH055'))
    field_information['GGDM 3.0']['MilitaryPnt']['EnumeratedIndexValues']['ZI014_PBY3'] = {}
    field_information['GGDM 3.0']['MilitaryPnt']['EnumeratedIndexValues']['ZI014_PBY3']['AH055']  = (-999999,1,2,6,7,8,12,13,15,89,999)
    field_information['GGDM 3.0']['MilitaryPnt']['ZI014_PPO'] = ('Enumeration',('AH055'))
    field_information['GGDM 3.0']['MilitaryPnt']['EnumeratedIndexValues']['ZI014_PPO'] = {}
    field_information['GGDM 3.0']['MilitaryPnt']['EnumeratedIndexValues']['ZI014_PPO']['AH055']  = (-999999,1,2,3,4,5,13,15,16,18,20,21,23,25,26,28,32,37,38,39,41,43,44,45,46,47,48,57,58,59,60,61,62,63,65,69,70,73,74,80,83,84,87,90,92,94,95,101,105,106,109,111,114,117,120,121,122,123,126,136,137,146,147,148,150,154,155,156,157,160,165,192,200,214,279,325,435,999)
    field_information['GGDM 3.0']['MilitaryPnt']['ZI014_PPO2'] = ('Enumeration',('AH055'))
    field_information['GGDM 3.0']['MilitaryPnt']['EnumeratedIndexValues']['ZI014_PPO2'] = {}
    field_information['GGDM 3.0']['MilitaryPnt']['EnumeratedIndexValues']['ZI014_PPO2']['AH055']  = (-999999,1,2,3,4,5,13,15,16,18,20,21,23,25,26,28,32,37,38,39,41,43,44,45,46,47,48,57,58,59,60,61,62,63,65,69,70,73,74,80,83,84,87,90,92,94,95,101,105,106,109,111,114,117,120,121,122,123,126,136,137,146,147,148,150,154,155,156,157,160,165,192,200,214,279,325,435,999)
    field_information['GGDM 3.0']['MilitaryPnt']['ZI014_PPO3'] = ('Enumeration',('AH055'))
    field_information['GGDM 3.0']['MilitaryPnt']['EnumeratedIndexValues']['ZI014_PPO3'] = {}
    field_information['GGDM 3.0']['MilitaryPnt']['EnumeratedIndexValues']['ZI014_PPO3']['AH055']  = (-999999,1,2,3,4,5,13,15,16,18,20,21,23,25,26,28,32,37,38,39,41,43,44,45,46,47,48,57,58,59,60,61,62,63,65,69,70,73,74,80,83,84,87,90,92,94,95,101,105,106,109,111,114,117,120,121,122,123,126,136,137,146,147,148,150,154,155,156,157,160,165,192,200,214,279,325,435,999)
    field_information['GGDM 3.0']['MilitaryPnt']['ZI014_PRW'] = ('Enumeration',('AH055'))
    field_information['GGDM 3.0']['MilitaryPnt']['EnumeratedIndexValues']['ZI014_PRW'] = {}
    field_information['GGDM 3.0']['MilitaryPnt']['EnumeratedIndexValues']['ZI014_PRW']['AH055']  = (-999999,1,2,5,9,10,11,12,14,16,18,27,28,29,30,33,38,39,41,45,46,48,50,52,54,57,60,64,66,68,70,75,78,79,83,84,85,87,90,93,94,96,97,99,118,119,999)
    field_information['GGDM 3.0']['MilitaryPnt']['ZI014_PRW2'] = ('Enumeration',('AH055'))
    field_information['GGDM 3.0']['MilitaryPnt']['EnumeratedIndexValues']['ZI014_PRW2'] = {}
    field_information['GGDM 3.0']['MilitaryPnt']['EnumeratedIndexValues']['ZI014_PRW2']['AH055']  = (-999999,1,2,5,9,10,11,12,14,16,18,27,28,29,30,33,38,39,41,45,46,48,50,52,54,57,60,64,66,68,70,75,78,79,83,84,85,87,90,93,94,96,97,99,118,119,999)
    field_information['GGDM 3.0']['MilitaryPnt']['ZI014_PRW3'] = ('Enumeration',('AH055'))
    field_information['GGDM 3.0']['MilitaryPnt']['EnumeratedIndexValues']['ZI014_PRW3'] = {}
    field_information['GGDM 3.0']['MilitaryPnt']['EnumeratedIndexValues']['ZI014_PRW3']['AH055']  = (-999999,1,2,5,9,10,11,12,14,16,18,27,28,29,30,33,38,39,41,45,46,48,50,52,54,57,60,64,66,68,70,75,78,79,83,84,85,87,90,93,94,96,97,99,118,119,999)
    field_information['GGDM 3.0']['MilitaryPnt']['ZI018_WIT'] = ('Enumeration',('AH055'))
    field_information['GGDM 3.0']['MilitaryPnt']['EnumeratedIndexValues']['ZI018_WIT'] = {}
    field_information['GGDM 3.0']['MilitaryPnt']['EnumeratedIndexValues']['ZI018_WIT']['AH055']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['MilitaryPnt']['ZI020_GE4'] = ('CodeList',('AH055','AH060','AL120','AL375','AL376','AM060','FA015','FA165','SU001'))
    field_information['GGDM 3.0']['MilitaryPnt']['ZI025_HDP'] = ('Real',('FA015'))
    field_information['GGDM 3.0']['MilitaryPnt']['ZI026_CTUC'] = ('Enumeration',('AH055','AH060','AL120','AL375','AL376','AM060','FA015','FA165','SU001'))
    field_information['GGDM 3.0']['MilitaryPnt']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['MilitaryPnt']['EnumeratedIndexValues']['ZI026_CTUC']['AH055']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['MilitaryPnt']['EnumeratedIndexValues']['ZI026_CTUC']['AH060']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['MilitaryPnt']['EnumeratedIndexValues']['ZI026_CTUC']['AL120']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['MilitaryPnt']['EnumeratedIndexValues']['ZI026_CTUC']['AL375']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['MilitaryPnt']['EnumeratedIndexValues']['ZI026_CTUC']['AL376']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['MilitaryPnt']['EnumeratedIndexValues']['ZI026_CTUC']['AM060']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['MilitaryPnt']['EnumeratedIndexValues']['ZI026_CTUC']['FA015']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['MilitaryPnt']['EnumeratedIndexValues']['ZI026_CTUC']['FA165']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['MilitaryPnt']['EnumeratedIndexValues']['ZI026_CTUC']['SU001']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['MilitaryPnt']['ZI026_CTUL'] = ('integer',('AH055','AH060','AL120','AL375','AL376','AM060','FA015','FA165','SU001'))
    field_information['GGDM 3.0']['MilitaryPnt']['ZI026_CTUU'] = ('integer',('AH055','AH060','AL120','AL375','AL376','AM060','FA015','FA165','SU001'))
    field_information['GGDM 3.0']['MilitaryPnt']['ZI031S_URI'] = ('StructuredText',('AH055','AH060','AL120','AL375','AL376','AM060','FA015','FA165','SU001'))
    field_information['GGDM 3.0']['MilitaryPnt']['ZI039S_UFI'] = ('StructuredText',('AH055','AH060','AL120','AL375','AL376','AM060','FA015','FA165','SU001'))
    field_information['GGDM 3.0']['MilitaryPnt']['ZSAX_RS0'] = ('CodeList',('AH055','AH060','AL120','AL375','AL376','AM060','FA015','FA165','SU001'))
    field_information['GGDM 3.0']['MilitaryPnt']['ZSAX_RX0'] = ('StructuredText',('AH055','AH060','AL120','AL375','AL376','AM060','FA015','FA165','SU001'))
    field_information['GGDM 3.0']['MilitaryPnt']['ZSAX_RX3'] = ('StructuredText',('AH055','AH060','AL120','AL375','AL376','AM060','FA015','FA165','SU001'))
    field_information['GGDM 3.0']['MilitaryPnt']['ZSAX_RX4'] = ('StructuredText',('AH055','AH060','AL120','AL375','AL376','AM060','FA015','FA165','SU001'))
    field_information['GGDM 3.0']['MilitaryPnt']['ZVH'] = ('Real',('AH055','AL120','AL375','AL376','AM060','FA015','FA165'))
    field_information['GGDM 3.0']['MilitaryPntExt']['ARA'] = ('Real',('AL121'))
    field_information['GGDM 3.0']['MilitaryPntExt']['AZC'] = ('Boolean',('BB150'))
    field_information['GGDM 3.0']['MilitaryPntExt']['BEN'] = ('StructuredText',('AL121','BB150'))
    field_information['GGDM 3.0']['MilitaryPntExt']['CAA'] = ('Enumeration',('AL121'))
    field_information['GGDM 3.0']['MilitaryPntExt']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['MilitaryPntExt']['EnumeratedIndexValues']['CAA']['AL121']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['MilitaryPntExt']['CNCP'] = ('StructuredText',('AL121','BB150'))
    field_information['GGDM 3.0']['MilitaryPntExt']['COS'] = ('Enumeration',('AL121','BB150'))
    field_information['GGDM 3.0']['MilitaryPntExt']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['MilitaryPntExt']['EnumeratedIndexValues']['COS']['AL121']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['MilitaryPntExt']['EnumeratedIndexValues']['COS']['BB150']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['MilitaryPntExt']['F_CODE'] = ('CONSTRAINED_STRING',('AL121','BB150'))
    field_information['GGDM 3.0']['MilitaryPntExt']['FUFI'] = ('StructuredText',('AL121','BB150'))
    field_information['GGDM 3.0']['MilitaryPntExt']['FURL'] = ('StructuredText',('AL121','BB150'))
    field_information['GGDM 3.0']['MilitaryPntExt']['GDBV'] = ('Enumeration',('AL121','BB150'))
    field_information['GGDM 3.0']['MilitaryPntExt']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['MilitaryPntExt']['EnumeratedIndexValues']['GDBV']['AL121']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['MilitaryPntExt']['EnumeratedIndexValues']['GDBV']['BB150']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['MilitaryPntExt']['HGT'] = ('Real',('AL121'))
    field_information['GGDM 3.0']['MilitaryPntExt']['LMC'] = ('Boolean',('AL121'))
    field_information['GGDM 3.0']['MilitaryPntExt']['LZN'] = ('Real',('AL121'))
    field_information['GGDM 3.0']['MilitaryPntExt']['OTH'] = ('StructuredText',('AL121','BB150'))
    field_information['GGDM 3.0']['MilitaryPntExt']['PCF'] = ('Enumeration',('AL121','BB150'))
    field_information['GGDM 3.0']['MilitaryPntExt']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['MilitaryPntExt']['EnumeratedIndexValues']['PCF']['AL121']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['MilitaryPntExt']['EnumeratedIndexValues']['PCF']['BB150']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['MilitaryPntExt']['UFI'] = ('StructuredText',('AL121','BB150'))
    field_information['GGDM 3.0']['MilitaryPntExt']['VCM'] = ('Enumeration',('AL121'))
    field_information['GGDM 3.0']['MilitaryPntExt']['EnumeratedIndexValues']['VCM'] = {}
    field_information['GGDM 3.0']['MilitaryPntExt']['EnumeratedIndexValues']['VCM']['AL121']  = (-999999,3,4,7,8,9,12,13,15,16,18,999)
    field_information['GGDM 3.0']['MilitaryPntExt']['VCM2'] = ('Enumeration',('AL121'))
    field_information['GGDM 3.0']['MilitaryPntExt']['EnumeratedIndexValues']['VCM2'] = {}
    field_information['GGDM 3.0']['MilitaryPntExt']['EnumeratedIndexValues']['VCM2']['AL121']  = (-999999,3,4,7,8,9,12,13,15,16,18,999)
    field_information['GGDM 3.0']['MilitaryPntExt']['VCM3'] = ('Enumeration',('AL121'))
    field_information['GGDM 3.0']['MilitaryPntExt']['EnumeratedIndexValues']['VCM3'] = {}
    field_information['GGDM 3.0']['MilitaryPntExt']['EnumeratedIndexValues']['VCM3']['AL121']  = (-999999,3,4,7,8,9,12,13,15,16,18,999)
    field_information['GGDM 3.0']['MilitaryPntExt']['WID'] = ('Real',('AL121'))
    field_information['GGDM 3.0']['MilitaryPntExt']['YSU'] = ('Enumeration',('AL121'))
    field_information['GGDM 3.0']['MilitaryPntExt']['EnumeratedIndexValues']['YSU'] = {}
    field_information['GGDM 3.0']['MilitaryPntExt']['EnumeratedIndexValues']['YSU']['AL121']  = (-999999,1,2,3,4,5,7,999)
    field_information['GGDM 3.0']['MilitaryPntExt']['ZI001_SDV'] = ('StructuredText',('AL121','BB150'))
    field_information['GGDM 3.0']['MilitaryPntExt']['ZI001_SRT'] = ('Enumeration',('AL121','BB150'))
    field_information['GGDM 3.0']['MilitaryPntExt']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['MilitaryPntExt']['EnumeratedIndexValues']['ZI001_SRT']['AL121']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['MilitaryPntExt']['EnumeratedIndexValues']['ZI001_SRT']['BB150']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['MilitaryPntExt']['ZI002_UFI'] = ('StructuredText',('AL121','BB150'))
    field_information['GGDM 3.0']['MilitaryPntExt']['ZI004_RCG'] = ('Enumeration',('AL121','BB150'))
    field_information['GGDM 3.0']['MilitaryPntExt']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['MilitaryPntExt']['EnumeratedIndexValues']['ZI004_RCG']['AL121']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['MilitaryPntExt']['EnumeratedIndexValues']['ZI004_RCG']['BB150']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['MilitaryPntExt']['ZI005_FNA'] = ('String',('AL121'))
    field_information['GGDM 3.0']['MilitaryPntExt']['ZI005_GNT'] = ('Enumeration',('AL121'))
    field_information['GGDM 3.0']['MilitaryPntExt']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['MilitaryPntExt']['EnumeratedIndexValues']['ZI005_GNT']['AL121']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['MilitaryPntExt']['ZI005_NFN'] = ('String',('AL121'))
    field_information['GGDM 3.0']['MilitaryPntExt']['ZI006_MEM'] = ('String',('AL121','BB150'))
    field_information['GGDM 3.0']['MilitaryPntExt']['ZI020_GE4'] = ('CodeList',('AL121','BB150'))
    field_information['GGDM 3.0']['MilitaryPntExt']['ZI026_CTUC'] = ('Enumeration',('AL121','BB150'))
    field_information['GGDM 3.0']['MilitaryPntExt']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['MilitaryPntExt']['EnumeratedIndexValues']['ZI026_CTUC']['AL121']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['MilitaryPntExt']['EnumeratedIndexValues']['ZI026_CTUC']['BB150']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['MilitaryPntExt']['ZI026_CTUL'] = ('integer',('AL121','BB150'))
    field_information['GGDM 3.0']['MilitaryPntExt']['ZI026_CTUU'] = ('integer',('AL121','BB150'))
    field_information['GGDM 3.0']['MilitaryPntExt']['ZI031S_URI'] = ('StructuredText',('AL121','BB150'))
    field_information['GGDM 3.0']['MilitaryPntExt']['ZI039S_UFI'] = ('StructuredText',('AL121','BB150'))
    field_information['GGDM 3.0']['MilitaryPntExt']['ZSAX_RS0'] = ('CodeList',('AL121','BB150'))
    field_information['GGDM 3.0']['MilitaryPntExt']['ZSAX_RX0'] = ('StructuredText',('AL121','BB150'))
    field_information['GGDM 3.0']['MilitaryPntExt']['ZSAX_RX3'] = ('StructuredText',('AL121','BB150'))
    field_information['GGDM 3.0']['MilitaryPntExt']['ZSAX_RX4'] = ('StructuredText',('AL121','BB150'))
    field_information['GGDM 3.0']['MilitarySrf']['ADR'] = ('String',('AH055','AL375','AL376','AM060','FA165','SU001','SU004'))
    field_information['GGDM 3.0']['MilitarySrf']['AOO'] = ('Real',('AH055','AL065','AL120','AL375','AL376','AM060','FA015','FA165','SU001'))
    field_information['GGDM 3.0']['MilitarySrf']['ARA'] = ('Real',('AH025','AH055','AH060','AL060','AL065','AL120','AL375','AL376','AM060','FA015','FA100','FA165','SU001','SU004'))
    field_information['GGDM 3.0']['MilitarySrf']['ATB'] = ('Boolean',('AH055'))
    field_information['GGDM 3.0']['MilitarySrf']['AWP'] = ('Boolean',('AH055','AL375'))
    field_information['GGDM 3.0']['MilitarySrf']['BEN'] = ('StructuredText',('AH025','AH055','AH060','AL060','AL065','AL120','AL375','AL376','AM060','FA015','FA100','FA165','SU001','SU004'))
    field_information['GGDM 3.0']['MilitarySrf']['BNF'] = ('Integer',('AH055','AL375'))
    field_information['GGDM 3.0']['MilitarySrf']['CAA'] = ('Enumeration',('AH055','AH060','AL120','AL375','AL376','AM060','FA015','FA165','SU001','SU004'))
    field_information['GGDM 3.0']['MilitarySrf']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['MilitarySrf']['EnumeratedIndexValues']['CAA']['AH055']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['MilitarySrf']['EnumeratedIndexValues']['CAA']['AH060']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['MilitarySrf']['EnumeratedIndexValues']['CAA']['AL120']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['MilitarySrf']['EnumeratedIndexValues']['CAA']['AL375']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['MilitarySrf']['EnumeratedIndexValues']['CAA']['AL376']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['MilitarySrf']['EnumeratedIndexValues']['CAA']['AM060']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['MilitarySrf']['EnumeratedIndexValues']['CAA']['FA015']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['MilitarySrf']['EnumeratedIndexValues']['CAA']['FA165']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['MilitarySrf']['EnumeratedIndexValues']['CAA']['SU001']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['MilitarySrf']['EnumeratedIndexValues']['CAA']['SU004']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['MilitarySrf']['CNCP'] = ('StructuredText',('AH025','AH055','AH060','AL060','AL120','AL375','AL376','AM060','FA015','FA100','FA165','SU001'))
    field_information['GGDM 3.0']['MilitarySrf']['COS'] = ('Enumeration',('AH025','AH055','AH060','AL060','AL120','AL375','AL376','AM060','FA015','FA100','FA165','SU001'))
    field_information['GGDM 3.0']['MilitarySrf']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['MilitarySrf']['EnumeratedIndexValues']['COS']['AH025']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['MilitarySrf']['EnumeratedIndexValues']['COS']['AH055']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['MilitarySrf']['EnumeratedIndexValues']['COS']['AH060']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['MilitarySrf']['EnumeratedIndexValues']['COS']['AL060']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['MilitarySrf']['EnumeratedIndexValues']['COS']['AL120']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['MilitarySrf']['EnumeratedIndexValues']['COS']['AL375']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['MilitarySrf']['EnumeratedIndexValues']['COS']['AL376']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['MilitarySrf']['EnumeratedIndexValues']['COS']['AM060']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['MilitarySrf']['EnumeratedIndexValues']['COS']['FA015']  = (-999999,2,4,6,9,13,14)
    field_information['GGDM 3.0']['MilitarySrf']['EnumeratedIndexValues']['COS']['FA100']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['MilitarySrf']['EnumeratedIndexValues']['COS']['FA165']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['MilitarySrf']['EnumeratedIndexValues']['COS']['SU001']  = (-999999,2,4,6,9,13,14)
    field_information['GGDM 3.0']['MilitarySrf']['DZP'] = ('Real',('AH025','AH060'))
    field_information['GGDM 3.0']['MilitarySrf']['EET'] = ('Enumeration',('AH025'))
    field_information['GGDM 3.0']['MilitarySrf']['EnumeratedIndexValues']['EET'] = {}
    field_information['GGDM 3.0']['MilitarySrf']['EnumeratedIndexValues']['EET']['AH025']  = (-999999,1,2,3,4,5,999)
    field_information['GGDM 3.0']['MilitarySrf']['F_CODE'] = ('CONSTRAINED_STRING',('AH025','AH055','AH060','AL060','AL065','AL120','AL375','AL376','AM060','FA015','FA100','FA165','SU001','SU004'))
    field_information['GGDM 3.0']['MilitarySrf']['FFN'] = ('Enumeration',('AH055','AL375','AL376','FA015','FA165'))
    field_information['GGDM 3.0']['MilitarySrf']['EnumeratedIndexValues']['FFN'] = {}
    field_information['GGDM 3.0']['MilitarySrf']['EnumeratedIndexValues']['FFN']['AH055']  = (-999999,2,3,9,14,15,19,20,21,27,30,35,40,50,60,70,83,87,91,95,99,100,101,102,103,104,105,106,107,110,111,112,113,114,115,116,118,119,120,121,122,123,124,125,129,130,140,150,155,160,161,165,171,181,190,191,192,195,210,221,225,230,231,232,233,234,235,236,237,240,241,242,243,250,251,255,257,260,270,272,280,289,290,301,304,305,306,310,320,321,322,323,324,325,330,331,332,333,334,340,341,342,343,350,351,352,355,356,360,361,362,363,370,372,382,383,385,440,459,460,464,465,466,470,473,474,475,476,477,478,480,481,482,483,484,486,487,488,489,490,491,494,495,496,497,500,501,505,507,508,510,511,512,513,520,525,529,530,535,536,537,538,539,540,541,545,548,549,550,551,552,553,554,555,556,557,558,559,563,570,572,573,574,578,579,580,582,594,601,604,610,612,614,615,616,617,620,621,622,625,626,632,633,640,642,643,651,662,663,671,680,681,691,696,701,706,711,714,717,720,721,722,725,730,741,752,757,760,761,770,775,780,781,791,795,801,807,808,809,810,811,812,813,814,815,817,818,819,821,822,825,826,827,828,829,830,831,832,833,835,836,837,838,839,840,841,842,843,844,845,846,847,848,850,851,852,855,857,860,861,862,863,864,865,866,871,873,875,881,882,883,884,885,887,888,890,891,892,893,894,895,900,902,905,906,907,909,912,913,914,919,921,922,923,930,931,950,954,955,961,962,963,964,965,966,967,970,980,999)
    field_information['GGDM 3.0']['MilitarySrf']['EnumeratedIndexValues']['FFN']['AL375']  = (-999999,551,563,570,572,578,809,810,811,815,822,835,836,843,847,905,922,930,970,999)
    field_information['GGDM 3.0']['MilitarySrf']['EnumeratedIndexValues']['FFN']['AL376']  = (-999999,551,563,570,572,578,809,810,811,815,822,835,836,843,847,905,922,930,970,999)
    field_information['GGDM 3.0']['MilitarySrf']['EnumeratedIndexValues']['FFN']['FA015']  = (-999999,835,841,921,999)
    field_information['GGDM 3.0']['MilitarySrf']['EnumeratedIndexValues']['FFN']['FA165']  = (-999999,811,831,832,835,839,841,845,846,847,848,857,888,912,914,954,970,999)
    field_information['GGDM 3.0']['MilitarySrf']['FFN2'] = ('Enumeration',('AH055','AL375','AL376','FA015','FA165'))
    field_information['GGDM 3.0']['MilitarySrf']['EnumeratedIndexValues']['FFN2'] = {}
    field_information['GGDM 3.0']['MilitarySrf']['EnumeratedIndexValues']['FFN2']['AH055']  = (-999999,2,3,9,14,15,19,20,21,27,30,35,40,50,60,70,83,87,91,95,99,100,101,102,103,104,105,106,107,110,111,112,113,114,115,116,118,119,120,121,122,123,124,125,129,130,140,150,155,160,161,165,171,181,190,191,192,195,210,221,225,230,231,232,233,234,235,236,237,240,241,242,243,250,251,255,257,260,270,272,280,289,290,301,304,305,306,310,320,321,322,323,324,325,330,331,332,333,334,340,341,342,343,350,351,352,355,356,360,361,362,363,370,372,382,383,385,440,459,460,464,465,466,470,473,474,475,476,477,478,480,481,482,483,484,486,487,488,489,490,491,494,495,496,497,500,501,505,507,508,510,511,512,513,520,525,529,530,535,536,537,538,539,540,541,545,548,549,550,551,552,553,554,555,556,557,558,559,563,570,572,573,574,578,579,580,582,594,601,604,610,612,614,615,616,617,620,621,622,625,626,632,633,640,642,643,651,662,663,671,680,681,691,696,701,706,711,714,717,720,721,722,725,730,741,752,757,760,761,770,775,780,781,791,795,801,807,808,809,810,811,812,813,814,815,817,818,819,821,822,825,826,827,828,829,830,831,832,833,835,836,837,838,839,840,841,842,843,844,845,846,847,848,850,851,852,855,857,860,861,862,863,864,865,866,871,873,875,881,882,883,884,885,887,888,890,891,892,893,894,895,900,902,905,906,907,909,912,913,914,919,921,922,923,930,931,950,954,955,961,962,963,964,965,966,967,970,980,999)
    field_information['GGDM 3.0']['MilitarySrf']['EnumeratedIndexValues']['FFN2']['AL375']  = (-999999,551,563,570,572,578,809,810,811,815,822,835,836,843,847,905,922,930,970,999)
    field_information['GGDM 3.0']['MilitarySrf']['EnumeratedIndexValues']['FFN2']['AL376']  = (-999999,551,563,570,572,578,809,810,811,815,822,835,836,843,847,905,922,930,970,999)
    field_information['GGDM 3.0']['MilitarySrf']['EnumeratedIndexValues']['FFN2']['FA015']  = (-999999,835,841,921,999)
    field_information['GGDM 3.0']['MilitarySrf']['EnumeratedIndexValues']['FFN2']['FA165']  = (-999999,811,831,832,835,839,841,845,846,847,848,857,888,912,914,954,970,999)
    field_information['GGDM 3.0']['MilitarySrf']['FFN3'] = ('Enumeration',('AH055','AL375','AL376','FA015','FA165'))
    field_information['GGDM 3.0']['MilitarySrf']['EnumeratedIndexValues']['FFN3'] = {}
    field_information['GGDM 3.0']['MilitarySrf']['EnumeratedIndexValues']['FFN3']['AH055']  = (-999999,2,3,9,14,15,19,20,21,27,30,35,40,50,60,70,83,87,91,95,99,100,101,102,103,104,105,106,107,110,111,112,113,114,115,116,118,119,120,121,122,123,124,125,129,130,140,150,155,160,161,165,171,181,190,191,192,195,210,221,225,230,231,232,233,234,235,236,237,240,241,242,243,250,251,255,257,260,270,272,280,289,290,301,304,305,306,310,320,321,322,323,324,325,330,331,332,333,334,340,341,342,343,350,351,352,355,356,360,361,362,363,370,372,382,383,385,440,459,460,464,465,466,470,473,474,475,476,477,478,480,481,482,483,484,486,487,488,489,490,491,494,495,496,497,500,501,505,507,508,510,511,512,513,520,525,529,530,535,536,537,538,539,540,541,545,548,549,550,551,552,553,554,555,556,557,558,559,563,570,572,573,574,578,579,580,582,594,601,604,610,612,614,615,616,617,620,621,622,625,626,632,633,640,642,643,651,662,663,671,680,681,691,696,701,706,711,714,717,720,721,722,725,730,741,752,757,760,761,770,775,780,781,791,795,801,807,808,809,810,811,812,813,814,815,817,818,819,821,822,825,826,827,828,829,830,831,832,833,835,836,837,838,839,840,841,842,843,844,845,846,847,848,850,851,852,855,857,860,861,862,863,864,865,866,871,873,875,881,882,883,884,885,887,888,890,891,892,893,894,895,900,902,905,906,907,909,912,913,914,919,921,922,923,930,931,950,954,955,961,962,963,964,965,966,967,970,980,999)
    field_information['GGDM 3.0']['MilitarySrf']['EnumeratedIndexValues']['FFN3']['AL375']  = (-999999,551,563,570,572,578,809,810,811,815,822,835,836,843,847,905,922,930,970,999)
    field_information['GGDM 3.0']['MilitarySrf']['EnumeratedIndexValues']['FFN3']['AL376']  = (-999999,551,563,570,572,578,809,810,811,815,822,835,836,843,847,905,922,930,970,999)
    field_information['GGDM 3.0']['MilitarySrf']['EnumeratedIndexValues']['FFN3']['FA015']  = (-999999,835,841,921,999)
    field_information['GGDM 3.0']['MilitarySrf']['EnumeratedIndexValues']['FFN3']['FA165']  = (-999999,811,831,832,835,839,841,845,846,847,848,857,888,912,914,954,970,999)
    field_information['GGDM 3.0']['MilitarySrf']['FRT'] = ('Enumeration',('FA015'))
    field_information['GGDM 3.0']['MilitarySrf']['EnumeratedIndexValues']['FRT'] = {}
    field_information['GGDM 3.0']['MilitarySrf']['EnumeratedIndexValues']['FRT']['FA015']  = (-999999,1,2,3,4,5,6,999)
    field_information['GGDM 3.0']['MilitarySrf']['FRT2'] = ('Enumeration',('FA015'))
    field_information['GGDM 3.0']['MilitarySrf']['EnumeratedIndexValues']['FRT2'] = {}
    field_information['GGDM 3.0']['MilitarySrf']['EnumeratedIndexValues']['FRT2']['FA015']  = (-999999,1,2,3,4,5,6,999)
    field_information['GGDM 3.0']['MilitarySrf']['FRT3'] = ('Enumeration',('FA015'))
    field_information['GGDM 3.0']['MilitarySrf']['EnumeratedIndexValues']['FRT3'] = {}
    field_information['GGDM 3.0']['MilitarySrf']['EnumeratedIndexValues']['FRT3']['FA015']  = (-999999,1,2,3,4,5,6,999)
    field_information['GGDM 3.0']['MilitarySrf']['FUFI'] = ('StructuredText',('AH025','AH055','AH060','AL060','AL065','AL120','AL375','AL376','AM060','FA015','FA100','FA165','SU001','SU004'))
    field_information['GGDM 3.0']['MilitarySrf']['FURL'] = ('StructuredText',('AH025','AH055','AH060','AL060','AL065','AL120','AL375','AL376','AM060','FA015','FA100','FA165','SU001','SU004'))
    field_information['GGDM 3.0']['MilitarySrf']['FZR'] = ('Enumeration',('AH055'))
    field_information['GGDM 3.0']['MilitarySrf']['EnumeratedIndexValues']['FZR'] = {}
    field_information['GGDM 3.0']['MilitarySrf']['EnumeratedIndexValues']['FZR']['AH055']  = (-999999,1,2,3,4,5,6,999)
    field_information['GGDM 3.0']['MilitarySrf']['GDBV'] = ('Enumeration',('AH025','AH055','AH060','AL060','AL065','AL120','AL375','AL376','AM060','FA015','FA100','FA165','SU001','SU004'))
    field_information['GGDM 3.0']['MilitarySrf']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['MilitarySrf']['EnumeratedIndexValues']['GDBV']['AH025']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['MilitarySrf']['EnumeratedIndexValues']['GDBV']['AH055']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['MilitarySrf']['EnumeratedIndexValues']['GDBV']['AH060']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['MilitarySrf']['EnumeratedIndexValues']['GDBV']['AL060']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['MilitarySrf']['EnumeratedIndexValues']['GDBV']['AL065']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['MilitarySrf']['EnumeratedIndexValues']['GDBV']['AL120']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['MilitarySrf']['EnumeratedIndexValues']['GDBV']['AL375']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['MilitarySrf']['EnumeratedIndexValues']['GDBV']['AL376']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['MilitarySrf']['EnumeratedIndexValues']['GDBV']['AM060']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['MilitarySrf']['EnumeratedIndexValues']['GDBV']['FA015']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['MilitarySrf']['EnumeratedIndexValues']['GDBV']['FA100']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['MilitarySrf']['EnumeratedIndexValues']['GDBV']['FA165']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['MilitarySrf']['EnumeratedIndexValues']['GDBV']['SU001']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['MilitarySrf']['EnumeratedIndexValues']['GDBV']['SU004']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['MilitarySrf']['HGT'] = ('Real',('AH055','AL060','AL375','AL376','AM060','FA015','FA165'))
    field_information['GGDM 3.0']['MilitarySrf']['HST'] = ('Enumeration',('AH025','AH055','AH060','AL375','AM060'))
    field_information['GGDM 3.0']['MilitarySrf']['EnumeratedIndexValues']['HST'] = {}
    field_information['GGDM 3.0']['MilitarySrf']['EnumeratedIndexValues']['HST']['AH025']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['MilitarySrf']['EnumeratedIndexValues']['HST']['AH055']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['MilitarySrf']['EnumeratedIndexValues']['HST']['AH060']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['MilitarySrf']['EnumeratedIndexValues']['HST']['AL375']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['MilitarySrf']['EnumeratedIndexValues']['HST']['AM060']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['MilitarySrf']['HST2'] = ('Enumeration',('AH025','AH055','AH060','AL375','AM060'))
    field_information['GGDM 3.0']['MilitarySrf']['EnumeratedIndexValues']['HST2'] = {}
    field_information['GGDM 3.0']['MilitarySrf']['EnumeratedIndexValues']['HST2']['AH025']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['MilitarySrf']['EnumeratedIndexValues']['HST2']['AH055']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['MilitarySrf']['EnumeratedIndexValues']['HST2']['AH060']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['MilitarySrf']['EnumeratedIndexValues']['HST2']['AL375']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['MilitarySrf']['EnumeratedIndexValues']['HST2']['AM060']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['MilitarySrf']['HST3'] = ('Enumeration',('AH025','AH055','AH060','AL375','AM060'))
    field_information['GGDM 3.0']['MilitarySrf']['EnumeratedIndexValues']['HST3'] = {}
    field_information['GGDM 3.0']['MilitarySrf']['EnumeratedIndexValues']['HST3']['AH025']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['MilitarySrf']['EnumeratedIndexValues']['HST3']['AH055']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['MilitarySrf']['EnumeratedIndexValues']['HST3']['AH060']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['MilitarySrf']['EnumeratedIndexValues']['HST3']['AL375']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['MilitarySrf']['EnumeratedIndexValues']['HST3']['AM060']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['MilitarySrf']['LEA'] = ('Real',('AH060'))
    field_information['GGDM 3.0']['MilitarySrf']['LMC'] = ('Boolean',('AH025','AH055','AL120','AL375','AL376','FA165','SU001'))
    field_information['GGDM 3.0']['MilitarySrf']['LUN'] = ('Boolean',('AL120','SU001'))
    field_information['GGDM 3.0']['MilitarySrf']['LZN'] = ('Real',('AH025','AH055','AH060','AL060','AL065','AL120','AL375','AL376','AM060','FA015','FA100','FA165','SU001','SU004'))
    field_information['GGDM 3.0']['MilitarySrf']['MCC'] = ('Enumeration',('AH060','AL060'))
    field_information['GGDM 3.0']['MilitarySrf']['EnumeratedIndexValues']['MCC'] = {}
    field_information['GGDM 3.0']['MilitarySrf']['EnumeratedIndexValues']['MCC']['AH060']  = (-999999,7,9,21,62,77,83,104,999)
    field_information['GGDM 3.0']['MilitarySrf']['EnumeratedIndexValues']['MCC']['AL060']  = (-999999,21,107,108,999)
    field_information['GGDM 3.0']['MilitarySrf']['MCC2'] = ('Enumeration',('AH060','AL060'))
    field_information['GGDM 3.0']['MilitarySrf']['EnumeratedIndexValues']['MCC2'] = {}
    field_information['GGDM 3.0']['MilitarySrf']['EnumeratedIndexValues']['MCC2']['AH060']  = (-999999,7,9,21,62,77,83,104,999)
    field_information['GGDM 3.0']['MilitarySrf']['EnumeratedIndexValues']['MCC2']['AL060']  = (-999999,21,107,108,999)
    field_information['GGDM 3.0']['MilitarySrf']['MCC3'] = ('Enumeration',('AH060','AL060'))
    field_information['GGDM 3.0']['MilitarySrf']['EnumeratedIndexValues']['MCC3'] = {}
    field_information['GGDM 3.0']['MilitarySrf']['EnumeratedIndexValues']['MCC3']['AH060']  = (-999999,7,9,21,62,77,83,104,999)
    field_information['GGDM 3.0']['MilitarySrf']['EnumeratedIndexValues']['MCC3']['AL060']  = (-999999,21,107,108,999)
    field_information['GGDM 3.0']['MilitarySrf']['MLOP'] = ('Enumeration',('SU001'))
    field_information['GGDM 3.0']['MilitarySrf']['EnumeratedIndexValues']['MLOP'] = {}
    field_information['GGDM 3.0']['MilitarySrf']['EnumeratedIndexValues']['MLOP']['SU001']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,999)
    field_information['GGDM 3.0']['MilitarySrf']['MLUS'] = ('Enumeration',('SU001'))
    field_information['GGDM 3.0']['MilitarySrf']['EnumeratedIndexValues']['MLUS'] = {}
    field_information['GGDM 3.0']['MilitarySrf']['EnumeratedIndexValues']['MLUS']['SU001']  = (-999999,1,2,3,4,5,6,7,8,9,10,18,19,999)
    field_information['GGDM 3.0']['MilitarySrf']['MST'] = ('Enumeration',('AL120'))
    field_information['GGDM 3.0']['MilitarySrf']['EnumeratedIndexValues']['MST'] = {}
    field_information['GGDM 3.0']['MilitarySrf']['EnumeratedIndexValues']['MST']['AL120']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,17,18,19,20,21,22,23,24,25,26,999)
    field_information['GGDM 3.0']['MilitarySrf']['MST2'] = ('Enumeration',('AL120'))
    field_information['GGDM 3.0']['MilitarySrf']['EnumeratedIndexValues']['MST2'] = {}
    field_information['GGDM 3.0']['MilitarySrf']['EnumeratedIndexValues']['MST2']['AL120']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,17,18,19,20,21,22,23,24,25,26,999)
    field_information['GGDM 3.0']['MilitarySrf']['MST3'] = ('Enumeration',('AL120'))
    field_information['GGDM 3.0']['MilitarySrf']['EnumeratedIndexValues']['MST3'] = {}
    field_information['GGDM 3.0']['MilitarySrf']['EnumeratedIndexValues']['MST3']['AL120']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,17,18,19,20,21,22,23,24,25,26,999)
    field_information['GGDM 3.0']['MilitarySrf']['MUB'] = ('Boolean',('AH055','AL375'))
    field_information['GGDM 3.0']['MilitarySrf']['OTH'] = ('StructuredText',('AH025','AH055','AH060','AL060','AL065','AL120','AL375','AL376','AM060','FA015','FA100','FA165','SU001','SU004'))
    field_information['GGDM 3.0']['MilitarySrf']['PCF'] = ('Enumeration',('AH025','AH055','AH060','AL060','AL065','AL120','AL375','AL376','AM060','FA015','FA100','FA165','SU001','SU004'))
    field_information['GGDM 3.0']['MilitarySrf']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['MilitarySrf']['EnumeratedIndexValues']['PCF']['AH025']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['MilitarySrf']['EnumeratedIndexValues']['PCF']['AH055']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['MilitarySrf']['EnumeratedIndexValues']['PCF']['AH060']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['MilitarySrf']['EnumeratedIndexValues']['PCF']['AL060']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['MilitarySrf']['EnumeratedIndexValues']['PCF']['AL065']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['MilitarySrf']['EnumeratedIndexValues']['PCF']['AL120']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['MilitarySrf']['EnumeratedIndexValues']['PCF']['AL375']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['MilitarySrf']['EnumeratedIndexValues']['PCF']['AL376']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['MilitarySrf']['EnumeratedIndexValues']['PCF']['AM060']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['MilitarySrf']['EnumeratedIndexValues']['PCF']['FA015']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['MilitarySrf']['EnumeratedIndexValues']['PCF']['FA100']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['MilitarySrf']['EnumeratedIndexValues']['PCF']['FA165']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['MilitarySrf']['EnumeratedIndexValues']['PCF']['SU001']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['MilitarySrf']['EnumeratedIndexValues']['PCF']['SU004']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['MilitarySrf']['PFHC'] = ('Enumeration',('AH025'))
    field_information['GGDM 3.0']['MilitarySrf']['EnumeratedIndexValues']['PFHC'] = {}
    field_information['GGDM 3.0']['MilitarySrf']['EnumeratedIndexValues']['PFHC']['AH025']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['MilitarySrf']['PFHL'] = ('real',('AH025'))
    field_information['GGDM 3.0']['MilitarySrf']['PFHU'] = ('real',('AH025'))
    field_information['GGDM 3.0']['MilitarySrf']['PPO'] = ('Enumeration',('AM060'))
    field_information['GGDM 3.0']['MilitarySrf']['EnumeratedIndexValues']['PPO'] = {}
    field_information['GGDM 3.0']['MilitarySrf']['EnumeratedIndexValues']['PPO']['AM060']  = (-999999,3,16,38,46,90,120,999)
    field_information['GGDM 3.0']['MilitarySrf']['PPO2'] = ('Enumeration',('AM060'))
    field_information['GGDM 3.0']['MilitarySrf']['EnumeratedIndexValues']['PPO2'] = {}
    field_information['GGDM 3.0']['MilitarySrf']['EnumeratedIndexValues']['PPO2']['AM060']  = (-999999,3,16,38,46,90,120,999)
    field_information['GGDM 3.0']['MilitarySrf']['PPO3'] = ('Enumeration',('AM060'))
    field_information['GGDM 3.0']['MilitarySrf']['EnumeratedIndexValues']['PPO3'] = {}
    field_information['GGDM 3.0']['MilitarySrf']['EnumeratedIndexValues']['PPO3']['AM060']  = (-999999,3,16,38,46,90,120,999)
    field_information['GGDM 3.0']['MilitarySrf']['PRM'] = ('Boolean',('AH060','AL120','FA015'))
    field_information['GGDM 3.0']['MilitarySrf']['RLE'] = ('Enumeration',('AH055'))
    field_information['GGDM 3.0']['MilitarySrf']['EnumeratedIndexValues']['RLE'] = {}
    field_information['GGDM 3.0']['MilitarySrf']['EnumeratedIndexValues']['RLE']['AH055']  = (-999999,1,2,3)
    field_information['GGDM 3.0']['MilitarySrf']['SSR'] = ('Enumeration',('AH055'))
    field_information['GGDM 3.0']['MilitarySrf']['EnumeratedIndexValues']['SSR'] = {}
    field_information['GGDM 3.0']['MilitarySrf']['EnumeratedIndexValues']['SSR']['AH055']  = (-999999,6,7,38,40,41,42,47,50,55,64,999)
    field_information['GGDM 3.0']['MilitarySrf']['SSR2'] = ('Enumeration',('AH055'))
    field_information['GGDM 3.0']['MilitarySrf']['EnumeratedIndexValues']['SSR2'] = {}
    field_information['GGDM 3.0']['MilitarySrf']['EnumeratedIndexValues']['SSR2']['AH055']  = (-999999,6,7,38,40,41,42,47,50,55,64,999)
    field_information['GGDM 3.0']['MilitarySrf']['SSR3'] = ('Enumeration',('AH055'))
    field_information['GGDM 3.0']['MilitarySrf']['EnumeratedIndexValues']['SSR3'] = {}
    field_information['GGDM 3.0']['MilitarySrf']['EnumeratedIndexValues']['SSR3']['AH055']  = (-999999,6,7,38,40,41,42,47,50,55,64,999)
    field_information['GGDM 3.0']['MilitarySrf']['UFI'] = ('StructuredText',('AH025','AH055','AH060','AL060','AL065','AL120','AL375','AL376','AM060','FA015','FA100','FA165','SU001','SU004'))
    field_information['GGDM 3.0']['MilitarySrf']['VCM'] = ('Enumeration',('AH055','AL120'))
    field_information['GGDM 3.0']['MilitarySrf']['EnumeratedIndexValues']['VCM'] = {}
    field_information['GGDM 3.0']['MilitarySrf']['EnumeratedIndexValues']['VCM']['AH055']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,999)
    field_information['GGDM 3.0']['MilitarySrf']['EnumeratedIndexValues']['VCM']['AL120']  = (-999999,3,4,6,7,8,9,12,13,15,16,18,999)
    field_information['GGDM 3.0']['MilitarySrf']['VCM2'] = ('Enumeration',('AH055','AL120'))
    field_information['GGDM 3.0']['MilitarySrf']['EnumeratedIndexValues']['VCM2'] = {}
    field_information['GGDM 3.0']['MilitarySrf']['EnumeratedIndexValues']['VCM2']['AH055']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,999)
    field_information['GGDM 3.0']['MilitarySrf']['EnumeratedIndexValues']['VCM2']['AL120']  = (-999999,3,4,6,7,8,9,12,13,15,16,18,999)
    field_information['GGDM 3.0']['MilitarySrf']['VCM3'] = ('Enumeration',('AH055','AL120'))
    field_information['GGDM 3.0']['MilitarySrf']['EnumeratedIndexValues']['VCM3'] = {}
    field_information['GGDM 3.0']['MilitarySrf']['EnumeratedIndexValues']['VCM3']['AH055']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,999)
    field_information['GGDM 3.0']['MilitarySrf']['EnumeratedIndexValues']['VCM3']['AL120']  = (-999999,3,4,6,7,8,9,12,13,15,16,18,999)
    field_information['GGDM 3.0']['MilitarySrf']['VOI'] = ('StructuredText',('AH055','AL375'))
    field_information['GGDM 3.0']['MilitarySrf']['WD3'] = ('Real',('AH025'))
    field_information['GGDM 3.0']['MilitarySrf']['WID'] = ('Real',('AH025','AH055','AH060','AL060','AL065','AL120','AL375','AL376','AM060','FA015','FA100','FA165','SU001','SU004'))
    field_information['GGDM 3.0']['MilitarySrf']['WPST'] = ('Integer',('AH055'))
    field_information['GGDM 3.0']['MilitarySrf']['WTYP'] = ('Enumeration',('AH055'))
    field_information['GGDM 3.0']['MilitarySrf']['EnumeratedIndexValues']['WTYP'] = {}
    field_information['GGDM 3.0']['MilitarySrf']['EnumeratedIndexValues']['WTYP']['AH055']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['MilitarySrf']['YSU'] = ('Enumeration',('AH025','AH055','AH060','AL120','FA015','SU001'))
    field_information['GGDM 3.0']['MilitarySrf']['EnumeratedIndexValues']['YSU'] = {}
    field_information['GGDM 3.0']['MilitarySrf']['EnumeratedIndexValues']['YSU']['AH025']  = (-999999,1,2,3,4,5,7,8,9,999)
    field_information['GGDM 3.0']['MilitarySrf']['EnumeratedIndexValues']['YSU']['AH055']  = (-999999,1,2,3,4,5,7,999)
    field_information['GGDM 3.0']['MilitarySrf']['EnumeratedIndexValues']['YSU']['AH060']  = (-999999,1,2,3,4,5,7,999)
    field_information['GGDM 3.0']['MilitarySrf']['EnumeratedIndexValues']['YSU']['AL120']  = (-999999,1,2,3,4,5,7,999)
    field_information['GGDM 3.0']['MilitarySrf']['EnumeratedIndexValues']['YSU']['FA015']  = (-999999,1,2,3,4,5,7,8,9,998,999)
    field_information['GGDM 3.0']['MilitarySrf']['EnumeratedIndexValues']['YSU']['SU001']  = (-999999,1,2,3,4,5,7,8,9,999)
    field_information['GGDM 3.0']['MilitarySrf']['ZI001_SDV'] = ('StructuredText',('AH025','AH055','AH060','AL060','AL065','AL120','AL375','AL376','AM060','FA015','FA100','FA165','SU001','SU004'))
    field_information['GGDM 3.0']['MilitarySrf']['ZI001_SRT'] = ('Enumeration',('AH025','AH055','AH060','AL060','AL065','AL120','AL375','AL376','AM060','FA015','FA100','FA165','SU001','SU004'))
    field_information['GGDM 3.0']['MilitarySrf']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['MilitarySrf']['EnumeratedIndexValues']['ZI001_SRT']['AH025']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['MilitarySrf']['EnumeratedIndexValues']['ZI001_SRT']['AH055']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['MilitarySrf']['EnumeratedIndexValues']['ZI001_SRT']['AH060']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['MilitarySrf']['EnumeratedIndexValues']['ZI001_SRT']['AL060']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['MilitarySrf']['EnumeratedIndexValues']['ZI001_SRT']['AL065']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['MilitarySrf']['EnumeratedIndexValues']['ZI001_SRT']['AL120']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['MilitarySrf']['EnumeratedIndexValues']['ZI001_SRT']['AL375']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['MilitarySrf']['EnumeratedIndexValues']['ZI001_SRT']['AL376']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['MilitarySrf']['EnumeratedIndexValues']['ZI001_SRT']['AM060']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['MilitarySrf']['EnumeratedIndexValues']['ZI001_SRT']['FA015']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['MilitarySrf']['EnumeratedIndexValues']['ZI001_SRT']['FA100']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['MilitarySrf']['EnumeratedIndexValues']['ZI001_SRT']['FA165']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['MilitarySrf']['EnumeratedIndexValues']['ZI001_SRT']['SU001']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['MilitarySrf']['EnumeratedIndexValues']['ZI001_SRT']['SU004']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['MilitarySrf']['ZI002_UFI'] = ('StructuredText',('AH025','AH055','AH060','AL060','AL065','AL120','AL375','AL376','AM060','FA015','FA100','FA165','SU001','SU004'))
    field_information['GGDM 3.0']['MilitarySrf']['ZI004_RCG'] = ('Enumeration',('AH025','AH055','AH060','AL060','AL065','AL120','AL375','AL376','AM060','FA015','FA100','FA165','SU001','SU004'))
    field_information['GGDM 3.0']['MilitarySrf']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['MilitarySrf']['EnumeratedIndexValues']['ZI004_RCG']['AH025']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['MilitarySrf']['EnumeratedIndexValues']['ZI004_RCG']['AH055']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['MilitarySrf']['EnumeratedIndexValues']['ZI004_RCG']['AH060']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['MilitarySrf']['EnumeratedIndexValues']['ZI004_RCG']['AL060']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['MilitarySrf']['EnumeratedIndexValues']['ZI004_RCG']['AL065']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['MilitarySrf']['EnumeratedIndexValues']['ZI004_RCG']['AL120']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['MilitarySrf']['EnumeratedIndexValues']['ZI004_RCG']['AL375']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['MilitarySrf']['EnumeratedIndexValues']['ZI004_RCG']['AL376']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['MilitarySrf']['EnumeratedIndexValues']['ZI004_RCG']['AM060']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['MilitarySrf']['EnumeratedIndexValues']['ZI004_RCG']['FA015']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['MilitarySrf']['EnumeratedIndexValues']['ZI004_RCG']['FA100']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['MilitarySrf']['EnumeratedIndexValues']['ZI004_RCG']['FA165']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['MilitarySrf']['EnumeratedIndexValues']['ZI004_RCG']['SU001']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['MilitarySrf']['EnumeratedIndexValues']['ZI004_RCG']['SU004']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['MilitarySrf']['ZI005_FNA'] = ('String',('AH025','AH055','AH060','AL120','AL375','AL376','AM060','FA015','FA100','FA165','SU001','SU004'))
    field_information['GGDM 3.0']['MilitarySrf']['ZI005_GNT'] = ('Enumeration',('AH025','AH055','AH060','AL120','AL375','AL376','AM060','FA015','FA100','FA165','SU001','SU004'))
    field_information['GGDM 3.0']['MilitarySrf']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['MilitarySrf']['EnumeratedIndexValues']['ZI005_GNT']['AH025']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['MilitarySrf']['EnumeratedIndexValues']['ZI005_GNT']['AH055']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['MilitarySrf']['EnumeratedIndexValues']['ZI005_GNT']['AH060']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['MilitarySrf']['EnumeratedIndexValues']['ZI005_GNT']['AL120']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['MilitarySrf']['EnumeratedIndexValues']['ZI005_GNT']['AL375']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['MilitarySrf']['EnumeratedIndexValues']['ZI005_GNT']['AL376']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['MilitarySrf']['EnumeratedIndexValues']['ZI005_GNT']['AM060']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['MilitarySrf']['EnumeratedIndexValues']['ZI005_GNT']['FA015']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['MilitarySrf']['EnumeratedIndexValues']['ZI005_GNT']['FA100']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['MilitarySrf']['EnumeratedIndexValues']['ZI005_GNT']['FA165']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['MilitarySrf']['EnumeratedIndexValues']['ZI005_GNT']['SU001']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['MilitarySrf']['EnumeratedIndexValues']['ZI005_GNT']['SU004']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['MilitarySrf']['ZI005_NFN'] = ('String',('AH025','AH055','AH060','AL120','AL375','AL376','AM060','FA015','FA100','FA165','SU001','SU004'))
    field_information['GGDM 3.0']['MilitarySrf']['ZI006_MEM'] = ('String',('AH025','AH055','AH060','AL060','AL065','AL120','AL375','AL376','AM060','FA015','FA100','FA165','SU001','SU004'))
    field_information['GGDM 3.0']['MilitarySrf']['ZI014_PBY'] = ('Enumeration',('AH055'))
    field_information['GGDM 3.0']['MilitarySrf']['EnumeratedIndexValues']['ZI014_PBY'] = {}
    field_information['GGDM 3.0']['MilitarySrf']['EnumeratedIndexValues']['ZI014_PBY']['AH055']  = (-999999,1,2,6,7,8,12,13,15,89,999)
    field_information['GGDM 3.0']['MilitarySrf']['ZI014_PBY2'] = ('Enumeration',('AH055'))
    field_information['GGDM 3.0']['MilitarySrf']['EnumeratedIndexValues']['ZI014_PBY2'] = {}
    field_information['GGDM 3.0']['MilitarySrf']['EnumeratedIndexValues']['ZI014_PBY2']['AH055']  = (-999999,1,2,6,7,8,12,13,15,89,999)
    field_information['GGDM 3.0']['MilitarySrf']['ZI014_PBY3'] = ('Enumeration',('AH055'))
    field_information['GGDM 3.0']['MilitarySrf']['EnumeratedIndexValues']['ZI014_PBY3'] = {}
    field_information['GGDM 3.0']['MilitarySrf']['EnumeratedIndexValues']['ZI014_PBY3']['AH055']  = (-999999,1,2,6,7,8,12,13,15,89,999)
    field_information['GGDM 3.0']['MilitarySrf']['ZI014_PPO'] = ('Enumeration',('AH055'))
    field_information['GGDM 3.0']['MilitarySrf']['EnumeratedIndexValues']['ZI014_PPO'] = {}
    field_information['GGDM 3.0']['MilitarySrf']['EnumeratedIndexValues']['ZI014_PPO']['AH055']  = (-999999,1,2,3,4,5,13,15,16,18,20,21,23,25,26,28,32,37,38,39,41,43,44,45,46,47,48,57,58,59,60,61,62,63,65,69,70,73,74,80,83,84,87,90,92,94,95,101,105,106,109,111,114,117,120,121,122,123,126,136,137,146,147,148,150,154,155,156,157,160,165,192,200,214,279,325,435,999)
    field_information['GGDM 3.0']['MilitarySrf']['ZI014_PPO2'] = ('Enumeration',('AH055'))
    field_information['GGDM 3.0']['MilitarySrf']['EnumeratedIndexValues']['ZI014_PPO2'] = {}
    field_information['GGDM 3.0']['MilitarySrf']['EnumeratedIndexValues']['ZI014_PPO2']['AH055']  = (-999999,1,2,3,4,5,13,15,16,18,20,21,23,25,26,28,32,37,38,39,41,43,44,45,46,47,48,57,58,59,60,61,62,63,65,69,70,73,74,80,83,84,87,90,92,94,95,101,105,106,109,111,114,117,120,121,122,123,126,136,137,146,147,148,150,154,155,156,157,160,165,192,200,214,279,325,435,999)
    field_information['GGDM 3.0']['MilitarySrf']['ZI014_PPO3'] = ('Enumeration',('AH055'))
    field_information['GGDM 3.0']['MilitarySrf']['EnumeratedIndexValues']['ZI014_PPO3'] = {}
    field_information['GGDM 3.0']['MilitarySrf']['EnumeratedIndexValues']['ZI014_PPO3']['AH055']  = (-999999,1,2,3,4,5,13,15,16,18,20,21,23,25,26,28,32,37,38,39,41,43,44,45,46,47,48,57,58,59,60,61,62,63,65,69,70,73,74,80,83,84,87,90,92,94,95,101,105,106,109,111,114,117,120,121,122,123,126,136,137,146,147,148,150,154,155,156,157,160,165,192,200,214,279,325,435,999)
    field_information['GGDM 3.0']['MilitarySrf']['ZI014_PRW'] = ('Enumeration',('AH055'))
    field_information['GGDM 3.0']['MilitarySrf']['EnumeratedIndexValues']['ZI014_PRW'] = {}
    field_information['GGDM 3.0']['MilitarySrf']['EnumeratedIndexValues']['ZI014_PRW']['AH055']  = (-999999,1,2,5,9,10,11,12,14,16,18,27,28,29,30,33,38,39,41,45,46,48,50,52,54,57,60,64,66,68,70,75,78,79,83,84,85,87,90,93,94,96,97,99,118,119,999)
    field_information['GGDM 3.0']['MilitarySrf']['ZI014_PRW2'] = ('Enumeration',('AH055'))
    field_information['GGDM 3.0']['MilitarySrf']['EnumeratedIndexValues']['ZI014_PRW2'] = {}
    field_information['GGDM 3.0']['MilitarySrf']['EnumeratedIndexValues']['ZI014_PRW2']['AH055']  = (-999999,1,2,5,9,10,11,12,14,16,18,27,28,29,30,33,38,39,41,45,46,48,50,52,54,57,60,64,66,68,70,75,78,79,83,84,85,87,90,93,94,96,97,99,118,119,999)
    field_information['GGDM 3.0']['MilitarySrf']['ZI014_PRW3'] = ('Enumeration',('AH055'))
    field_information['GGDM 3.0']['MilitarySrf']['EnumeratedIndexValues']['ZI014_PRW3'] = {}
    field_information['GGDM 3.0']['MilitarySrf']['EnumeratedIndexValues']['ZI014_PRW3']['AH055']  = (-999999,1,2,5,9,10,11,12,14,16,18,27,28,29,30,33,38,39,41,45,46,48,50,52,54,57,60,64,66,68,70,75,78,79,83,84,85,87,90,93,94,96,97,99,118,119,999)
    field_information['GGDM 3.0']['MilitarySrf']['ZI018_WIT'] = ('Enumeration',('AH055'))
    field_information['GGDM 3.0']['MilitarySrf']['EnumeratedIndexValues']['ZI018_WIT'] = {}
    field_information['GGDM 3.0']['MilitarySrf']['EnumeratedIndexValues']['ZI018_WIT']['AH055']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['MilitarySrf']['ZI020_GE4'] = ('CodeList',('AH025','AH055','AH060','AL060','AL065','AL120','AL375','AL376','AM060','FA015','FA100','FA165','SU001','SU004'))
    field_information['GGDM 3.0']['MilitarySrf']['ZI025_HDP'] = ('Real',('FA015'))
    field_information['GGDM 3.0']['MilitarySrf']['ZI026_CTUC'] = ('Enumeration',('AH025','AH055','AH060','AL060','AL065','AL120','AL375','AL376','AM060','FA015','FA100','FA165','SU001','SU004'))
    field_information['GGDM 3.0']['MilitarySrf']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['MilitarySrf']['EnumeratedIndexValues']['ZI026_CTUC']['AH025']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['MilitarySrf']['EnumeratedIndexValues']['ZI026_CTUC']['AH055']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['MilitarySrf']['EnumeratedIndexValues']['ZI026_CTUC']['AH060']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['MilitarySrf']['EnumeratedIndexValues']['ZI026_CTUC']['AL060']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['MilitarySrf']['EnumeratedIndexValues']['ZI026_CTUC']['AL065']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['MilitarySrf']['EnumeratedIndexValues']['ZI026_CTUC']['AL120']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['MilitarySrf']['EnumeratedIndexValues']['ZI026_CTUC']['AL375']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['MilitarySrf']['EnumeratedIndexValues']['ZI026_CTUC']['AL376']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['MilitarySrf']['EnumeratedIndexValues']['ZI026_CTUC']['AM060']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['MilitarySrf']['EnumeratedIndexValues']['ZI026_CTUC']['FA015']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['MilitarySrf']['EnumeratedIndexValues']['ZI026_CTUC']['FA100']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['MilitarySrf']['EnumeratedIndexValues']['ZI026_CTUC']['FA165']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['MilitarySrf']['EnumeratedIndexValues']['ZI026_CTUC']['SU001']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['MilitarySrf']['EnumeratedIndexValues']['ZI026_CTUC']['SU004']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['MilitarySrf']['ZI026_CTUL'] = ('integer',('AH025','AH055','AH060','AL060','AL065','AL120','AL375','AL376','AM060','FA015','FA100','FA165','SU001','SU004'))
    field_information['GGDM 3.0']['MilitarySrf']['ZI026_CTUU'] = ('integer',('AH025','AH055','AH060','AL060','AL065','AL120','AL375','AL376','AM060','FA015','FA100','FA165','SU001','SU004'))
    field_information['GGDM 3.0']['MilitarySrf']['ZI031S_URI'] = ('StructuredText',('AH025','AH055','AH060','AL060','AL065','AL120','AL375','AL376','AM060','FA015','FA100','FA165','SU001','SU004'))
    field_information['GGDM 3.0']['MilitarySrf']['ZI039S_UFI'] = ('StructuredText',('AH025','AH055','AH060','AL060','AL065','AL120','AL375','AL376','AM060','FA015','FA100','FA165','SU001','SU004'))
    field_information['GGDM 3.0']['MilitarySrf']['ZSAX_RS0'] = ('CodeList',('AH025','AH055','AH060','AL060','AL065','AL120','AL375','AL376','AM060','FA015','FA100','FA165','SU001','SU004'))
    field_information['GGDM 3.0']['MilitarySrf']['ZSAX_RX0'] = ('StructuredText',('AH025','AH055','AH060','AL060','AL065','AL120','AL375','AL376','AM060','FA015','FA100','FA165','SU001','SU004'))
    field_information['GGDM 3.0']['MilitarySrf']['ZSAX_RX3'] = ('StructuredText',('AH025','AH055','AH060','AL060','AL065','AL120','AL375','AL376','AM060','FA015','FA100','FA165','SU001','SU004'))
    field_information['GGDM 3.0']['MilitarySrf']['ZSAX_RX4'] = ('StructuredText',('AH025','AH055','AH060','AL060','AL065','AL120','AL375','AL376','AM060','FA015','FA100','FA165','SU001','SU004'))
    field_information['GGDM 3.0']['MilitarySrf']['ZVH'] = ('Real',('AH055','AL120','AL375','AL376','AM060','FA015','FA165'))
    field_information['GGDM 3.0']['MilitarySrfExt']['ARA'] = ('Real',('AL121'))
    field_information['GGDM 3.0']['MilitarySrfExt']['AZC'] = ('Boolean',('BB150'))
    field_information['GGDM 3.0']['MilitarySrfExt']['BEN'] = ('StructuredText',('AL121','BB150'))
    field_information['GGDM 3.0']['MilitarySrfExt']['CAA'] = ('Enumeration',('AL121'))
    field_information['GGDM 3.0']['MilitarySrfExt']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['MilitarySrfExt']['EnumeratedIndexValues']['CAA']['AL121']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['MilitarySrfExt']['CNCP'] = ('StructuredText',('AL121','BB150'))
    field_information['GGDM 3.0']['MilitarySrfExt']['COS'] = ('Enumeration',('AL121','BB150'))
    field_information['GGDM 3.0']['MilitarySrfExt']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['MilitarySrfExt']['EnumeratedIndexValues']['COS']['AL121']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['MilitarySrfExt']['EnumeratedIndexValues']['COS']['BB150']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['MilitarySrfExt']['F_CODE'] = ('CONSTRAINED_STRING',('AL121','BB150'))
    field_information['GGDM 3.0']['MilitarySrfExt']['FUFI'] = ('StructuredText',('AL121','BB150'))
    field_information['GGDM 3.0']['MilitarySrfExt']['FURL'] = ('StructuredText',('AL121','BB150'))
    field_information['GGDM 3.0']['MilitarySrfExt']['GDBV'] = ('Enumeration',('AL121','BB150'))
    field_information['GGDM 3.0']['MilitarySrfExt']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['MilitarySrfExt']['EnumeratedIndexValues']['GDBV']['AL121']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['MilitarySrfExt']['EnumeratedIndexValues']['GDBV']['BB150']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['MilitarySrfExt']['HGT'] = ('Real',('AL121'))
    field_information['GGDM 3.0']['MilitarySrfExt']['LMC'] = ('Boolean',('AL121'))
    field_information['GGDM 3.0']['MilitarySrfExt']['LZN'] = ('Real',('AL121'))
    field_information['GGDM 3.0']['MilitarySrfExt']['OTH'] = ('StructuredText',('AL121','BB150'))
    field_information['GGDM 3.0']['MilitarySrfExt']['PCF'] = ('Enumeration',('AL121','BB150'))
    field_information['GGDM 3.0']['MilitarySrfExt']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['MilitarySrfExt']['EnumeratedIndexValues']['PCF']['AL121']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['MilitarySrfExt']['EnumeratedIndexValues']['PCF']['BB150']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['MilitarySrfExt']['UFI'] = ('StructuredText',('AL121','BB150'))
    field_information['GGDM 3.0']['MilitarySrfExt']['VCM'] = ('Enumeration',('AL121'))
    field_information['GGDM 3.0']['MilitarySrfExt']['EnumeratedIndexValues']['VCM'] = {}
    field_information['GGDM 3.0']['MilitarySrfExt']['EnumeratedIndexValues']['VCM']['AL121']  = (-999999,3,4,7,8,9,12,13,15,16,18,999)
    field_information['GGDM 3.0']['MilitarySrfExt']['VCM2'] = ('Enumeration',('AL121'))
    field_information['GGDM 3.0']['MilitarySrfExt']['EnumeratedIndexValues']['VCM2'] = {}
    field_information['GGDM 3.0']['MilitarySrfExt']['EnumeratedIndexValues']['VCM2']['AL121']  = (-999999,3,4,7,8,9,12,13,15,16,18,999)
    field_information['GGDM 3.0']['MilitarySrfExt']['VCM3'] = ('Enumeration',('AL121'))
    field_information['GGDM 3.0']['MilitarySrfExt']['EnumeratedIndexValues']['VCM3'] = {}
    field_information['GGDM 3.0']['MilitarySrfExt']['EnumeratedIndexValues']['VCM3']['AL121']  = (-999999,3,4,7,8,9,12,13,15,16,18,999)
    field_information['GGDM 3.0']['MilitarySrfExt']['WID'] = ('Real',('AL121'))
    field_information['GGDM 3.0']['MilitarySrfExt']['YSU'] = ('Enumeration',('AL121'))
    field_information['GGDM 3.0']['MilitarySrfExt']['EnumeratedIndexValues']['YSU'] = {}
    field_information['GGDM 3.0']['MilitarySrfExt']['EnumeratedIndexValues']['YSU']['AL121']  = (-999999,1,2,3,4,5,7,999)
    field_information['GGDM 3.0']['MilitarySrfExt']['ZI001_SDV'] = ('StructuredText',('AL121','BB150'))
    field_information['GGDM 3.0']['MilitarySrfExt']['ZI001_SRT'] = ('Enumeration',('AL121','BB150'))
    field_information['GGDM 3.0']['MilitarySrfExt']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['MilitarySrfExt']['EnumeratedIndexValues']['ZI001_SRT']['AL121']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['MilitarySrfExt']['EnumeratedIndexValues']['ZI001_SRT']['BB150']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['MilitarySrfExt']['ZI002_UFI'] = ('StructuredText',('AL121','BB150'))
    field_information['GGDM 3.0']['MilitarySrfExt']['ZI004_RCG'] = ('Enumeration',('AL121','BB150'))
    field_information['GGDM 3.0']['MilitarySrfExt']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['MilitarySrfExt']['EnumeratedIndexValues']['ZI004_RCG']['AL121']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['MilitarySrfExt']['EnumeratedIndexValues']['ZI004_RCG']['BB150']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['MilitarySrfExt']['ZI005_FNA'] = ('String',('AL121'))
    field_information['GGDM 3.0']['MilitarySrfExt']['ZI005_GNT'] = ('Enumeration',('AL121'))
    field_information['GGDM 3.0']['MilitarySrfExt']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['MilitarySrfExt']['EnumeratedIndexValues']['ZI005_GNT']['AL121']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['MilitarySrfExt']['ZI005_NFN'] = ('String',('AL121'))
    field_information['GGDM 3.0']['MilitarySrfExt']['ZI006_MEM'] = ('String',('AL121','BB150'))
    field_information['GGDM 3.0']['MilitarySrfExt']['ZI020_GE4'] = ('CodeList',('AL121','BB150'))
    field_information['GGDM 3.0']['MilitarySrfExt']['ZI026_CTUC'] = ('Enumeration',('AL121','BB150'))
    field_information['GGDM 3.0']['MilitarySrfExt']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['MilitarySrfExt']['EnumeratedIndexValues']['ZI026_CTUC']['AL121']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['MilitarySrfExt']['EnumeratedIndexValues']['ZI026_CTUC']['BB150']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['MilitarySrfExt']['ZI026_CTUL'] = ('integer',('AL121','BB150'))
    field_information['GGDM 3.0']['MilitarySrfExt']['ZI026_CTUU'] = ('integer',('AL121','BB150'))
    field_information['GGDM 3.0']['MilitarySrfExt']['ZI031S_URI'] = ('StructuredText',('AL121','BB150'))
    field_information['GGDM 3.0']['MilitarySrfExt']['ZI039S_UFI'] = ('StructuredText',('AL121','BB150'))
    field_information['GGDM 3.0']['MilitarySrfExt']['ZSAX_RS0'] = ('CodeList',('AL121','BB150'))
    field_information['GGDM 3.0']['MilitarySrfExt']['ZSAX_RX0'] = ('StructuredText',('AL121','BB150'))
    field_information['GGDM 3.0']['MilitarySrfExt']['ZSAX_RX3'] = ('StructuredText',('AL121','BB150'))
    field_information['GGDM 3.0']['MilitarySrfExt']['ZSAX_RX4'] = ('StructuredText',('AL121','BB150'))
    field_information['GGDM 3.0']['PhysiographyAONExt']['ARA'] = ('Real',('NM160'))
    field_information['GGDM 3.0']['PhysiographyAONExt']['BEN'] = ('StructuredText',('NM160'))
    field_information['GGDM 3.0']['PhysiographyAONExt']['DMF'] = ('Integer',('NM160'))
    field_information['GGDM 3.0']['PhysiographyAONExt']['F_CODE'] = ('CONSTRAINED_STRING',('NM160'))
    field_information['GGDM 3.0']['PhysiographyAONExt']['FUFI'] = ('StructuredText',('NM160'))
    field_information['GGDM 3.0']['PhysiographyAONExt']['FURL'] = ('StructuredText',('NM160'))
    field_information['GGDM 3.0']['PhysiographyAONExt']['GDBV'] = ('Enumeration',('NM160'))
    field_information['GGDM 3.0']['PhysiographyAONExt']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['PhysiographyAONExt']['EnumeratedIndexValues']['GDBV']['NM160']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['PhysiographyAONExt']['LMC'] = ('Boolean',('NM160'))
    field_information['GGDM 3.0']['PhysiographyAONExt']['LZN'] = ('Real',('NM160'))
    field_information['GGDM 3.0']['PhysiographyAONExt']['OTH'] = ('StructuredText',('NM160'))
    field_information['GGDM 3.0']['PhysiographyAONExt']['UFI'] = ('StructuredText',('NM160'))
    field_information['GGDM 3.0']['PhysiographyAONExt']['WID'] = ('Real',('NM160'))
    field_information['GGDM 3.0']['PhysiographyAONExt']['ZI001_SDV'] = ('StructuredText',('NM160'))
    field_information['GGDM 3.0']['PhysiographyAONExt']['ZI001_SRT'] = ('Enumeration',('NM160'))
    field_information['GGDM 3.0']['PhysiographyAONExt']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['PhysiographyAONExt']['EnumeratedIndexValues']['ZI001_SRT']['NM160']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['PhysiographyAONExt']['ZI002_UFI'] = ('StructuredText',('NM160'))
    field_information['GGDM 3.0']['PhysiographyAONExt']['ZI004_RCG'] = ('Enumeration',('NM160'))
    field_information['GGDM 3.0']['PhysiographyAONExt']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['PhysiographyAONExt']['EnumeratedIndexValues']['ZI004_RCG']['NM160']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['PhysiographyAONExt']['ZI005_FNA'] = ('String',('NM160'))
    field_information['GGDM 3.0']['PhysiographyAONExt']['ZI005_GNT'] = ('Enumeration',('NM160'))
    field_information['GGDM 3.0']['PhysiographyAONExt']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['PhysiographyAONExt']['EnumeratedIndexValues']['ZI005_GNT']['NM160']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['PhysiographyAONExt']['ZI005_NFN'] = ('String',('NM160'))
    field_information['GGDM 3.0']['PhysiographyAONExt']['ZI006_MEM'] = ('String',('NM160'))
    field_information['GGDM 3.0']['PhysiographyAONExt']['ZI020_GE4'] = ('CodeList',('NM160'))
    field_information['GGDM 3.0']['PhysiographyAONExt']['ZI026_CTUC'] = ('Enumeration',('NM160'))
    field_information['GGDM 3.0']['PhysiographyAONExt']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['PhysiographyAONExt']['EnumeratedIndexValues']['ZI026_CTUC']['NM160']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['PhysiographyAONExt']['ZI026_CTUL'] = ('integer',('NM160'))
    field_information['GGDM 3.0']['PhysiographyAONExt']['ZI026_CTUU'] = ('integer',('NM160'))
    field_information['GGDM 3.0']['PhysiographyAONExt']['ZI031S_URI'] = ('StructuredText',('NM160'))
    field_information['GGDM 3.0']['PhysiographyAONExt']['ZI039S_UFI'] = ('StructuredText',('NM160'))
    field_information['GGDM 3.0']['PhysiographyAONExt']['ZSAX_RS0'] = ('CodeList',('NM160'))
    field_information['GGDM 3.0']['PhysiographyAONExt']['ZSAX_RX0'] = ('StructuredText',('NM160'))
    field_information['GGDM 3.0']['PhysiographyAONExt']['ZSAX_RX3'] = ('StructuredText',('NM160'))
    field_information['GGDM 3.0']['PhysiographyAONExt']['ZSAX_RX4'] = ('StructuredText',('NM160'))
    field_information['GGDM 3.0']['PhysiographyCrv']['ARA'] = ('Real',('BJ031','DB010','DB061','DB070','DB090','DB100','DB110','DB190'))
    field_information['GGDM 3.0']['PhysiographyCrv']['AZC'] = ('Boolean',('BA010'))
    field_information['GGDM 3.0']['PhysiographyCrv']['BA000_VDC'] = ('Enumeration',('BA010'))
    field_information['GGDM 3.0']['PhysiographyCrv']['EnumeratedIndexValues']['BA000_VDC'] = {}
    field_information['GGDM 3.0']['PhysiographyCrv']['EnumeratedIndexValues']['BA000_VDC']['BA010']  = (-999999,4,7,9,10,11,13,14,15,19,20,24,28,30,90,999)
    field_information['GGDM 3.0']['PhysiographyCrv']['BA000_VDR'] = ('String',('BA010'))
    field_information['GGDM 3.0']['PhysiographyCrv']['BEN'] = ('StructuredText',('BA010','BJ031','BJ040','DB010','DB061','DB070','DB071','DB090','DB100','DB110','DB190'))
    field_information['GGDM 3.0']['PhysiographyCrv']['CAA'] = ('Enumeration',('DB090'))
    field_information['GGDM 3.0']['PhysiographyCrv']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['PhysiographyCrv']['EnumeratedIndexValues']['CAA']['DB090']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['PhysiographyCrv']['CET'] = ('Enumeration',('DB070','DB090'))
    field_information['GGDM 3.0']['PhysiographyCrv']['EnumeratedIndexValues']['CET'] = {}
    field_information['GGDM 3.0']['PhysiographyCrv']['EnumeratedIndexValues']['CET']['DB070']  = (-999999,1,2,999)
    field_information['GGDM 3.0']['PhysiographyCrv']['EnumeratedIndexValues']['CET']['DB090']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['PhysiographyCrv']['CNCP'] = ('StructuredText',('DB090'))
    field_information['GGDM 3.0']['PhysiographyCrv']['COS'] = ('Enumeration',('DB090'))
    field_information['GGDM 3.0']['PhysiographyCrv']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['PhysiographyCrv']['EnumeratedIndexValues']['COS']['DB090']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['PhysiographyCrv']['DZP'] = ('Real',('BJ031','DB061','DB070'))
    field_information['GGDM 3.0']['PhysiographyCrv']['F_CODE'] = ('CONSTRAINED_STRING',('BA010','BJ031','BJ040','DB010','DB061','DB070','DB071','DB090','DB100','DB110','DB190'))
    field_information['GGDM 3.0']['PhysiographyCrv']['FDI'] = ('Real',('DB110'))
    field_information['GGDM 3.0']['PhysiographyCrv']['FIC'] = ('Enumeration',('DB090'))
    field_information['GGDM 3.0']['PhysiographyCrv']['EnumeratedIndexValues']['FIC'] = {}
    field_information['GGDM 3.0']['PhysiographyCrv']['EnumeratedIndexValues']['FIC']['DB090']  = (-999999,1,2,3,5,6,999)
    field_information['GGDM 3.0']['PhysiographyCrv']['FUFI'] = ('StructuredText',('BA010','BJ031','BJ040','DB010','DB061','DB070','DB071','DB090','DB100','DB110','DB190'))
    field_information['GGDM 3.0']['PhysiographyCrv']['FURL'] = ('StructuredText',('BA010','BJ031','BJ040','DB010','DB061','DB070','DB071','DB090','DB100','DB110','DB190'))
    field_information['GGDM 3.0']['PhysiographyCrv']['GDBV'] = ('Enumeration',('BA010','BJ031','BJ040','DB010','DB061','DB070','DB071','DB090','DB100','DB110','DB190'))
    field_information['GGDM 3.0']['PhysiographyCrv']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['PhysiographyCrv']['EnumeratedIndexValues']['GDBV']['BA010']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['PhysiographyCrv']['EnumeratedIndexValues']['GDBV']['BJ031']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['PhysiographyCrv']['EnumeratedIndexValues']['GDBV']['BJ040']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['PhysiographyCrv']['EnumeratedIndexValues']['GDBV']['DB010']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['PhysiographyCrv']['EnumeratedIndexValues']['GDBV']['DB061']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['PhysiographyCrv']['EnumeratedIndexValues']['GDBV']['DB070']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['PhysiographyCrv']['EnumeratedIndexValues']['GDBV']['DB071']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['PhysiographyCrv']['EnumeratedIndexValues']['GDBV']['DB090']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['PhysiographyCrv']['EnumeratedIndexValues']['GDBV']['DB100']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['PhysiographyCrv']['EnumeratedIndexValues']['GDBV']['DB110']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['PhysiographyCrv']['EnumeratedIndexValues']['GDBV']['DB190']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['PhysiographyCrv']['GFT'] = ('Boolean',('DB110'))
    field_information['GGDM 3.0']['PhysiographyCrv']['GFY'] = ('Enumeration',('DB110'))
    field_information['GGDM 3.0']['PhysiographyCrv']['EnumeratedIndexValues']['GFY'] = {}
    field_information['GGDM 3.0']['PhysiographyCrv']['EnumeratedIndexValues']['GFY']['DB110']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,999)
    field_information['GGDM 3.0']['PhysiographyCrv']['HDP'] = ('Real',('DB070'))
    field_information['GGDM 3.0']['PhysiographyCrv']['HGT'] = ('Real',('BJ040','DB010','DB070','DB090','DB100','DB190'))
    field_information['GGDM 3.0']['PhysiographyCrv']['LMC'] = ('Boolean',('DB090','DB100'))
    field_information['GGDM 3.0']['PhysiographyCrv']['LZN'] = ('Real',('BA010','BJ031','BJ040','DB010','DB061','DB070','DB071','DB090','DB100','DB110','DB190'))
    field_information['GGDM 3.0']['PhysiographyCrv']['MCC'] = ('Enumeration',('DB010','DB061','DB090'))
    field_information['GGDM 3.0']['PhysiographyCrv']['EnumeratedIndexValues']['MCC'] = {}
    field_information['GGDM 3.0']['PhysiographyCrv']['EnumeratedIndexValues']['MCC']['DB010']  = (-999999,84,104,999)
    field_information['GGDM 3.0']['PhysiographyCrv']['EnumeratedIndexValues']['MCC']['DB061']  = (-999999,84,104,999)
    field_information['GGDM 3.0']['PhysiographyCrv']['EnumeratedIndexValues']['MCC']['DB090']  = (-999999,8,21,46,52,62,64,84,86,104,117,999)
    field_information['GGDM 3.0']['PhysiographyCrv']['MCC2'] = ('Enumeration',('DB010','DB061','DB090'))
    field_information['GGDM 3.0']['PhysiographyCrv']['EnumeratedIndexValues']['MCC2'] = {}
    field_information['GGDM 3.0']['PhysiographyCrv']['EnumeratedIndexValues']['MCC2']['DB010']  = (-999999,84,104,999)
    field_information['GGDM 3.0']['PhysiographyCrv']['EnumeratedIndexValues']['MCC2']['DB061']  = (-999999,84,104,999)
    field_information['GGDM 3.0']['PhysiographyCrv']['EnumeratedIndexValues']['MCC2']['DB090']  = (-999999,8,21,46,52,62,64,84,86,104,117,999)
    field_information['GGDM 3.0']['PhysiographyCrv']['MCC3'] = ('Enumeration',('DB061','DB090'))
    field_information['GGDM 3.0']['PhysiographyCrv']['EnumeratedIndexValues']['MCC3'] = {}
    field_information['GGDM 3.0']['PhysiographyCrv']['EnumeratedIndexValues']['MCC3']['DB061']  = (-999999,84,104,999)
    field_information['GGDM 3.0']['PhysiographyCrv']['EnumeratedIndexValues']['MCC3']['DB090']  = (-999999,8,21,46,52,62,64,84,86,104,117,999)
    field_information['GGDM 3.0']['PhysiographyCrv']['OTH'] = ('StructuredText',('BA010','BJ031','BJ040','DB010','DB061','DB070','DB071','DB090','DB100','DB110','DB190'))
    field_information['GGDM 3.0']['PhysiographyCrv']['PCF'] = ('Enumeration',('DB070','DB090'))
    field_information['GGDM 3.0']['PhysiographyCrv']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['PhysiographyCrv']['EnumeratedIndexValues']['PCF']['DB070']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['PhysiographyCrv']['EnumeratedIndexValues']['PCF']['DB090']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['PhysiographyCrv']['PFD'] = ('Real',('BJ031','DB061','DB070'))
    field_information['GGDM 3.0']['PhysiographyCrv']['PFH'] = ('Real',('BJ040','DB010','DB070','DB071','DB090'))
    field_information['GGDM 3.0']['PhysiographyCrv']['SDI'] = ('Real',('DB110'))
    field_information['GGDM 3.0']['PhysiographyCrv']['SGCC'] = ('Enumeration',('DB010','DB070','DB071','DB090','DB190'))
    field_information['GGDM 3.0']['PhysiographyCrv']['EnumeratedIndexValues']['SGCC'] = {}
    field_information['GGDM 3.0']['PhysiographyCrv']['EnumeratedIndexValues']['SGCC']['DB010']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['PhysiographyCrv']['EnumeratedIndexValues']['SGCC']['DB070']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['PhysiographyCrv']['EnumeratedIndexValues']['SGCC']['DB071']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['PhysiographyCrv']['EnumeratedIndexValues']['SGCC']['DB090']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['PhysiographyCrv']['EnumeratedIndexValues']['SGCC']['DB190']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['PhysiographyCrv']['SGCL'] = ('real',('DB010','DB070','DB071','DB090','DB190'))
    field_information['GGDM 3.0']['PhysiographyCrv']['SGCU'] = ('real',('DB010','DB070','DB071','DB090','DB190'))
    field_information['GGDM 3.0']['PhysiographyCrv']['SHD'] = ('Boolean',('BA010'))
    field_information['GGDM 3.0']['PhysiographyCrv']['SHO'] = ('Enumeration',('BA010'))
    field_information['GGDM 3.0']['PhysiographyCrv']['EnumeratedIndexValues']['SHO'] = {}
    field_information['GGDM 3.0']['PhysiographyCrv']['EnumeratedIndexValues']['SHO']['BA010']  = (-999999,1,2,7,8,9,999)
    field_information['GGDM 3.0']['PhysiographyCrv']['SLT'] = ('Enumeration',('BA010'))
    field_information['GGDM 3.0']['PhysiographyCrv']['EnumeratedIndexValues']['SLT'] = {}
    field_information['GGDM 3.0']['PhysiographyCrv']['EnumeratedIndexValues']['SLT']['BA010']  = (-999999,6,8,10,11,12,13,14,16,17,18,998,999)
    field_information['GGDM 3.0']['PhysiographyCrv']['SNDC'] = ('Enumeration',('BJ031'))
    field_information['GGDM 3.0']['PhysiographyCrv']['EnumeratedIndexValues']['SNDC'] = {}
    field_information['GGDM 3.0']['PhysiographyCrv']['EnumeratedIndexValues']['SNDC']['BJ031']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['PhysiographyCrv']['SNDL'] = ('real',('BJ031'))
    field_information['GGDM 3.0']['PhysiographyCrv']['SNDU'] = ('real',('BJ031'))
    field_information['GGDM 3.0']['PhysiographyCrv']['TRS'] = ('Enumeration',('DB070','DB071','DB090'))
    field_information['GGDM 3.0']['PhysiographyCrv']['EnumeratedIndexValues']['TRS'] = {}
    field_information['GGDM 3.0']['PhysiographyCrv']['EnumeratedIndexValues']['TRS']['DB070']  = (-999999,2,5,12,13,999)
    field_information['GGDM 3.0']['PhysiographyCrv']['EnumeratedIndexValues']['TRS']['DB071']  = (-999999,2,5,12,13,999)
    field_information['GGDM 3.0']['PhysiographyCrv']['EnumeratedIndexValues']['TRS']['DB090']  = (-999999,2,5,8,10,12,13,999)
    field_information['GGDM 3.0']['PhysiographyCrv']['TRS2'] = ('Enumeration',('DB070','DB071','DB090'))
    field_information['GGDM 3.0']['PhysiographyCrv']['EnumeratedIndexValues']['TRS2'] = {}
    field_information['GGDM 3.0']['PhysiographyCrv']['EnumeratedIndexValues']['TRS2']['DB070']  = (-999999,2,5,12,13,999)
    field_information['GGDM 3.0']['PhysiographyCrv']['EnumeratedIndexValues']['TRS2']['DB071']  = (-999999,2,5,12,13,999)
    field_information['GGDM 3.0']['PhysiographyCrv']['EnumeratedIndexValues']['TRS2']['DB090']  = (-999999,2,5,8,10,12,13,999)
    field_information['GGDM 3.0']['PhysiographyCrv']['TRS3'] = ('Enumeration',('DB070','DB071','DB090'))
    field_information['GGDM 3.0']['PhysiographyCrv']['EnumeratedIndexValues']['TRS3'] = {}
    field_information['GGDM 3.0']['PhysiographyCrv']['EnumeratedIndexValues']['TRS3']['DB070']  = (-999999,2,5,12,13,999)
    field_information['GGDM 3.0']['PhysiographyCrv']['EnumeratedIndexValues']['TRS3']['DB071']  = (-999999,2,5,12,13,999)
    field_information['GGDM 3.0']['PhysiographyCrv']['EnumeratedIndexValues']['TRS3']['DB090']  = (-999999,2,5,8,10,12,13,999)
    field_information['GGDM 3.0']['PhysiographyCrv']['UFI'] = ('StructuredText',('BA010','BJ031','BJ040','DB010','DB061','DB070','DB071','DB090','DB100','DB110','DB190'))
    field_information['GGDM 3.0']['PhysiographyCrv']['WID'] = ('Real',('BJ031','DB010','DB061','DB070','DB090','DB100','DB110','DB190'))
    field_information['GGDM 3.0']['PhysiographyCrv']['WLE'] = ('Enumeration',('DB090'))
    field_information['GGDM 3.0']['PhysiographyCrv']['EnumeratedIndexValues']['WLE'] = {}
    field_information['GGDM 3.0']['PhysiographyCrv']['EnumeratedIndexValues']['WLE']['DB090']  = (-999999,1,2,3,4,5,9,999)
    field_information['GGDM 3.0']['PhysiographyCrv']['ZI001_SDV'] = ('StructuredText',('BA010','BJ031','BJ040','DB010','DB061','DB070','DB071','DB090','DB100','DB110','DB190'))
    field_information['GGDM 3.0']['PhysiographyCrv']['ZI001_SRT'] = ('Enumeration',('BA010','BJ031','BJ040','DB010','DB061','DB070','DB071','DB090','DB100','DB110','DB190'))
    field_information['GGDM 3.0']['PhysiographyCrv']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['PhysiographyCrv']['EnumeratedIndexValues']['ZI001_SRT']['BA010']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['PhysiographyCrv']['EnumeratedIndexValues']['ZI001_SRT']['BJ031']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['PhysiographyCrv']['EnumeratedIndexValues']['ZI001_SRT']['BJ040']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['PhysiographyCrv']['EnumeratedIndexValues']['ZI001_SRT']['DB010']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['PhysiographyCrv']['EnumeratedIndexValues']['ZI001_SRT']['DB061']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['PhysiographyCrv']['EnumeratedIndexValues']['ZI001_SRT']['DB070']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['PhysiographyCrv']['EnumeratedIndexValues']['ZI001_SRT']['DB071']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['PhysiographyCrv']['EnumeratedIndexValues']['ZI001_SRT']['DB090']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['PhysiographyCrv']['EnumeratedIndexValues']['ZI001_SRT']['DB100']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['PhysiographyCrv']['EnumeratedIndexValues']['ZI001_SRT']['DB110']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['PhysiographyCrv']['EnumeratedIndexValues']['ZI001_SRT']['DB190']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['PhysiographyCrv']['ZI002_UFI'] = ('StructuredText',('BA010','BJ031','BJ040','DB010','DB061','DB070','DB071','DB090','DB100','DB110','DB190'))
    field_information['GGDM 3.0']['PhysiographyCrv']['ZI004_RCG'] = ('Enumeration',('BA010','BJ031','BJ040','DB010','DB061','DB070','DB071','DB090','DB100','DB110','DB190'))
    field_information['GGDM 3.0']['PhysiographyCrv']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['PhysiographyCrv']['EnumeratedIndexValues']['ZI004_RCG']['BA010']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['PhysiographyCrv']['EnumeratedIndexValues']['ZI004_RCG']['BJ031']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['PhysiographyCrv']['EnumeratedIndexValues']['ZI004_RCG']['BJ040']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['PhysiographyCrv']['EnumeratedIndexValues']['ZI004_RCG']['DB010']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['PhysiographyCrv']['EnumeratedIndexValues']['ZI004_RCG']['DB061']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['PhysiographyCrv']['EnumeratedIndexValues']['ZI004_RCG']['DB070']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['PhysiographyCrv']['EnumeratedIndexValues']['ZI004_RCG']['DB071']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['PhysiographyCrv']['EnumeratedIndexValues']['ZI004_RCG']['DB090']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['PhysiographyCrv']['EnumeratedIndexValues']['ZI004_RCG']['DB100']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['PhysiographyCrv']['EnumeratedIndexValues']['ZI004_RCG']['DB110']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['PhysiographyCrv']['EnumeratedIndexValues']['ZI004_RCG']['DB190']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['PhysiographyCrv']['ZI005_FNA'] = ('String',('BA010','BJ040','DB010','DB061','DB070','DB090','DB100','DB110','DB190'))
    field_information['GGDM 3.0']['PhysiographyCrv']['ZI005_GNT'] = ('Enumeration',('BA010','BJ040','DB010','DB061','DB070','DB090','DB100','DB110','DB190'))
    field_information['GGDM 3.0']['PhysiographyCrv']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['PhysiographyCrv']['EnumeratedIndexValues']['ZI005_GNT']['BA010']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['PhysiographyCrv']['EnumeratedIndexValues']['ZI005_GNT']['BJ040']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['PhysiographyCrv']['EnumeratedIndexValues']['ZI005_GNT']['DB010']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['PhysiographyCrv']['EnumeratedIndexValues']['ZI005_GNT']['DB061']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['PhysiographyCrv']['EnumeratedIndexValues']['ZI005_GNT']['DB070']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['PhysiographyCrv']['EnumeratedIndexValues']['ZI005_GNT']['DB090']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['PhysiographyCrv']['EnumeratedIndexValues']['ZI005_GNT']['DB100']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['PhysiographyCrv']['EnumeratedIndexValues']['ZI005_GNT']['DB110']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['PhysiographyCrv']['EnumeratedIndexValues']['ZI005_GNT']['DB190']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['PhysiographyCrv']['ZI005_NFN'] = ('String',('BA010','BJ040','DB010','DB061','DB070','DB090','DB100','DB110','DB190'))
    field_information['GGDM 3.0']['PhysiographyCrv']['ZI006_MEM'] = ('String',('BA010','BJ031','BJ040','DB010','DB061','DB070','DB071','DB090','DB100','DB110','DB190'))
    field_information['GGDM 3.0']['PhysiographyCrv']['ZI020_GE4'] = ('CodeList',('BA010','BJ031','BJ040','DB010','DB061','DB070','DB071','DB090','DB100','DB110','DB190'))
    field_information['GGDM 3.0']['PhysiographyCrv']['ZI026_CTUC'] = ('Enumeration',('BA010','BJ031','BJ040','DB010','DB061','DB070','DB071','DB090','DB100','DB110','DB190'))
    field_information['GGDM 3.0']['PhysiographyCrv']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['PhysiographyCrv']['EnumeratedIndexValues']['ZI026_CTUC']['BA010']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['PhysiographyCrv']['EnumeratedIndexValues']['ZI026_CTUC']['BJ031']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['PhysiographyCrv']['EnumeratedIndexValues']['ZI026_CTUC']['BJ040']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['PhysiographyCrv']['EnumeratedIndexValues']['ZI026_CTUC']['DB010']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['PhysiographyCrv']['EnumeratedIndexValues']['ZI026_CTUC']['DB061']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['PhysiographyCrv']['EnumeratedIndexValues']['ZI026_CTUC']['DB070']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['PhysiographyCrv']['EnumeratedIndexValues']['ZI026_CTUC']['DB071']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['PhysiographyCrv']['EnumeratedIndexValues']['ZI026_CTUC']['DB090']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['PhysiographyCrv']['EnumeratedIndexValues']['ZI026_CTUC']['DB100']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['PhysiographyCrv']['EnumeratedIndexValues']['ZI026_CTUC']['DB110']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['PhysiographyCrv']['EnumeratedIndexValues']['ZI026_CTUC']['DB190']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['PhysiographyCrv']['ZI026_CTUL'] = ('integer',('BA010','BJ031','BJ040','DB010','DB061','DB070','DB071','DB090','DB100','DB110','DB190'))
    field_information['GGDM 3.0']['PhysiographyCrv']['ZI026_CTUU'] = ('integer',('BA010','BJ031','BJ040','DB010','DB061','DB070','DB071','DB090','DB100','DB110','DB190'))
    field_information['GGDM 3.0']['PhysiographyCrv']['ZI031S_URI'] = ('StructuredText',('BA010','BJ031','BJ040','DB010','DB061','DB070','DB071','DB090','DB100','DB110','DB190'))
    field_information['GGDM 3.0']['PhysiographyCrv']['ZI039S_UFI'] = ('StructuredText',('BA010','BJ031','BJ040','DB010','DB061','DB070','DB071','DB090','DB100','DB110','DB190'))
    field_information['GGDM 3.0']['PhysiographyCrv']['ZSAX_RS0'] = ('CodeList',('BA010','BJ031','BJ040','DB010','DB061','DB070','DB071','DB090','DB100','DB110','DB190'))
    field_information['GGDM 3.0']['PhysiographyCrv']['ZSAX_RX0'] = ('StructuredText',('BA010','BJ031','BJ040','DB010','DB061','DB070','DB071','DB090','DB100','DB110','DB190'))
    field_information['GGDM 3.0']['PhysiographyCrv']['ZSAX_RX3'] = ('StructuredText',('BA010','BJ031','BJ040','DB010','DB061','DB070','DB071','DB090','DB100','DB110','DB190'))
    field_information['GGDM 3.0']['PhysiographyCrv']['ZSAX_RX4'] = ('StructuredText',('BA010','BJ031','BJ040','DB010','DB061','DB070','DB071','DB090','DB100','DB110','DB190'))
    field_information['GGDM 3.0']['PhysiographyCrv']['ZVH'] = ('Real',('BJ031','BJ040','DB010','DB061','DB090','DB100','DB190'))
    field_information['GGDM 3.0']['PhysiographyCrvExt']['AZC'] = ('Boolean',('BA024'))
    field_information['GGDM 3.0']['PhysiographyCrvExt']['BEN'] = ('StructuredText',('BA024','BE050','BJ070'))
    field_information['GGDM 3.0']['PhysiographyCrvExt']['F_CODE'] = ('CONSTRAINED_STRING',('BA024','BE050','BJ070'))
    field_information['GGDM 3.0']['PhysiographyCrvExt']['FUFI'] = ('StructuredText',('BA024','BE050','BJ070'))
    field_information['GGDM 3.0']['PhysiographyCrvExt']['FURL'] = ('StructuredText',('BA024','BE050','BJ070'))
    field_information['GGDM 3.0']['PhysiographyCrvExt']['GDBV'] = ('Enumeration',('BA024','BE050','BJ070'))
    field_information['GGDM 3.0']['PhysiographyCrvExt']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['PhysiographyCrvExt']['EnumeratedIndexValues']['GDBV']['BA024']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['PhysiographyCrvExt']['EnumeratedIndexValues']['GDBV']['BE050']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['PhysiographyCrvExt']['EnumeratedIndexValues']['GDBV']['BJ070']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['PhysiographyCrvExt']['OTH'] = ('StructuredText',('BA024','BE050','BJ070'))
    field_information['GGDM 3.0']['PhysiographyCrvExt']['SLT'] = ('Enumeration',('BA024'))
    field_information['GGDM 3.0']['PhysiographyCrvExt']['EnumeratedIndexValues']['SLT'] = {}
    field_information['GGDM 3.0']['PhysiographyCrvExt']['EnumeratedIndexValues']['SLT']['BA024']  = (-999999,6,8,10,11,12,13,14,16,17,18,999)
    field_information['GGDM 3.0']['PhysiographyCrvExt']['SSE'] = ('StructuredText',('BJ070'))
    field_information['GGDM 3.0']['PhysiographyCrvExt']['UFI'] = ('StructuredText',('BA024','BE050','BJ070'))
    field_information['GGDM 3.0']['PhysiographyCrvExt']['ZI001_SDV'] = ('StructuredText',('BA024','BE050','BJ070'))
    field_information['GGDM 3.0']['PhysiographyCrvExt']['ZI001_SRT'] = ('Enumeration',('BA024','BE050','BJ070'))
    field_information['GGDM 3.0']['PhysiographyCrvExt']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['PhysiographyCrvExt']['EnumeratedIndexValues']['ZI001_SRT']['BA024']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['PhysiographyCrvExt']['EnumeratedIndexValues']['ZI001_SRT']['BE050']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['PhysiographyCrvExt']['EnumeratedIndexValues']['ZI001_SRT']['BJ070']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['PhysiographyCrvExt']['ZI002_UFI'] = ('StructuredText',('BA024','BE050','BJ070'))
    field_information['GGDM 3.0']['PhysiographyCrvExt']['ZI004_RCG'] = ('Enumeration',('BA024','BE050','BJ070'))
    field_information['GGDM 3.0']['PhysiographyCrvExt']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['PhysiographyCrvExt']['EnumeratedIndexValues']['ZI004_RCG']['BA024']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['PhysiographyCrvExt']['EnumeratedIndexValues']['ZI004_RCG']['BE050']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['PhysiographyCrvExt']['EnumeratedIndexValues']['ZI004_RCG']['BJ070']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['PhysiographyCrvExt']['ZI005_FNA'] = ('String',('BJ070'))
    field_information['GGDM 3.0']['PhysiographyCrvExt']['ZI005_GNT'] = ('Enumeration',('BJ070'))
    field_information['GGDM 3.0']['PhysiographyCrvExt']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['PhysiographyCrvExt']['EnumeratedIndexValues']['ZI005_GNT']['BJ070']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['PhysiographyCrvExt']['ZI005_NFN'] = ('String',('BJ070'))
    field_information['GGDM 3.0']['PhysiographyCrvExt']['ZI006_MEM'] = ('String',('BA024','BE050','BJ070'))
    field_information['GGDM 3.0']['PhysiographyCrvExt']['ZI020_GE4'] = ('CodeList',('BA024','BE050','BJ070'))
    field_information['GGDM 3.0']['PhysiographyCrvExt']['ZI026_CTUC'] = ('Enumeration',('BA024','BE050','BJ070'))
    field_information['GGDM 3.0']['PhysiographyCrvExt']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['PhysiographyCrvExt']['EnumeratedIndexValues']['ZI026_CTUC']['BA024']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['PhysiographyCrvExt']['EnumeratedIndexValues']['ZI026_CTUC']['BE050']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['PhysiographyCrvExt']['EnumeratedIndexValues']['ZI026_CTUC']['BJ070']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['PhysiographyCrvExt']['ZI026_CTUL'] = ('integer',('BA024','BE050','BJ070'))
    field_information['GGDM 3.0']['PhysiographyCrvExt']['ZI026_CTUU'] = ('integer',('BA024','BE050','BJ070'))
    field_information['GGDM 3.0']['PhysiographyCrvExt']['ZI031S_URI'] = ('StructuredText',('BA024','BE050','BJ070'))
    field_information['GGDM 3.0']['PhysiographyCrvExt']['ZI039S_UFI'] = ('StructuredText',('BA024','BE050','BJ070'))
    field_information['GGDM 3.0']['PhysiographyCrvExt']['ZSAX_RS0'] = ('CodeList',('BA024','BE050','BJ070'))
    field_information['GGDM 3.0']['PhysiographyCrvExt']['ZSAX_RX0'] = ('StructuredText',('BA024','BE050','BJ070'))
    field_information['GGDM 3.0']['PhysiographyCrvExt']['ZSAX_RX3'] = ('StructuredText',('BA024','BE050','BJ070'))
    field_information['GGDM 3.0']['PhysiographyCrvExt']['ZSAX_RX4'] = ('StructuredText',('BA024','BE050','BJ070'))
    field_information['GGDM 3.0']['PhysiographyPnt']['AOO'] = ('Real',('BA030','DB029','DB150','DB160'))
    field_information['GGDM 3.0']['PhysiographyPnt']['AQN'] = ('String',('DB115'))
    field_information['GGDM 3.0']['PhysiographyPnt']['ARA'] = ('Real',('BA030','BJ060','DB115','DB150','DB160','DB180','EC020'))
    field_information['GGDM 3.0']['PhysiographyPnt']['BA000_VDC'] = ('Enumeration',('BA030'))
    field_information['GGDM 3.0']['PhysiographyPnt']['EnumeratedIndexValues']['BA000_VDC'] = {}
    field_information['GGDM 3.0']['PhysiographyPnt']['EnumeratedIndexValues']['BA000_VDC']['BA030']  = (-999999,4,7,9,10,11,13,14,15,19,20,24,28,30,90,999)
    field_information['GGDM 3.0']['PhysiographyPnt']['BA000_VDR'] = ('String',('BA030'))
    field_information['GGDM 3.0']['PhysiographyPnt']['BEN'] = ('StructuredText',('BA030','BJ060','DB029','DB115','DB150','DB160','DB180','EC020'))
    field_information['GGDM 3.0']['PhysiographyPnt']['CAA'] = ('Enumeration',('DB029','DB115'))
    field_information['GGDM 3.0']['PhysiographyPnt']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['PhysiographyPnt']['EnumeratedIndexValues']['CAA']['DB029']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['PhysiographyPnt']['EnumeratedIndexValues']['CAA']['DB115']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['PhysiographyPnt']['DOF'] = ('Real',('DB115'))
    field_information['GGDM 3.0']['PhysiographyPnt']['F_CODE'] = ('CONSTRAINED_STRING',('BA030','BJ060','DB029','DB115','DB150','DB160','DB180','EC020'))
    field_information['GGDM 3.0']['PhysiographyPnt']['FUFI'] = ('StructuredText',('BA030','BJ060','DB029','DB115','DB150','DB160','DB180','EC020'))
    field_information['GGDM 3.0']['PhysiographyPnt']['FURL'] = ('StructuredText',('BA030','BJ060','DB029','DB115','DB150','DB160','DB180','EC020'))
    field_information['GGDM 3.0']['PhysiographyPnt']['GDBV'] = ('Enumeration',('BA030','BJ060','DB029','DB115','DB150','DB160','DB180','EC020'))
    field_information['GGDM 3.0']['PhysiographyPnt']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['PhysiographyPnt']['EnumeratedIndexValues']['GDBV']['BA030']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['PhysiographyPnt']['EnumeratedIndexValues']['GDBV']['BJ060']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['PhysiographyPnt']['EnumeratedIndexValues']['GDBV']['DB029']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['PhysiographyPnt']['EnumeratedIndexValues']['GDBV']['DB115']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['PhysiographyPnt']['EnumeratedIndexValues']['GDBV']['DB150']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['PhysiographyPnt']['EnumeratedIndexValues']['GDBV']['DB160']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['PhysiographyPnt']['EnumeratedIndexValues']['GDBV']['DB180']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['PhysiographyPnt']['EnumeratedIndexValues']['GDBV']['EC020']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['PhysiographyPnt']['GOT'] = ('Enumeration',('DB115'))
    field_information['GGDM 3.0']['PhysiographyPnt']['EnumeratedIndexValues']['GOT'] = {}
    field_information['GGDM 3.0']['PhysiographyPnt']['EnumeratedIndexValues']['GOT']['DB115']  = (-999999,1,2,3,4,5,999)
    field_information['GGDM 3.0']['PhysiographyPnt']['HGT'] = ('Real',('BA030','BJ060','DB160','DB180'))
    field_information['GGDM 3.0']['PhysiographyPnt']['LMC'] = ('Boolean',('BA030','BJ060','DB029','DB115','DB160','DB180'))
    field_information['GGDM 3.0']['PhysiographyPnt']['LZN'] = ('Real',('BA030','BJ060','DB029','DB115','DB150','DB160','DB180','EC020'))
    field_information['GGDM 3.0']['PhysiographyPnt']['MCC'] = ('Enumeration',('BJ060'))
    field_information['GGDM 3.0']['PhysiographyPnt']['EnumeratedIndexValues']['MCC'] = {}
    field_information['GGDM 3.0']['PhysiographyPnt']['EnumeratedIndexValues']['MCC']['BJ060']  = (-999999,84,88,103,104,999)
    field_information['GGDM 3.0']['PhysiographyPnt']['MCC2'] = ('Enumeration',('BJ060'))
    field_information['GGDM 3.0']['PhysiographyPnt']['EnumeratedIndexValues']['MCC2'] = {}
    field_information['GGDM 3.0']['PhysiographyPnt']['EnumeratedIndexValues']['MCC2']['BJ060']  = (-999999,84,88,103,104,999)
    field_information['GGDM 3.0']['PhysiographyPnt']['MCC3'] = ('Enumeration',('BJ060'))
    field_information['GGDM 3.0']['PhysiographyPnt']['EnumeratedIndexValues']['MCC3'] = {}
    field_information['GGDM 3.0']['PhysiographyPnt']['EnumeratedIndexValues']['MCC3']['BJ060']  = (-999999,84,88,103,104,999)
    field_information['GGDM 3.0']['PhysiographyPnt']['OHC'] = ('Real',('DB029'))
    field_information['GGDM 3.0']['PhysiographyPnt']['OTH'] = ('StructuredText',('BA030','BJ060','DB029','DB115','DB150','DB160','DB180','EC020'))
    field_information['GGDM 3.0']['PhysiographyPnt']['PCF'] = ('Enumeration',('DB029','EC020'))
    field_information['GGDM 3.0']['PhysiographyPnt']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['PhysiographyPnt']['EnumeratedIndexValues']['PCF']['DB029']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['PhysiographyPnt']['EnumeratedIndexValues']['PCF']['EC020']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['PhysiographyPnt']['PFH'] = ('Real',('DB160'))
    field_information['GGDM 3.0']['PhysiographyPnt']['RKF'] = ('Enumeration',('DB160'))
    field_information['GGDM 3.0']['PhysiographyPnt']['EnumeratedIndexValues']['RKF'] = {}
    field_information['GGDM 3.0']['PhysiographyPnt']['EnumeratedIndexValues']['RKF']['DB160']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['PhysiographyPnt']['SHD'] = ('Boolean',('BA030'))
    field_information['GGDM 3.0']['PhysiographyPnt']['SLT'] = ('Enumeration',('BA030'))
    field_information['GGDM 3.0']['PhysiographyPnt']['EnumeratedIndexValues']['SLT'] = {}
    field_information['GGDM 3.0']['PhysiographyPnt']['EnumeratedIndexValues']['SLT']['BA030']  = (-999999,6,8,10,11,12,13,14,16,17,18,999)
    field_information['GGDM 3.0']['PhysiographyPnt']['SNDC'] = ('Enumeration',('BJ060'))
    field_information['GGDM 3.0']['PhysiographyPnt']['EnumeratedIndexValues']['SNDC'] = {}
    field_information['GGDM 3.0']['PhysiographyPnt']['EnumeratedIndexValues']['SNDC']['BJ060']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['PhysiographyPnt']['SNDL'] = ('real',('BJ060'))
    field_information['GGDM 3.0']['PhysiographyPnt']['SNDU'] = ('real',('BJ060'))
    field_information['GGDM 3.0']['PhysiographyPnt']['UFI'] = ('StructuredText',('BA030','BJ060','DB029','DB115','DB150','DB160','DB180','EC020'))
    field_information['GGDM 3.0']['PhysiographyPnt']['VGT'] = ('Enumeration',('DB180'))
    field_information['GGDM 3.0']['PhysiographyPnt']['EnumeratedIndexValues']['VGT'] = {}
    field_information['GGDM 3.0']['PhysiographyPnt']['EnumeratedIndexValues']['VGT']['DB180']  = (-999999,1,2,3,4,5)
    field_information['GGDM 3.0']['PhysiographyPnt']['VOA'] = ('Enumeration',('DB180'))
    field_information['GGDM 3.0']['PhysiographyPnt']['EnumeratedIndexValues']['VOA'] = {}
    field_information['GGDM 3.0']['PhysiographyPnt']['EnumeratedIndexValues']['VOA']['DB180']  = (-999999,1,2,3)
    field_information['GGDM 3.0']['PhysiographyPnt']['VTI'] = ('Real',('EC020'))
    field_information['GGDM 3.0']['PhysiographyPnt']['WID'] = ('Real',('BA030','BJ060','DB115','DB150','DB160','DB180','EC020'))
    field_information['GGDM 3.0']['PhysiographyPnt']['ZI001_SDV'] = ('StructuredText',('BA030','BJ060','DB029','DB115','DB150','DB160','DB180','EC020'))
    field_information['GGDM 3.0']['PhysiographyPnt']['ZI001_SRT'] = ('Enumeration',('BA030','BJ060','DB029','DB115','DB150','DB160','DB180','EC020'))
    field_information['GGDM 3.0']['PhysiographyPnt']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['PhysiographyPnt']['EnumeratedIndexValues']['ZI001_SRT']['BA030']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['PhysiographyPnt']['EnumeratedIndexValues']['ZI001_SRT']['BJ060']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['PhysiographyPnt']['EnumeratedIndexValues']['ZI001_SRT']['DB029']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['PhysiographyPnt']['EnumeratedIndexValues']['ZI001_SRT']['DB115']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['PhysiographyPnt']['EnumeratedIndexValues']['ZI001_SRT']['DB150']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['PhysiographyPnt']['EnumeratedIndexValues']['ZI001_SRT']['DB160']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['PhysiographyPnt']['EnumeratedIndexValues']['ZI001_SRT']['DB180']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['PhysiographyPnt']['EnumeratedIndexValues']['ZI001_SRT']['EC020']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['PhysiographyPnt']['ZI002_UFI'] = ('StructuredText',('BA030','BJ060','DB029','DB115','DB150','DB160','DB180','EC020'))
    field_information['GGDM 3.0']['PhysiographyPnt']['ZI004_RCG'] = ('Enumeration',('BA030','BJ060','DB029','DB115','DB150','DB160','DB180','EC020'))
    field_information['GGDM 3.0']['PhysiographyPnt']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['PhysiographyPnt']['EnumeratedIndexValues']['ZI004_RCG']['BA030']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['PhysiographyPnt']['EnumeratedIndexValues']['ZI004_RCG']['BJ060']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['PhysiographyPnt']['EnumeratedIndexValues']['ZI004_RCG']['DB029']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['PhysiographyPnt']['EnumeratedIndexValues']['ZI004_RCG']['DB115']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['PhysiographyPnt']['EnumeratedIndexValues']['ZI004_RCG']['DB150']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['PhysiographyPnt']['EnumeratedIndexValues']['ZI004_RCG']['DB160']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['PhysiographyPnt']['EnumeratedIndexValues']['ZI004_RCG']['DB180']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['PhysiographyPnt']['EnumeratedIndexValues']['ZI004_RCG']['EC020']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['PhysiographyPnt']['ZI005_FNA'] = ('String',('BA030','BJ060','DB029','DB115','DB150','DB160','DB180','EC020'))
    field_information['GGDM 3.0']['PhysiographyPnt']['ZI005_FNA2'] = ('String',('DB115'))
    field_information['GGDM 3.0']['PhysiographyPnt']['ZI005_FNA3'] = ('String',('DB115'))
    field_information['GGDM 3.0']['PhysiographyPnt']['ZI005_GNT'] = ('Enumeration',('BA030','BJ060','DB029','DB115','DB150','DB160','DB180','EC020'))
    field_information['GGDM 3.0']['PhysiographyPnt']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['PhysiographyPnt']['EnumeratedIndexValues']['ZI005_GNT']['BA030']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['PhysiographyPnt']['EnumeratedIndexValues']['ZI005_GNT']['BJ060']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['PhysiographyPnt']['EnumeratedIndexValues']['ZI005_GNT']['DB029']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['PhysiographyPnt']['EnumeratedIndexValues']['ZI005_GNT']['DB115']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['PhysiographyPnt']['EnumeratedIndexValues']['ZI005_GNT']['DB150']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['PhysiographyPnt']['EnumeratedIndexValues']['ZI005_GNT']['DB160']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['PhysiographyPnt']['EnumeratedIndexValues']['ZI005_GNT']['DB180']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['PhysiographyPnt']['EnumeratedIndexValues']['ZI005_GNT']['EC020']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['PhysiographyPnt']['ZI005_GNT2'] = ('Enumeration',('DB115'))
    field_information['GGDM 3.0']['PhysiographyPnt']['EnumeratedIndexValues']['ZI005_GNT2'] = {}
    field_information['GGDM 3.0']['PhysiographyPnt']['EnumeratedIndexValues']['ZI005_GNT2']['DB115']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['PhysiographyPnt']['ZI005_GNT3'] = ('Enumeration',('DB115'))
    field_information['GGDM 3.0']['PhysiographyPnt']['EnumeratedIndexValues']['ZI005_GNT3'] = {}
    field_information['GGDM 3.0']['PhysiographyPnt']['EnumeratedIndexValues']['ZI005_GNT3']['DB115']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['PhysiographyPnt']['ZI005_NFN'] = ('String',('BA030','BJ060','DB029','DB115','DB150','DB160','DB180','EC020'))
    field_information['GGDM 3.0']['PhysiographyPnt']['ZI005_NFN2'] = ('String',('DB115'))
    field_information['GGDM 3.0']['PhysiographyPnt']['ZI005_NFN3'] = ('String',('DB115'))
    field_information['GGDM 3.0']['PhysiographyPnt']['ZI006_MEM'] = ('String',('BA030','BJ060','DB029','DB115','DB150','DB160','DB180','EC020'))
    field_information['GGDM 3.0']['PhysiographyPnt']['ZI020_GE4'] = ('CodeList',('BA030','BJ060','DB029','DB115','DB150','DB160','DB180','EC020'))
    field_information['GGDM 3.0']['PhysiographyPnt']['ZI024_ASE'] = ('Real',('DB115'))
    field_information['GGDM 3.0']['PhysiographyPnt']['ZI024_AWO'] = ('Real',('DB115'))
    field_information['GGDM 3.0']['PhysiographyPnt']['ZI024_AWOI'] = ('Real',('DB115'))
    field_information['GGDM 3.0']['PhysiographyPnt']['ZI024_AWOX'] = ('Real',('DB115'))
    field_information['GGDM 3.0']['PhysiographyPnt']['ZI024_CFR'] = ('Real',('DB115'))
    field_information['GGDM 3.0']['PhysiographyPnt']['ZI024_CLO'] = ('Real',('DB115'))
    field_information['GGDM 3.0']['PhysiographyPnt']['ZI024_CYN'] = ('Real',('DB115'))
    field_information['GGDM 3.0']['PhysiographyPnt']['ZI024_FMR'] = ('Real',('DB115'))
    field_information['GGDM 3.0']['PhysiographyPnt']['ZI024_FRR'] = ('Real',('DB115'))
    field_information['GGDM 3.0']['PhysiographyPnt']['ZI024_HAR'] = ('Real',('DB115'))
    field_information['GGDM 3.0']['PhysiographyPnt']['ZI024_HYP'] = ('Enumeration',('DB115'))
    field_information['GGDM 3.0']['PhysiographyPnt']['EnumeratedIndexValues']['ZI024_HYP'] = {}
    field_information['GGDM 3.0']['PhysiographyPnt']['EnumeratedIndexValues']['ZI024_HYP']['DB115']  = (-999999,1,2,4)
    field_information['GGDM 3.0']['PhysiographyPnt']['ZI024_MGN'] = ('Real',('DB115'))
    field_information['GGDM 3.0']['PhysiographyPnt']['ZI024_PHW'] = ('Real',('DB115'))
    field_information['GGDM 3.0']['PhysiographyPnt']['ZI024_SCC'] = ('Enumeration',('DB115'))
    field_information['GGDM 3.0']['PhysiographyPnt']['EnumeratedIndexValues']['ZI024_SCC'] = {}
    field_information['GGDM 3.0']['PhysiographyPnt']['EnumeratedIndexValues']['ZI024_SCC']['DB115']  = (-999999,1,4,10,11,12,13,14,998,999)
    field_information['GGDM 3.0']['PhysiographyPnt']['ZI024_SUL'] = ('Real',('DB115'))
    field_information['GGDM 3.0']['PhysiographyPnt']['ZI024_TDS'] = ('Real',('DB115'))
    field_information['GGDM 3.0']['PhysiographyPnt']['ZI024_TEP'] = ('Real',('DB115'))
    field_information['GGDM 3.0']['PhysiographyPnt']['ZI024_TUR'] = ('Real',('DB115'))
    field_information['GGDM 3.0']['PhysiographyPnt']['ZI024_WAC'] = ('Real',('DB115'))
    field_information['GGDM 3.0']['PhysiographyPnt']['ZI024_WTNO'] = ('Real',('DB115'))
    field_information['GGDM 3.0']['PhysiographyPnt']['ZI024_WUR'] = ('Enumeration',('DB115'))
    field_information['GGDM 3.0']['PhysiographyPnt']['EnumeratedIndexValues']['ZI024_WUR'] = {}
    field_information['GGDM 3.0']['PhysiographyPnt']['EnumeratedIndexValues']['ZI024_WUR']['DB115']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['PhysiographyPnt']['ZI024_WUR2'] = ('Enumeration',('DB115'))
    field_information['GGDM 3.0']['PhysiographyPnt']['EnumeratedIndexValues']['ZI024_WUR2'] = {}
    field_information['GGDM 3.0']['PhysiographyPnt']['EnumeratedIndexValues']['ZI024_WUR2']['DB115']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['PhysiographyPnt']['ZI024_WUR3'] = ('Enumeration',('DB115'))
    field_information['GGDM 3.0']['PhysiographyPnt']['EnumeratedIndexValues']['ZI024_WUR3'] = {}
    field_information['GGDM 3.0']['PhysiographyPnt']['EnumeratedIndexValues']['ZI024_WUR3']['DB115']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['PhysiographyPnt']['ZI024_WUR4'] = ('Enumeration',('DB115'))
    field_information['GGDM 3.0']['PhysiographyPnt']['EnumeratedIndexValues']['ZI024_WUR4'] = {}
    field_information['GGDM 3.0']['PhysiographyPnt']['EnumeratedIndexValues']['ZI024_WUR4']['DB115']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['PhysiographyPnt']['ZI024_YWQ'] = ('Enumeration',('DB115'))
    field_information['GGDM 3.0']['PhysiographyPnt']['EnumeratedIndexValues']['ZI024_YWQ'] = {}
    field_information['GGDM 3.0']['PhysiographyPnt']['EnumeratedIndexValues']['ZI024_YWQ']['DB115']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['PhysiographyPnt']['ZI025_HDP'] = ('Real',('DB029','DB115'))
    field_information['GGDM 3.0']['PhysiographyPnt']['ZI026_CTUC'] = ('Enumeration',('BA030','BJ060','DB029','DB115','DB150','DB160','DB180','EC020'))
    field_information['GGDM 3.0']['PhysiographyPnt']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['PhysiographyPnt']['EnumeratedIndexValues']['ZI026_CTUC']['BA030']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['PhysiographyPnt']['EnumeratedIndexValues']['ZI026_CTUC']['BJ060']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['PhysiographyPnt']['EnumeratedIndexValues']['ZI026_CTUC']['DB029']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['PhysiographyPnt']['EnumeratedIndexValues']['ZI026_CTUC']['DB115']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['PhysiographyPnt']['EnumeratedIndexValues']['ZI026_CTUC']['DB150']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['PhysiographyPnt']['EnumeratedIndexValues']['ZI026_CTUC']['DB160']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['PhysiographyPnt']['EnumeratedIndexValues']['ZI026_CTUC']['DB180']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['PhysiographyPnt']['EnumeratedIndexValues']['ZI026_CTUC']['EC020']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['PhysiographyPnt']['ZI026_CTUL'] = ('integer',('BA030','BJ060','DB029','DB115','DB150','DB160','DB180','EC020'))
    field_information['GGDM 3.0']['PhysiographyPnt']['ZI026_CTUU'] = ('integer',('BA030','BJ060','DB029','DB115','DB150','DB160','DB180','EC020'))
    field_information['GGDM 3.0']['PhysiographyPnt']['ZI031S_URI'] = ('StructuredText',('BA030','BJ060','DB029','DB115','DB150','DB160','DB180','EC020'))
    field_information['GGDM 3.0']['PhysiographyPnt']['ZI039S_UFI'] = ('StructuredText',('BA030','BJ060','DB029','DB115','DB150','DB160','DB180','EC020'))
    field_information['GGDM 3.0']['PhysiographyPnt']['ZI071_CTX'] = ('Enumeration',('DB029'))
    field_information['GGDM 3.0']['PhysiographyPnt']['EnumeratedIndexValues']['ZI071_CTX'] = {}
    field_information['GGDM 3.0']['PhysiographyPnt']['EnumeratedIndexValues']['ZI071_CTX']['DB029']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['PhysiographyPnt']['ZI071_FFN'] = ('Enumeration',('DB029'))
    field_information['GGDM 3.0']['PhysiographyPnt']['EnumeratedIndexValues']['ZI071_FFN'] = {}
    field_information['GGDM 3.0']['PhysiographyPnt']['EnumeratedIndexValues']['ZI071_FFN']['DB029']  = (-999999,530,563,835,930,999)
    field_information['GGDM 3.0']['PhysiographyPnt']['ZI071_FFN2'] = ('Enumeration',('DB029'))
    field_information['GGDM 3.0']['PhysiographyPnt']['EnumeratedIndexValues']['ZI071_FFN2'] = {}
    field_information['GGDM 3.0']['PhysiographyPnt']['EnumeratedIndexValues']['ZI071_FFN2']['DB029']  = (-999999,530,563,835,930,999)
    field_information['GGDM 3.0']['PhysiographyPnt']['ZI071_FFN3'] = ('Enumeration',('DB029'))
    field_information['GGDM 3.0']['PhysiographyPnt']['EnumeratedIndexValues']['ZI071_FFN3'] = {}
    field_information['GGDM 3.0']['PhysiographyPnt']['EnumeratedIndexValues']['ZI071_FFN3']['DB029']  = (-999999,530,563,835,930,999)
    field_information['GGDM 3.0']['PhysiographyPnt']['ZI071_UAO'] = ('Enumeration',('DB029'))
    field_information['GGDM 3.0']['PhysiographyPnt']['EnumeratedIndexValues']['ZI071_UAO'] = {}
    field_information['GGDM 3.0']['PhysiographyPnt']['EnumeratedIndexValues']['ZI071_UAO']['DB029']  = (-999999,1,2,3,4,5)
    field_information['GGDM 3.0']['PhysiographyPnt']['ZSAX_RS0'] = ('CodeList',('BA030','BJ060','DB029','DB115','DB150','DB160','DB180','EC020'))
    field_information['GGDM 3.0']['PhysiographyPnt']['ZSAX_RX0'] = ('StructuredText',('BA030','BJ060','DB029','DB115','DB150','DB160','DB180','EC020'))
    field_information['GGDM 3.0']['PhysiographyPnt']['ZSAX_RX3'] = ('StructuredText',('BA030','BJ060','DB029','DB115','DB150','DB160','DB180','EC020'))
    field_information['GGDM 3.0']['PhysiographyPnt']['ZSAX_RX4'] = ('StructuredText',('BA030','BJ060','DB029','DB115','DB150','DB160','DB180','EC020'))
    field_information['GGDM 3.0']['PhysiographyPnt']['ZVH'] = ('Real',('BA030','BJ060','DB150','DB160','DB180'))
    field_information['GGDM 3.0']['PhysiographyPntExt']['ARA'] = ('Real',('DB080','DB185'))
    field_information['GGDM 3.0']['PhysiographyPntExt']['BEN'] = ('StructuredText',('DB080','DB185'))
    field_information['GGDM 3.0']['PhysiographyPntExt']['DZP'] = ('Real',('DB080','DB185'))
    field_information['GGDM 3.0']['PhysiographyPntExt']['F_CODE'] = ('CONSTRAINED_STRING',('DB080','DB185'))
    field_information['GGDM 3.0']['PhysiographyPntExt']['FUFI'] = ('StructuredText',('DB080','DB185'))
    field_information['GGDM 3.0']['PhysiographyPntExt']['FURL'] = ('StructuredText',('DB080','DB185'))
    field_information['GGDM 3.0']['PhysiographyPntExt']['GDBV'] = ('Enumeration',('DB080','DB185'))
    field_information['GGDM 3.0']['PhysiographyPntExt']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['PhysiographyPntExt']['EnumeratedIndexValues']['GDBV']['DB080']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['PhysiographyPntExt']['EnumeratedIndexValues']['GDBV']['DB185']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['PhysiographyPntExt']['LMC'] = ('Boolean',('DB185'))
    field_information['GGDM 3.0']['PhysiographyPntExt']['LZN'] = ('Real',('DB080','DB185'))
    field_information['GGDM 3.0']['PhysiographyPntExt']['OTH'] = ('StructuredText',('DB080','DB185'))
    field_information['GGDM 3.0']['PhysiographyPntExt']['PFD'] = ('Real',('DB080'))
    field_information['GGDM 3.0']['PhysiographyPntExt']['SGCC'] = ('Enumeration',('DB080'))
    field_information['GGDM 3.0']['PhysiographyPntExt']['EnumeratedIndexValues']['SGCC'] = {}
    field_information['GGDM 3.0']['PhysiographyPntExt']['EnumeratedIndexValues']['SGCC']['DB080']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['PhysiographyPntExt']['SGCL'] = ('real',('DB080'))
    field_information['GGDM 3.0']['PhysiographyPntExt']['SGCU'] = ('real',('DB080'))
    field_information['GGDM 3.0']['PhysiographyPntExt']['UFI'] = ('StructuredText',('DB080','DB185'))
    field_information['GGDM 3.0']['PhysiographyPntExt']['WID'] = ('Real',('DB080','DB185'))
    field_information['GGDM 3.0']['PhysiographyPntExt']['ZI001_SDV'] = ('StructuredText',('DB080','DB185'))
    field_information['GGDM 3.0']['PhysiographyPntExt']['ZI001_SRT'] = ('Enumeration',('DB080','DB185'))
    field_information['GGDM 3.0']['PhysiographyPntExt']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['PhysiographyPntExt']['EnumeratedIndexValues']['ZI001_SRT']['DB080']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['PhysiographyPntExt']['EnumeratedIndexValues']['ZI001_SRT']['DB185']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['PhysiographyPntExt']['ZI002_UFI'] = ('StructuredText',('DB080','DB185'))
    field_information['GGDM 3.0']['PhysiographyPntExt']['ZI004_RCG'] = ('Enumeration',('DB080','DB185'))
    field_information['GGDM 3.0']['PhysiographyPntExt']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['PhysiographyPntExt']['EnumeratedIndexValues']['ZI004_RCG']['DB080']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['PhysiographyPntExt']['EnumeratedIndexValues']['ZI004_RCG']['DB185']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['PhysiographyPntExt']['ZI005_FNA'] = ('String',('DB080','DB185'))
    field_information['GGDM 3.0']['PhysiographyPntExt']['ZI005_GNT'] = ('Enumeration',('DB080','DB185'))
    field_information['GGDM 3.0']['PhysiographyPntExt']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['PhysiographyPntExt']['EnumeratedIndexValues']['ZI005_GNT']['DB080']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['PhysiographyPntExt']['EnumeratedIndexValues']['ZI005_GNT']['DB185']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['PhysiographyPntExt']['ZI005_NFN'] = ('String',('DB080','DB185'))
    field_information['GGDM 3.0']['PhysiographyPntExt']['ZI006_MEM'] = ('String',('DB080','DB185'))
    field_information['GGDM 3.0']['PhysiographyPntExt']['ZI020_GE4'] = ('CodeList',('DB080','DB185'))
    field_information['GGDM 3.0']['PhysiographyPntExt']['ZI026_CTUC'] = ('Enumeration',('DB080','DB185'))
    field_information['GGDM 3.0']['PhysiographyPntExt']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['PhysiographyPntExt']['EnumeratedIndexValues']['ZI026_CTUC']['DB080']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['PhysiographyPntExt']['EnumeratedIndexValues']['ZI026_CTUC']['DB185']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['PhysiographyPntExt']['ZI026_CTUL'] = ('integer',('DB080','DB185'))
    field_information['GGDM 3.0']['PhysiographyPntExt']['ZI026_CTUU'] = ('integer',('DB080','DB185'))
    field_information['GGDM 3.0']['PhysiographyPntExt']['ZI031S_URI'] = ('StructuredText',('DB080','DB185'))
    field_information['GGDM 3.0']['PhysiographyPntExt']['ZI039S_UFI'] = ('StructuredText',('DB080','DB185'))
    field_information['GGDM 3.0']['PhysiographyPntExt']['ZSAX_RS0'] = ('CodeList',('DB080','DB185'))
    field_information['GGDM 3.0']['PhysiographyPntExt']['ZSAX_RX0'] = ('StructuredText',('DB080','DB185'))
    field_information['GGDM 3.0']['PhysiographyPntExt']['ZSAX_RX3'] = ('StructuredText',('DB080','DB185'))
    field_information['GGDM 3.0']['PhysiographyPntExt']['ZSAX_RX4'] = ('StructuredText',('DB080','DB185'))
    field_information['GGDM 3.0']['PhysiographySrf']['AOO'] = ('Real',('BA030','DB160'))
    field_information['GGDM 3.0']['PhysiographySrf']['AQN'] = ('String',('DB115'))
    field_information['GGDM 3.0']['PhysiographySrf']['ARA'] = ('Real',('BA030','BH150','BH160','BJ020','BJ030','BJ031','BJ065','BJ080','BJ099','BJ100','DA005','DA010','DB061','DB080','DB090','DB115','DB160','DB170','DB180','DB211','EC020','EE030'))
    field_information['GGDM 3.0']['PhysiographySrf']['BA000_VDC'] = ('Enumeration',('BA030'))
    field_information['GGDM 3.0']['PhysiographySrf']['EnumeratedIndexValues']['BA000_VDC'] = {}
    field_information['GGDM 3.0']['PhysiographySrf']['EnumeratedIndexValues']['BA000_VDC']['BA030']  = (-999999,4,7,9,10,11,13,14,15,19,20,24,28,30,90,999)
    field_information['GGDM 3.0']['PhysiographySrf']['BA000_VDR'] = ('String',('BA030'))
    field_information['GGDM 3.0']['PhysiographySrf']['BEN'] = ('StructuredText',('BA030','BH150','BH160','BJ020','BJ030','BJ031','BJ065','BJ080','BJ099','BJ100','DA005','DA010','DB061','DB080','DB090','DB115','DB160','DB170','DB180','DB211','EC020','EE030'))
    field_information['GGDM 3.0']['PhysiographySrf']['CAA'] = ('Enumeration',('DB090','DB115'))
    field_information['GGDM 3.0']['PhysiographySrf']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['PhysiographySrf']['EnumeratedIndexValues']['CAA']['DB090']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['PhysiographySrf']['EnumeratedIndexValues']['CAA']['DB115']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['PhysiographySrf']['CET'] = ('Enumeration',('DB090'))
    field_information['GGDM 3.0']['PhysiographySrf']['EnumeratedIndexValues']['CET'] = {}
    field_information['GGDM 3.0']['PhysiographySrf']['EnumeratedIndexValues']['CET']['DB090']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['PhysiographySrf']['CNCP'] = ('StructuredText',('DB090'))
    field_information['GGDM 3.0']['PhysiographySrf']['COS'] = ('Enumeration',('DB090'))
    field_information['GGDM 3.0']['PhysiographySrf']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['PhysiographySrf']['EnumeratedIndexValues']['COS']['DB090']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['PhysiographySrf']['DOF'] = ('Real',('DB115'))
    field_information['GGDM 3.0']['PhysiographySrf']['DZP'] = ('Real',('BJ031','DB061','DB080'))
    field_information['GGDM 3.0']['PhysiographySrf']['F_CODE'] = ('CONSTRAINED_STRING',('BA030','BH150','BH160','BJ020','BJ030','BJ031','BJ065','BJ080','BJ099','BJ100','DA005','DA010','DB061','DB080','DB090','DB115','DB160','DB170','DB180','DB211','EC020','EE030'))
    field_information['GGDM 3.0']['PhysiographySrf']['FIC'] = ('Enumeration',('DB090'))
    field_information['GGDM 3.0']['PhysiographySrf']['EnumeratedIndexValues']['FIC'] = {}
    field_information['GGDM 3.0']['PhysiographySrf']['EnumeratedIndexValues']['FIC']['DB090']  = (-999999,1,2,3,5,6,999)
    field_information['GGDM 3.0']['PhysiographySrf']['FUFI'] = ('StructuredText',('BA030','BH150','BH160','BJ020','BJ030','BJ031','BJ065','BJ080','BJ099','BJ100','DA005','DA010','DB061','DB080','DB090','DB115','DB160','DB170','DB180','DB211','EC020','EE030'))
    field_information['GGDM 3.0']['PhysiographySrf']['FURL'] = ('StructuredText',('BA030','BH150','BH160','BJ020','BJ030','BJ031','BJ065','BJ080','BJ099','BJ100','DA005','DA010','DB061','DB080','DB090','DB115','DB160','DB170','DB180','DB211','EC020','EE030'))
    field_information['GGDM 3.0']['PhysiographySrf']['GDBV'] = ('Enumeration',('BA030','BH150','BH160','BJ020','BJ030','BJ031','BJ065','BJ080','BJ099','BJ100','DA005','DA010','DB061','DB080','DB090','DB115','DB160','DB170','DB180','DB211','EC020','EE030'))
    field_information['GGDM 3.0']['PhysiographySrf']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['PhysiographySrf']['EnumeratedIndexValues']['GDBV']['BA030']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['PhysiographySrf']['EnumeratedIndexValues']['GDBV']['BH150']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['PhysiographySrf']['EnumeratedIndexValues']['GDBV']['BH160']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['PhysiographySrf']['EnumeratedIndexValues']['GDBV']['BJ020']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['PhysiographySrf']['EnumeratedIndexValues']['GDBV']['BJ030']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['PhysiographySrf']['EnumeratedIndexValues']['GDBV']['BJ031']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['PhysiographySrf']['EnumeratedIndexValues']['GDBV']['BJ065']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['PhysiographySrf']['EnumeratedIndexValues']['GDBV']['BJ080']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['PhysiographySrf']['EnumeratedIndexValues']['GDBV']['BJ099']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['PhysiographySrf']['EnumeratedIndexValues']['GDBV']['BJ100']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['PhysiographySrf']['EnumeratedIndexValues']['GDBV']['DA005']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['PhysiographySrf']['EnumeratedIndexValues']['GDBV']['DA010']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['PhysiographySrf']['EnumeratedIndexValues']['GDBV']['DB061']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['PhysiographySrf']['EnumeratedIndexValues']['GDBV']['DB080']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['PhysiographySrf']['EnumeratedIndexValues']['GDBV']['DB090']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['PhysiographySrf']['EnumeratedIndexValues']['GDBV']['DB115']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['PhysiographySrf']['EnumeratedIndexValues']['GDBV']['DB160']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['PhysiographySrf']['EnumeratedIndexValues']['GDBV']['DB170']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['PhysiographySrf']['EnumeratedIndexValues']['GDBV']['DB180']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['PhysiographySrf']['EnumeratedIndexValues']['GDBV']['DB211']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['PhysiographySrf']['EnumeratedIndexValues']['GDBV']['EC020']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['PhysiographySrf']['EnumeratedIndexValues']['GDBV']['EE030']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['PhysiographySrf']['GOT'] = ('Enumeration',('DB115'))
    field_information['GGDM 3.0']['PhysiographySrf']['EnumeratedIndexValues']['GOT'] = {}
    field_information['GGDM 3.0']['PhysiographySrf']['EnumeratedIndexValues']['GOT']['DB115']  = (-999999,1,2,3,4,5,999)
    field_information['GGDM 3.0']['PhysiographySrf']['HGT'] = ('Real',('BA030','BJ080','DB090','DB160','DB170','DB180'))
    field_information['GGDM 3.0']['PhysiographySrf']['LMC'] = ('Boolean',('BA030','BH160','DA005','DB090','DB115','DB160','DB180'))
    field_information['GGDM 3.0']['PhysiographySrf']['LND'] = ('Enumeration',('BJ099'))
    field_information['GGDM 3.0']['PhysiographySrf']['EnumeratedIndexValues']['LND'] = {}
    field_information['GGDM 3.0']['PhysiographySrf']['EnumeratedIndexValues']['LND']['BJ099']  = (-999999,19,41,56,999)
    field_information['GGDM 3.0']['PhysiographySrf']['LZN'] = ('Real',('BA030','BH150','BH160','BJ020','BJ030','BJ031','BJ065','BJ080','BJ099','BJ100','DA005','DA010','DB061','DB080','DB090','DB115','DB160','DB170','DB180','DB211','EC020','EE030'))
    field_information['GGDM 3.0']['PhysiographySrf']['MCC'] = ('Enumeration',('BH150','DB061','DB090'))
    field_information['GGDM 3.0']['PhysiographySrf']['EnumeratedIndexValues']['MCC'] = {}
    field_information['GGDM 3.0']['PhysiographySrf']['EnumeratedIndexValues']['MCC']['BH150']  = (-999999,88,104,119,999)
    field_information['GGDM 3.0']['PhysiographySrf']['EnumeratedIndexValues']['MCC']['DB061']  = (-999999,84,104,999)
    field_information['GGDM 3.0']['PhysiographySrf']['EnumeratedIndexValues']['MCC']['DB090']  = (-999999,8,21,46,52,62,64,84,86,104,117,999)
    field_information['GGDM 3.0']['PhysiographySrf']['MCC2'] = ('Enumeration',('BH150','DB061','DB090'))
    field_information['GGDM 3.0']['PhysiographySrf']['EnumeratedIndexValues']['MCC2'] = {}
    field_information['GGDM 3.0']['PhysiographySrf']['EnumeratedIndexValues']['MCC2']['BH150']  = (-999999,88,104,119,999)
    field_information['GGDM 3.0']['PhysiographySrf']['EnumeratedIndexValues']['MCC2']['DB061']  = (-999999,84,104,999)
    field_information['GGDM 3.0']['PhysiographySrf']['EnumeratedIndexValues']['MCC2']['DB090']  = (-999999,8,21,46,52,62,64,84,86,104,117,999)
    field_information['GGDM 3.0']['PhysiographySrf']['MCC3'] = ('Enumeration',('BH150','DB061','DB090'))
    field_information['GGDM 3.0']['PhysiographySrf']['EnumeratedIndexValues']['MCC3'] = {}
    field_information['GGDM 3.0']['PhysiographySrf']['EnumeratedIndexValues']['MCC3']['BH150']  = (-999999,88,104,119,999)
    field_information['GGDM 3.0']['PhysiographySrf']['EnumeratedIndexValues']['MCC3']['DB061']  = (-999999,84,104,999)
    field_information['GGDM 3.0']['PhysiographySrf']['EnumeratedIndexValues']['MCC3']['DB090']  = (-999999,8,21,46,52,62,64,84,86,104,117,999)
    field_information['GGDM 3.0']['PhysiographySrf']['OTH'] = ('StructuredText',('BA030','BH150','BH160','BJ020','BJ030','BJ031','BJ065','BJ080','BJ099','BJ100','DA005','DA010','DB061','DB080','DB090','DB115','DB160','DB170','DB180','DB211','EC020','EE030'))
    field_information['GGDM 3.0']['PhysiographySrf']['PCF'] = ('Enumeration',('DB090','EC020'))
    field_information['GGDM 3.0']['PhysiographySrf']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['PhysiographySrf']['EnumeratedIndexValues']['PCF']['DB090']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['PhysiographySrf']['EnumeratedIndexValues']['PCF']['EC020']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['PhysiographySrf']['PFD'] = ('Real',('BJ031','DB061','DB080'))
    field_information['GGDM 3.0']['PhysiographySrf']['PFH'] = ('Real',('BJ080','DB090','DB160'))
    field_information['GGDM 3.0']['PhysiographySrf']['RKF'] = ('Enumeration',('DB160'))
    field_information['GGDM 3.0']['PhysiographySrf']['EnumeratedIndexValues']['RKF'] = {}
    field_information['GGDM 3.0']['PhysiographySrf']['EnumeratedIndexValues']['RKF']['DB160']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['PhysiographySrf']['SAD'] = ('Boolean',('DB170'))
    field_information['GGDM 3.0']['PhysiographySrf']['SDCC'] = ('Enumeration',('BJ100','DA010'))
    field_information['GGDM 3.0']['PhysiographySrf']['EnumeratedIndexValues']['SDCC'] = {}
    field_information['GGDM 3.0']['PhysiographySrf']['EnumeratedIndexValues']['SDCC']['BJ100']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['PhysiographySrf']['EnumeratedIndexValues']['SDCC']['DA010']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['PhysiographySrf']['SDCL'] = ('real',('BJ100','DA010'))
    field_information['GGDM 3.0']['PhysiographySrf']['SDCU'] = ('real',('BJ100','DA010'))
    field_information['GGDM 3.0']['PhysiographySrf']['SDO'] = ('Real',('DB170'))
    field_information['GGDM 3.0']['PhysiographySrf']['SDT'] = ('Enumeration',('DB170'))
    field_information['GGDM 3.0']['PhysiographySrf']['EnumeratedIndexValues']['SDT'] = {}
    field_information['GGDM 3.0']['PhysiographySrf']['EnumeratedIndexValues']['SDT']['DB170']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['GGDM 3.0']['PhysiographySrf']['SGCC'] = ('Enumeration',('DB080','DB090'))
    field_information['GGDM 3.0']['PhysiographySrf']['EnumeratedIndexValues']['SGCC'] = {}
    field_information['GGDM 3.0']['PhysiographySrf']['EnumeratedIndexValues']['SGCC']['DB080']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['PhysiographySrf']['EnumeratedIndexValues']['SGCC']['DB090']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['PhysiographySrf']['SGCL'] = ('real',('DB080','DB090'))
    field_information['GGDM 3.0']['PhysiographySrf']['SGCU'] = ('real',('DB080','DB090'))
    field_information['GGDM 3.0']['PhysiographySrf']['SHD'] = ('Boolean',('BA030'))
    field_information['GGDM 3.0']['PhysiographySrf']['SIC'] = ('Enumeration',('BJ100'))
    field_information['GGDM 3.0']['PhysiographySrf']['EnumeratedIndexValues']['SIC'] = {}
    field_information['GGDM 3.0']['PhysiographySrf']['EnumeratedIndexValues']['SIC']['BJ100']  = (-999999,1,2)
    field_information['GGDM 3.0']['PhysiographySrf']['SLT'] = ('Enumeration',('BA030'))
    field_information['GGDM 3.0']['PhysiographySrf']['EnumeratedIndexValues']['SLT'] = {}
    field_information['GGDM 3.0']['PhysiographySrf']['EnumeratedIndexValues']['SLT']['BA030']  = (-999999,6,8,10,11,12,13,14,16,17,18,999)
    field_information['GGDM 3.0']['PhysiographySrf']['SNDC'] = ('Enumeration',('BJ031','BJ080','BJ099','BJ100'))
    field_information['GGDM 3.0']['PhysiographySrf']['EnumeratedIndexValues']['SNDC'] = {}
    field_information['GGDM 3.0']['PhysiographySrf']['EnumeratedIndexValues']['SNDC']['BJ031']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['PhysiographySrf']['EnumeratedIndexValues']['SNDC']['BJ080']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['PhysiographySrf']['EnumeratedIndexValues']['SNDC']['BJ099']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['PhysiographySrf']['EnumeratedIndexValues']['SNDC']['BJ100']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['PhysiographySrf']['SNDL'] = ('real',('BJ031','BJ080','BJ099','BJ100'))
    field_information['GGDM 3.0']['PhysiographySrf']['SNDU'] = ('real',('BJ031','BJ080','BJ099','BJ100'))
    field_information['GGDM 3.0']['PhysiographySrf']['SRD'] = ('Enumeration',('BJ099','BJ100','DA010'))
    field_information['GGDM 3.0']['PhysiographySrf']['EnumeratedIndexValues']['SRD'] = {}
    field_information['GGDM 3.0']['PhysiographySrf']['EnumeratedIndexValues']['SRD']['BJ099']  = (-999999,1,17,36,70,999)
    field_information['GGDM 3.0']['PhysiographySrf']['EnumeratedIndexValues']['SRD']['BJ100']  = (-999999,1,2,11,12,16,17,18,35,36,43,52,53,55,56,57,70,81,999)
    field_information['GGDM 3.0']['PhysiographySrf']['EnumeratedIndexValues']['SRD']['DA010']  = (-999999,1,2,11,12,13,14,15,16,17,18,19,20,31,32,33,34,35,36,37,43,51,52,53,54,55,56,57,58,59,60,61,63,64,65,66,67,69,70,81,86,88,89,90,91,92,93,94,95,999)
    field_information['GGDM 3.0']['PhysiographySrf']['SSE'] = ('StructuredText',('BJ080'))
    field_information['GGDM 3.0']['PhysiographySrf']['STP'] = ('Enumeration',('DA010'))
    field_information['GGDM 3.0']['PhysiographySrf']['EnumeratedIndexValues']['STP'] = {}
    field_information['GGDM 3.0']['PhysiographySrf']['EnumeratedIndexValues']['STP']['DA010']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,17,18,99,999)
    field_information['GGDM 3.0']['PhysiographySrf']['SWC'] = ('Enumeration',('DA010'))
    field_information['GGDM 3.0']['PhysiographySrf']['EnumeratedIndexValues']['SWC'] = {}
    field_information['GGDM 3.0']['PhysiographySrf']['EnumeratedIndexValues']['SWC']['DA010']  = (-999999,1,2,3,4)
    field_information['GGDM 3.0']['PhysiographySrf']['TRS'] = ('Enumeration',('DB090'))
    field_information['GGDM 3.0']['PhysiographySrf']['EnumeratedIndexValues']['TRS'] = {}
    field_information['GGDM 3.0']['PhysiographySrf']['EnumeratedIndexValues']['TRS']['DB090']  = (-999999,2,5,8,10,12,13,999)
    field_information['GGDM 3.0']['PhysiographySrf']['TRS2'] = ('Enumeration',('DB090'))
    field_information['GGDM 3.0']['PhysiographySrf']['EnumeratedIndexValues']['TRS2'] = {}
    field_information['GGDM 3.0']['PhysiographySrf']['EnumeratedIndexValues']['TRS2']['DB090']  = (-999999,2,5,8,10,12,13,999)
    field_information['GGDM 3.0']['PhysiographySrf']['TRS3'] = ('Enumeration',('DB090'))
    field_information['GGDM 3.0']['PhysiographySrf']['EnumeratedIndexValues']['TRS3'] = {}
    field_information['GGDM 3.0']['PhysiographySrf']['EnumeratedIndexValues']['TRS3']['DB090']  = (-999999,2,5,8,10,12,13,999)
    field_information['GGDM 3.0']['PhysiographySrf']['TSM'] = ('Enumeration',('DA010','EE030'))
    field_information['GGDM 3.0']['PhysiographySrf']['EnumeratedIndexValues']['TSM'] = {}
    field_information['GGDM 3.0']['PhysiographySrf']['EnumeratedIndexValues']['TSM']['DA010']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,999)
    field_information['GGDM 3.0']['PhysiographySrf']['EnumeratedIndexValues']['TSM']['EE030']  = (-999999,2,3,5,6,7,8,9,10,12,13,14,999)
    field_information['GGDM 3.0']['PhysiographySrf']['TSM2'] = ('Enumeration',('DA010','EE030'))
    field_information['GGDM 3.0']['PhysiographySrf']['EnumeratedIndexValues']['TSM2'] = {}
    field_information['GGDM 3.0']['PhysiographySrf']['EnumeratedIndexValues']['TSM2']['DA010']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,999)
    field_information['GGDM 3.0']['PhysiographySrf']['EnumeratedIndexValues']['TSM2']['EE030']  = (-999999,2,3,5,6,7,8,9,10,12,13,14,999)
    field_information['GGDM 3.0']['PhysiographySrf']['TSM3'] = ('Enumeration',('DA010','EE030'))
    field_information['GGDM 3.0']['PhysiographySrf']['EnumeratedIndexValues']['TSM3'] = {}
    field_information['GGDM 3.0']['PhysiographySrf']['EnumeratedIndexValues']['TSM3']['DA010']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,999)
    field_information['GGDM 3.0']['PhysiographySrf']['EnumeratedIndexValues']['TSM3']['EE030']  = (-999999,2,3,5,6,7,8,9,10,12,13,14,999)
    field_information['GGDM 3.0']['PhysiographySrf']['UFI'] = ('StructuredText',('BA030','BH150','BH160','BJ020','BJ030','BJ031','BJ065','BJ080','BJ099','BJ100','DA005','DA010','DB061','DB080','DB090','DB115','DB160','DB170','DB180','DB211','EC020','EE030'))
    field_information['GGDM 3.0']['PhysiographySrf']['VGT'] = ('Enumeration',('DB180'))
    field_information['GGDM 3.0']['PhysiographySrf']['EnumeratedIndexValues']['VGT'] = {}
    field_information['GGDM 3.0']['PhysiographySrf']['EnumeratedIndexValues']['VGT']['DB180']  = (-999999,1,2,3,4,5)
    field_information['GGDM 3.0']['PhysiographySrf']['VOA'] = ('Enumeration',('DB180'))
    field_information['GGDM 3.0']['PhysiographySrf']['EnumeratedIndexValues']['VOA'] = {}
    field_information['GGDM 3.0']['PhysiographySrf']['EnumeratedIndexValues']['VOA']['DB180']  = (-999999,1,2,3)
    field_information['GGDM 3.0']['PhysiographySrf']['VTI'] = ('Real',('EC020'))
    field_information['GGDM 3.0']['PhysiographySrf']['WID'] = ('Real',('BA030','BH150','BH160','BJ020','BJ030','BJ031','BJ065','BJ080','BJ099','BJ100','DA005','DA010','DB061','DB080','DB090','DB115','DB160','DB170','DB180','DB211','EC020','EE030'))
    field_information['GGDM 3.0']['PhysiographySrf']['WLE'] = ('Enumeration',('DB090'))
    field_information['GGDM 3.0']['PhysiographySrf']['EnumeratedIndexValues']['WLE'] = {}
    field_information['GGDM 3.0']['PhysiographySrf']['EnumeratedIndexValues']['WLE']['DB090']  = (-999999,1,2,3,4,5,9,999)
    field_information['GGDM 3.0']['PhysiographySrf']['ZI001_SDV'] = ('StructuredText',('BA030','BH150','BH160','BJ020','BJ030','BJ031','BJ065','BJ080','BJ099','BJ100','DA005','DA010','DB061','DB080','DB090','DB115','DB160','DB170','DB180','DB211','EC020','EE030'))
    field_information['GGDM 3.0']['PhysiographySrf']['ZI001_SRT'] = ('Enumeration',('BA030','BH150','BH160','BJ020','BJ030','BJ031','BJ065','BJ080','BJ099','BJ100','DA005','DA010','DB061','DB080','DB090','DB115','DB160','DB170','DB180','DB211','EC020','EE030'))
    field_information['GGDM 3.0']['PhysiographySrf']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['PhysiographySrf']['EnumeratedIndexValues']['ZI001_SRT']['BA030']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['PhysiographySrf']['EnumeratedIndexValues']['ZI001_SRT']['BH150']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['PhysiographySrf']['EnumeratedIndexValues']['ZI001_SRT']['BH160']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['PhysiographySrf']['EnumeratedIndexValues']['ZI001_SRT']['BJ020']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['PhysiographySrf']['EnumeratedIndexValues']['ZI001_SRT']['BJ030']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['PhysiographySrf']['EnumeratedIndexValues']['ZI001_SRT']['BJ031']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['PhysiographySrf']['EnumeratedIndexValues']['ZI001_SRT']['BJ065']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['PhysiographySrf']['EnumeratedIndexValues']['ZI001_SRT']['BJ080']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['PhysiographySrf']['EnumeratedIndexValues']['ZI001_SRT']['BJ099']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['PhysiographySrf']['EnumeratedIndexValues']['ZI001_SRT']['BJ100']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['PhysiographySrf']['EnumeratedIndexValues']['ZI001_SRT']['DA005']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['PhysiographySrf']['EnumeratedIndexValues']['ZI001_SRT']['DA010']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['PhysiographySrf']['EnumeratedIndexValues']['ZI001_SRT']['DB061']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['PhysiographySrf']['EnumeratedIndexValues']['ZI001_SRT']['DB080']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['PhysiographySrf']['EnumeratedIndexValues']['ZI001_SRT']['DB090']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['PhysiographySrf']['EnumeratedIndexValues']['ZI001_SRT']['DB115']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['PhysiographySrf']['EnumeratedIndexValues']['ZI001_SRT']['DB160']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['PhysiographySrf']['EnumeratedIndexValues']['ZI001_SRT']['DB170']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['PhysiographySrf']['EnumeratedIndexValues']['ZI001_SRT']['DB180']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['PhysiographySrf']['EnumeratedIndexValues']['ZI001_SRT']['DB211']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['PhysiographySrf']['EnumeratedIndexValues']['ZI001_SRT']['EC020']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['PhysiographySrf']['EnumeratedIndexValues']['ZI001_SRT']['EE030']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['PhysiographySrf']['ZI002_UFI'] = ('StructuredText',('BA030','BH150','BH160','BJ020','BJ030','BJ031','BJ065','BJ080','BJ099','BJ100','DA005','DA010','DB061','DB080','DB090','DB115','DB160','DB170','DB180','DB211','EC020','EE030'))
    field_information['GGDM 3.0']['PhysiographySrf']['ZI004_RCG'] = ('Enumeration',('BA030','BH150','BH160','BJ020','BJ030','BJ031','BJ065','BJ080','BJ099','BJ100','DA005','DA010','DB061','DB080','DB090','DB115','DB160','DB170','DB180','DB211','EC020','EE030'))
    field_information['GGDM 3.0']['PhysiographySrf']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['PhysiographySrf']['EnumeratedIndexValues']['ZI004_RCG']['BA030']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['PhysiographySrf']['EnumeratedIndexValues']['ZI004_RCG']['BH150']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['PhysiographySrf']['EnumeratedIndexValues']['ZI004_RCG']['BH160']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['PhysiographySrf']['EnumeratedIndexValues']['ZI004_RCG']['BJ020']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['PhysiographySrf']['EnumeratedIndexValues']['ZI004_RCG']['BJ030']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['PhysiographySrf']['EnumeratedIndexValues']['ZI004_RCG']['BJ031']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['PhysiographySrf']['EnumeratedIndexValues']['ZI004_RCG']['BJ065']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['PhysiographySrf']['EnumeratedIndexValues']['ZI004_RCG']['BJ080']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['PhysiographySrf']['EnumeratedIndexValues']['ZI004_RCG']['BJ099']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['PhysiographySrf']['EnumeratedIndexValues']['ZI004_RCG']['BJ100']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['PhysiographySrf']['EnumeratedIndexValues']['ZI004_RCG']['DA005']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['PhysiographySrf']['EnumeratedIndexValues']['ZI004_RCG']['DA010']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['PhysiographySrf']['EnumeratedIndexValues']['ZI004_RCG']['DB061']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['PhysiographySrf']['EnumeratedIndexValues']['ZI004_RCG']['DB080']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['PhysiographySrf']['EnumeratedIndexValues']['ZI004_RCG']['DB090']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['PhysiographySrf']['EnumeratedIndexValues']['ZI004_RCG']['DB115']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['PhysiographySrf']['EnumeratedIndexValues']['ZI004_RCG']['DB160']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['PhysiographySrf']['EnumeratedIndexValues']['ZI004_RCG']['DB170']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['PhysiographySrf']['EnumeratedIndexValues']['ZI004_RCG']['DB180']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['PhysiographySrf']['EnumeratedIndexValues']['ZI004_RCG']['DB211']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['PhysiographySrf']['EnumeratedIndexValues']['ZI004_RCG']['EC020']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['PhysiographySrf']['EnumeratedIndexValues']['ZI004_RCG']['EE030']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['PhysiographySrf']['ZI005_FNA'] = ('String',('BA030','BH150','BH160','BJ020','BJ030','BJ065','BJ080','BJ099','BJ100','DA005','DA010','DB061','DB080','DB090','DB115','DB160','DB170','DB180','DB211','EC020','EE030'))
    field_information['GGDM 3.0']['PhysiographySrf']['ZI005_FNA2'] = ('String',('DB115'))
    field_information['GGDM 3.0']['PhysiographySrf']['ZI005_FNA3'] = ('String',('DB115'))
    field_information['GGDM 3.0']['PhysiographySrf']['ZI005_GNT'] = ('Enumeration',('BA030','BH150','BH160','BJ020','BJ030','BJ065','BJ080','BJ099','BJ100','DA005','DA010','DB061','DB080','DB090','DB115','DB160','DB170','DB180','DB211','EC020','EE030'))
    field_information['GGDM 3.0']['PhysiographySrf']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['PhysiographySrf']['EnumeratedIndexValues']['ZI005_GNT']['BA030']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['PhysiographySrf']['EnumeratedIndexValues']['ZI005_GNT']['BH150']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['PhysiographySrf']['EnumeratedIndexValues']['ZI005_GNT']['BH160']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['PhysiographySrf']['EnumeratedIndexValues']['ZI005_GNT']['BJ020']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['PhysiographySrf']['EnumeratedIndexValues']['ZI005_GNT']['BJ030']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['PhysiographySrf']['EnumeratedIndexValues']['ZI005_GNT']['BJ065']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['PhysiographySrf']['EnumeratedIndexValues']['ZI005_GNT']['BJ080']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['PhysiographySrf']['EnumeratedIndexValues']['ZI005_GNT']['BJ099']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['PhysiographySrf']['EnumeratedIndexValues']['ZI005_GNT']['BJ100']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['PhysiographySrf']['EnumeratedIndexValues']['ZI005_GNT']['DA005']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['PhysiographySrf']['EnumeratedIndexValues']['ZI005_GNT']['DA010']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['PhysiographySrf']['EnumeratedIndexValues']['ZI005_GNT']['DB061']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['PhysiographySrf']['EnumeratedIndexValues']['ZI005_GNT']['DB080']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['PhysiographySrf']['EnumeratedIndexValues']['ZI005_GNT']['DB090']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['PhysiographySrf']['EnumeratedIndexValues']['ZI005_GNT']['DB115']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['PhysiographySrf']['EnumeratedIndexValues']['ZI005_GNT']['DB160']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['PhysiographySrf']['EnumeratedIndexValues']['ZI005_GNT']['DB170']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['PhysiographySrf']['EnumeratedIndexValues']['ZI005_GNT']['DB180']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['PhysiographySrf']['EnumeratedIndexValues']['ZI005_GNT']['DB211']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['PhysiographySrf']['EnumeratedIndexValues']['ZI005_GNT']['EC020']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['PhysiographySrf']['EnumeratedIndexValues']['ZI005_GNT']['EE030']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['PhysiographySrf']['ZI005_GNT2'] = ('Enumeration',('DB115'))
    field_information['GGDM 3.0']['PhysiographySrf']['EnumeratedIndexValues']['ZI005_GNT2'] = {}
    field_information['GGDM 3.0']['PhysiographySrf']['EnumeratedIndexValues']['ZI005_GNT2']['DB115']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['PhysiographySrf']['ZI005_GNT3'] = ('Enumeration',('DB115'))
    field_information['GGDM 3.0']['PhysiographySrf']['EnumeratedIndexValues']['ZI005_GNT3'] = {}
    field_information['GGDM 3.0']['PhysiographySrf']['EnumeratedIndexValues']['ZI005_GNT3']['DB115']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['PhysiographySrf']['ZI005_NFN'] = ('String',('BA030','BH150','BH160','BJ020','BJ030','BJ065','BJ080','BJ099','BJ100','DA005','DA010','DB061','DB080','DB090','DB115','DB160','DB170','DB180','DB211','EC020','EE030'))
    field_information['GGDM 3.0']['PhysiographySrf']['ZI005_NFN2'] = ('String',('DB115'))
    field_information['GGDM 3.0']['PhysiographySrf']['ZI005_NFN3'] = ('String',('DB115'))
    field_information['GGDM 3.0']['PhysiographySrf']['ZI006_MEM'] = ('String',('BA030','BH150','BH160','BJ020','BJ030','BJ031','BJ065','BJ080','BJ099','BJ100','DA005','DA010','DB061','DB080','DB090','DB115','DB160','DB170','DB180','DB211','EC020','EE030'))
    field_information['GGDM 3.0']['PhysiographySrf']['ZI020_GE4'] = ('CodeList',('BA030','BH150','BH160','BJ020','BJ030','BJ031','BJ065','BJ080','BJ099','BJ100','DA005','DA010','DB061','DB080','DB090','DB115','DB160','DB170','DB180','DB211','EC020','EE030'))
    field_information['GGDM 3.0']['PhysiographySrf']['ZI024_ASE'] = ('Real',('DB115'))
    field_information['GGDM 3.0']['PhysiographySrf']['ZI024_AWO'] = ('Real',('DB115'))
    field_information['GGDM 3.0']['PhysiographySrf']['ZI024_AWOI'] = ('Real',('DB115'))
    field_information['GGDM 3.0']['PhysiographySrf']['ZI024_AWOX'] = ('Real',('DB115'))
    field_information['GGDM 3.0']['PhysiographySrf']['ZI024_CFR'] = ('Real',('DB115'))
    field_information['GGDM 3.0']['PhysiographySrf']['ZI024_CLO'] = ('Real',('DB115'))
    field_information['GGDM 3.0']['PhysiographySrf']['ZI024_CYN'] = ('Real',('DB115'))
    field_information['GGDM 3.0']['PhysiographySrf']['ZI024_FMR'] = ('Real',('DB115'))
    field_information['GGDM 3.0']['PhysiographySrf']['ZI024_FRR'] = ('Real',('DB115'))
    field_information['GGDM 3.0']['PhysiographySrf']['ZI024_HAR'] = ('Real',('DB115'))
    field_information['GGDM 3.0']['PhysiographySrf']['ZI024_HYP'] = ('Enumeration',('DB115'))
    field_information['GGDM 3.0']['PhysiographySrf']['EnumeratedIndexValues']['ZI024_HYP'] = {}
    field_information['GGDM 3.0']['PhysiographySrf']['EnumeratedIndexValues']['ZI024_HYP']['DB115']  = (-999999,1,2,4)
    field_information['GGDM 3.0']['PhysiographySrf']['ZI024_MGN'] = ('Real',('DB115'))
    field_information['GGDM 3.0']['PhysiographySrf']['ZI024_PHW'] = ('Real',('DB115'))
    field_information['GGDM 3.0']['PhysiographySrf']['ZI024_SCC'] = ('Enumeration',('DB115'))
    field_information['GGDM 3.0']['PhysiographySrf']['EnumeratedIndexValues']['ZI024_SCC'] = {}
    field_information['GGDM 3.0']['PhysiographySrf']['EnumeratedIndexValues']['ZI024_SCC']['DB115']  = (-999999,1,4,10,11,12,13,14,998,999)
    field_information['GGDM 3.0']['PhysiographySrf']['ZI024_SUL'] = ('Real',('DB115'))
    field_information['GGDM 3.0']['PhysiographySrf']['ZI024_TDS'] = ('Real',('DB115'))
    field_information['GGDM 3.0']['PhysiographySrf']['ZI024_TEP'] = ('Real',('DB115'))
    field_information['GGDM 3.0']['PhysiographySrf']['ZI024_TUR'] = ('Real',('DB115'))
    field_information['GGDM 3.0']['PhysiographySrf']['ZI024_WAC'] = ('Real',('DB115'))
    field_information['GGDM 3.0']['PhysiographySrf']['ZI024_WTNO'] = ('Real',('DB115'))
    field_information['GGDM 3.0']['PhysiographySrf']['ZI024_WUR'] = ('Enumeration',('DB115'))
    field_information['GGDM 3.0']['PhysiographySrf']['EnumeratedIndexValues']['ZI024_WUR'] = {}
    field_information['GGDM 3.0']['PhysiographySrf']['EnumeratedIndexValues']['ZI024_WUR']['DB115']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['PhysiographySrf']['ZI024_WUR2'] = ('Enumeration',('DB115'))
    field_information['GGDM 3.0']['PhysiographySrf']['EnumeratedIndexValues']['ZI024_WUR2'] = {}
    field_information['GGDM 3.0']['PhysiographySrf']['EnumeratedIndexValues']['ZI024_WUR2']['DB115']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['PhysiographySrf']['ZI024_WUR3'] = ('Enumeration',('DB115'))
    field_information['GGDM 3.0']['PhysiographySrf']['EnumeratedIndexValues']['ZI024_WUR3'] = {}
    field_information['GGDM 3.0']['PhysiographySrf']['EnumeratedIndexValues']['ZI024_WUR3']['DB115']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['PhysiographySrf']['ZI024_WUR4'] = ('Enumeration',('DB115'))
    field_information['GGDM 3.0']['PhysiographySrf']['EnumeratedIndexValues']['ZI024_WUR4'] = {}
    field_information['GGDM 3.0']['PhysiographySrf']['EnumeratedIndexValues']['ZI024_WUR4']['DB115']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['PhysiographySrf']['ZI024_YWQ'] = ('Enumeration',('DB115'))
    field_information['GGDM 3.0']['PhysiographySrf']['EnumeratedIndexValues']['ZI024_YWQ'] = {}
    field_information['GGDM 3.0']['PhysiographySrf']['EnumeratedIndexValues']['ZI024_YWQ']['DB115']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['PhysiographySrf']['ZI025_HDP'] = ('Real',('DB115'))
    field_information['GGDM 3.0']['PhysiographySrf']['ZI026_CTUC'] = ('Enumeration',('BA030','BH150','BH160','BJ020','BJ030','BJ031','BJ065','BJ080','BJ099','BJ100','DA005','DA010','DB061','DB080','DB090','DB115','DB160','DB170','DB180','DB211','EC020','EE030'))
    field_information['GGDM 3.0']['PhysiographySrf']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['PhysiographySrf']['EnumeratedIndexValues']['ZI026_CTUC']['BA030']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['PhysiographySrf']['EnumeratedIndexValues']['ZI026_CTUC']['BH150']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['PhysiographySrf']['EnumeratedIndexValues']['ZI026_CTUC']['BH160']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['PhysiographySrf']['EnumeratedIndexValues']['ZI026_CTUC']['BJ020']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['PhysiographySrf']['EnumeratedIndexValues']['ZI026_CTUC']['BJ030']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['PhysiographySrf']['EnumeratedIndexValues']['ZI026_CTUC']['BJ031']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['PhysiographySrf']['EnumeratedIndexValues']['ZI026_CTUC']['BJ065']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['PhysiographySrf']['EnumeratedIndexValues']['ZI026_CTUC']['BJ080']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['PhysiographySrf']['EnumeratedIndexValues']['ZI026_CTUC']['BJ099']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['PhysiographySrf']['EnumeratedIndexValues']['ZI026_CTUC']['BJ100']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['PhysiographySrf']['EnumeratedIndexValues']['ZI026_CTUC']['DA005']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['PhysiographySrf']['EnumeratedIndexValues']['ZI026_CTUC']['DA010']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['PhysiographySrf']['EnumeratedIndexValues']['ZI026_CTUC']['DB061']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['PhysiographySrf']['EnumeratedIndexValues']['ZI026_CTUC']['DB080']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['PhysiographySrf']['EnumeratedIndexValues']['ZI026_CTUC']['DB090']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['PhysiographySrf']['EnumeratedIndexValues']['ZI026_CTUC']['DB115']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['PhysiographySrf']['EnumeratedIndexValues']['ZI026_CTUC']['DB160']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['PhysiographySrf']['EnumeratedIndexValues']['ZI026_CTUC']['DB170']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['PhysiographySrf']['EnumeratedIndexValues']['ZI026_CTUC']['DB180']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['PhysiographySrf']['EnumeratedIndexValues']['ZI026_CTUC']['DB211']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['PhysiographySrf']['EnumeratedIndexValues']['ZI026_CTUC']['EC020']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['PhysiographySrf']['EnumeratedIndexValues']['ZI026_CTUC']['EE030']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['PhysiographySrf']['ZI026_CTUL'] = ('integer',('BA030','BH150','BH160','BJ020','BJ030','BJ031','BJ065','BJ080','BJ099','BJ100','DA005','DA010','DB061','DB080','DB090','DB115','DB160','DB170','DB180','DB211','EC020','EE030'))
    field_information['GGDM 3.0']['PhysiographySrf']['ZI026_CTUU'] = ('integer',('BA030','BH150','BH160','BJ020','BJ030','BJ031','BJ065','BJ080','BJ099','BJ100','DA005','DA010','DB061','DB080','DB090','DB115','DB160','DB170','DB180','DB211','EC020','EE030'))
    field_information['GGDM 3.0']['PhysiographySrf']['ZI031S_URI'] = ('StructuredText',('BA030','BH150','BH160','BJ020','BJ030','BJ031','BJ065','BJ080','BJ099','BJ100','DA005','DA010','DB061','DB080','DB090','DB115','DB160','DB170','DB180','DB211','EC020','EE030'))
    field_information['GGDM 3.0']['PhysiographySrf']['ZI039S_UFI'] = ('StructuredText',('BA030','BH150','BH160','BJ020','BJ030','BJ031','BJ065','BJ080','BJ099','BJ100','DA005','DA010','DB061','DB080','DB090','DB115','DB160','DB170','DB180','DB211','EC020','EE030'))
    field_information['GGDM 3.0']['PhysiographySrf']['ZSAX_RS0'] = ('CodeList',('BA030','BH150','BH160','BJ020','BJ030','BJ031','BJ065','BJ080','BJ099','BJ100','DA005','DA010','DB061','DB080','DB090','DB115','DB160','DB170','DB180','DB211','EC020','EE030'))
    field_information['GGDM 3.0']['PhysiographySrf']['ZSAX_RX0'] = ('StructuredText',('BA030','BH150','BH160','BJ020','BJ030','BJ031','BJ065','BJ080','BJ099','BJ100','DA005','DA010','DB061','DB080','DB090','DB115','DB160','DB170','DB180','DB211','EC020','EE030'))
    field_information['GGDM 3.0']['PhysiographySrf']['ZSAX_RX3'] = ('StructuredText',('BA030','BH150','BH160','BJ020','BJ030','BJ031','BJ065','BJ080','BJ099','BJ100','DA005','DA010','DB061','DB080','DB090','DB115','DB160','DB170','DB180','DB211','EC020','EE030'))
    field_information['GGDM 3.0']['PhysiographySrf']['ZSAX_RX4'] = ('StructuredText',('BA030','BH150','BH160','BJ020','BJ030','BJ031','BJ065','BJ080','BJ099','BJ100','DA005','DA010','DB061','DB080','DB090','DB115','DB160','DB170','DB180','DB211','EC020','EE030'))
    field_information['GGDM 3.0']['PhysiographySrf']['ZVH'] = ('Real',('BA030','BJ030','BJ031','BJ080','DB061','DB090','DB160','DB170','DB180'))
    field_information['GGDM 3.0']['PhysiographySrfExt']['ARA'] = ('Real',('DB185','NA170'))
    field_information['GGDM 3.0']['PhysiographySrfExt']['BEN'] = ('StructuredText',('BA023','BA050','BJ070','DB185','NA170','SA050'))
    field_information['GGDM 3.0']['PhysiographySrfExt']['DZP'] = ('Real',('DB185'))
    field_information['GGDM 3.0']['PhysiographySrfExt']['F_CODE'] = ('CONSTRAINED_STRING',('BA023','BA050','BJ070','DB185','NA170','SA050'))
    field_information['GGDM 3.0']['PhysiographySrfExt']['FUFI'] = ('StructuredText',('BA023','BA050','BJ070','DB185','NA170','SA050'))
    field_information['GGDM 3.0']['PhysiographySrfExt']['FURL'] = ('StructuredText',('BA023','BA050','BJ070','DB185','NA170','SA050'))
    field_information['GGDM 3.0']['PhysiographySrfExt']['GDBV'] = ('Enumeration',('BA023','BA050','BJ070','DB185','NA170','SA050'))
    field_information['GGDM 3.0']['PhysiographySrfExt']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['PhysiographySrfExt']['EnumeratedIndexValues']['GDBV']['BA023']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['PhysiographySrfExt']['EnumeratedIndexValues']['GDBV']['BA050']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['PhysiographySrfExt']['EnumeratedIndexValues']['GDBV']['BJ070']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['PhysiographySrfExt']['EnumeratedIndexValues']['GDBV']['DB185']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['PhysiographySrfExt']['EnumeratedIndexValues']['GDBV']['NA170']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['PhysiographySrfExt']['EnumeratedIndexValues']['GDBV']['SA050']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['PhysiographySrfExt']['LMC'] = ('Boolean',('DB185'))
    field_information['GGDM 3.0']['PhysiographySrfExt']['LZN'] = ('Real',('DB185','NA170'))
    field_information['GGDM 3.0']['PhysiographySrfExt']['MBC_MCC1'] = ('Enumeration',('BA023','BA050'))
    field_information['GGDM 3.0']['PhysiographySrfExt']['EnumeratedIndexValues']['MBC_MCC1'] = {}
    field_information['GGDM 3.0']['PhysiographySrfExt']['EnumeratedIndexValues']['MBC_MCC1']['BA023']  = (-999999,4,7,8,10,12,14,15,16,18,22,24,25,28,36,37,45,46,49,52,55,58,59,61,63,65,66,69,70,73,75,79,80,81,84,88,90,92,96,98,99,103,104,105,106,108,111,115,999)
    field_information['GGDM 3.0']['PhysiographySrfExt']['EnumeratedIndexValues']['MBC_MCC1']['BA050']  = (-999999,4,7,8,10,12,14,15,16,18,22,24,25,28,36,37,45,46,49,52,55,58,59,61,63,65,66,69,70,73,75,79,80,81,84,88,90,92,96,98,99,103,104,105,106,108,111,115,999)
    field_information['GGDM 3.0']['PhysiographySrfExt']['MBC_MCC2'] = ('Enumeration',('BA023','BA050'))
    field_information['GGDM 3.0']['PhysiographySrfExt']['EnumeratedIndexValues']['MBC_MCC2'] = {}
    field_information['GGDM 3.0']['PhysiographySrfExt']['EnumeratedIndexValues']['MBC_MCC2']['BA023']  = (-999999,4,7,8,10,12,14,15,16,18,22,24,25,28,36,37,45,46,49,52,55,58,59,61,63,65,66,69,70,73,75,79,80,81,84,88,90,92,96,98,99,103,104,105,106,108,111,115,999)
    field_information['GGDM 3.0']['PhysiographySrfExt']['EnumeratedIndexValues']['MBC_MCC2']['BA050']  = (-999999,4,7,8,10,12,14,15,16,18,22,24,25,28,36,37,45,46,49,52,55,58,59,61,63,65,66,69,70,73,75,79,80,81,84,88,90,92,96,98,99,103,104,105,106,108,111,115,999)
    field_information['GGDM 3.0']['PhysiographySrfExt']['MBC_PSC1'] = ('Enumeration',('BA023','BA050'))
    field_information['GGDM 3.0']['PhysiographySrfExt']['EnumeratedIndexValues']['MBC_PSC1'] = {}
    field_information['GGDM 3.0']['PhysiographySrfExt']['EnumeratedIndexValues']['MBC_PSC1']['BA023']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,17,18,19,20,21,22,23,24,25,26,27,29,999)
    field_information['GGDM 3.0']['PhysiographySrfExt']['EnumeratedIndexValues']['MBC_PSC1']['BA050']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,17,18,19,20,21,22,23,24,25,26,27,29,999)
    field_information['GGDM 3.0']['PhysiographySrfExt']['MBC_PSC2'] = ('Enumeration',('BA023','BA050'))
    field_information['GGDM 3.0']['PhysiographySrfExt']['EnumeratedIndexValues']['MBC_PSC2'] = {}
    field_information['GGDM 3.0']['PhysiographySrfExt']['EnumeratedIndexValues']['MBC_PSC2']['BA023']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,17,18,19,20,21,22,23,24,25,26,27,29,999)
    field_information['GGDM 3.0']['PhysiographySrfExt']['EnumeratedIndexValues']['MBC_PSC2']['BA050']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,17,18,19,20,21,22,23,24,25,26,27,29,999)
    field_information['GGDM 3.0']['PhysiographySrfExt']['MBC_SCO1'] = ('Enumeration',('BA023','BA050'))
    field_information['GGDM 3.0']['PhysiographySrfExt']['EnumeratedIndexValues']['MBC_SCO1'] = {}
    field_information['GGDM 3.0']['PhysiographySrfExt']['EnumeratedIndexValues']['MBC_SCO1']['BA023']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,999)
    field_information['GGDM 3.0']['PhysiographySrfExt']['EnumeratedIndexValues']['MBC_SCO1']['BA050']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,999)
    field_information['GGDM 3.0']['PhysiographySrfExt']['MBC_SCO2'] = ('Enumeration',('BA023','BA050'))
    field_information['GGDM 3.0']['PhysiographySrfExt']['EnumeratedIndexValues']['MBC_SCO2'] = {}
    field_information['GGDM 3.0']['PhysiographySrfExt']['EnumeratedIndexValues']['MBC_SCO2']['BA023']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,999)
    field_information['GGDM 3.0']['PhysiographySrfExt']['EnumeratedIndexValues']['MBC_SCO2']['BA050']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,999)
    field_information['GGDM 3.0']['PhysiographySrfExt']['OTH'] = ('StructuredText',('BA023','BA050','BJ070','DB185','NA170','SA050'))
    field_information['GGDM 3.0']['PhysiographySrfExt']['PCF'] = ('Enumeration',('NA170'))
    field_information['GGDM 3.0']['PhysiographySrfExt']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['PhysiographySrfExt']['EnumeratedIndexValues']['PCF']['NA170']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['PhysiographySrfExt']['PRVR'] = ('StructuredText',('NA170'))
    field_information['GGDM 3.0']['PhysiographySrfExt']['SGCC'] = ('Enumeration',('SA050'))
    field_information['GGDM 3.0']['PhysiographySrfExt']['EnumeratedIndexValues']['SGCC'] = {}
    field_information['GGDM 3.0']['PhysiographySrfExt']['EnumeratedIndexValues']['SGCC']['SA050']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['PhysiographySrfExt']['SGCL'] = ('real',('SA050'))
    field_information['GGDM 3.0']['PhysiographySrfExt']['SGCU'] = ('real',('SA050'))
    field_information['GGDM 3.0']['PhysiographySrfExt']['SSE'] = ('StructuredText',('BJ070'))
    field_information['GGDM 3.0']['PhysiographySrfExt']['STP'] = ('Enumeration',('BA023','BA050'))
    field_information['GGDM 3.0']['PhysiographySrfExt']['EnumeratedIndexValues']['STP'] = {}
    field_information['GGDM 3.0']['PhysiographySrfExt']['EnumeratedIndexValues']['STP']['BA023']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,17,18,99,999)
    field_information['GGDM 3.0']['PhysiographySrfExt']['EnumeratedIndexValues']['STP']['BA050']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,17,18,99,999)
    field_information['GGDM 3.0']['PhysiographySrfExt']['SWC'] = ('Enumeration',('BA023','BA050'))
    field_information['GGDM 3.0']['PhysiographySrfExt']['EnumeratedIndexValues']['SWC'] = {}
    field_information['GGDM 3.0']['PhysiographySrfExt']['EnumeratedIndexValues']['SWC']['BA023']  = (-999999,1,2,3,4)
    field_information['GGDM 3.0']['PhysiographySrfExt']['EnumeratedIndexValues']['SWC']['BA050']  = (-999999,1,2,3,4)
    field_information['GGDM 3.0']['PhysiographySrfExt']['UFI'] = ('StructuredText',('BA023','BA050','BJ070','DB185','NA170','SA050'))
    field_information['GGDM 3.0']['PhysiographySrfExt']['VTI'] = ('Real',('NA170'))
    field_information['GGDM 3.0']['PhysiographySrfExt']['WID'] = ('Real',('DB185','NA170'))
    field_information['GGDM 3.0']['PhysiographySrfExt']['ZI001_SDV'] = ('StructuredText',('BA023','BA050','BJ070','DB185','NA170','SA050'))
    field_information['GGDM 3.0']['PhysiographySrfExt']['ZI001_SRT'] = ('Enumeration',('BA023','BA050','BJ070','DB185','NA170','SA050'))
    field_information['GGDM 3.0']['PhysiographySrfExt']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['PhysiographySrfExt']['EnumeratedIndexValues']['ZI001_SRT']['BA023']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['PhysiographySrfExt']['EnumeratedIndexValues']['ZI001_SRT']['BA050']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['PhysiographySrfExt']['EnumeratedIndexValues']['ZI001_SRT']['BJ070']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['PhysiographySrfExt']['EnumeratedIndexValues']['ZI001_SRT']['DB185']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['PhysiographySrfExt']['EnumeratedIndexValues']['ZI001_SRT']['NA170']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['PhysiographySrfExt']['EnumeratedIndexValues']['ZI001_SRT']['SA050']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['PhysiographySrfExt']['ZI002_UFI'] = ('StructuredText',('BA023','BA050','BJ070','DB185','NA170','SA050'))
    field_information['GGDM 3.0']['PhysiographySrfExt']['ZI004_RCG'] = ('Enumeration',('BA023','BA050','BJ070','DB185','NA170','SA050'))
    field_information['GGDM 3.0']['PhysiographySrfExt']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['PhysiographySrfExt']['EnumeratedIndexValues']['ZI004_RCG']['BA023']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['PhysiographySrfExt']['EnumeratedIndexValues']['ZI004_RCG']['BA050']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['PhysiographySrfExt']['EnumeratedIndexValues']['ZI004_RCG']['BJ070']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['PhysiographySrfExt']['EnumeratedIndexValues']['ZI004_RCG']['DB185']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['PhysiographySrfExt']['EnumeratedIndexValues']['ZI004_RCG']['NA170']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['PhysiographySrfExt']['EnumeratedIndexValues']['ZI004_RCG']['SA050']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['PhysiographySrfExt']['ZI005_FNA'] = ('String',('BA023','BA050','BJ070','DB185','NA170'))
    field_information['GGDM 3.0']['PhysiographySrfExt']['ZI005_GNT'] = ('Enumeration',('BA023','BA050','BJ070','DB185','NA170'))
    field_information['GGDM 3.0']['PhysiographySrfExt']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['PhysiographySrfExt']['EnumeratedIndexValues']['ZI005_GNT']['BA023']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['PhysiographySrfExt']['EnumeratedIndexValues']['ZI005_GNT']['BA050']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['PhysiographySrfExt']['EnumeratedIndexValues']['ZI005_GNT']['BJ070']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['PhysiographySrfExt']['EnumeratedIndexValues']['ZI005_GNT']['DB185']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['PhysiographySrfExt']['EnumeratedIndexValues']['ZI005_GNT']['NA170']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['PhysiographySrfExt']['ZI005_NFN'] = ('String',('BA023','BA050','BJ070','DB185','NA170'))
    field_information['GGDM 3.0']['PhysiographySrfExt']['ZI006_MEM'] = ('String',('BA023','BA050','BJ070','DB185','NA170','SA050'))
    field_information['GGDM 3.0']['PhysiographySrfExt']['ZI020_GE4'] = ('CodeList',('BA023','BA050','BJ070','DB185','NA170','SA050'))
    field_information['GGDM 3.0']['PhysiographySrfExt']['ZI026_CTUC'] = ('Enumeration',('BA023','BA050','BJ070','DB185','NA170','SA050'))
    field_information['GGDM 3.0']['PhysiographySrfExt']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['PhysiographySrfExt']['EnumeratedIndexValues']['ZI026_CTUC']['BA023']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['PhysiographySrfExt']['EnumeratedIndexValues']['ZI026_CTUC']['BA050']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['PhysiographySrfExt']['EnumeratedIndexValues']['ZI026_CTUC']['BJ070']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['PhysiographySrfExt']['EnumeratedIndexValues']['ZI026_CTUC']['DB185']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['PhysiographySrfExt']['EnumeratedIndexValues']['ZI026_CTUC']['NA170']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['PhysiographySrfExt']['EnumeratedIndexValues']['ZI026_CTUC']['SA050']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['PhysiographySrfExt']['ZI026_CTUL'] = ('integer',('BA023','BA050','BJ070','DB185','NA170','SA050'))
    field_information['GGDM 3.0']['PhysiographySrfExt']['ZI026_CTUU'] = ('integer',('BA023','BA050','BJ070','DB185','NA170','SA050'))
    field_information['GGDM 3.0']['PhysiographySrfExt']['ZI031S_URI'] = ('StructuredText',('BA023','BA050','BJ070','DB185','NA170','SA050'))
    field_information['GGDM 3.0']['PhysiographySrfExt']['ZI039S_UFI'] = ('StructuredText',('BA023','BA050','BJ070','DB185','NA170','SA050'))
    field_information['GGDM 3.0']['PhysiographySrfExt']['ZSAX_RS0'] = ('CodeList',('BA023','BA050','BJ070','DB185','NA170','SA050'))
    field_information['GGDM 3.0']['PhysiographySrfExt']['ZSAX_RX0'] = ('StructuredText',('BA023','BA050','BJ070','DB185','NA170','SA050'))
    field_information['GGDM 3.0']['PhysiographySrfExt']['ZSAX_RX3'] = ('StructuredText',('BA023','BA050','BJ070','DB185','NA170','SA050'))
    field_information['GGDM 3.0']['PhysiographySrfExt']['ZSAX_RX4'] = ('StructuredText',('BA023','BA050','BJ070','DB185','NA170','SA050'))
    field_information['GGDM 3.0']['PortHarbourCrv']['AOO'] = ('Real',('BB081'))
    field_information['GGDM 3.0']['PortHarbourCrv']['ARA'] = ('Real',('BB081','BB082'))
    field_information['GGDM 3.0']['PortHarbourCrv']['BEN'] = ('StructuredText',('BB081','BB082'))
    field_information['GGDM 3.0']['PortHarbourCrv']['CAA'] = ('Enumeration',('BB081'))
    field_information['GGDM 3.0']['PortHarbourCrv']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['PortHarbourCrv']['EnumeratedIndexValues']['CAA']['BB081']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['PortHarbourCrv']['CNCP'] = ('StructuredText',('BB081','BB082'))
    field_information['GGDM 3.0']['PortHarbourCrv']['COS'] = ('Enumeration',('BB081','BB082'))
    field_information['GGDM 3.0']['PortHarbourCrv']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['PortHarbourCrv']['EnumeratedIndexValues']['COS']['BB081']  = (-999999,2,4,6,9,13,14)
    field_information['GGDM 3.0']['PortHarbourCrv']['EnumeratedIndexValues']['COS']['BB082']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['PortHarbourCrv']['F_CODE'] = ('CONSTRAINED_STRING',('BB081','BB082'))
    field_information['GGDM 3.0']['PortHarbourCrv']['FAC'] = ('Boolean',('BB081'))
    field_information['GGDM 3.0']['PortHarbourCrv']['FFN'] = ('Enumeration',('BB081'))
    field_information['GGDM 3.0']['PortHarbourCrv']['EnumeratedIndexValues']['FFN'] = {}
    field_information['GGDM 3.0']['PortHarbourCrv']['EnumeratedIndexValues']['FFN']['BB081']  = (-999999,30,99,440,529,530,921,999)
    field_information['GGDM 3.0']['PortHarbourCrv']['FFN2'] = ('Enumeration',('BB081'))
    field_information['GGDM 3.0']['PortHarbourCrv']['EnumeratedIndexValues']['FFN2'] = {}
    field_information['GGDM 3.0']['PortHarbourCrv']['EnumeratedIndexValues']['FFN2']['BB081']  = (-999999,30,99,440,529,530,921,999)
    field_information['GGDM 3.0']['PortHarbourCrv']['FFN3'] = ('Enumeration',('BB081'))
    field_information['GGDM 3.0']['PortHarbourCrv']['EnumeratedIndexValues']['FFN3'] = {}
    field_information['GGDM 3.0']['PortHarbourCrv']['EnumeratedIndexValues']['FFN3']['BB081']  = (-999999,30,99,440,529,530,921,999)
    field_information['GGDM 3.0']['PortHarbourCrv']['FLO'] = ('Boolean',('BB081'))
    field_information['GGDM 3.0']['PortHarbourCrv']['FUFI'] = ('StructuredText',('BB081','BB082'))
    field_information['GGDM 3.0']['PortHarbourCrv']['FURL'] = ('StructuredText',('BB081','BB082'))
    field_information['GGDM 3.0']['PortHarbourCrv']['GDBV'] = ('Enumeration',('BB081','BB082'))
    field_information['GGDM 3.0']['PortHarbourCrv']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['PortHarbourCrv']['EnumeratedIndexValues']['GDBV']['BB081']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['PortHarbourCrv']['EnumeratedIndexValues']['GDBV']['BB082']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['PortHarbourCrv']['HGT'] = ('Real',('BB081','BB082'))
    field_information['GGDM 3.0']['PortHarbourCrv']['LMC'] = ('Boolean',('BB081'))
    field_information['GGDM 3.0']['PortHarbourCrv']['LZN'] = ('Real',('BB081','BB082'))
    field_information['GGDM 3.0']['PortHarbourCrv']['MCC'] = ('Enumeration',('BB081','BB082'))
    field_information['GGDM 3.0']['PortHarbourCrv']['EnumeratedIndexValues']['MCC'] = {}
    field_information['GGDM 3.0']['PortHarbourCrv']['EnumeratedIndexValues']['MCC']['BB081']  = (-999999,5,8,9,21,62,64,77,83,84,86,104,107,108,117,150,999)
    field_information['GGDM 3.0']['PortHarbourCrv']['EnumeratedIndexValues']['MCC']['BB082']  = (-999999,5,9,21,46,62,88,104,999)
    field_information['GGDM 3.0']['PortHarbourCrv']['MCC2'] = ('Enumeration',('BB081','BB082'))
    field_information['GGDM 3.0']['PortHarbourCrv']['EnumeratedIndexValues']['MCC2'] = {}
    field_information['GGDM 3.0']['PortHarbourCrv']['EnumeratedIndexValues']['MCC2']['BB081']  = (-999999,5,8,9,21,62,64,77,83,84,86,104,107,108,117,150,999)
    field_information['GGDM 3.0']['PortHarbourCrv']['EnumeratedIndexValues']['MCC2']['BB082']  = (-999999,5,9,21,46,62,88,104,999)
    field_information['GGDM 3.0']['PortHarbourCrv']['MCC3'] = ('Enumeration',('BB081','BB082'))
    field_information['GGDM 3.0']['PortHarbourCrv']['EnumeratedIndexValues']['MCC3'] = {}
    field_information['GGDM 3.0']['PortHarbourCrv']['EnumeratedIndexValues']['MCC3']['BB081']  = (-999999,5,8,9,21,62,64,77,83,84,86,104,107,108,117,150,999)
    field_information['GGDM 3.0']['PortHarbourCrv']['EnumeratedIndexValues']['MCC3']['BB082']  = (-999999,5,9,21,46,62,88,104,999)
    field_information['GGDM 3.0']['PortHarbourCrv']['OTH'] = ('StructuredText',('BB081','BB082'))
    field_information['GGDM 3.0']['PortHarbourCrv']['PCF'] = ('Enumeration',('BB081','BB082'))
    field_information['GGDM 3.0']['PortHarbourCrv']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['PortHarbourCrv']['EnumeratedIndexValues']['PCF']['BB081']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['PortHarbourCrv']['EnumeratedIndexValues']['PCF']['BB082']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['PortHarbourCrv']['PWC'] = ('Enumeration',('BB081'))
    field_information['GGDM 3.0']['PortHarbourCrv']['EnumeratedIndexValues']['PWC'] = {}
    field_information['GGDM 3.0']['PortHarbourCrv']['EnumeratedIndexValues']['PWC']['BB081']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,18,999)
    field_information['GGDM 3.0']['PortHarbourCrv']['SGCC'] = ('Enumeration',('BB082'))
    field_information['GGDM 3.0']['PortHarbourCrv']['EnumeratedIndexValues']['SGCC'] = {}
    field_information['GGDM 3.0']['PortHarbourCrv']['EnumeratedIndexValues']['SGCC']['BB082']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['PortHarbourCrv']['SGCL'] = ('real',('BB082'))
    field_information['GGDM 3.0']['PortHarbourCrv']['SGCU'] = ('real',('BB082'))
    field_information['GGDM 3.0']['PortHarbourCrv']['SLR'] = ('Enumeration',('BB082'))
    field_information['GGDM 3.0']['PortHarbourCrv']['EnumeratedIndexValues']['SLR'] = {}
    field_information['GGDM 3.0']['PortHarbourCrv']['EnumeratedIndexValues']['SLR']['BB082']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['PortHarbourCrv']['UFI'] = ('StructuredText',('BB081','BB082'))
    field_information['GGDM 3.0']['PortHarbourCrv']['WID'] = ('Real',('BB081','BB082'))
    field_information['GGDM 3.0']['PortHarbourCrv']['WLE'] = ('Enumeration',('BB081','BB082'))
    field_information['GGDM 3.0']['PortHarbourCrv']['EnumeratedIndexValues']['WLE'] = {}
    field_information['GGDM 3.0']['PortHarbourCrv']['EnumeratedIndexValues']['WLE']['BB081']  = (-999999,1,2,3,4,5,9,999)
    field_information['GGDM 3.0']['PortHarbourCrv']['EnumeratedIndexValues']['WLE']['BB082']  = (-999999,1,2,3,4,5,9,999)
    field_information['GGDM 3.0']['PortHarbourCrv']['ZI001_SDV'] = ('StructuredText',('BB081','BB082'))
    field_information['GGDM 3.0']['PortHarbourCrv']['ZI001_SRT'] = ('Enumeration',('BB081','BB082'))
    field_information['GGDM 3.0']['PortHarbourCrv']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['PortHarbourCrv']['EnumeratedIndexValues']['ZI001_SRT']['BB081']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['PortHarbourCrv']['EnumeratedIndexValues']['ZI001_SRT']['BB082']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['PortHarbourCrv']['ZI002_UFI'] = ('StructuredText',('BB081','BB082'))
    field_information['GGDM 3.0']['PortHarbourCrv']['ZI004_RCG'] = ('Enumeration',('BB081','BB082'))
    field_information['GGDM 3.0']['PortHarbourCrv']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['PortHarbourCrv']['EnumeratedIndexValues']['ZI004_RCG']['BB081']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['PortHarbourCrv']['EnumeratedIndexValues']['ZI004_RCG']['BB082']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['PortHarbourCrv']['ZI005_FNA'] = ('String',('BB081','BB082'))
    field_information['GGDM 3.0']['PortHarbourCrv']['ZI005_GNT'] = ('Enumeration',('BB081','BB082'))
    field_information['GGDM 3.0']['PortHarbourCrv']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['PortHarbourCrv']['EnumeratedIndexValues']['ZI005_GNT']['BB081']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['PortHarbourCrv']['EnumeratedIndexValues']['ZI005_GNT']['BB082']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['PortHarbourCrv']['ZI005_NFN'] = ('String',('BB081','BB082'))
    field_information['GGDM 3.0']['PortHarbourCrv']['ZI006_MEM'] = ('String',('BB081','BB082'))
    field_information['GGDM 3.0']['PortHarbourCrv']['ZI020_GE4'] = ('CodeList',('BB081','BB082'))
    field_information['GGDM 3.0']['PortHarbourCrv']['ZI026_CTUC'] = ('Enumeration',('BB081','BB082'))
    field_information['GGDM 3.0']['PortHarbourCrv']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['PortHarbourCrv']['EnumeratedIndexValues']['ZI026_CTUC']['BB081']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['PortHarbourCrv']['EnumeratedIndexValues']['ZI026_CTUC']['BB082']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['PortHarbourCrv']['ZI026_CTUL'] = ('integer',('BB081','BB082'))
    field_information['GGDM 3.0']['PortHarbourCrv']['ZI026_CTUU'] = ('integer',('BB081','BB082'))
    field_information['GGDM 3.0']['PortHarbourCrv']['ZI031S_URI'] = ('StructuredText',('BB081','BB082'))
    field_information['GGDM 3.0']['PortHarbourCrv']['ZI039S_UFI'] = ('StructuredText',('BB081','BB082'))
    field_information['GGDM 3.0']['PortHarbourCrv']['ZSAX_RS0'] = ('CodeList',('BB081','BB082'))
    field_information['GGDM 3.0']['PortHarbourCrv']['ZSAX_RX0'] = ('StructuredText',('BB081','BB082'))
    field_information['GGDM 3.0']['PortHarbourCrv']['ZSAX_RX3'] = ('StructuredText',('BB081','BB082'))
    field_information['GGDM 3.0']['PortHarbourCrv']['ZSAX_RX4'] = ('StructuredText',('BB081','BB082'))
    field_information['GGDM 3.0']['PortHarbourCrv']['ZVH'] = ('Real',('BB081','BB082'))
    field_information['GGDM 3.0']['PortHarbourPnt']['ADR'] = ('String',('BB009','BB201','BB241'))
    field_information['GGDM 3.0']['PortHarbourPnt']['AOO'] = ('Real',('BB009','BB201','BB241'))
    field_information['GGDM 3.0']['PortHarbourPnt']['ARA'] = ('Real',('BB009','BB201','BB241','BD100'))
    field_information['GGDM 3.0']['PortHarbourPnt']['BEN'] = ('StructuredText',('BB009','BB201','BB241','BD100'))
    field_information['GGDM 3.0']['PortHarbourPnt']['CAA'] = ('Enumeration',('BB009','BB201','BB241'))
    field_information['GGDM 3.0']['PortHarbourPnt']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['PortHarbourPnt']['EnumeratedIndexValues']['CAA']['BB009']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['PortHarbourPnt']['EnumeratedIndexValues']['CAA']['BB201']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['PortHarbourPnt']['EnumeratedIndexValues']['CAA']['BB241']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['PortHarbourPnt']['CNCP'] = ('StructuredText',('BB009','BB201','BB241'))
    field_information['GGDM 3.0']['PortHarbourPnt']['COS'] = ('Enumeration',('BB009','BB201','BB241'))
    field_information['GGDM 3.0']['PortHarbourPnt']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['PortHarbourPnt']['EnumeratedIndexValues']['COS']['BB009']  = (-999999,1,2,3,4,6,9,13,14)
    field_information['GGDM 3.0']['PortHarbourPnt']['EnumeratedIndexValues']['COS']['BB201']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['PortHarbourPnt']['EnumeratedIndexValues']['COS']['BB241']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['PortHarbourPnt']['F_CODE'] = ('CONSTRAINED_STRING',('BB009','BB201','BB241','BD100'))
    field_information['GGDM 3.0']['PortHarbourPnt']['FFN'] = ('Enumeration',('BB009','BB201','BB241'))
    field_information['GGDM 3.0']['PortHarbourPnt']['EnumeratedIndexValues']['FFN'] = {}
    field_information['GGDM 3.0']['PortHarbourPnt']['EnumeratedIndexValues']['FFN']['BB009']  = (-999999,301,340,484,490,497,500,505,507,508,510,511,512,513,520,530,536,537,538,539,827,829,833,835,841,842,847,888,955,970,999)
    field_information['GGDM 3.0']['PortHarbourPnt']['EnumeratedIndexValues']['FFN']['BB201']  = (-999999,340,382,466,470,476,484,505,507,508,550,570,572,612,829,847,888,921,923,955,970,999)
    field_information['GGDM 3.0']['PortHarbourPnt']['EnumeratedIndexValues']['FFN']['BB241']  = (-999999,99,257,270,280,301,331,333,334,340,505,530,835,999)
    field_information['GGDM 3.0']['PortHarbourPnt']['FFN2'] = ('Enumeration',('BB009','BB201','BB241'))
    field_information['GGDM 3.0']['PortHarbourPnt']['EnumeratedIndexValues']['FFN2'] = {}
    field_information['GGDM 3.0']['PortHarbourPnt']['EnumeratedIndexValues']['FFN2']['BB009']  = (-999999,301,340,484,490,497,500,505,507,508,510,511,512,513,520,530,536,537,538,539,827,829,833,835,841,842,847,888,955,970,999)
    field_information['GGDM 3.0']['PortHarbourPnt']['EnumeratedIndexValues']['FFN2']['BB201']  = (-999999,340,382,466,470,476,484,505,507,508,550,570,572,612,829,847,888,921,923,955,970,999)
    field_information['GGDM 3.0']['PortHarbourPnt']['EnumeratedIndexValues']['FFN2']['BB241']  = (-999999,99,257,270,280,301,331,333,334,340,505,530,835,999)
    field_information['GGDM 3.0']['PortHarbourPnt']['FFN3'] = ('Enumeration',('BB009','BB201','BB241'))
    field_information['GGDM 3.0']['PortHarbourPnt']['EnumeratedIndexValues']['FFN3'] = {}
    field_information['GGDM 3.0']['PortHarbourPnt']['EnumeratedIndexValues']['FFN3']['BB009']  = (-999999,301,340,484,490,497,500,505,507,508,510,511,512,513,520,530,536,537,538,539,827,829,833,835,841,842,847,888,955,970,999)
    field_information['GGDM 3.0']['PortHarbourPnt']['EnumeratedIndexValues']['FFN3']['BB201']  = (-999999,340,382,466,470,476,484,505,507,508,550,570,572,612,829,847,888,921,923,955,970,999)
    field_information['GGDM 3.0']['PortHarbourPnt']['EnumeratedIndexValues']['FFN3']['BB241']  = (-999999,99,257,270,280,301,331,333,334,340,505,530,835,999)
    field_information['GGDM 3.0']['PortHarbourPnt']['FUFI'] = ('StructuredText',('BB009','BB201','BB241','BD100'))
    field_information['GGDM 3.0']['PortHarbourPnt']['FURL'] = ('StructuredText',('BB009','BB201','BB241','BD100'))
    field_information['GGDM 3.0']['PortHarbourPnt']['GDBV'] = ('Enumeration',('BB009','BB201','BB241','BD100'))
    field_information['GGDM 3.0']['PortHarbourPnt']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['PortHarbourPnt']['EnumeratedIndexValues']['GDBV']['BB009']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['PortHarbourPnt']['EnumeratedIndexValues']['GDBV']['BB201']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['PortHarbourPnt']['EnumeratedIndexValues']['GDBV']['BB241']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['PortHarbourPnt']['EnumeratedIndexValues']['GDBV']['BD100']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['PortHarbourPnt']['HGT'] = ('Real',('BB009','BB201','BB241','BD100'))
    field_information['GGDM 3.0']['PortHarbourPnt']['LMC'] = ('Boolean',('BB009','BB201','BB241','BD100'))
    field_information['GGDM 3.0']['PortHarbourPnt']['LZN'] = ('Real',('BB009','BB201','BB241','BD100'))
    field_information['GGDM 3.0']['PortHarbourPnt']['MCC'] = ('Enumeration',('BD100'))
    field_information['GGDM 3.0']['PortHarbourPnt']['EnumeratedIndexValues']['MCC'] = {}
    field_information['GGDM 3.0']['PortHarbourPnt']['EnumeratedIndexValues']['MCC']['BD100']  = (-999999,21,51,64,107,117,150,999)
    field_information['GGDM 3.0']['PortHarbourPnt']['MCC2'] = ('Enumeration',('BD100'))
    field_information['GGDM 3.0']['PortHarbourPnt']['EnumeratedIndexValues']['MCC2'] = {}
    field_information['GGDM 3.0']['PortHarbourPnt']['EnumeratedIndexValues']['MCC2']['BD100']  = (-999999,21,51,64,107,117,150,999)
    field_information['GGDM 3.0']['PortHarbourPnt']['MCC3'] = ('Enumeration',('BD100'))
    field_information['GGDM 3.0']['PortHarbourPnt']['EnumeratedIndexValues']['MCC3'] = {}
    field_information['GGDM 3.0']['PortHarbourPnt']['EnumeratedIndexValues']['MCC3']['BD100']  = (-999999,21,51,64,107,117,150,999)
    field_information['GGDM 3.0']['PortHarbourPnt']['OTH'] = ('StructuredText',('BB009','BB201','BB241','BD100'))
    field_information['GGDM 3.0']['PortHarbourPnt']['PCF'] = ('Enumeration',('BB009','BB201','BB241','BD100'))
    field_information['GGDM 3.0']['PortHarbourPnt']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['PortHarbourPnt']['EnumeratedIndexValues']['PCF']['BB009']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['PortHarbourPnt']['EnumeratedIndexValues']['PCF']['BB201']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['PortHarbourPnt']['EnumeratedIndexValues']['PCF']['BB241']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['PortHarbourPnt']['EnumeratedIndexValues']['PCF']['BD100']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['PortHarbourPnt']['PLC'] = ('Enumeration',('BD100'))
    field_information['GGDM 3.0']['PortHarbourPnt']['EnumeratedIndexValues']['PLC'] = {}
    field_information['GGDM 3.0']['PortHarbourPnt']['EnumeratedIndexValues']['PLC']['BD100']  = (-999999,1,3,4,5,999)
    field_information['GGDM 3.0']['PortHarbourPnt']['TID'] = ('Boolean',('BB009'))
    field_information['GGDM 3.0']['PortHarbourPnt']['UFI'] = ('StructuredText',('BB009','BB201','BB241','BD100'))
    field_information['GGDM 3.0']['PortHarbourPnt']['WID'] = ('Real',('BB009','BB201','BB241','BD100'))
    field_information['GGDM 3.0']['PortHarbourPnt']['WPI'] = ('String',('BB009'))
    field_information['GGDM 3.0']['PortHarbourPnt']['YSU'] = ('Enumeration',('BB241'))
    field_information['GGDM 3.0']['PortHarbourPnt']['EnumeratedIndexValues']['YSU'] = {}
    field_information['GGDM 3.0']['PortHarbourPnt']['EnumeratedIndexValues']['YSU']['BB241']  = (-999999,2,3,4,5,7,999)
    field_information['GGDM 3.0']['PortHarbourPnt']['ZI001_SDV'] = ('StructuredText',('BB009','BB201','BB241','BD100'))
    field_information['GGDM 3.0']['PortHarbourPnt']['ZI001_SRT'] = ('Enumeration',('BB009','BB201','BB241','BD100'))
    field_information['GGDM 3.0']['PortHarbourPnt']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['PortHarbourPnt']['EnumeratedIndexValues']['ZI001_SRT']['BB009']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['PortHarbourPnt']['EnumeratedIndexValues']['ZI001_SRT']['BB201']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['PortHarbourPnt']['EnumeratedIndexValues']['ZI001_SRT']['BB241']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['PortHarbourPnt']['EnumeratedIndexValues']['ZI001_SRT']['BD100']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['PortHarbourPnt']['ZI002_UFI'] = ('StructuredText',('BB009','BB201','BB241','BD100'))
    field_information['GGDM 3.0']['PortHarbourPnt']['ZI004_RCG'] = ('Enumeration',('BB009','BB201','BB241','BD100'))
    field_information['GGDM 3.0']['PortHarbourPnt']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['PortHarbourPnt']['EnumeratedIndexValues']['ZI004_RCG']['BB009']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['PortHarbourPnt']['EnumeratedIndexValues']['ZI004_RCG']['BB201']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['PortHarbourPnt']['EnumeratedIndexValues']['ZI004_RCG']['BB241']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['PortHarbourPnt']['EnumeratedIndexValues']['ZI004_RCG']['BD100']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['PortHarbourPnt']['ZI005_FNA'] = ('String',('BB009','BB201','BB241','BD100'))
    field_information['GGDM 3.0']['PortHarbourPnt']['ZI005_GNT'] = ('Enumeration',('BB009','BB201','BB241','BD100'))
    field_information['GGDM 3.0']['PortHarbourPnt']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['PortHarbourPnt']['EnumeratedIndexValues']['ZI005_GNT']['BB009']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['PortHarbourPnt']['EnumeratedIndexValues']['ZI005_GNT']['BB201']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['PortHarbourPnt']['EnumeratedIndexValues']['ZI005_GNT']['BB241']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['PortHarbourPnt']['EnumeratedIndexValues']['ZI005_GNT']['BD100']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['PortHarbourPnt']['ZI005_NFN'] = ('String',('BB009','BB201','BB241','BD100'))
    field_information['GGDM 3.0']['PortHarbourPnt']['ZI006_MEM'] = ('String',('BB009','BB201','BB241','BD100'))
    field_information['GGDM 3.0']['PortHarbourPnt']['ZI014_PBY'] = ('Enumeration',('BB009'))
    field_information['GGDM 3.0']['PortHarbourPnt']['EnumeratedIndexValues']['ZI014_PBY'] = {}
    field_information['GGDM 3.0']['PortHarbourPnt']['EnumeratedIndexValues']['ZI014_PBY']['BB009']  = (-999999,1,2,6,7,8,12,13,15,89,999)
    field_information['GGDM 3.0']['PortHarbourPnt']['ZI014_PBY2'] = ('Enumeration',('BB009'))
    field_information['GGDM 3.0']['PortHarbourPnt']['EnumeratedIndexValues']['ZI014_PBY2'] = {}
    field_information['GGDM 3.0']['PortHarbourPnt']['EnumeratedIndexValues']['ZI014_PBY2']['BB009']  = (-999999,1,2,6,7,8,12,13,15,89,999)
    field_information['GGDM 3.0']['PortHarbourPnt']['ZI014_PBY3'] = ('Enumeration',('BB009'))
    field_information['GGDM 3.0']['PortHarbourPnt']['EnumeratedIndexValues']['ZI014_PBY3'] = {}
    field_information['GGDM 3.0']['PortHarbourPnt']['EnumeratedIndexValues']['ZI014_PBY3']['BB009']  = (-999999,1,2,6,7,8,12,13,15,89,999)
    field_information['GGDM 3.0']['PortHarbourPnt']['ZI014_PPO'] = ('Enumeration',('BB009'))
    field_information['GGDM 3.0']['PortHarbourPnt']['EnumeratedIndexValues']['ZI014_PPO'] = {}
    field_information['GGDM 3.0']['PortHarbourPnt']['EnumeratedIndexValues']['ZI014_PPO']['BB009']  = (-999999,1,2,3,4,5,13,15,16,18,20,21,23,25,26,28,32,37,38,39,41,43,44,45,46,47,48,57,58,59,60,61,62,63,65,69,70,73,74,80,83,84,87,90,92,94,95,101,105,106,109,111,114,117,120,121,122,123,126,136,137,146,147,148,150,154,155,156,157,160,165,192,200,214,279,325,435,999)
    field_information['GGDM 3.0']['PortHarbourPnt']['ZI014_PPO2'] = ('Enumeration',('BB009'))
    field_information['GGDM 3.0']['PortHarbourPnt']['EnumeratedIndexValues']['ZI014_PPO2'] = {}
    field_information['GGDM 3.0']['PortHarbourPnt']['EnumeratedIndexValues']['ZI014_PPO2']['BB009']  = (-999999,1,2,3,4,5,13,15,16,18,20,21,23,25,26,28,32,37,38,39,41,43,44,45,46,47,48,57,58,59,60,61,62,63,65,69,70,73,74,80,83,84,87,90,92,94,95,101,105,106,109,111,114,117,120,121,122,123,126,136,137,146,147,148,150,154,155,156,157,160,165,192,200,214,279,325,435,999)
    field_information['GGDM 3.0']['PortHarbourPnt']['ZI014_PPO3'] = ('Enumeration',('BB009'))
    field_information['GGDM 3.0']['PortHarbourPnt']['EnumeratedIndexValues']['ZI014_PPO3'] = {}
    field_information['GGDM 3.0']['PortHarbourPnt']['EnumeratedIndexValues']['ZI014_PPO3']['BB009']  = (-999999,1,2,3,4,5,13,15,16,18,20,21,23,25,26,28,32,37,38,39,41,43,44,45,46,47,48,57,58,59,60,61,62,63,65,69,70,73,74,80,83,84,87,90,92,94,95,101,105,106,109,111,114,117,120,121,122,123,126,136,137,146,147,148,150,154,155,156,157,160,165,192,200,214,279,325,435,999)
    field_information['GGDM 3.0']['PortHarbourPnt']['ZI014_PRW'] = ('Enumeration',('BB009'))
    field_information['GGDM 3.0']['PortHarbourPnt']['EnumeratedIndexValues']['ZI014_PRW'] = {}
    field_information['GGDM 3.0']['PortHarbourPnt']['EnumeratedIndexValues']['ZI014_PRW']['BB009']  = (-999999,1,2,5,9,10,11,12,14,16,18,27,28,29,30,33,38,39,41,45,46,48,50,52,54,57,60,64,66,68,70,75,78,79,83,84,85,87,90,93,94,96,97,99,118,119,999)
    field_information['GGDM 3.0']['PortHarbourPnt']['ZI014_PRW2'] = ('Enumeration',('BB009'))
    field_information['GGDM 3.0']['PortHarbourPnt']['EnumeratedIndexValues']['ZI014_PRW2'] = {}
    field_information['GGDM 3.0']['PortHarbourPnt']['EnumeratedIndexValues']['ZI014_PRW2']['BB009']  = (-999999,1,2,5,9,10,11,12,14,16,18,27,28,29,30,33,38,39,41,45,46,48,50,52,54,57,60,64,66,68,70,75,78,79,83,84,85,87,90,93,94,96,97,99,118,119,999)
    field_information['GGDM 3.0']['PortHarbourPnt']['ZI014_PRW3'] = ('Enumeration',('BB009'))
    field_information['GGDM 3.0']['PortHarbourPnt']['EnumeratedIndexValues']['ZI014_PRW3'] = {}
    field_information['GGDM 3.0']['PortHarbourPnt']['EnumeratedIndexValues']['ZI014_PRW3']['BB009']  = (-999999,1,2,5,9,10,11,12,14,16,18,27,28,29,30,33,38,39,41,45,46,48,50,52,54,57,60,64,66,68,70,75,78,79,83,84,85,87,90,93,94,96,97,99,118,119,999)
    field_information['GGDM 3.0']['PortHarbourPnt']['ZI020_GE4'] = ('CodeList',('BB009','BB201','BB241','BD100'))
    field_information['GGDM 3.0']['PortHarbourPnt']['ZI025_HDP'] = ('Real',('BD100'))
    field_information['GGDM 3.0']['PortHarbourPnt']['ZI025_WLE'] = ('Enumeration',('BD100'))
    field_information['GGDM 3.0']['PortHarbourPnt']['EnumeratedIndexValues']['ZI025_WLE'] = {}
    field_information['GGDM 3.0']['PortHarbourPnt']['EnumeratedIndexValues']['ZI025_WLE']['BD100']  = (-999999,1,2,3,4,5,9,999)
    field_information['GGDM 3.0']['PortHarbourPnt']['ZI026_CTUC'] = ('Enumeration',('BB009','BB201','BB241','BD100'))
    field_information['GGDM 3.0']['PortHarbourPnt']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['PortHarbourPnt']['EnumeratedIndexValues']['ZI026_CTUC']['BB009']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['PortHarbourPnt']['EnumeratedIndexValues']['ZI026_CTUC']['BB201']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['PortHarbourPnt']['EnumeratedIndexValues']['ZI026_CTUC']['BB241']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['PortHarbourPnt']['EnumeratedIndexValues']['ZI026_CTUC']['BD100']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['PortHarbourPnt']['ZI026_CTUL'] = ('integer',('BB009','BB201','BB241','BD100'))
    field_information['GGDM 3.0']['PortHarbourPnt']['ZI026_CTUU'] = ('integer',('BB009','BB201','BB241','BD100'))
    field_information['GGDM 3.0']['PortHarbourPnt']['ZI031S_URI'] = ('StructuredText',('BB009','BB201','BB241','BD100'))
    field_information['GGDM 3.0']['PortHarbourPnt']['ZI039S_UFI'] = ('StructuredText',('BB009','BB201','BB241','BD100'))
    field_information['GGDM 3.0']['PortHarbourPnt']['ZSAX_RS0'] = ('CodeList',('BB009','BB201','BB241','BD100'))
    field_information['GGDM 3.0']['PortHarbourPnt']['ZSAX_RX0'] = ('StructuredText',('BB009','BB201','BB241','BD100'))
    field_information['GGDM 3.0']['PortHarbourPnt']['ZSAX_RX3'] = ('StructuredText',('BB009','BB201','BB241','BD100'))
    field_information['GGDM 3.0']['PortHarbourPnt']['ZSAX_RX4'] = ('StructuredText',('BB009','BB201','BB241','BD100'))
    field_information['GGDM 3.0']['PortHarbourPnt']['ZVH'] = ('Real',('BB009','BB201','BB241','BD100'))
    field_information['GGDM 3.0']['PortHarbourPntExt']['ACH'] = ('Enumeration',('BB010'))
    field_information['GGDM 3.0']['PortHarbourPntExt']['EnumeratedIndexValues']['ACH'] = {}
    field_information['GGDM 3.0']['PortHarbourPntExt']['EnumeratedIndexValues']['ACH']['BB010']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,999)
    field_information['GGDM 3.0']['PortHarbourPntExt']['ARA'] = ('Real',('BB010','BB080'))
    field_information['GGDM 3.0']['PortHarbourPntExt']['BEN'] = ('StructuredText',('BB010','BB019','BB020','BB050','BB080'))
    field_information['GGDM 3.0']['PortHarbourPntExt']['BER'] = ('String',('BB020'))
    field_information['GGDM 3.0']['PortHarbourPntExt']['CNCP'] = ('StructuredText',('BB010','BB019','BB020','BB080'))
    field_information['GGDM 3.0']['PortHarbourPntExt']['COS'] = ('Enumeration',('BB010','BB019','BB020','BB080'))
    field_information['GGDM 3.0']['PortHarbourPntExt']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['PortHarbourPntExt']['EnumeratedIndexValues']['COS']['BB010']  = (-999999,2,4,6,9,13,14)
    field_information['GGDM 3.0']['PortHarbourPntExt']['EnumeratedIndexValues']['COS']['BB019']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['PortHarbourPntExt']['EnumeratedIndexValues']['COS']['BB020']  = (-999999,2,4,6,9,13,14)
    field_information['GGDM 3.0']['PortHarbourPntExt']['EnumeratedIndexValues']['COS']['BB080']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['PortHarbourPntExt']['DF1'] = ('Integer',('BB050'))
    field_information['GGDM 3.0']['PortHarbourPntExt']['DF2'] = ('Integer',('BB050'))
    field_information['GGDM 3.0']['PortHarbourPntExt']['DF3'] = ('Integer',('BB050'))
    field_information['GGDM 3.0']['PortHarbourPntExt']['DF4'] = ('Integer',('BB050'))
    field_information['GGDM 3.0']['PortHarbourPntExt']['F_CODE'] = ('CONSTRAINED_STRING',('BB010','BB019','BB020','BB050','BB080'))
    field_information['GGDM 3.0']['PortHarbourPntExt']['FUFI'] = ('StructuredText',('BB010','BB019','BB020','BB050','BB080'))
    field_information['GGDM 3.0']['PortHarbourPntExt']['FURL'] = ('StructuredText',('BB010','BB019','BB020','BB050','BB080'))
    field_information['GGDM 3.0']['PortHarbourPntExt']['GDBV'] = ('Enumeration',('BB010','BB019','BB020','BB050','BB080'))
    field_information['GGDM 3.0']['PortHarbourPntExt']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['PortHarbourPntExt']['EnumeratedIndexValues']['GDBV']['BB010']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['PortHarbourPntExt']['EnumeratedIndexValues']['GDBV']['BB019']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['PortHarbourPntExt']['EnumeratedIndexValues']['GDBV']['BB020']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['PortHarbourPntExt']['EnumeratedIndexValues']['GDBV']['BB050']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['PortHarbourPntExt']['EnumeratedIndexValues']['GDBV']['BB080']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['PortHarbourPntExt']['HDP'] = ('Real',('BB010'))
    field_information['GGDM 3.0']['PortHarbourPntExt']['LZN'] = ('Real',('BB080'))
    field_information['GGDM 3.0']['PortHarbourPntExt']['OTH'] = ('StructuredText',('BB010','BB019','BB020','BB050','BB080'))
    field_information['GGDM 3.0']['PortHarbourPntExt']['PCF'] = ('Enumeration',('BB010','BB019','BB020','BB080'))
    field_information['GGDM 3.0']['PortHarbourPntExt']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['PortHarbourPntExt']['EnumeratedIndexValues']['PCF']['BB010']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['PortHarbourPntExt']['EnumeratedIndexValues']['PCF']['BB019']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['PortHarbourPntExt']['EnumeratedIndexValues']['PCF']['BB020']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['PortHarbourPntExt']['EnumeratedIndexValues']['PCF']['BB080']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['PortHarbourPntExt']['UFI'] = ('StructuredText',('BB010','BB019','BB020','BB050','BB080'))
    field_information['GGDM 3.0']['PortHarbourPntExt']['ZI001_SDV'] = ('StructuredText',('BB010','BB019','BB020','BB050','BB080'))
    field_information['GGDM 3.0']['PortHarbourPntExt']['ZI001_SRT'] = ('Enumeration',('BB010','BB019','BB020','BB050','BB080'))
    field_information['GGDM 3.0']['PortHarbourPntExt']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['PortHarbourPntExt']['EnumeratedIndexValues']['ZI001_SRT']['BB010']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['PortHarbourPntExt']['EnumeratedIndexValues']['ZI001_SRT']['BB019']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['PortHarbourPntExt']['EnumeratedIndexValues']['ZI001_SRT']['BB020']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['PortHarbourPntExt']['EnumeratedIndexValues']['ZI001_SRT']['BB050']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['PortHarbourPntExt']['EnumeratedIndexValues']['ZI001_SRT']['BB080']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['PortHarbourPntExt']['ZI002_UFI'] = ('StructuredText',('BB010','BB019','BB020','BB050','BB080'))
    field_information['GGDM 3.0']['PortHarbourPntExt']['ZI004_RCG'] = ('Enumeration',('BB010','BB019','BB020','BB050','BB080'))
    field_information['GGDM 3.0']['PortHarbourPntExt']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['PortHarbourPntExt']['EnumeratedIndexValues']['ZI004_RCG']['BB010']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['PortHarbourPntExt']['EnumeratedIndexValues']['ZI004_RCG']['BB019']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['PortHarbourPntExt']['EnumeratedIndexValues']['ZI004_RCG']['BB020']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['PortHarbourPntExt']['EnumeratedIndexValues']['ZI004_RCG']['BB050']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['PortHarbourPntExt']['EnumeratedIndexValues']['ZI004_RCG']['BB080']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['PortHarbourPntExt']['ZI005_FNA'] = ('String',('BB010','BB019','BB050','BB080'))
    field_information['GGDM 3.0']['PortHarbourPntExt']['ZI005_GNT'] = ('Enumeration',('BB010','BB019','BB050','BB080'))
    field_information['GGDM 3.0']['PortHarbourPntExt']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['PortHarbourPntExt']['EnumeratedIndexValues']['ZI005_GNT']['BB010']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['PortHarbourPntExt']['EnumeratedIndexValues']['ZI005_GNT']['BB019']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['PortHarbourPntExt']['EnumeratedIndexValues']['ZI005_GNT']['BB050']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['PortHarbourPntExt']['EnumeratedIndexValues']['ZI005_GNT']['BB080']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['PortHarbourPntExt']['ZI005_NFN'] = ('String',('BB010','BB019','BB050','BB080'))
    field_information['GGDM 3.0']['PortHarbourPntExt']['ZI006_MEM'] = ('String',('BB010','BB019','BB020','BB050','BB080'))
    field_information['GGDM 3.0']['PortHarbourPntExt']['ZI020_GE4'] = ('CodeList',('BB010','BB019','BB020','BB050','BB080'))
    field_information['GGDM 3.0']['PortHarbourPntExt']['ZI026_CTUC'] = ('Enumeration',('BB010','BB019','BB020','BB050','BB080'))
    field_information['GGDM 3.0']['PortHarbourPntExt']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['PortHarbourPntExt']['EnumeratedIndexValues']['ZI026_CTUC']['BB010']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['PortHarbourPntExt']['EnumeratedIndexValues']['ZI026_CTUC']['BB019']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['PortHarbourPntExt']['EnumeratedIndexValues']['ZI026_CTUC']['BB020']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['PortHarbourPntExt']['EnumeratedIndexValues']['ZI026_CTUC']['BB050']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['PortHarbourPntExt']['EnumeratedIndexValues']['ZI026_CTUC']['BB080']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['PortHarbourPntExt']['ZI026_CTUL'] = ('integer',('BB010','BB019','BB020','BB050','BB080'))
    field_information['GGDM 3.0']['PortHarbourPntExt']['ZI026_CTUU'] = ('integer',('BB010','BB019','BB020','BB050','BB080'))
    field_information['GGDM 3.0']['PortHarbourPntExt']['ZI031S_URI'] = ('StructuredText',('BB010','BB019','BB020','BB050','BB080'))
    field_information['GGDM 3.0']['PortHarbourPntExt']['ZI039S_UFI'] = ('StructuredText',('BB010','BB019','BB020','BB050','BB080'))
    field_information['GGDM 3.0']['PortHarbourPntExt']['ZSAX_RS0'] = ('CodeList',('BB010','BB019','BB020','BB050','BB080'))
    field_information['GGDM 3.0']['PortHarbourPntExt']['ZSAX_RX0'] = ('StructuredText',('BB010','BB019','BB020','BB050','BB080'))
    field_information['GGDM 3.0']['PortHarbourPntExt']['ZSAX_RX3'] = ('StructuredText',('BB010','BB019','BB020','BB050','BB080'))
    field_information['GGDM 3.0']['PortHarbourPntExt']['ZSAX_RX4'] = ('StructuredText',('BB010','BB019','BB020','BB050','BB080'))
    field_information['GGDM 3.0']['PortHarbourSrf']['ADR'] = ('String',('BB009','BB201','BB241'))
    field_information['GGDM 3.0']['PortHarbourSrf']['AOO'] = ('Real',('BB009','BB081','BB090','BB199','BB201','BB241','BI005'))
    field_information['GGDM 3.0']['PortHarbourSrf']['ARA'] = ('Real',('BB005','BB009','BB081','BB082','BB090','BB199','BB201','BB241','BD100','BI005'))
    field_information['GGDM 3.0']['PortHarbourSrf']['BEN'] = ('StructuredText',('BB005','BB009','BB081','BB082','BB090','BB199','BB201','BB241','BD100','BI005'))
    field_information['GGDM 3.0']['PortHarbourSrf']['CAA'] = ('Enumeration',('BB005','BB009','BB081','BB090','BB199','BB201','BB241','BI005'))
    field_information['GGDM 3.0']['PortHarbourSrf']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['PortHarbourSrf']['EnumeratedIndexValues']['CAA']['BB005']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['PortHarbourSrf']['EnumeratedIndexValues']['CAA']['BB009']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['PortHarbourSrf']['EnumeratedIndexValues']['CAA']['BB081']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['PortHarbourSrf']['EnumeratedIndexValues']['CAA']['BB090']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['PortHarbourSrf']['EnumeratedIndexValues']['CAA']['BB199']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['PortHarbourSrf']['EnumeratedIndexValues']['CAA']['BB201']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['PortHarbourSrf']['EnumeratedIndexValues']['CAA']['BB241']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['PortHarbourSrf']['EnumeratedIndexValues']['CAA']['BI005']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['PortHarbourSrf']['CNCP'] = ('StructuredText',('BB005','BB009','BB081','BB082','BB090','BB199','BB201','BB241','BI005'))
    field_information['GGDM 3.0']['PortHarbourSrf']['COS'] = ('Enumeration',('BB005','BB009','BB081','BB082','BB090','BB199','BB201','BB241','BI005'))
    field_information['GGDM 3.0']['PortHarbourSrf']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['PortHarbourSrf']['EnumeratedIndexValues']['COS']['BB005']  = (-999999,2,4,6,9,13,14)
    field_information['GGDM 3.0']['PortHarbourSrf']['EnumeratedIndexValues']['COS']['BB009']  = (-999999,1,2,3,4,6,9,13,14)
    field_information['GGDM 3.0']['PortHarbourSrf']['EnumeratedIndexValues']['COS']['BB081']  = (-999999,2,4,6,9,13,14)
    field_information['GGDM 3.0']['PortHarbourSrf']['EnumeratedIndexValues']['COS']['BB082']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['PortHarbourSrf']['EnumeratedIndexValues']['COS']['BB090']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['PortHarbourSrf']['EnumeratedIndexValues']['COS']['BB199']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['PortHarbourSrf']['EnumeratedIndexValues']['COS']['BB201']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['PortHarbourSrf']['EnumeratedIndexValues']['COS']['BB241']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['PortHarbourSrf']['EnumeratedIndexValues']['COS']['BI005']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['PortHarbourSrf']['DZP'] = ('Real',('BB090','BB199'))
    field_information['GGDM 3.0']['PortHarbourSrf']['F_CODE'] = ('CONSTRAINED_STRING',('BB005','BB009','BB081','BB082','BB090','BB199','BB201','BB241','BD100','BI005'))
    field_information['GGDM 3.0']['PortHarbourSrf']['FAC'] = ('Boolean',('BB081'))
    field_information['GGDM 3.0']['PortHarbourSrf']['FFN'] = ('Enumeration',('BB009','BB081','BB201','BB241'))
    field_information['GGDM 3.0']['PortHarbourSrf']['EnumeratedIndexValues']['FFN'] = {}
    field_information['GGDM 3.0']['PortHarbourSrf']['EnumeratedIndexValues']['FFN']['BB009']  = (-999999,301,340,484,490,497,500,505,507,508,510,511,512,513,520,530,536,537,538,539,827,829,833,835,841,842,847,888,955,970,999)
    field_information['GGDM 3.0']['PortHarbourSrf']['EnumeratedIndexValues']['FFN']['BB081']  = (-999999,30,99,440,529,530,921,999)
    field_information['GGDM 3.0']['PortHarbourSrf']['EnumeratedIndexValues']['FFN']['BB201']  = (-999999,340,382,466,470,476,484,505,507,508,550,570,572,612,829,847,888,921,923,955,970,999)
    field_information['GGDM 3.0']['PortHarbourSrf']['EnumeratedIndexValues']['FFN']['BB241']  = (-999999,99,257,270,280,301,331,333,334,340,505,530,835,999)
    field_information['GGDM 3.0']['PortHarbourSrf']['FFN2'] = ('Enumeration',('BB009','BB081','BB201','BB241'))
    field_information['GGDM 3.0']['PortHarbourSrf']['EnumeratedIndexValues']['FFN2'] = {}
    field_information['GGDM 3.0']['PortHarbourSrf']['EnumeratedIndexValues']['FFN2']['BB009']  = (-999999,301,340,484,490,497,500,505,507,508,510,511,512,513,520,530,536,537,538,539,827,829,833,835,841,842,847,888,955,970,999)
    field_information['GGDM 3.0']['PortHarbourSrf']['EnumeratedIndexValues']['FFN2']['BB081']  = (-999999,30,99,440,529,530,921,999)
    field_information['GGDM 3.0']['PortHarbourSrf']['EnumeratedIndexValues']['FFN2']['BB201']  = (-999999,340,382,466,470,476,484,505,507,508,550,570,572,612,829,847,888,921,923,955,970,999)
    field_information['GGDM 3.0']['PortHarbourSrf']['EnumeratedIndexValues']['FFN2']['BB241']  = (-999999,99,257,270,280,301,331,333,334,340,505,530,835,999)
    field_information['GGDM 3.0']['PortHarbourSrf']['FFN3'] = ('Enumeration',('BB009','BB081','BB201','BB241'))
    field_information['GGDM 3.0']['PortHarbourSrf']['EnumeratedIndexValues']['FFN3'] = {}
    field_information['GGDM 3.0']['PortHarbourSrf']['EnumeratedIndexValues']['FFN3']['BB009']  = (-999999,301,340,484,490,497,500,505,507,508,510,511,512,513,520,530,536,537,538,539,827,829,833,835,841,842,847,888,955,970,999)
    field_information['GGDM 3.0']['PortHarbourSrf']['EnumeratedIndexValues']['FFN3']['BB081']  = (-999999,30,99,440,529,530,921,999)
    field_information['GGDM 3.0']['PortHarbourSrf']['EnumeratedIndexValues']['FFN3']['BB201']  = (-999999,340,382,466,470,476,484,505,507,508,550,570,572,612,829,847,888,921,923,955,970,999)
    field_information['GGDM 3.0']['PortHarbourSrf']['EnumeratedIndexValues']['FFN3']['BB241']  = (-999999,99,257,270,280,301,331,333,334,340,505,530,835,999)
    field_information['GGDM 3.0']['PortHarbourSrf']['FHC'] = ('Enumeration',('BB005'))
    field_information['GGDM 3.0']['PortHarbourSrf']['EnumeratedIndexValues']['FHC'] = {}
    field_information['GGDM 3.0']['PortHarbourSrf']['EnumeratedIndexValues']['FHC']['BB005']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['PortHarbourSrf']['FHC2'] = ('Enumeration',('BB005'))
    field_information['GGDM 3.0']['PortHarbourSrf']['EnumeratedIndexValues']['FHC2'] = {}
    field_information['GGDM 3.0']['PortHarbourSrf']['EnumeratedIndexValues']['FHC2']['BB005']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['PortHarbourSrf']['FHC3'] = ('Enumeration',('BB005'))
    field_information['GGDM 3.0']['PortHarbourSrf']['EnumeratedIndexValues']['FHC3'] = {}
    field_information['GGDM 3.0']['PortHarbourSrf']['EnumeratedIndexValues']['FHC3']['BB005']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['PortHarbourSrf']['FLO'] = ('Boolean',('BB081'))
    field_information['GGDM 3.0']['PortHarbourSrf']['FUFI'] = ('StructuredText',('BB005','BB009','BB081','BB082','BB090','BB199','BB201','BB241','BD100','BI005'))
    field_information['GGDM 3.0']['PortHarbourSrf']['FURL'] = ('StructuredText',('BB005','BB009','BB081','BB082','BB090','BB199','BB201','BB241','BD100','BI005'))
    field_information['GGDM 3.0']['PortHarbourSrf']['GDBV'] = ('Enumeration',('BB005','BB009','BB081','BB082','BB090','BB199','BB201','BB241','BD100','BI005'))
    field_information['GGDM 3.0']['PortHarbourSrf']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['PortHarbourSrf']['EnumeratedIndexValues']['GDBV']['BB005']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['PortHarbourSrf']['EnumeratedIndexValues']['GDBV']['BB009']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['PortHarbourSrf']['EnumeratedIndexValues']['GDBV']['BB081']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['PortHarbourSrf']['EnumeratedIndexValues']['GDBV']['BB082']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['PortHarbourSrf']['EnumeratedIndexValues']['GDBV']['BB090']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['PortHarbourSrf']['EnumeratedIndexValues']['GDBV']['BB199']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['PortHarbourSrf']['EnumeratedIndexValues']['GDBV']['BB201']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['PortHarbourSrf']['EnumeratedIndexValues']['GDBV']['BB241']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['PortHarbourSrf']['EnumeratedIndexValues']['GDBV']['BD100']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['PortHarbourSrf']['EnumeratedIndexValues']['GDBV']['BI005']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['PortHarbourSrf']['HGT'] = ('Real',('BB009','BB081','BB082','BB090','BB199','BB201','BB241','BD100','BI005'))
    field_information['GGDM 3.0']['PortHarbourSrf']['LCA'] = ('Real',('BI005'))
    field_information['GGDM 3.0']['PortHarbourSrf']['LMC'] = ('Boolean',('BB005','BB009','BB081','BB090','BB199','BB201','BB241','BD100','BI005'))
    field_information['GGDM 3.0']['PortHarbourSrf']['LNU'] = ('Real',('BB090'))
    field_information['GGDM 3.0']['PortHarbourSrf']['LZN'] = ('Real',('BB005','BB009','BB081','BB082','BB090','BB199','BB201','BB241','BD100','BI005'))
    field_information['GGDM 3.0']['PortHarbourSrf']['MCC'] = ('Enumeration',('BB081','BB082','BB090','BB199','BD100'))
    field_information['GGDM 3.0']['PortHarbourSrf']['EnumeratedIndexValues']['MCC'] = {}
    field_information['GGDM 3.0']['PortHarbourSrf']['EnumeratedIndexValues']['MCC']['BB081']  = (-999999,5,8,9,21,62,64,77,83,84,86,104,107,108,117,150,999)
    field_information['GGDM 3.0']['PortHarbourSrf']['EnumeratedIndexValues']['MCC']['BB082']  = (-999999,5,9,21,46,62,88,104,999)
    field_information['GGDM 3.0']['PortHarbourSrf']['EnumeratedIndexValues']['MCC']['BB090']  = (-999999,8,21,62,64,77,83,84,86,104,107,117,150,999)
    field_information['GGDM 3.0']['PortHarbourSrf']['EnumeratedIndexValues']['MCC']['BB199']  = (-999999,107,117,999)
    field_information['GGDM 3.0']['PortHarbourSrf']['EnumeratedIndexValues']['MCC']['BD100']  = (-999999,21,51,64,107,117,150,999)
    field_information['GGDM 3.0']['PortHarbourSrf']['MCC2'] = ('Enumeration',('BB081','BB082','BB090','BB199','BD100'))
    field_information['GGDM 3.0']['PortHarbourSrf']['EnumeratedIndexValues']['MCC2'] = {}
    field_information['GGDM 3.0']['PortHarbourSrf']['EnumeratedIndexValues']['MCC2']['BB081']  = (-999999,5,8,9,21,62,64,77,83,84,86,104,107,108,117,150,999)
    field_information['GGDM 3.0']['PortHarbourSrf']['EnumeratedIndexValues']['MCC2']['BB082']  = (-999999,5,9,21,46,62,88,104,999)
    field_information['GGDM 3.0']['PortHarbourSrf']['EnumeratedIndexValues']['MCC2']['BB090']  = (-999999,8,21,62,64,77,83,84,86,104,107,117,150,999)
    field_information['GGDM 3.0']['PortHarbourSrf']['EnumeratedIndexValues']['MCC2']['BB199']  = (-999999,107,117,999)
    field_information['GGDM 3.0']['PortHarbourSrf']['EnumeratedIndexValues']['MCC2']['BD100']  = (-999999,21,51,64,107,117,150,999)
    field_information['GGDM 3.0']['PortHarbourSrf']['MCC3'] = ('Enumeration',('BB081','BB082','BB090','BD100'))
    field_information['GGDM 3.0']['PortHarbourSrf']['EnumeratedIndexValues']['MCC3'] = {}
    field_information['GGDM 3.0']['PortHarbourSrf']['EnumeratedIndexValues']['MCC3']['BB081']  = (-999999,5,8,9,21,62,64,77,83,84,86,104,107,108,117,150,999)
    field_information['GGDM 3.0']['PortHarbourSrf']['EnumeratedIndexValues']['MCC3']['BB082']  = (-999999,5,9,21,46,62,88,104,999)
    field_information['GGDM 3.0']['PortHarbourSrf']['EnumeratedIndexValues']['MCC3']['BB090']  = (-999999,8,21,62,64,77,83,84,86,104,107,117,150,999)
    field_information['GGDM 3.0']['PortHarbourSrf']['EnumeratedIndexValues']['MCC3']['BD100']  = (-999999,21,51,64,107,117,150,999)
    field_information['GGDM 3.0']['PortHarbourSrf']['MWD'] = ('Real',('BB090','BB199'))
    field_information['GGDM 3.0']['PortHarbourSrf']['OTH'] = ('StructuredText',('BB005','BB009','BB081','BB082','BB090','BB199','BB201','BB241','BD100','BI005'))
    field_information['GGDM 3.0']['PortHarbourSrf']['PCF'] = ('Enumeration',('BB005','BB009','BB081','BB082','BB090','BB199','BB201','BB241','BD100','BI005'))
    field_information['GGDM 3.0']['PortHarbourSrf']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['PortHarbourSrf']['EnumeratedIndexValues']['PCF']['BB005']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['PortHarbourSrf']['EnumeratedIndexValues']['PCF']['BB009']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['PortHarbourSrf']['EnumeratedIndexValues']['PCF']['BB081']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['PortHarbourSrf']['EnumeratedIndexValues']['PCF']['BB082']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['PortHarbourSrf']['EnumeratedIndexValues']['PCF']['BB090']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['PortHarbourSrf']['EnumeratedIndexValues']['PCF']['BB199']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['PortHarbourSrf']['EnumeratedIndexValues']['PCF']['BB201']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['PortHarbourSrf']['EnumeratedIndexValues']['PCF']['BB241']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['PortHarbourSrf']['EnumeratedIndexValues']['PCF']['BD100']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['PortHarbourSrf']['EnumeratedIndexValues']['PCF']['BI005']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['PortHarbourSrf']['PLC'] = ('Enumeration',('BD100'))
    field_information['GGDM 3.0']['PortHarbourSrf']['EnumeratedIndexValues']['PLC'] = {}
    field_information['GGDM 3.0']['PortHarbourSrf']['EnumeratedIndexValues']['PLC']['BD100']  = (-999999,1,3,4,5,999)
    field_information['GGDM 3.0']['PortHarbourSrf']['PWC'] = ('Enumeration',('BB081'))
    field_information['GGDM 3.0']['PortHarbourSrf']['EnumeratedIndexValues']['PWC'] = {}
    field_information['GGDM 3.0']['PortHarbourSrf']['EnumeratedIndexValues']['PWC']['BB081']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,18,999)
    field_information['GGDM 3.0']['PortHarbourSrf']['SGCC'] = ('Enumeration',('BB082'))
    field_information['GGDM 3.0']['PortHarbourSrf']['EnumeratedIndexValues']['SGCC'] = {}
    field_information['GGDM 3.0']['PortHarbourSrf']['EnumeratedIndexValues']['SGCC']['BB082']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['PortHarbourSrf']['SGCL'] = ('real',('BB082'))
    field_information['GGDM 3.0']['PortHarbourSrf']['SGCU'] = ('real',('BB082'))
    field_information['GGDM 3.0']['PortHarbourSrf']['SLR'] = ('Enumeration',('BB082'))
    field_information['GGDM 3.0']['PortHarbourSrf']['EnumeratedIndexValues']['SLR'] = {}
    field_information['GGDM 3.0']['PortHarbourSrf']['EnumeratedIndexValues']['SLR']['BB082']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['PortHarbourSrf']['TID'] = ('Boolean',('BB005','BB009'))
    field_information['GGDM 3.0']['PortHarbourSrf']['UFI'] = ('StructuredText',('BB005','BB009','BB081','BB082','BB090','BB199','BB201','BB241','BD100','BI005'))
    field_information['GGDM 3.0']['PortHarbourSrf']['WDU'] = ('Real',('BB090'))
    field_information['GGDM 3.0']['PortHarbourSrf']['WID'] = ('Real',('BB005','BB009','BB081','BB082','BB090','BB199','BB201','BB241','BD100','BI005'))
    field_information['GGDM 3.0']['PortHarbourSrf']['WLE'] = ('Enumeration',('BB081','BB082'))
    field_information['GGDM 3.0']['PortHarbourSrf']['EnumeratedIndexValues']['WLE'] = {}
    field_information['GGDM 3.0']['PortHarbourSrf']['EnumeratedIndexValues']['WLE']['BB081']  = (-999999,1,2,3,4,5,9,999)
    field_information['GGDM 3.0']['PortHarbourSrf']['EnumeratedIndexValues']['WLE']['BB082']  = (-999999,1,2,3,4,5,9,999)
    field_information['GGDM 3.0']['PortHarbourSrf']['WPI'] = ('String',('BB005','BB009'))
    field_information['GGDM 3.0']['PortHarbourSrf']['YSU'] = ('Enumeration',('BB241'))
    field_information['GGDM 3.0']['PortHarbourSrf']['EnumeratedIndexValues']['YSU'] = {}
    field_information['GGDM 3.0']['PortHarbourSrf']['EnumeratedIndexValues']['YSU']['BB241']  = (-999999,2,3,4,5,7,999)
    field_information['GGDM 3.0']['PortHarbourSrf']['ZI001_SDV'] = ('StructuredText',('BB005','BB009','BB081','BB082','BB090','BB199','BB201','BB241','BD100','BI005'))
    field_information['GGDM 3.0']['PortHarbourSrf']['ZI001_SRT'] = ('Enumeration',('BB005','BB009','BB081','BB082','BB090','BB199','BB201','BB241','BD100','BI005'))
    field_information['GGDM 3.0']['PortHarbourSrf']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['PortHarbourSrf']['EnumeratedIndexValues']['ZI001_SRT']['BB005']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['PortHarbourSrf']['EnumeratedIndexValues']['ZI001_SRT']['BB009']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['PortHarbourSrf']['EnumeratedIndexValues']['ZI001_SRT']['BB081']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['PortHarbourSrf']['EnumeratedIndexValues']['ZI001_SRT']['BB082']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['PortHarbourSrf']['EnumeratedIndexValues']['ZI001_SRT']['BB090']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['PortHarbourSrf']['EnumeratedIndexValues']['ZI001_SRT']['BB199']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['PortHarbourSrf']['EnumeratedIndexValues']['ZI001_SRT']['BB201']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['PortHarbourSrf']['EnumeratedIndexValues']['ZI001_SRT']['BB241']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['PortHarbourSrf']['EnumeratedIndexValues']['ZI001_SRT']['BD100']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['PortHarbourSrf']['EnumeratedIndexValues']['ZI001_SRT']['BI005']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['PortHarbourSrf']['ZI002_UFI'] = ('StructuredText',('BB005','BB009','BB081','BB082','BB090','BB199','BB201','BB241','BD100','BI005'))
    field_information['GGDM 3.0']['PortHarbourSrf']['ZI004_RCG'] = ('Enumeration',('BB005','BB009','BB081','BB082','BB090','BB199','BB201','BB241','BD100','BI005'))
    field_information['GGDM 3.0']['PortHarbourSrf']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['PortHarbourSrf']['EnumeratedIndexValues']['ZI004_RCG']['BB005']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['PortHarbourSrf']['EnumeratedIndexValues']['ZI004_RCG']['BB009']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['PortHarbourSrf']['EnumeratedIndexValues']['ZI004_RCG']['BB081']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['PortHarbourSrf']['EnumeratedIndexValues']['ZI004_RCG']['BB082']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['PortHarbourSrf']['EnumeratedIndexValues']['ZI004_RCG']['BB090']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['PortHarbourSrf']['EnumeratedIndexValues']['ZI004_RCG']['BB199']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['PortHarbourSrf']['EnumeratedIndexValues']['ZI004_RCG']['BB201']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['PortHarbourSrf']['EnumeratedIndexValues']['ZI004_RCG']['BB241']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['PortHarbourSrf']['EnumeratedIndexValues']['ZI004_RCG']['BD100']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['PortHarbourSrf']['EnumeratedIndexValues']['ZI004_RCG']['BI005']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['PortHarbourSrf']['ZI005_FNA'] = ('String',('BB005','BB009','BB081','BB082','BB090','BB199','BB201','BB241','BD100','BI005'))
    field_information['GGDM 3.0']['PortHarbourSrf']['ZI005_FNA2'] = ('String',('BB005'))
    field_information['GGDM 3.0']['PortHarbourSrf']['ZI005_GNT'] = ('Enumeration',('BB005','BB009','BB081','BB082','BB090','BB199','BB201','BB241','BD100','BI005'))
    field_information['GGDM 3.0']['PortHarbourSrf']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['PortHarbourSrf']['EnumeratedIndexValues']['ZI005_GNT']['BB005']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['PortHarbourSrf']['EnumeratedIndexValues']['ZI005_GNT']['BB009']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['PortHarbourSrf']['EnumeratedIndexValues']['ZI005_GNT']['BB081']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['PortHarbourSrf']['EnumeratedIndexValues']['ZI005_GNT']['BB082']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['PortHarbourSrf']['EnumeratedIndexValues']['ZI005_GNT']['BB090']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['PortHarbourSrf']['EnumeratedIndexValues']['ZI005_GNT']['BB199']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['PortHarbourSrf']['EnumeratedIndexValues']['ZI005_GNT']['BB201']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['PortHarbourSrf']['EnumeratedIndexValues']['ZI005_GNT']['BB241']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['PortHarbourSrf']['EnumeratedIndexValues']['ZI005_GNT']['BD100']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['PortHarbourSrf']['EnumeratedIndexValues']['ZI005_GNT']['BI005']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['PortHarbourSrf']['ZI005_GNT2'] = ('Enumeration',('BB005'))
    field_information['GGDM 3.0']['PortHarbourSrf']['EnumeratedIndexValues']['ZI005_GNT2'] = {}
    field_information['GGDM 3.0']['PortHarbourSrf']['EnumeratedIndexValues']['ZI005_GNT2']['BB005']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['PortHarbourSrf']['ZI005_NFN'] = ('String',('BB005','BB009','BB081','BB082','BB090','BB199','BB201','BB241','BD100','BI005'))
    field_information['GGDM 3.0']['PortHarbourSrf']['ZI005_NFN2'] = ('String',('BB005'))
    field_information['GGDM 3.0']['PortHarbourSrf']['ZI006_MEM'] = ('String',('BB005','BB009','BB081','BB082','BB090','BB199','BB201','BB241','BD100','BI005'))
    field_information['GGDM 3.0']['PortHarbourSrf']['ZI014_PBY'] = ('Enumeration',('BB009'))
    field_information['GGDM 3.0']['PortHarbourSrf']['EnumeratedIndexValues']['ZI014_PBY'] = {}
    field_information['GGDM 3.0']['PortHarbourSrf']['EnumeratedIndexValues']['ZI014_PBY']['BB009']  = (-999999,1,2,6,7,8,12,13,15,89,999)
    field_information['GGDM 3.0']['PortHarbourSrf']['ZI014_PBY2'] = ('Enumeration',('BB009'))
    field_information['GGDM 3.0']['PortHarbourSrf']['EnumeratedIndexValues']['ZI014_PBY2'] = {}
    field_information['GGDM 3.0']['PortHarbourSrf']['EnumeratedIndexValues']['ZI014_PBY2']['BB009']  = (-999999,1,2,6,7,8,12,13,15,89,999)
    field_information['GGDM 3.0']['PortHarbourSrf']['ZI014_PBY3'] = ('Enumeration',('BB009'))
    field_information['GGDM 3.0']['PortHarbourSrf']['EnumeratedIndexValues']['ZI014_PBY3'] = {}
    field_information['GGDM 3.0']['PortHarbourSrf']['EnumeratedIndexValues']['ZI014_PBY3']['BB009']  = (-999999,1,2,6,7,8,12,13,15,89,999)
    field_information['GGDM 3.0']['PortHarbourSrf']['ZI014_PPO'] = ('Enumeration',('BB009'))
    field_information['GGDM 3.0']['PortHarbourSrf']['EnumeratedIndexValues']['ZI014_PPO'] = {}
    field_information['GGDM 3.0']['PortHarbourSrf']['EnumeratedIndexValues']['ZI014_PPO']['BB009']  = (-999999,1,2,3,4,5,13,15,16,18,20,21,23,25,26,28,32,37,38,39,41,43,44,45,46,47,48,57,58,59,60,61,62,63,65,69,70,73,74,80,83,84,87,90,92,94,95,101,105,106,109,111,114,117,120,121,122,123,126,136,137,146,147,148,150,154,155,156,157,160,165,192,200,214,279,325,435,999)
    field_information['GGDM 3.0']['PortHarbourSrf']['ZI014_PPO2'] = ('Enumeration',('BB009'))
    field_information['GGDM 3.0']['PortHarbourSrf']['EnumeratedIndexValues']['ZI014_PPO2'] = {}
    field_information['GGDM 3.0']['PortHarbourSrf']['EnumeratedIndexValues']['ZI014_PPO2']['BB009']  = (-999999,1,2,3,4,5,13,15,16,18,20,21,23,25,26,28,32,37,38,39,41,43,44,45,46,47,48,57,58,59,60,61,62,63,65,69,70,73,74,80,83,84,87,90,92,94,95,101,105,106,109,111,114,117,120,121,122,123,126,136,137,146,147,148,150,154,155,156,157,160,165,192,200,214,279,325,435,999)
    field_information['GGDM 3.0']['PortHarbourSrf']['ZI014_PPO3'] = ('Enumeration',('BB009'))
    field_information['GGDM 3.0']['PortHarbourSrf']['EnumeratedIndexValues']['ZI014_PPO3'] = {}
    field_information['GGDM 3.0']['PortHarbourSrf']['EnumeratedIndexValues']['ZI014_PPO3']['BB009']  = (-999999,1,2,3,4,5,13,15,16,18,20,21,23,25,26,28,32,37,38,39,41,43,44,45,46,47,48,57,58,59,60,61,62,63,65,69,70,73,74,80,83,84,87,90,92,94,95,101,105,106,109,111,114,117,120,121,122,123,126,136,137,146,147,148,150,154,155,156,157,160,165,192,200,214,279,325,435,999)
    field_information['GGDM 3.0']['PortHarbourSrf']['ZI014_PRW'] = ('Enumeration',('BB009'))
    field_information['GGDM 3.0']['PortHarbourSrf']['EnumeratedIndexValues']['ZI014_PRW'] = {}
    field_information['GGDM 3.0']['PortHarbourSrf']['EnumeratedIndexValues']['ZI014_PRW']['BB009']  = (-999999,1,2,5,9,10,11,12,14,16,18,27,28,29,30,33,38,39,41,45,46,48,50,52,54,57,60,64,66,68,70,75,78,79,83,84,85,87,90,93,94,96,97,99,118,119,999)
    field_information['GGDM 3.0']['PortHarbourSrf']['ZI014_PRW2'] = ('Enumeration',('BB009'))
    field_information['GGDM 3.0']['PortHarbourSrf']['EnumeratedIndexValues']['ZI014_PRW2'] = {}
    field_information['GGDM 3.0']['PortHarbourSrf']['EnumeratedIndexValues']['ZI014_PRW2']['BB009']  = (-999999,1,2,5,9,10,11,12,14,16,18,27,28,29,30,33,38,39,41,45,46,48,50,52,54,57,60,64,66,68,70,75,78,79,83,84,85,87,90,93,94,96,97,99,118,119,999)
    field_information['GGDM 3.0']['PortHarbourSrf']['ZI014_PRW3'] = ('Enumeration',('BB009'))
    field_information['GGDM 3.0']['PortHarbourSrf']['EnumeratedIndexValues']['ZI014_PRW3'] = {}
    field_information['GGDM 3.0']['PortHarbourSrf']['EnumeratedIndexValues']['ZI014_PRW3']['BB009']  = (-999999,1,2,5,9,10,11,12,14,16,18,27,28,29,30,33,38,39,41,45,46,48,50,52,54,57,60,64,66,68,70,75,78,79,83,84,85,87,90,93,94,96,97,99,118,119,999)
    field_information['GGDM 3.0']['PortHarbourSrf']['ZI020_GE4'] = ('CodeList',('BB005','BB009','BB081','BB082','BB090','BB199','BB201','BB241','BD100','BI005'))
    field_information['GGDM 3.0']['PortHarbourSrf']['ZI025_HDP'] = ('Real',('BD100'))
    field_information['GGDM 3.0']['PortHarbourSrf']['ZI025_WLE'] = ('Enumeration',('BD100'))
    field_information['GGDM 3.0']['PortHarbourSrf']['EnumeratedIndexValues']['ZI025_WLE'] = {}
    field_information['GGDM 3.0']['PortHarbourSrf']['EnumeratedIndexValues']['ZI025_WLE']['BD100']  = (-999999,1,2,3,4,5,9,999)
    field_information['GGDM 3.0']['PortHarbourSrf']['ZI026_CTUC'] = ('Enumeration',('BB005','BB009','BB081','BB082','BB090','BB199','BB201','BB241','BD100','BI005'))
    field_information['GGDM 3.0']['PortHarbourSrf']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['PortHarbourSrf']['EnumeratedIndexValues']['ZI026_CTUC']['BB005']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['PortHarbourSrf']['EnumeratedIndexValues']['ZI026_CTUC']['BB009']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['PortHarbourSrf']['EnumeratedIndexValues']['ZI026_CTUC']['BB081']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['PortHarbourSrf']['EnumeratedIndexValues']['ZI026_CTUC']['BB082']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['PortHarbourSrf']['EnumeratedIndexValues']['ZI026_CTUC']['BB090']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['PortHarbourSrf']['EnumeratedIndexValues']['ZI026_CTUC']['BB199']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['PortHarbourSrf']['EnumeratedIndexValues']['ZI026_CTUC']['BB201']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['PortHarbourSrf']['EnumeratedIndexValues']['ZI026_CTUC']['BB241']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['PortHarbourSrf']['EnumeratedIndexValues']['ZI026_CTUC']['BD100']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['PortHarbourSrf']['EnumeratedIndexValues']['ZI026_CTUC']['BI005']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['PortHarbourSrf']['ZI026_CTUL'] = ('integer',('BB005','BB009','BB081','BB082','BB090','BB199','BB201','BB241','BD100','BI005'))
    field_information['GGDM 3.0']['PortHarbourSrf']['ZI026_CTUU'] = ('integer',('BB005','BB009','BB081','BB082','BB090','BB199','BB201','BB241','BD100','BI005'))
    field_information['GGDM 3.0']['PortHarbourSrf']['ZI031S_URI'] = ('StructuredText',('BB005','BB009','BB081','BB082','BB090','BB199','BB201','BB241','BD100','BI005'))
    field_information['GGDM 3.0']['PortHarbourSrf']['ZI039S_UFI'] = ('StructuredText',('BB005','BB009','BB081','BB082','BB090','BB199','BB201','BB241','BD100','BI005'))
    field_information['GGDM 3.0']['PortHarbourSrf']['ZSAX_RS0'] = ('CodeList',('BB005','BB009','BB081','BB082','BB090','BB199','BB201','BB241','BD100','BI005'))
    field_information['GGDM 3.0']['PortHarbourSrf']['ZSAX_RX0'] = ('StructuredText',('BB005','BB009','BB081','BB082','BB090','BB199','BB201','BB241','BD100','BI005'))
    field_information['GGDM 3.0']['PortHarbourSrf']['ZSAX_RX3'] = ('StructuredText',('BB005','BB009','BB081','BB082','BB090','BB199','BB201','BB241','BD100','BI005'))
    field_information['GGDM 3.0']['PortHarbourSrf']['ZSAX_RX4'] = ('StructuredText',('BB005','BB009','BB081','BB082','BB090','BB199','BB201','BB241','BD100','BI005'))
    field_information['GGDM 3.0']['PortHarbourSrf']['ZVH'] = ('Real',('BB009','BB081','BB082','BB090','BB199','BB201','BB241','BD100','BI005'))
    field_information['GGDM 3.0']['PortHarbourSrfExt']['ACH'] = ('Enumeration',('BB010'))
    field_information['GGDM 3.0']['PortHarbourSrfExt']['EnumeratedIndexValues']['ACH'] = {}
    field_information['GGDM 3.0']['PortHarbourSrfExt']['EnumeratedIndexValues']['ACH']['BB010']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,999)
    field_information['GGDM 3.0']['PortHarbourSrfExt']['ARA'] = ('Real',('BB010','BB115'))
    field_information['GGDM 3.0']['PortHarbourSrfExt']['BEN'] = ('StructuredText',('BB010','BB115'))
    field_information['GGDM 3.0']['PortHarbourSrfExt']['CNCP'] = ('StructuredText',('BB010','BB115'))
    field_information['GGDM 3.0']['PortHarbourSrfExt']['COS'] = ('Enumeration',('BB010','BB115'))
    field_information['GGDM 3.0']['PortHarbourSrfExt']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['PortHarbourSrfExt']['EnumeratedIndexValues']['COS']['BB010']  = (-999999,2,4,6,9,13,14)
    field_information['GGDM 3.0']['PortHarbourSrfExt']['EnumeratedIndexValues']['COS']['BB115']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['PortHarbourSrfExt']['F_CODE'] = ('CONSTRAINED_STRING',('BB010','BB115'))
    field_information['GGDM 3.0']['PortHarbourSrfExt']['FUFI'] = ('StructuredText',('BB010','BB115'))
    field_information['GGDM 3.0']['PortHarbourSrfExt']['FURL'] = ('StructuredText',('BB010','BB115'))
    field_information['GGDM 3.0']['PortHarbourSrfExt']['GDBV'] = ('Enumeration',('BB010','BB115'))
    field_information['GGDM 3.0']['PortHarbourSrfExt']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['PortHarbourSrfExt']['EnumeratedIndexValues']['GDBV']['BB010']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['PortHarbourSrfExt']['EnumeratedIndexValues']['GDBV']['BB115']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['PortHarbourSrfExt']['HDP'] = ('Real',('BB010'))
    field_information['GGDM 3.0']['PortHarbourSrfExt']['LZN'] = ('Real',('BB115'))
    field_information['GGDM 3.0']['PortHarbourSrfExt']['MCC'] = ('Enumeration',('BB115'))
    field_information['GGDM 3.0']['PortHarbourSrfExt']['EnumeratedIndexValues']['MCC'] = {}
    field_information['GGDM 3.0']['PortHarbourSrfExt']['EnumeratedIndexValues']['MCC']['BB115']  = (-999999,21,51,62,64,117,150,999)
    field_information['GGDM 3.0']['PortHarbourSrfExt']['MCC2'] = ('Enumeration',('BB115'))
    field_information['GGDM 3.0']['PortHarbourSrfExt']['EnumeratedIndexValues']['MCC2'] = {}
    field_information['GGDM 3.0']['PortHarbourSrfExt']['EnumeratedIndexValues']['MCC2']['BB115']  = (-999999,21,51,62,64,117,150,999)
    field_information['GGDM 3.0']['PortHarbourSrfExt']['MCC3'] = ('Enumeration',('BB115'))
    field_information['GGDM 3.0']['PortHarbourSrfExt']['EnumeratedIndexValues']['MCC3'] = {}
    field_information['GGDM 3.0']['PortHarbourSrfExt']['EnumeratedIndexValues']['MCC3']['BB115']  = (-999999,21,51,62,64,117,150,999)
    field_information['GGDM 3.0']['PortHarbourSrfExt']['OTH'] = ('StructuredText',('BB010','BB115'))
    field_information['GGDM 3.0']['PortHarbourSrfExt']['PCF'] = ('Enumeration',('BB010','BB115'))
    field_information['GGDM 3.0']['PortHarbourSrfExt']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['PortHarbourSrfExt']['EnumeratedIndexValues']['PCF']['BB010']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['PortHarbourSrfExt']['EnumeratedIndexValues']['PCF']['BB115']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['PortHarbourSrfExt']['UFI'] = ('StructuredText',('BB010','BB115'))
    field_information['GGDM 3.0']['PortHarbourSrfExt']['WID'] = ('Real',('BB115'))
    field_information['GGDM 3.0']['PortHarbourSrfExt']['WLE'] = ('Enumeration',('BB115'))
    field_information['GGDM 3.0']['PortHarbourSrfExt']['EnumeratedIndexValues']['WLE'] = {}
    field_information['GGDM 3.0']['PortHarbourSrfExt']['EnumeratedIndexValues']['WLE']['BB115']  = (-999999,1,2,3,4,5,9,999)
    field_information['GGDM 3.0']['PortHarbourSrfExt']['ZI001_SDV'] = ('StructuredText',('BB010','BB115'))
    field_information['GGDM 3.0']['PortHarbourSrfExt']['ZI001_SRT'] = ('Enumeration',('BB010','BB115'))
    field_information['GGDM 3.0']['PortHarbourSrfExt']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['PortHarbourSrfExt']['EnumeratedIndexValues']['ZI001_SRT']['BB010']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['PortHarbourSrfExt']['EnumeratedIndexValues']['ZI001_SRT']['BB115']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['PortHarbourSrfExt']['ZI002_UFI'] = ('StructuredText',('BB010','BB115'))
    field_information['GGDM 3.0']['PortHarbourSrfExt']['ZI004_RCG'] = ('Enumeration',('BB010','BB115'))
    field_information['GGDM 3.0']['PortHarbourSrfExt']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['PortHarbourSrfExt']['EnumeratedIndexValues']['ZI004_RCG']['BB010']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['PortHarbourSrfExt']['EnumeratedIndexValues']['ZI004_RCG']['BB115']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['PortHarbourSrfExt']['ZI005_FNA'] = ('String',('BB010','BB115'))
    field_information['GGDM 3.0']['PortHarbourSrfExt']['ZI005_GNT'] = ('Enumeration',('BB010','BB115'))
    field_information['GGDM 3.0']['PortHarbourSrfExt']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['PortHarbourSrfExt']['EnumeratedIndexValues']['ZI005_GNT']['BB010']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['PortHarbourSrfExt']['EnumeratedIndexValues']['ZI005_GNT']['BB115']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['PortHarbourSrfExt']['ZI005_NFN'] = ('String',('BB010','BB115'))
    field_information['GGDM 3.0']['PortHarbourSrfExt']['ZI006_MEM'] = ('String',('BB010','BB115'))
    field_information['GGDM 3.0']['PortHarbourSrfExt']['ZI020_GE4'] = ('CodeList',('BB010','BB115'))
    field_information['GGDM 3.0']['PortHarbourSrfExt']['ZI026_CTUC'] = ('Enumeration',('BB010','BB115'))
    field_information['GGDM 3.0']['PortHarbourSrfExt']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['PortHarbourSrfExt']['EnumeratedIndexValues']['ZI026_CTUC']['BB010']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['PortHarbourSrfExt']['EnumeratedIndexValues']['ZI026_CTUC']['BB115']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['PortHarbourSrfExt']['ZI026_CTUL'] = ('integer',('BB010','BB115'))
    field_information['GGDM 3.0']['PortHarbourSrfExt']['ZI026_CTUU'] = ('integer',('BB010','BB115'))
    field_information['GGDM 3.0']['PortHarbourSrfExt']['ZI031S_URI'] = ('StructuredText',('BB010','BB115'))
    field_information['GGDM 3.0']['PortHarbourSrfExt']['ZI039S_UFI'] = ('StructuredText',('BB010','BB115'))
    field_information['GGDM 3.0']['PortHarbourSrfExt']['ZSAX_RS0'] = ('CodeList',('BB010','BB115'))
    field_information['GGDM 3.0']['PortHarbourSrfExt']['ZSAX_RX0'] = ('StructuredText',('BB010','BB115'))
    field_information['GGDM 3.0']['PortHarbourSrfExt']['ZSAX_RX3'] = ('StructuredText',('BB010','BB115'))
    field_information['GGDM 3.0']['PortHarbourSrfExt']['ZSAX_RX4'] = ('StructuredText',('BB010','BB115'))
    field_information['GGDM 3.0']['RecreationAONExt']['ARA'] = ('Real',('NU170'))
    field_information['GGDM 3.0']['RecreationAONExt']['BEN'] = ('StructuredText',('NU170'))
    field_information['GGDM 3.0']['RecreationAONExt']['CAA'] = ('Enumeration',('NU170'))
    field_information['GGDM 3.0']['RecreationAONExt']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['RecreationAONExt']['EnumeratedIndexValues']['CAA']['NU170']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['RecreationAONExt']['CNCP'] = ('StructuredText',('NU170'))
    field_information['GGDM 3.0']['RecreationAONExt']['COS'] = ('Enumeration',('NU170'))
    field_information['GGDM 3.0']['RecreationAONExt']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['RecreationAONExt']['EnumeratedIndexValues']['COS']['NU170']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['RecreationAONExt']['DMF'] = ('Integer',('NU170'))
    field_information['GGDM 3.0']['RecreationAONExt']['DZP'] = ('Real',('NU170'))
    field_information['GGDM 3.0']['RecreationAONExt']['F_CODE'] = ('CONSTRAINED_STRING',('NU170'))
    field_information['GGDM 3.0']['RecreationAONExt']['FUFI'] = ('StructuredText',('NU170'))
    field_information['GGDM 3.0']['RecreationAONExt']['FURL'] = ('StructuredText',('NU170'))
    field_information['GGDM 3.0']['RecreationAONExt']['GDBV'] = ('Enumeration',('NU170'))
    field_information['GGDM 3.0']['RecreationAONExt']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['RecreationAONExt']['EnumeratedIndexValues']['GDBV']['NU170']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['RecreationAONExt']['HGT'] = ('Real',('NU170'))
    field_information['GGDM 3.0']['RecreationAONExt']['LMC'] = ('Boolean',('NU170'))
    field_information['GGDM 3.0']['RecreationAONExt']['LOC'] = ('Enumeration',('NU170'))
    field_information['GGDM 3.0']['RecreationAONExt']['EnumeratedIndexValues']['LOC'] = {}
    field_information['GGDM 3.0']['RecreationAONExt']['EnumeratedIndexValues']['LOC']['NU170']  = (-999999,17,23,40,44,45,46,47)
    field_information['GGDM 3.0']['RecreationAONExt']['LZN'] = ('Real',('NU170'))
    field_information['GGDM 3.0']['RecreationAONExt']['OTH'] = ('StructuredText',('NU170'))
    field_information['GGDM 3.0']['RecreationAONExt']['PCF'] = ('Enumeration',('NU170'))
    field_information['GGDM 3.0']['RecreationAONExt']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['RecreationAONExt']['EnumeratedIndexValues']['PCF']['NU170']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['RecreationAONExt']['UFI'] = ('StructuredText',('NU170'))
    field_information['GGDM 3.0']['RecreationAONExt']['VLM'] = ('Real',('NU170'))
    field_information['GGDM 3.0']['RecreationAONExt']['WID'] = ('Real',('NU170'))
    field_information['GGDM 3.0']['RecreationAONExt']['ZI001_SDV'] = ('StructuredText',('NU170'))
    field_information['GGDM 3.0']['RecreationAONExt']['ZI001_SRT'] = ('Enumeration',('NU170'))
    field_information['GGDM 3.0']['RecreationAONExt']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['RecreationAONExt']['EnumeratedIndexValues']['ZI001_SRT']['NU170']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['RecreationAONExt']['ZI002_UFI'] = ('StructuredText',('NU170'))
    field_information['GGDM 3.0']['RecreationAONExt']['ZI004_RCG'] = ('Enumeration',('NU170'))
    field_information['GGDM 3.0']['RecreationAONExt']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['RecreationAONExt']['EnumeratedIndexValues']['ZI004_RCG']['NU170']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['RecreationAONExt']['ZI005_FNA'] = ('String',('NU170'))
    field_information['GGDM 3.0']['RecreationAONExt']['ZI005_GNT'] = ('Enumeration',('NU170'))
    field_information['GGDM 3.0']['RecreationAONExt']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['RecreationAONExt']['EnumeratedIndexValues']['ZI005_GNT']['NU170']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['RecreationAONExt']['ZI005_NFN'] = ('String',('NU170'))
    field_information['GGDM 3.0']['RecreationAONExt']['ZI006_MEM'] = ('String',('NU170'))
    field_information['GGDM 3.0']['RecreationAONExt']['ZI020_GE4'] = ('CodeList',('NU170'))
    field_information['GGDM 3.0']['RecreationAONExt']['ZI024_ASE'] = ('Real',('NU170'))
    field_information['GGDM 3.0']['RecreationAONExt']['ZI024_CFR'] = ('Real',('NU170'))
    field_information['GGDM 3.0']['RecreationAONExt']['ZI024_CLO'] = ('Real',('NU170'))
    field_information['GGDM 3.0']['RecreationAONExt']['ZI024_CYN'] = ('Real',('NU170'))
    field_information['GGDM 3.0']['RecreationAONExt']['ZI024_FMR'] = ('Real',('NU170'))
    field_information['GGDM 3.0']['RecreationAONExt']['ZI024_FRR'] = ('Real',('NU170'))
    field_information['GGDM 3.0']['RecreationAONExt']['ZI024_HAR'] = ('Real',('NU170'))
    field_information['GGDM 3.0']['RecreationAONExt']['ZI024_HYP'] = ('Enumeration',('NU170'))
    field_information['GGDM 3.0']['RecreationAONExt']['EnumeratedIndexValues']['ZI024_HYP'] = {}
    field_information['GGDM 3.0']['RecreationAONExt']['EnumeratedIndexValues']['ZI024_HYP']['NU170']  = (-999999,1,2,4)
    field_information['GGDM 3.0']['RecreationAONExt']['ZI024_MGN'] = ('Real',('NU170'))
    field_information['GGDM 3.0']['RecreationAONExt']['ZI024_PHW'] = ('Real',('NU170'))
    field_information['GGDM 3.0']['RecreationAONExt']['ZI024_SCC'] = ('Enumeration',('NU170'))
    field_information['GGDM 3.0']['RecreationAONExt']['EnumeratedIndexValues']['ZI024_SCC'] = {}
    field_information['GGDM 3.0']['RecreationAONExt']['EnumeratedIndexValues']['ZI024_SCC']['NU170']  = (-999999,1,4,10,11,12,13,14,998,999)
    field_information['GGDM 3.0']['RecreationAONExt']['ZI024_SUL'] = ('Real',('NU170'))
    field_information['GGDM 3.0']['RecreationAONExt']['ZI024_TDS'] = ('Real',('NU170'))
    field_information['GGDM 3.0']['RecreationAONExt']['ZI024_TEP'] = ('Real',('NU170'))
    field_information['GGDM 3.0']['RecreationAONExt']['ZI024_TUR'] = ('Real',('NU170'))
    field_information['GGDM 3.0']['RecreationAONExt']['ZI024_WAC'] = ('Real',('NU170'))
    field_information['GGDM 3.0']['RecreationAONExt']['ZI024_WTNO'] = ('Real',('NU170'))
    field_information['GGDM 3.0']['RecreationAONExt']['ZI024_WUR'] = ('Enumeration',('NU170'))
    field_information['GGDM 3.0']['RecreationAONExt']['EnumeratedIndexValues']['ZI024_WUR'] = {}
    field_information['GGDM 3.0']['RecreationAONExt']['EnumeratedIndexValues']['ZI024_WUR']['NU170']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['RecreationAONExt']['ZI024_WUR2'] = ('Enumeration',('NU170'))
    field_information['GGDM 3.0']['RecreationAONExt']['EnumeratedIndexValues']['ZI024_WUR2'] = {}
    field_information['GGDM 3.0']['RecreationAONExt']['EnumeratedIndexValues']['ZI024_WUR2']['NU170']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['RecreationAONExt']['ZI024_WUR3'] = ('Enumeration',('NU170'))
    field_information['GGDM 3.0']['RecreationAONExt']['EnumeratedIndexValues']['ZI024_WUR3'] = {}
    field_information['GGDM 3.0']['RecreationAONExt']['EnumeratedIndexValues']['ZI024_WUR3']['NU170']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['RecreationAONExt']['ZI024_WUR4'] = ('Enumeration',('NU170'))
    field_information['GGDM 3.0']['RecreationAONExt']['EnumeratedIndexValues']['ZI024_WUR4'] = {}
    field_information['GGDM 3.0']['RecreationAONExt']['EnumeratedIndexValues']['ZI024_WUR4']['NU170']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['RecreationAONExt']['ZI026_CTUC'] = ('Enumeration',('NU170'))
    field_information['GGDM 3.0']['RecreationAONExt']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['RecreationAONExt']['EnumeratedIndexValues']['ZI026_CTUC']['NU170']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['RecreationAONExt']['ZI026_CTUL'] = ('integer',('NU170'))
    field_information['GGDM 3.0']['RecreationAONExt']['ZI026_CTUU'] = ('integer',('NU170'))
    field_information['GGDM 3.0']['RecreationAONExt']['ZI031S_URI'] = ('StructuredText',('NU170'))
    field_information['GGDM 3.0']['RecreationAONExt']['ZI039S_UFI'] = ('StructuredText',('NU170'))
    field_information['GGDM 3.0']['RecreationAONExt']['ZSAX_RS0'] = ('CodeList',('NU170'))
    field_information['GGDM 3.0']['RecreationAONExt']['ZSAX_RX0'] = ('StructuredText',('NU170'))
    field_information['GGDM 3.0']['RecreationAONExt']['ZSAX_RX3'] = ('StructuredText',('NU170'))
    field_information['GGDM 3.0']['RecreationAONExt']['ZSAX_RX4'] = ('StructuredText',('NU170'))
    field_information['GGDM 3.0']['RecreationCrv']['ADR'] = ('String',('AK130'))
    field_information['GGDM 3.0']['RecreationCrv']['AMA'] = ('Enumeration',('AK020'))
    field_information['GGDM 3.0']['RecreationCrv']['EnumeratedIndexValues']['AMA'] = {}
    field_information['GGDM 3.0']['RecreationCrv']['EnumeratedIndexValues']['AMA']['AK020']  = (-999999,1,2,3,4,5,6,999)
    field_information['GGDM 3.0']['RecreationCrv']['AOO'] = ('Real',('AK020','AK080','AK150'))
    field_information['GGDM 3.0']['RecreationCrv']['ARA'] = ('Real',('AK020','AK080','AK130','AK150','AK155'))
    field_information['GGDM 3.0']['RecreationCrv']['AWP'] = ('Boolean',('AK020','AK080','AK150'))
    field_information['GGDM 3.0']['RecreationCrv']['BEN'] = ('StructuredText',('AK020','AK080','AK130','AK150','AK155'))
    field_information['GGDM 3.0']['RecreationCrv']['CAA'] = ('Enumeration',('AK020','AK080','AK150'))
    field_information['GGDM 3.0']['RecreationCrv']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['RecreationCrv']['EnumeratedIndexValues']['CAA']['AK020']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['RecreationCrv']['EnumeratedIndexValues']['CAA']['AK080']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['RecreationCrv']['EnumeratedIndexValues']['CAA']['AK150']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['RecreationCrv']['CNCP'] = ('StructuredText',('AK020','AK080','AK130','AK150','AK155'))
    field_information['GGDM 3.0']['RecreationCrv']['COS'] = ('Enumeration',('AK020','AK080','AK130','AK150','AK155'))
    field_information['GGDM 3.0']['RecreationCrv']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['RecreationCrv']['EnumeratedIndexValues']['COS']['AK020']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['RecreationCrv']['EnumeratedIndexValues']['COS']['AK080']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['RecreationCrv']['EnumeratedIndexValues']['COS']['AK130']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['RecreationCrv']['EnumeratedIndexValues']['COS']['AK150']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['RecreationCrv']['EnumeratedIndexValues']['COS']['AK155']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['RecreationCrv']['F_CODE'] = ('CONSTRAINED_STRING',('AK020','AK080','AK130','AK150','AK155'))
    field_information['GGDM 3.0']['RecreationCrv']['FUFI'] = ('StructuredText',('AK020','AK080','AK130','AK150','AK155'))
    field_information['GGDM 3.0']['RecreationCrv']['FURL'] = ('StructuredText',('AK020','AK080','AK130','AK150','AK155'))
    field_information['GGDM 3.0']['RecreationCrv']['GDBV'] = ('Enumeration',('AK020','AK080','AK130','AK150','AK155'))
    field_information['GGDM 3.0']['RecreationCrv']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['RecreationCrv']['EnumeratedIndexValues']['GDBV']['AK020']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['RecreationCrv']['EnumeratedIndexValues']['GDBV']['AK080']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['RecreationCrv']['EnumeratedIndexValues']['GDBV']['AK130']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['RecreationCrv']['EnumeratedIndexValues']['GDBV']['AK150']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['RecreationCrv']['EnumeratedIndexValues']['GDBV']['AK155']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['RecreationCrv']['HEI'] = ('Real',('AK080'))
    field_information['GGDM 3.0']['RecreationCrv']['HGT'] = ('Real',('AK020','AK080','AK130','AK150','AK155'))
    field_information['GGDM 3.0']['RecreationCrv']['LMC'] = ('Boolean',('AK020','AK080','AK130','AK150','AK155'))
    field_information['GGDM 3.0']['RecreationCrv']['LZN'] = ('Real',('AK020','AK080','AK130','AK150','AK155'))
    field_information['GGDM 3.0']['RecreationCrv']['OTH'] = ('StructuredText',('AK020','AK080','AK130','AK150','AK155'))
    field_information['GGDM 3.0']['RecreationCrv']['PCF'] = ('Enumeration',('AK020','AK080','AK130','AK150','AK155'))
    field_information['GGDM 3.0']['RecreationCrv']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['RecreationCrv']['EnumeratedIndexValues']['PCF']['AK020']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['RecreationCrv']['EnumeratedIndexValues']['PCF']['AK080']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['RecreationCrv']['EnumeratedIndexValues']['PCF']['AK130']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['RecreationCrv']['EnumeratedIndexValues']['PCF']['AK150']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['RecreationCrv']['EnumeratedIndexValues']['PCF']['AK155']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['RecreationCrv']['RAY'] = ('Enumeration',('AK130'))
    field_information['GGDM 3.0']['RecreationCrv']['EnumeratedIndexValues']['RAY'] = {}
    field_information['GGDM 3.0']['RecreationCrv']['EnumeratedIndexValues']['RAY']['AK130']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['RecreationCrv']['THI'] = ('Real',('AK080'))
    field_information['GGDM 3.0']['RecreationCrv']['UFI'] = ('StructuredText',('AK020','AK080','AK130','AK150','AK155'))
    field_information['GGDM 3.0']['RecreationCrv']['VOI'] = ('StructuredText',('AK020','AK080','AK150'))
    field_information['GGDM 3.0']['RecreationCrv']['WID'] = ('Real',('AK020','AK130','AK150','AK155'))
    field_information['GGDM 3.0']['RecreationCrv']['ZI001_SDV'] = ('StructuredText',('AK020','AK080','AK130','AK150','AK155'))
    field_information['GGDM 3.0']['RecreationCrv']['ZI001_SRT'] = ('Enumeration',('AK020','AK080','AK130','AK150','AK155'))
    field_information['GGDM 3.0']['RecreationCrv']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['RecreationCrv']['EnumeratedIndexValues']['ZI001_SRT']['AK020']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['RecreationCrv']['EnumeratedIndexValues']['ZI001_SRT']['AK080']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['RecreationCrv']['EnumeratedIndexValues']['ZI001_SRT']['AK130']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['RecreationCrv']['EnumeratedIndexValues']['ZI001_SRT']['AK150']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['RecreationCrv']['EnumeratedIndexValues']['ZI001_SRT']['AK155']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['RecreationCrv']['ZI002_UFI'] = ('StructuredText',('AK020','AK080','AK130','AK150','AK155'))
    field_information['GGDM 3.0']['RecreationCrv']['ZI004_RCG'] = ('Enumeration',('AK020','AK080','AK130','AK150','AK155'))
    field_information['GGDM 3.0']['RecreationCrv']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['RecreationCrv']['EnumeratedIndexValues']['ZI004_RCG']['AK020']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['RecreationCrv']['EnumeratedIndexValues']['ZI004_RCG']['AK080']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['RecreationCrv']['EnumeratedIndexValues']['ZI004_RCG']['AK130']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['RecreationCrv']['EnumeratedIndexValues']['ZI004_RCG']['AK150']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['RecreationCrv']['EnumeratedIndexValues']['ZI004_RCG']['AK155']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['RecreationCrv']['ZI005_FNA'] = ('String',('AK020','AK080','AK130','AK150','AK155'))
    field_information['GGDM 3.0']['RecreationCrv']['ZI005_GNT'] = ('Enumeration',('AK020','AK080','AK130','AK150','AK155'))
    field_information['GGDM 3.0']['RecreationCrv']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['RecreationCrv']['EnumeratedIndexValues']['ZI005_GNT']['AK020']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['RecreationCrv']['EnumeratedIndexValues']['ZI005_GNT']['AK080']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['RecreationCrv']['EnumeratedIndexValues']['ZI005_GNT']['AK130']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['RecreationCrv']['EnumeratedIndexValues']['ZI005_GNT']['AK150']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['RecreationCrv']['EnumeratedIndexValues']['ZI005_GNT']['AK155']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['RecreationCrv']['ZI005_NFN'] = ('String',('AK020','AK080','AK130','AK150','AK155'))
    field_information['GGDM 3.0']['RecreationCrv']['ZI006_MEM'] = ('String',('AK020','AK080','AK130','AK150','AK155'))
    field_information['GGDM 3.0']['RecreationCrv']['ZI020_GE4'] = ('CodeList',('AK020','AK080','AK130','AK150','AK155'))
    field_information['GGDM 3.0']['RecreationCrv']['ZI026_CTUC'] = ('Enumeration',('AK020','AK080','AK130','AK150','AK155'))
    field_information['GGDM 3.0']['RecreationCrv']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['RecreationCrv']['EnumeratedIndexValues']['ZI026_CTUC']['AK020']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['RecreationCrv']['EnumeratedIndexValues']['ZI026_CTUC']['AK080']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['RecreationCrv']['EnumeratedIndexValues']['ZI026_CTUC']['AK130']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['RecreationCrv']['EnumeratedIndexValues']['ZI026_CTUC']['AK150']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['RecreationCrv']['EnumeratedIndexValues']['ZI026_CTUC']['AK155']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['RecreationCrv']['ZI026_CTUL'] = ('integer',('AK020','AK080','AK130','AK150','AK155'))
    field_information['GGDM 3.0']['RecreationCrv']['ZI026_CTUU'] = ('integer',('AK020','AK080','AK130','AK150','AK155'))
    field_information['GGDM 3.0']['RecreationCrv']['ZI031S_URI'] = ('StructuredText',('AK020','AK080','AK130','AK150','AK155'))
    field_information['GGDM 3.0']['RecreationCrv']['ZI039S_UFI'] = ('StructuredText',('AK020','AK080','AK130','AK150','AK155'))
    field_information['GGDM 3.0']['RecreationCrv']['ZSAX_RS0'] = ('CodeList',('AK020','AK080','AK130','AK150','AK155'))
    field_information['GGDM 3.0']['RecreationCrv']['ZSAX_RX0'] = ('StructuredText',('AK020','AK080','AK130','AK150','AK155'))
    field_information['GGDM 3.0']['RecreationCrv']['ZSAX_RX3'] = ('StructuredText',('AK020','AK080','AK130','AK150','AK155'))
    field_information['GGDM 3.0']['RecreationCrv']['ZSAX_RX4'] = ('StructuredText',('AK020','AK080','AK130','AK150','AK155'))
    field_information['GGDM 3.0']['RecreationCrv']['ZVH'] = ('Real',('AK020','AK080','AK150','AK155'))
    field_information['GGDM 3.0']['RecreationPnt']['ADR'] = ('String',('AK030','AK160','AK164','AK170','AK180','AL170'))
    field_information['GGDM 3.0']['RecreationPnt']['AMA'] = ('Enumeration',('AK020'))
    field_information['GGDM 3.0']['RecreationPnt']['EnumeratedIndexValues']['AMA'] = {}
    field_information['GGDM 3.0']['RecreationPnt']['EnumeratedIndexValues']['AMA']['AK020']  = (-999999,1,2,3,4,5,6,999)
    field_information['GGDM 3.0']['RecreationPnt']['AOO'] = ('Real',('AK020','AK030','AK080','AK110','AK150','AK160','AK161','AK164','AK180'))
    field_information['GGDM 3.0']['RecreationPnt']['ARA'] = ('Real',('AK020','AK030','AK040','AK060','AK080','AK110','AK150','AK160','AK161','AK164','AK170','AK180','AL170'))
    field_information['GGDM 3.0']['RecreationPnt']['AWP'] = ('Boolean',('AK020','AK080','AK110','AK150','AK160','AK161'))
    field_information['GGDM 3.0']['RecreationPnt']['BEN'] = ('StructuredText',('AK020','AK030','AK040','AK060','AK080','AK110','AK150','AK160','AK161','AK164','AK170','AK180','AL170'))
    field_information['GGDM 3.0']['RecreationPnt']['CAA'] = ('Enumeration',('AK020','AK030','AK080','AK110','AK150','AK160','AK161','AK170','AK180'))
    field_information['GGDM 3.0']['RecreationPnt']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['RecreationPnt']['EnumeratedIndexValues']['CAA']['AK020']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['RecreationPnt']['EnumeratedIndexValues']['CAA']['AK030']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['RecreationPnt']['EnumeratedIndexValues']['CAA']['AK080']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['RecreationPnt']['EnumeratedIndexValues']['CAA']['AK110']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['RecreationPnt']['EnumeratedIndexValues']['CAA']['AK150']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['RecreationPnt']['EnumeratedIndexValues']['CAA']['AK160']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['RecreationPnt']['EnumeratedIndexValues']['CAA']['AK161']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['RecreationPnt']['EnumeratedIndexValues']['CAA']['AK170']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['RecreationPnt']['EnumeratedIndexValues']['CAA']['AK180']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['RecreationPnt']['CCT'] = ('Enumeration',('AK160'))
    field_information['GGDM 3.0']['RecreationPnt']['EnumeratedIndexValues']['CCT'] = {}
    field_information['GGDM 3.0']['RecreationPnt']['EnumeratedIndexValues']['CCT']['AK160']  = (-999999,1,2,3,4)
    field_information['GGDM 3.0']['RecreationPnt']['CNCP'] = ('StructuredText',('AK020','AK030','AK040','AK060','AK080','AK110','AK150','AK160','AK161','AK164','AK170','AK180','AL170'))
    field_information['GGDM 3.0']['RecreationPnt']['COS'] = ('Enumeration',('AK020','AK030','AK040','AK060','AK080','AK110','AK150','AK160','AK161','AK164','AK170','AK180','AL170'))
    field_information['GGDM 3.0']['RecreationPnt']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['RecreationPnt']['EnumeratedIndexValues']['COS']['AK020']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['RecreationPnt']['EnumeratedIndexValues']['COS']['AK030']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['RecreationPnt']['EnumeratedIndexValues']['COS']['AK040']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['RecreationPnt']['EnumeratedIndexValues']['COS']['AK060']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['RecreationPnt']['EnumeratedIndexValues']['COS']['AK080']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['RecreationPnt']['EnumeratedIndexValues']['COS']['AK110']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['RecreationPnt']['EnumeratedIndexValues']['COS']['AK150']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['RecreationPnt']['EnumeratedIndexValues']['COS']['AK160']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['RecreationPnt']['EnumeratedIndexValues']['COS']['AK161']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['RecreationPnt']['EnumeratedIndexValues']['COS']['AK164']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['RecreationPnt']['EnumeratedIndexValues']['COS']['AK170']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['RecreationPnt']['EnumeratedIndexValues']['COS']['AK180']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['RecreationPnt']['EnumeratedIndexValues']['COS']['AL170']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['RecreationPnt']['DZP'] = ('Real',('AK170'))
    field_information['GGDM 3.0']['RecreationPnt']['F_CODE'] = ('CONSTRAINED_STRING',('AK020','AK030','AK040','AK060','AK080','AK110','AK150','AK160','AK161','AK164','AK170','AK180','AL170'))
    field_information['GGDM 3.0']['RecreationPnt']['FFN'] = ('Enumeration',('AK030','AK160'))
    field_information['GGDM 3.0']['RecreationPnt']['EnumeratedIndexValues']['FFN'] = {}
    field_information['GGDM 3.0']['RecreationPnt']['EnumeratedIndexValues']['FFN']['AK030']  = (-999999,382,464,465,466,475,480,551,552,570,572,573,574,594,643,780,863,890,891,894,895,900,905,906,907,909,912,915,921,922,923,930,970,999)
    field_information['GGDM 3.0']['RecreationPnt']['EnumeratedIndexValues']['FFN']['AK160']  = (-999999,570,572,900,912,921,930,954,999)
    field_information['GGDM 3.0']['RecreationPnt']['FFN2'] = ('Enumeration',('AK030','AK160'))
    field_information['GGDM 3.0']['RecreationPnt']['EnumeratedIndexValues']['FFN2'] = {}
    field_information['GGDM 3.0']['RecreationPnt']['EnumeratedIndexValues']['FFN2']['AK030']  = (-999999,382,464,465,466,475,480,551,552,570,572,573,574,594,643,780,863,890,891,894,895,900,905,906,907,909,912,915,921,922,923,930,970,999)
    field_information['GGDM 3.0']['RecreationPnt']['EnumeratedIndexValues']['FFN2']['AK160']  = (-999999,570,572,900,912,921,930,954,999)
    field_information['GGDM 3.0']['RecreationPnt']['FFN3'] = ('Enumeration',('AK030','AK160'))
    field_information['GGDM 3.0']['RecreationPnt']['EnumeratedIndexValues']['FFN3'] = {}
    field_information['GGDM 3.0']['RecreationPnt']['EnumeratedIndexValues']['FFN3']['AK030']  = (-999999,382,464,465,466,475,480,551,552,570,572,573,574,594,643,780,863,890,891,894,895,900,905,906,907,909,912,915,921,922,923,930,970,999)
    field_information['GGDM 3.0']['RecreationPnt']['EnumeratedIndexValues']['FFN3']['AK160']  = (-999999,570,572,900,912,921,930,954,999)
    field_information['GGDM 3.0']['RecreationPnt']['FUFI'] = ('StructuredText',('AK020','AK030','AK040','AK060','AK080','AK110','AK150','AK160','AK161','AK164','AK170','AK180','AL170'))
    field_information['GGDM 3.0']['RecreationPnt']['FURL'] = ('StructuredText',('AK020','AK030','AK040','AK060','AK080','AK110','AK150','AK160','AK161','AK164','AK170','AK180','AL170'))
    field_information['GGDM 3.0']['RecreationPnt']['GDBV'] = ('Enumeration',('AK020','AK030','AK040','AK060','AK080','AK110','AK150','AK160','AK161','AK164','AK170','AK180','AL170'))
    field_information['GGDM 3.0']['RecreationPnt']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['RecreationPnt']['EnumeratedIndexValues']['GDBV']['AK020']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['RecreationPnt']['EnumeratedIndexValues']['GDBV']['AK030']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['RecreationPnt']['EnumeratedIndexValues']['GDBV']['AK040']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['RecreationPnt']['EnumeratedIndexValues']['GDBV']['AK060']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['RecreationPnt']['EnumeratedIndexValues']['GDBV']['AK080']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['RecreationPnt']['EnumeratedIndexValues']['GDBV']['AK110']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['RecreationPnt']['EnumeratedIndexValues']['GDBV']['AK150']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['RecreationPnt']['EnumeratedIndexValues']['GDBV']['AK160']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['RecreationPnt']['EnumeratedIndexValues']['GDBV']['AK161']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['RecreationPnt']['EnumeratedIndexValues']['GDBV']['AK164']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['RecreationPnt']['EnumeratedIndexValues']['GDBV']['AK170']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['RecreationPnt']['EnumeratedIndexValues']['GDBV']['AK180']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['RecreationPnt']['EnumeratedIndexValues']['GDBV']['AL170']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['RecreationPnt']['HEI'] = ('Real',('AK080','AK161'))
    field_information['GGDM 3.0']['RecreationPnt']['HGT'] = ('Real',('AK020','AK030','AK040','AK080','AK110','AK150','AK160','AK161','AK164','AK170','AK180'))
    field_information['GGDM 3.0']['RecreationPnt']['LMC'] = ('Boolean',('AK020','AK030','AK040','AK060','AK080','AK110','AK150','AK160','AK161','AK164','AK170','AK180'))
    field_information['GGDM 3.0']['RecreationPnt']['LOC'] = ('Enumeration',('AK170'))
    field_information['GGDM 3.0']['RecreationPnt']['EnumeratedIndexValues']['LOC'] = {}
    field_information['GGDM 3.0']['RecreationPnt']['EnumeratedIndexValues']['LOC']['AK170']  = (-999999,17,23,40,44,45,46,47)
    field_information['GGDM 3.0']['RecreationPnt']['LZN'] = ('Real',('AK020','AK030','AK040','AK060','AK080','AK110','AK150','AK160','AK161','AK164','AK170','AK180','AL170'))
    field_information['GGDM 3.0']['RecreationPnt']['OTH'] = ('StructuredText',('AK020','AK030','AK040','AK060','AK080','AK110','AK150','AK160','AK161','AK164','AK170','AK180','AL170'))
    field_information['GGDM 3.0']['RecreationPnt']['PCF'] = ('Enumeration',('AK020','AK030','AK040','AK060','AK080','AK110','AK150','AK160','AK161','AK164','AK170','AK180','AL170'))
    field_information['GGDM 3.0']['RecreationPnt']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['RecreationPnt']['EnumeratedIndexValues']['PCF']['AK020']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['RecreationPnt']['EnumeratedIndexValues']['PCF']['AK030']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['RecreationPnt']['EnumeratedIndexValues']['PCF']['AK040']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['RecreationPnt']['EnumeratedIndexValues']['PCF']['AK060']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['RecreationPnt']['EnumeratedIndexValues']['PCF']['AK080']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['RecreationPnt']['EnumeratedIndexValues']['PCF']['AK110']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['RecreationPnt']['EnumeratedIndexValues']['PCF']['AK150']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['RecreationPnt']['EnumeratedIndexValues']['PCF']['AK160']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['RecreationPnt']['EnumeratedIndexValues']['PCF']['AK161']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['RecreationPnt']['EnumeratedIndexValues']['PCF']['AK164']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['RecreationPnt']['EnumeratedIndexValues']['PCF']['AK170']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['RecreationPnt']['EnumeratedIndexValues']['PCF']['AK180']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['RecreationPnt']['EnumeratedIndexValues']['PCF']['AL170']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['RecreationPnt']['SSR'] = ('Enumeration',('AK160'))
    field_information['GGDM 3.0']['RecreationPnt']['EnumeratedIndexValues']['SSR'] = {}
    field_information['GGDM 3.0']['RecreationPnt']['EnumeratedIndexValues']['SSR']['AK160']  = (-999999,6,7,38,40,41,42,47,50,55,64,999)
    field_information['GGDM 3.0']['RecreationPnt']['SSR2'] = ('Enumeration',('AK160'))
    field_information['GGDM 3.0']['RecreationPnt']['EnumeratedIndexValues']['SSR2'] = {}
    field_information['GGDM 3.0']['RecreationPnt']['EnumeratedIndexValues']['SSR2']['AK160']  = (-999999,6,7,38,40,41,42,47,50,55,64,999)
    field_information['GGDM 3.0']['RecreationPnt']['SSR3'] = ('Enumeration',('AK160'))
    field_information['GGDM 3.0']['RecreationPnt']['EnumeratedIndexValues']['SSR3'] = {}
    field_information['GGDM 3.0']['RecreationPnt']['EnumeratedIndexValues']['SSR3']['AK160']  = (-999999,6,7,38,40,41,42,47,50,55,64,999)
    field_information['GGDM 3.0']['RecreationPnt']['THI'] = ('Real',('AK080'))
    field_information['GGDM 3.0']['RecreationPnt']['UFI'] = ('StructuredText',('AK020','AK030','AK040','AK060','AK080','AK110','AK150','AK160','AK161','AK164','AK170','AK180','AL170'))
    field_information['GGDM 3.0']['RecreationPnt']['VLM'] = ('Real',('AK170'))
    field_information['GGDM 3.0']['RecreationPnt']['VOI'] = ('StructuredText',('AK020','AK080','AK110','AK150','AK160','AK161'))
    field_information['GGDM 3.0']['RecreationPnt']['WID'] = ('Real',('AK020','AK030','AK040','AK060','AK110','AK150','AK160','AK164','AK170','AK180','AL170'))
    field_information['GGDM 3.0']['RecreationPnt']['ZI001_SDV'] = ('StructuredText',('AK020','AK030','AK040','AK060','AK080','AK110','AK150','AK160','AK161','AK164','AK170','AK180','AL170'))
    field_information['GGDM 3.0']['RecreationPnt']['ZI001_SRT'] = ('Enumeration',('AK020','AK030','AK040','AK060','AK080','AK110','AK150','AK160','AK161','AK164','AK170','AK180','AL170'))
    field_information['GGDM 3.0']['RecreationPnt']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['RecreationPnt']['EnumeratedIndexValues']['ZI001_SRT']['AK020']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['RecreationPnt']['EnumeratedIndexValues']['ZI001_SRT']['AK030']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['RecreationPnt']['EnumeratedIndexValues']['ZI001_SRT']['AK040']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['RecreationPnt']['EnumeratedIndexValues']['ZI001_SRT']['AK060']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['RecreationPnt']['EnumeratedIndexValues']['ZI001_SRT']['AK080']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['RecreationPnt']['EnumeratedIndexValues']['ZI001_SRT']['AK110']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['RecreationPnt']['EnumeratedIndexValues']['ZI001_SRT']['AK150']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['RecreationPnt']['EnumeratedIndexValues']['ZI001_SRT']['AK160']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['RecreationPnt']['EnumeratedIndexValues']['ZI001_SRT']['AK161']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['RecreationPnt']['EnumeratedIndexValues']['ZI001_SRT']['AK164']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['RecreationPnt']['EnumeratedIndexValues']['ZI001_SRT']['AK170']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['RecreationPnt']['EnumeratedIndexValues']['ZI001_SRT']['AK180']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['RecreationPnt']['EnumeratedIndexValues']['ZI001_SRT']['AL170']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['RecreationPnt']['ZI002_UFI'] = ('StructuredText',('AK020','AK030','AK040','AK060','AK080','AK110','AK150','AK160','AK161','AK164','AK170','AK180','AL170'))
    field_information['GGDM 3.0']['RecreationPnt']['ZI004_RCG'] = ('Enumeration',('AK020','AK030','AK040','AK060','AK080','AK110','AK150','AK160','AK161','AK164','AK170','AK180','AL170'))
    field_information['GGDM 3.0']['RecreationPnt']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['RecreationPnt']['EnumeratedIndexValues']['ZI004_RCG']['AK020']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['RecreationPnt']['EnumeratedIndexValues']['ZI004_RCG']['AK030']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['RecreationPnt']['EnumeratedIndexValues']['ZI004_RCG']['AK040']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['RecreationPnt']['EnumeratedIndexValues']['ZI004_RCG']['AK060']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['RecreationPnt']['EnumeratedIndexValues']['ZI004_RCG']['AK080']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['RecreationPnt']['EnumeratedIndexValues']['ZI004_RCG']['AK110']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['RecreationPnt']['EnumeratedIndexValues']['ZI004_RCG']['AK150']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['RecreationPnt']['EnumeratedIndexValues']['ZI004_RCG']['AK160']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['RecreationPnt']['EnumeratedIndexValues']['ZI004_RCG']['AK161']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['RecreationPnt']['EnumeratedIndexValues']['ZI004_RCG']['AK164']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['RecreationPnt']['EnumeratedIndexValues']['ZI004_RCG']['AK170']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['RecreationPnt']['EnumeratedIndexValues']['ZI004_RCG']['AK180']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['RecreationPnt']['EnumeratedIndexValues']['ZI004_RCG']['AL170']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['RecreationPnt']['ZI005_FNA'] = ('String',('AK020','AK030','AK040','AK060','AK080','AK110','AK150','AK160','AK161','AK164','AK170','AK180','AL170'))
    field_information['GGDM 3.0']['RecreationPnt']['ZI005_GNT'] = ('Enumeration',('AK020','AK030','AK040','AK060','AK080','AK110','AK150','AK160','AK161','AK164','AK170','AK180','AL170'))
    field_information['GGDM 3.0']['RecreationPnt']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['RecreationPnt']['EnumeratedIndexValues']['ZI005_GNT']['AK020']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['RecreationPnt']['EnumeratedIndexValues']['ZI005_GNT']['AK030']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['RecreationPnt']['EnumeratedIndexValues']['ZI005_GNT']['AK040']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['RecreationPnt']['EnumeratedIndexValues']['ZI005_GNT']['AK060']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['RecreationPnt']['EnumeratedIndexValues']['ZI005_GNT']['AK080']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['RecreationPnt']['EnumeratedIndexValues']['ZI005_GNT']['AK110']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['RecreationPnt']['EnumeratedIndexValues']['ZI005_GNT']['AK150']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['RecreationPnt']['EnumeratedIndexValues']['ZI005_GNT']['AK160']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['RecreationPnt']['EnumeratedIndexValues']['ZI005_GNT']['AK161']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['RecreationPnt']['EnumeratedIndexValues']['ZI005_GNT']['AK164']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['RecreationPnt']['EnumeratedIndexValues']['ZI005_GNT']['AK170']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['RecreationPnt']['EnumeratedIndexValues']['ZI005_GNT']['AK180']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['RecreationPnt']['EnumeratedIndexValues']['ZI005_GNT']['AL170']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['RecreationPnt']['ZI005_NFN'] = ('String',('AK020','AK030','AK040','AK060','AK080','AK110','AK150','AK160','AK161','AK164','AK170','AK180','AL170'))
    field_information['GGDM 3.0']['RecreationPnt']['ZI006_MEM'] = ('String',('AK020','AK030','AK040','AK060','AK080','AK110','AK150','AK160','AK161','AK164','AK170','AK180','AL170'))
    field_information['GGDM 3.0']['RecreationPnt']['ZI020_GE4'] = ('CodeList',('AK020','AK030','AK040','AK060','AK080','AK110','AK150','AK160','AK161','AK164','AK170','AK180','AL170'))
    field_information['GGDM 3.0']['RecreationPnt']['ZI024_ASE'] = ('Real',('AK170'))
    field_information['GGDM 3.0']['RecreationPnt']['ZI024_CFR'] = ('Real',('AK170'))
    field_information['GGDM 3.0']['RecreationPnt']['ZI024_CLO'] = ('Real',('AK170'))
    field_information['GGDM 3.0']['RecreationPnt']['ZI024_CYN'] = ('Real',('AK170'))
    field_information['GGDM 3.0']['RecreationPnt']['ZI024_FMR'] = ('Real',('AK170'))
    field_information['GGDM 3.0']['RecreationPnt']['ZI024_FRR'] = ('Real',('AK170'))
    field_information['GGDM 3.0']['RecreationPnt']['ZI024_HAR'] = ('Real',('AK170'))
    field_information['GGDM 3.0']['RecreationPnt']['ZI024_HYP'] = ('Enumeration',('AK170'))
    field_information['GGDM 3.0']['RecreationPnt']['EnumeratedIndexValues']['ZI024_HYP'] = {}
    field_information['GGDM 3.0']['RecreationPnt']['EnumeratedIndexValues']['ZI024_HYP']['AK170']  = (-999999,1,2,4)
    field_information['GGDM 3.0']['RecreationPnt']['ZI024_MGN'] = ('Real',('AK170'))
    field_information['GGDM 3.0']['RecreationPnt']['ZI024_PHW'] = ('Real',('AK170'))
    field_information['GGDM 3.0']['RecreationPnt']['ZI024_SCC'] = ('Enumeration',('AK170'))
    field_information['GGDM 3.0']['RecreationPnt']['EnumeratedIndexValues']['ZI024_SCC'] = {}
    field_information['GGDM 3.0']['RecreationPnt']['EnumeratedIndexValues']['ZI024_SCC']['AK170']  = (-999999,1,4,10,11,12,13,14,998,999)
    field_information['GGDM 3.0']['RecreationPnt']['ZI024_SUL'] = ('Real',('AK170'))
    field_information['GGDM 3.0']['RecreationPnt']['ZI024_TDS'] = ('Real',('AK170'))
    field_information['GGDM 3.0']['RecreationPnt']['ZI024_TEP'] = ('Real',('AK170'))
    field_information['GGDM 3.0']['RecreationPnt']['ZI024_TUR'] = ('Real',('AK170'))
    field_information['GGDM 3.0']['RecreationPnt']['ZI024_WAC'] = ('Real',('AK170'))
    field_information['GGDM 3.0']['RecreationPnt']['ZI024_WTNO'] = ('Real',('AK170'))
    field_information['GGDM 3.0']['RecreationPnt']['ZI024_WUR'] = ('Enumeration',('AK170'))
    field_information['GGDM 3.0']['RecreationPnt']['EnumeratedIndexValues']['ZI024_WUR'] = {}
    field_information['GGDM 3.0']['RecreationPnt']['EnumeratedIndexValues']['ZI024_WUR']['AK170']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['RecreationPnt']['ZI024_WUR2'] = ('Enumeration',('AK170'))
    field_information['GGDM 3.0']['RecreationPnt']['EnumeratedIndexValues']['ZI024_WUR2'] = {}
    field_information['GGDM 3.0']['RecreationPnt']['EnumeratedIndexValues']['ZI024_WUR2']['AK170']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['RecreationPnt']['ZI024_WUR3'] = ('Enumeration',('AK170'))
    field_information['GGDM 3.0']['RecreationPnt']['EnumeratedIndexValues']['ZI024_WUR3'] = {}
    field_information['GGDM 3.0']['RecreationPnt']['EnumeratedIndexValues']['ZI024_WUR3']['AK170']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['RecreationPnt']['ZI024_WUR4'] = ('Enumeration',('AK170'))
    field_information['GGDM 3.0']['RecreationPnt']['EnumeratedIndexValues']['ZI024_WUR4'] = {}
    field_information['GGDM 3.0']['RecreationPnt']['EnumeratedIndexValues']['ZI024_WUR4']['AK170']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['RecreationPnt']['ZI026_CTUC'] = ('Enumeration',('AK020','AK030','AK040','AK060','AK080','AK110','AK150','AK160','AK161','AK164','AK170','AK180','AL170'))
    field_information['GGDM 3.0']['RecreationPnt']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['RecreationPnt']['EnumeratedIndexValues']['ZI026_CTUC']['AK020']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['RecreationPnt']['EnumeratedIndexValues']['ZI026_CTUC']['AK030']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['RecreationPnt']['EnumeratedIndexValues']['ZI026_CTUC']['AK040']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['RecreationPnt']['EnumeratedIndexValues']['ZI026_CTUC']['AK060']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['RecreationPnt']['EnumeratedIndexValues']['ZI026_CTUC']['AK080']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['RecreationPnt']['EnumeratedIndexValues']['ZI026_CTUC']['AK110']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['RecreationPnt']['EnumeratedIndexValues']['ZI026_CTUC']['AK150']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['RecreationPnt']['EnumeratedIndexValues']['ZI026_CTUC']['AK160']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['RecreationPnt']['EnumeratedIndexValues']['ZI026_CTUC']['AK161']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['RecreationPnt']['EnumeratedIndexValues']['ZI026_CTUC']['AK164']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['RecreationPnt']['EnumeratedIndexValues']['ZI026_CTUC']['AK170']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['RecreationPnt']['EnumeratedIndexValues']['ZI026_CTUC']['AK180']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['RecreationPnt']['EnumeratedIndexValues']['ZI026_CTUC']['AL170']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['RecreationPnt']['ZI026_CTUL'] = ('integer',('AK020','AK030','AK040','AK060','AK080','AK110','AK150','AK160','AK161','AK164','AK170','AK180','AL170'))
    field_information['GGDM 3.0']['RecreationPnt']['ZI026_CTUU'] = ('integer',('AK020','AK030','AK040','AK060','AK080','AK110','AK150','AK160','AK161','AK164','AK170','AK180','AL170'))
    field_information['GGDM 3.0']['RecreationPnt']['ZI031S_URI'] = ('StructuredText',('AK020','AK030','AK040','AK060','AK080','AK110','AK150','AK160','AK161','AK164','AK170','AK180','AL170'))
    field_information['GGDM 3.0']['RecreationPnt']['ZI039S_UFI'] = ('StructuredText',('AK020','AK030','AK040','AK060','AK080','AK110','AK150','AK160','AK161','AK164','AK170','AK180','AL170'))
    field_information['GGDM 3.0']['RecreationPnt']['ZSAX_RS0'] = ('CodeList',('AK020','AK030','AK040','AK060','AK080','AK110','AK150','AK160','AK161','AK164','AK170','AK180','AL170'))
    field_information['GGDM 3.0']['RecreationPnt']['ZSAX_RX0'] = ('StructuredText',('AK020','AK030','AK040','AK060','AK080','AK110','AK150','AK160','AK161','AK164','AK170','AK180','AL170'))
    field_information['GGDM 3.0']['RecreationPnt']['ZSAX_RX3'] = ('StructuredText',('AK020','AK030','AK040','AK060','AK080','AK110','AK150','AK160','AK161','AK164','AK170','AK180','AL170'))
    field_information['GGDM 3.0']['RecreationPnt']['ZSAX_RX4'] = ('StructuredText',('AK020','AK030','AK040','AK060','AK080','AK110','AK150','AK160','AK161','AK164','AK170','AK180','AL170'))
    field_information['GGDM 3.0']['RecreationPnt']['ZVH'] = ('Real',('AK020','AK030','AK040','AK080','AK110','AK150','AK160','AK161','AK164','AK180'))
    field_information['GGDM 3.0']['RecreationSrf']['ADR'] = ('String',('AK030','AK070','AK090','AK100','AK101','AK130','AK160','AK164','AK170','AK180','AL170'))
    field_information['GGDM 3.0']['RecreationSrf']['AMA'] = ('Enumeration',('AK020'))
    field_information['GGDM 3.0']['RecreationSrf']['EnumeratedIndexValues']['AMA'] = {}
    field_information['GGDM 3.0']['RecreationSrf']['EnumeratedIndexValues']['AMA']['AK020']  = (-999999,1,2,3,4,5,6,999)
    field_information['GGDM 3.0']['RecreationSrf']['AOO'] = ('Real',('AK020','AK030','AK070','AK090','AK100','AK110','AK160','AK164','AK180'))
    field_information['GGDM 3.0']['RecreationSrf']['ARA'] = ('Real',('AK020','AK030','AK040','AK060','AK061','AK070','AK090','AK100','AK101','AK110','AK130','AK155','AK160','AK164','AK170','AK180','AL170'))
    field_information['GGDM 3.0']['RecreationSrf']['AWP'] = ('Boolean',('AK020','AK110','AK160'))
    field_information['GGDM 3.0']['RecreationSrf']['BEN'] = ('StructuredText',('AK020','AK030','AK040','AK060','AK061','AK070','AK090','AK100','AK101','AK110','AK130','AK155','AK160','AK164','AK170','AK180','AL170'))
    field_information['GGDM 3.0']['RecreationSrf']['CAA'] = ('Enumeration',('AK020','AK030','AK070','AK090','AK100','AK110','AK160','AK170','AK180'))
    field_information['GGDM 3.0']['RecreationSrf']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['RecreationSrf']['EnumeratedIndexValues']['CAA']['AK020']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['RecreationSrf']['EnumeratedIndexValues']['CAA']['AK030']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['RecreationSrf']['EnumeratedIndexValues']['CAA']['AK070']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['RecreationSrf']['EnumeratedIndexValues']['CAA']['AK090']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['RecreationSrf']['EnumeratedIndexValues']['CAA']['AK100']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['RecreationSrf']['EnumeratedIndexValues']['CAA']['AK110']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['RecreationSrf']['EnumeratedIndexValues']['CAA']['AK160']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['RecreationSrf']['EnumeratedIndexValues']['CAA']['AK170']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['RecreationSrf']['EnumeratedIndexValues']['CAA']['AK180']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['RecreationSrf']['CCT'] = ('Enumeration',('AK160'))
    field_information['GGDM 3.0']['RecreationSrf']['EnumeratedIndexValues']['CCT'] = {}
    field_information['GGDM 3.0']['RecreationSrf']['EnumeratedIndexValues']['CCT']['AK160']  = (-999999,1,2,3,4)
    field_information['GGDM 3.0']['RecreationSrf']['CNCP'] = ('StructuredText',('AK020','AK030','AK040','AK060','AK061','AK070','AK090','AK100','AK101','AK110','AK130','AK155','AK160','AK164','AK170','AK180','AL170'))
    field_information['GGDM 3.0']['RecreationSrf']['COS'] = ('Enumeration',('AK020','AK030','AK040','AK060','AK061','AK070','AK090','AK100','AK101','AK110','AK130','AK155','AK160','AK164','AK170','AK180','AL170'))
    field_information['GGDM 3.0']['RecreationSrf']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['RecreationSrf']['EnumeratedIndexValues']['COS']['AK020']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['RecreationSrf']['EnumeratedIndexValues']['COS']['AK030']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['RecreationSrf']['EnumeratedIndexValues']['COS']['AK040']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['RecreationSrf']['EnumeratedIndexValues']['COS']['AK060']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['RecreationSrf']['EnumeratedIndexValues']['COS']['AK061']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['RecreationSrf']['EnumeratedIndexValues']['COS']['AK070']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['RecreationSrf']['EnumeratedIndexValues']['COS']['AK090']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['RecreationSrf']['EnumeratedIndexValues']['COS']['AK100']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['RecreationSrf']['EnumeratedIndexValues']['COS']['AK101']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['RecreationSrf']['EnumeratedIndexValues']['COS']['AK110']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['RecreationSrf']['EnumeratedIndexValues']['COS']['AK130']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['RecreationSrf']['EnumeratedIndexValues']['COS']['AK155']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['RecreationSrf']['EnumeratedIndexValues']['COS']['AK160']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['RecreationSrf']['EnumeratedIndexValues']['COS']['AK164']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['RecreationSrf']['EnumeratedIndexValues']['COS']['AK170']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['RecreationSrf']['EnumeratedIndexValues']['COS']['AK180']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['RecreationSrf']['EnumeratedIndexValues']['COS']['AL170']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['RecreationSrf']['DZP'] = ('Real',('AK170'))
    field_information['GGDM 3.0']['RecreationSrf']['F_CODE'] = ('CONSTRAINED_STRING',('AK020','AK030','AK040','AK060','AK061','AK070','AK090','AK100','AK101','AK110','AK130','AK155','AK160','AK164','AK170','AK180','AL170'))
    field_information['GGDM 3.0']['RecreationSrf']['FFN'] = ('Enumeration',('AK030','AK070','AK090','AK160'))
    field_information['GGDM 3.0']['RecreationSrf']['EnumeratedIndexValues']['FFN'] = {}
    field_information['GGDM 3.0']['RecreationSrf']['EnumeratedIndexValues']['FFN']['AK030']  = (-999999,382,464,465,466,475,480,551,552,570,572,573,574,594,643,780,863,890,891,894,895,900,905,906,907,909,912,915,921,922,923,930,970,999)
    field_information['GGDM 3.0']['RecreationSrf']['EnumeratedIndexValues']['FFN']['AK070']  = (-999999,382,466,594,847,921,922,923,970,999)
    field_information['GGDM 3.0']['RecreationSrf']['EnumeratedIndexValues']['FFN']['AK090']  = (-999999,382,475,480,570,572,574,643,780,810,847,862,863,891,892,905,919,921,922,923,930,970,999)
    field_information['GGDM 3.0']['RecreationSrf']['EnumeratedIndexValues']['FFN']['AK160']  = (-999999,570,572,900,912,921,930,954,999)
    field_information['GGDM 3.0']['RecreationSrf']['FFN2'] = ('Enumeration',('AK030','AK070','AK090','AK160'))
    field_information['GGDM 3.0']['RecreationSrf']['EnumeratedIndexValues']['FFN2'] = {}
    field_information['GGDM 3.0']['RecreationSrf']['EnumeratedIndexValues']['FFN2']['AK030']  = (-999999,382,464,465,466,475,480,551,552,570,572,573,574,594,643,780,863,890,891,894,895,900,905,906,907,909,912,915,921,922,923,930,970,999)
    field_information['GGDM 3.0']['RecreationSrf']['EnumeratedIndexValues']['FFN2']['AK070']  = (-999999,382,466,594,847,921,922,923,970,999)
    field_information['GGDM 3.0']['RecreationSrf']['EnumeratedIndexValues']['FFN2']['AK090']  = (-999999,382,475,480,570,572,574,643,780,810,847,862,863,891,892,905,919,921,922,923,930,970,999)
    field_information['GGDM 3.0']['RecreationSrf']['EnumeratedIndexValues']['FFN2']['AK160']  = (-999999,570,572,900,912,921,930,954,999)
    field_information['GGDM 3.0']['RecreationSrf']['FFN3'] = ('Enumeration',('AK030','AK070','AK090','AK160'))
    field_information['GGDM 3.0']['RecreationSrf']['EnumeratedIndexValues']['FFN3'] = {}
    field_information['GGDM 3.0']['RecreationSrf']['EnumeratedIndexValues']['FFN3']['AK030']  = (-999999,382,464,465,466,475,480,551,552,570,572,573,574,594,643,780,863,890,891,894,895,900,905,906,907,909,912,915,921,922,923,930,970,999)
    field_information['GGDM 3.0']['RecreationSrf']['EnumeratedIndexValues']['FFN3']['AK070']  = (-999999,382,466,594,847,921,922,923,970,999)
    field_information['GGDM 3.0']['RecreationSrf']['EnumeratedIndexValues']['FFN3']['AK090']  = (-999999,382,475,480,570,572,574,643,780,810,847,862,863,891,892,905,919,921,922,923,930,970,999)
    field_information['GGDM 3.0']['RecreationSrf']['EnumeratedIndexValues']['FFN3']['AK160']  = (-999999,570,572,900,912,921,930,954,999)
    field_information['GGDM 3.0']['RecreationSrf']['FUFI'] = ('StructuredText',('AK020','AK030','AK040','AK060','AK061','AK070','AK090','AK100','AK101','AK110','AK130','AK155','AK160','AK164','AK170','AK180','AL170'))
    field_information['GGDM 3.0']['RecreationSrf']['FURL'] = ('StructuredText',('AK020','AK030','AK040','AK060','AK061','AK070','AK090','AK100','AK101','AK110','AK130','AK155','AK160','AK164','AK170','AK180','AL170'))
    field_information['GGDM 3.0']['RecreationSrf']['GDBV'] = ('Enumeration',('AK020','AK030','AK040','AK060','AK061','AK070','AK090','AK100','AK101','AK110','AK130','AK155','AK160','AK164','AK170','AK180','AL170'))
    field_information['GGDM 3.0']['RecreationSrf']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['RecreationSrf']['EnumeratedIndexValues']['GDBV']['AK020']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['RecreationSrf']['EnumeratedIndexValues']['GDBV']['AK030']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['RecreationSrf']['EnumeratedIndexValues']['GDBV']['AK040']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['RecreationSrf']['EnumeratedIndexValues']['GDBV']['AK060']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['RecreationSrf']['EnumeratedIndexValues']['GDBV']['AK061']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['RecreationSrf']['EnumeratedIndexValues']['GDBV']['AK070']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['RecreationSrf']['EnumeratedIndexValues']['GDBV']['AK090']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['RecreationSrf']['EnumeratedIndexValues']['GDBV']['AK100']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['RecreationSrf']['EnumeratedIndexValues']['GDBV']['AK101']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['RecreationSrf']['EnumeratedIndexValues']['GDBV']['AK110']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['RecreationSrf']['EnumeratedIndexValues']['GDBV']['AK130']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['RecreationSrf']['EnumeratedIndexValues']['GDBV']['AK155']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['RecreationSrf']['EnumeratedIndexValues']['GDBV']['AK160']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['RecreationSrf']['EnumeratedIndexValues']['GDBV']['AK164']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['RecreationSrf']['EnumeratedIndexValues']['GDBV']['AK170']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['RecreationSrf']['EnumeratedIndexValues']['GDBV']['AK180']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['RecreationSrf']['EnumeratedIndexValues']['GDBV']['AL170']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['RecreationSrf']['HGT'] = ('Real',('AK020','AK030','AK040','AK070','AK090','AK110','AK130','AK155','AK160','AK164','AK170','AK180'))
    field_information['GGDM 3.0']['RecreationSrf']['LMC'] = ('Boolean',('AK020','AK030','AK040','AK060','AK061','AK070','AK090','AK100','AK101','AK110','AK130','AK155','AK160','AK164','AK170','AK180'))
    field_information['GGDM 3.0']['RecreationSrf']['LOC'] = ('Enumeration',('AK170'))
    field_information['GGDM 3.0']['RecreationSrf']['EnumeratedIndexValues']['LOC'] = {}
    field_information['GGDM 3.0']['RecreationSrf']['EnumeratedIndexValues']['LOC']['AK170']  = (-999999,17,23,40,44,45,46,47)
    field_information['GGDM 3.0']['RecreationSrf']['LZN'] = ('Real',('AK020','AK030','AK040','AK060','AK061','AK070','AK090','AK100','AK101','AK110','AK130','AK155','AK160','AK164','AK170','AK180','AL170'))
    field_information['GGDM 3.0']['RecreationSrf']['OTH'] = ('StructuredText',('AK020','AK030','AK040','AK060','AK061','AK070','AK090','AK100','AK101','AK110','AK130','AK155','AK160','AK164','AK170','AK180','AL170'))
    field_information['GGDM 3.0']['RecreationSrf']['PCF'] = ('Enumeration',('AK020','AK030','AK040','AK060','AK061','AK070','AK090','AK100','AK101','AK110','AK130','AK155','AK160','AK164','AK170','AK180','AL170'))
    field_information['GGDM 3.0']['RecreationSrf']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['RecreationSrf']['EnumeratedIndexValues']['PCF']['AK020']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['RecreationSrf']['EnumeratedIndexValues']['PCF']['AK030']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['RecreationSrf']['EnumeratedIndexValues']['PCF']['AK040']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['RecreationSrf']['EnumeratedIndexValues']['PCF']['AK060']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['RecreationSrf']['EnumeratedIndexValues']['PCF']['AK061']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['RecreationSrf']['EnumeratedIndexValues']['PCF']['AK070']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['RecreationSrf']['EnumeratedIndexValues']['PCF']['AK090']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['RecreationSrf']['EnumeratedIndexValues']['PCF']['AK100']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['RecreationSrf']['EnumeratedIndexValues']['PCF']['AK101']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['RecreationSrf']['EnumeratedIndexValues']['PCF']['AK110']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['RecreationSrf']['EnumeratedIndexValues']['PCF']['AK130']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['RecreationSrf']['EnumeratedIndexValues']['PCF']['AK155']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['RecreationSrf']['EnumeratedIndexValues']['PCF']['AK160']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['RecreationSrf']['EnumeratedIndexValues']['PCF']['AK164']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['RecreationSrf']['EnumeratedIndexValues']['PCF']['AK170']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['RecreationSrf']['EnumeratedIndexValues']['PCF']['AK180']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['RecreationSrf']['EnumeratedIndexValues']['PCF']['AL170']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['RecreationSrf']['RAY'] = ('Enumeration',('AK130'))
    field_information['GGDM 3.0']['RecreationSrf']['EnumeratedIndexValues']['RAY'] = {}
    field_information['GGDM 3.0']['RecreationSrf']['EnumeratedIndexValues']['RAY']['AK130']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['RecreationSrf']['SSR'] = ('Enumeration',('AK160'))
    field_information['GGDM 3.0']['RecreationSrf']['EnumeratedIndexValues']['SSR'] = {}
    field_information['GGDM 3.0']['RecreationSrf']['EnumeratedIndexValues']['SSR']['AK160']  = (-999999,6,7,38,40,41,42,47,50,55,64,999)
    field_information['GGDM 3.0']['RecreationSrf']['SSR2'] = ('Enumeration',('AK160'))
    field_information['GGDM 3.0']['RecreationSrf']['EnumeratedIndexValues']['SSR2'] = {}
    field_information['GGDM 3.0']['RecreationSrf']['EnumeratedIndexValues']['SSR2']['AK160']  = (-999999,6,7,38,40,41,42,47,50,55,64,999)
    field_information['GGDM 3.0']['RecreationSrf']['SSR3'] = ('Enumeration',('AK160'))
    field_information['GGDM 3.0']['RecreationSrf']['EnumeratedIndexValues']['SSR3'] = {}
    field_information['GGDM 3.0']['RecreationSrf']['EnumeratedIndexValues']['SSR3']['AK160']  = (-999999,6,7,38,40,41,42,47,50,55,64,999)
    field_information['GGDM 3.0']['RecreationSrf']['UFI'] = ('StructuredText',('AK020','AK030','AK040','AK060','AK061','AK070','AK090','AK100','AK101','AK110','AK130','AK155','AK160','AK164','AK170','AK180','AL170'))
    field_information['GGDM 3.0']['RecreationSrf']['VLM'] = ('Real',('AK170'))
    field_information['GGDM 3.0']['RecreationSrf']['VOI'] = ('StructuredText',('AK020','AK110','AK160'))
    field_information['GGDM 3.0']['RecreationSrf']['WID'] = ('Real',('AK020','AK030','AK040','AK060','AK061','AK070','AK090','AK100','AK101','AK110','AK130','AK155','AK160','AK164','AK170','AK180','AL170'))
    field_information['GGDM 3.0']['RecreationSrf']['ZI001_SDV'] = ('StructuredText',('AK020','AK030','AK040','AK060','AK061','AK070','AK090','AK100','AK101','AK110','AK130','AK155','AK160','AK164','AK170','AK180','AL170'))
    field_information['GGDM 3.0']['RecreationSrf']['ZI001_SRT'] = ('Enumeration',('AK020','AK030','AK040','AK060','AK061','AK070','AK090','AK100','AK101','AK110','AK130','AK155','AK160','AK164','AK170','AK180','AL170'))
    field_information['GGDM 3.0']['RecreationSrf']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['RecreationSrf']['EnumeratedIndexValues']['ZI001_SRT']['AK020']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['RecreationSrf']['EnumeratedIndexValues']['ZI001_SRT']['AK030']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['RecreationSrf']['EnumeratedIndexValues']['ZI001_SRT']['AK040']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['RecreationSrf']['EnumeratedIndexValues']['ZI001_SRT']['AK060']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['RecreationSrf']['EnumeratedIndexValues']['ZI001_SRT']['AK061']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['RecreationSrf']['EnumeratedIndexValues']['ZI001_SRT']['AK070']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['RecreationSrf']['EnumeratedIndexValues']['ZI001_SRT']['AK090']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['RecreationSrf']['EnumeratedIndexValues']['ZI001_SRT']['AK100']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['RecreationSrf']['EnumeratedIndexValues']['ZI001_SRT']['AK101']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['RecreationSrf']['EnumeratedIndexValues']['ZI001_SRT']['AK110']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['RecreationSrf']['EnumeratedIndexValues']['ZI001_SRT']['AK130']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['RecreationSrf']['EnumeratedIndexValues']['ZI001_SRT']['AK155']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['RecreationSrf']['EnumeratedIndexValues']['ZI001_SRT']['AK160']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['RecreationSrf']['EnumeratedIndexValues']['ZI001_SRT']['AK164']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['RecreationSrf']['EnumeratedIndexValues']['ZI001_SRT']['AK170']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['RecreationSrf']['EnumeratedIndexValues']['ZI001_SRT']['AK180']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['RecreationSrf']['EnumeratedIndexValues']['ZI001_SRT']['AL170']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['RecreationSrf']['ZI002_UFI'] = ('StructuredText',('AK020','AK030','AK040','AK060','AK061','AK070','AK090','AK100','AK101','AK110','AK130','AK155','AK160','AK164','AK170','AK180','AL170'))
    field_information['GGDM 3.0']['RecreationSrf']['ZI004_RCG'] = ('Enumeration',('AK020','AK030','AK040','AK060','AK061','AK070','AK090','AK100','AK101','AK110','AK130','AK155','AK160','AK164','AK170','AK180','AL170'))
    field_information['GGDM 3.0']['RecreationSrf']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['RecreationSrf']['EnumeratedIndexValues']['ZI004_RCG']['AK020']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['RecreationSrf']['EnumeratedIndexValues']['ZI004_RCG']['AK030']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['RecreationSrf']['EnumeratedIndexValues']['ZI004_RCG']['AK040']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['RecreationSrf']['EnumeratedIndexValues']['ZI004_RCG']['AK060']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['RecreationSrf']['EnumeratedIndexValues']['ZI004_RCG']['AK061']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['RecreationSrf']['EnumeratedIndexValues']['ZI004_RCG']['AK070']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['RecreationSrf']['EnumeratedIndexValues']['ZI004_RCG']['AK090']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['RecreationSrf']['EnumeratedIndexValues']['ZI004_RCG']['AK100']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['RecreationSrf']['EnumeratedIndexValues']['ZI004_RCG']['AK101']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['RecreationSrf']['EnumeratedIndexValues']['ZI004_RCG']['AK110']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['RecreationSrf']['EnumeratedIndexValues']['ZI004_RCG']['AK130']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['RecreationSrf']['EnumeratedIndexValues']['ZI004_RCG']['AK155']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['RecreationSrf']['EnumeratedIndexValues']['ZI004_RCG']['AK160']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['RecreationSrf']['EnumeratedIndexValues']['ZI004_RCG']['AK164']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['RecreationSrf']['EnumeratedIndexValues']['ZI004_RCG']['AK170']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['RecreationSrf']['EnumeratedIndexValues']['ZI004_RCG']['AK180']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['RecreationSrf']['EnumeratedIndexValues']['ZI004_RCG']['AL170']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['RecreationSrf']['ZI005_FNA'] = ('String',('AK020','AK030','AK040','AK060','AK061','AK070','AK090','AK100','AK101','AK110','AK130','AK155','AK160','AK164','AK170','AK180','AL170'))
    field_information['GGDM 3.0']['RecreationSrf']['ZI005_GNT'] = ('Enumeration',('AK020','AK030','AK040','AK060','AK061','AK070','AK090','AK100','AK101','AK110','AK130','AK155','AK160','AK164','AK170','AK180','AL170'))
    field_information['GGDM 3.0']['RecreationSrf']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['RecreationSrf']['EnumeratedIndexValues']['ZI005_GNT']['AK020']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['RecreationSrf']['EnumeratedIndexValues']['ZI005_GNT']['AK030']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['RecreationSrf']['EnumeratedIndexValues']['ZI005_GNT']['AK040']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['RecreationSrf']['EnumeratedIndexValues']['ZI005_GNT']['AK060']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['RecreationSrf']['EnumeratedIndexValues']['ZI005_GNT']['AK061']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['RecreationSrf']['EnumeratedIndexValues']['ZI005_GNT']['AK070']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['RecreationSrf']['EnumeratedIndexValues']['ZI005_GNT']['AK090']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['RecreationSrf']['EnumeratedIndexValues']['ZI005_GNT']['AK100']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['RecreationSrf']['EnumeratedIndexValues']['ZI005_GNT']['AK101']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['RecreationSrf']['EnumeratedIndexValues']['ZI005_GNT']['AK110']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['RecreationSrf']['EnumeratedIndexValues']['ZI005_GNT']['AK130']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['RecreationSrf']['EnumeratedIndexValues']['ZI005_GNT']['AK155']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['RecreationSrf']['EnumeratedIndexValues']['ZI005_GNT']['AK160']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['RecreationSrf']['EnumeratedIndexValues']['ZI005_GNT']['AK164']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['RecreationSrf']['EnumeratedIndexValues']['ZI005_GNT']['AK170']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['RecreationSrf']['EnumeratedIndexValues']['ZI005_GNT']['AK180']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['RecreationSrf']['EnumeratedIndexValues']['ZI005_GNT']['AL170']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['RecreationSrf']['ZI005_NFN'] = ('String',('AK020','AK030','AK040','AK060','AK061','AK070','AK090','AK100','AK101','AK110','AK130','AK155','AK160','AK164','AK170','AK180','AL170'))
    field_information['GGDM 3.0']['RecreationSrf']['ZI006_MEM'] = ('String',('AK020','AK030','AK040','AK060','AK061','AK070','AK090','AK100','AK101','AK110','AK130','AK155','AK160','AK164','AK170','AK180','AL170'))
    field_information['GGDM 3.0']['RecreationSrf']['ZI020_GE4'] = ('CodeList',('AK020','AK030','AK040','AK060','AK061','AK070','AK090','AK100','AK101','AK110','AK130','AK155','AK160','AK164','AK170','AK180','AL170'))
    field_information['GGDM 3.0']['RecreationSrf']['ZI024_ASE'] = ('Real',('AK170'))
    field_information['GGDM 3.0']['RecreationSrf']['ZI024_CFR'] = ('Real',('AK170'))
    field_information['GGDM 3.0']['RecreationSrf']['ZI024_CLO'] = ('Real',('AK170'))
    field_information['GGDM 3.0']['RecreationSrf']['ZI024_CYN'] = ('Real',('AK170'))
    field_information['GGDM 3.0']['RecreationSrf']['ZI024_FMR'] = ('Real',('AK170'))
    field_information['GGDM 3.0']['RecreationSrf']['ZI024_FRR'] = ('Real',('AK170'))
    field_information['GGDM 3.0']['RecreationSrf']['ZI024_HAR'] = ('Real',('AK170'))
    field_information['GGDM 3.0']['RecreationSrf']['ZI024_HYP'] = ('Enumeration',('AK170'))
    field_information['GGDM 3.0']['RecreationSrf']['EnumeratedIndexValues']['ZI024_HYP'] = {}
    field_information['GGDM 3.0']['RecreationSrf']['EnumeratedIndexValues']['ZI024_HYP']['AK170']  = (-999999,1,2,4)
    field_information['GGDM 3.0']['RecreationSrf']['ZI024_MGN'] = ('Real',('AK170'))
    field_information['GGDM 3.0']['RecreationSrf']['ZI024_PHW'] = ('Real',('AK170'))
    field_information['GGDM 3.0']['RecreationSrf']['ZI024_SCC'] = ('Enumeration',('AK170'))
    field_information['GGDM 3.0']['RecreationSrf']['EnumeratedIndexValues']['ZI024_SCC'] = {}
    field_information['GGDM 3.0']['RecreationSrf']['EnumeratedIndexValues']['ZI024_SCC']['AK170']  = (-999999,1,4,10,11,12,13,14,998,999)
    field_information['GGDM 3.0']['RecreationSrf']['ZI024_SUL'] = ('Real',('AK170'))
    field_information['GGDM 3.0']['RecreationSrf']['ZI024_TDS'] = ('Real',('AK170'))
    field_information['GGDM 3.0']['RecreationSrf']['ZI024_TEP'] = ('Real',('AK170'))
    field_information['GGDM 3.0']['RecreationSrf']['ZI024_TUR'] = ('Real',('AK170'))
    field_information['GGDM 3.0']['RecreationSrf']['ZI024_WAC'] = ('Real',('AK170'))
    field_information['GGDM 3.0']['RecreationSrf']['ZI024_WTNO'] = ('Real',('AK170'))
    field_information['GGDM 3.0']['RecreationSrf']['ZI024_WUR'] = ('Enumeration',('AK170'))
    field_information['GGDM 3.0']['RecreationSrf']['EnumeratedIndexValues']['ZI024_WUR'] = {}
    field_information['GGDM 3.0']['RecreationSrf']['EnumeratedIndexValues']['ZI024_WUR']['AK170']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['RecreationSrf']['ZI024_WUR2'] = ('Enumeration',('AK170'))
    field_information['GGDM 3.0']['RecreationSrf']['EnumeratedIndexValues']['ZI024_WUR2'] = {}
    field_information['GGDM 3.0']['RecreationSrf']['EnumeratedIndexValues']['ZI024_WUR2']['AK170']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['RecreationSrf']['ZI024_WUR3'] = ('Enumeration',('AK170'))
    field_information['GGDM 3.0']['RecreationSrf']['EnumeratedIndexValues']['ZI024_WUR3'] = {}
    field_information['GGDM 3.0']['RecreationSrf']['EnumeratedIndexValues']['ZI024_WUR3']['AK170']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['RecreationSrf']['ZI024_WUR4'] = ('Enumeration',('AK170'))
    field_information['GGDM 3.0']['RecreationSrf']['EnumeratedIndexValues']['ZI024_WUR4'] = {}
    field_information['GGDM 3.0']['RecreationSrf']['EnumeratedIndexValues']['ZI024_WUR4']['AK170']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['RecreationSrf']['ZI026_CTUC'] = ('Enumeration',('AK020','AK030','AK040','AK060','AK061','AK070','AK090','AK100','AK101','AK110','AK130','AK155','AK160','AK164','AK170','AK180','AL170'))
    field_information['GGDM 3.0']['RecreationSrf']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['RecreationSrf']['EnumeratedIndexValues']['ZI026_CTUC']['AK020']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['RecreationSrf']['EnumeratedIndexValues']['ZI026_CTUC']['AK030']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['RecreationSrf']['EnumeratedIndexValues']['ZI026_CTUC']['AK040']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['RecreationSrf']['EnumeratedIndexValues']['ZI026_CTUC']['AK060']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['RecreationSrf']['EnumeratedIndexValues']['ZI026_CTUC']['AK061']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['RecreationSrf']['EnumeratedIndexValues']['ZI026_CTUC']['AK070']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['RecreationSrf']['EnumeratedIndexValues']['ZI026_CTUC']['AK090']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['RecreationSrf']['EnumeratedIndexValues']['ZI026_CTUC']['AK100']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['RecreationSrf']['EnumeratedIndexValues']['ZI026_CTUC']['AK101']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['RecreationSrf']['EnumeratedIndexValues']['ZI026_CTUC']['AK110']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['RecreationSrf']['EnumeratedIndexValues']['ZI026_CTUC']['AK130']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['RecreationSrf']['EnumeratedIndexValues']['ZI026_CTUC']['AK155']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['RecreationSrf']['EnumeratedIndexValues']['ZI026_CTUC']['AK160']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['RecreationSrf']['EnumeratedIndexValues']['ZI026_CTUC']['AK164']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['RecreationSrf']['EnumeratedIndexValues']['ZI026_CTUC']['AK170']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['RecreationSrf']['EnumeratedIndexValues']['ZI026_CTUC']['AK180']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['RecreationSrf']['EnumeratedIndexValues']['ZI026_CTUC']['AL170']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['RecreationSrf']['ZI026_CTUL'] = ('integer',('AK020','AK030','AK040','AK060','AK061','AK070','AK090','AK100','AK101','AK110','AK130','AK155','AK160','AK164','AK170','AK180','AL170'))
    field_information['GGDM 3.0']['RecreationSrf']['ZI026_CTUU'] = ('integer',('AK020','AK030','AK040','AK060','AK061','AK070','AK090','AK100','AK101','AK110','AK130','AK155','AK160','AK164','AK170','AK180','AL170'))
    field_information['GGDM 3.0']['RecreationSrf']['ZI031S_URI'] = ('StructuredText',('AK020','AK030','AK040','AK060','AK061','AK070','AK090','AK100','AK101','AK110','AK130','AK155','AK160','AK164','AK170','AK180','AL170'))
    field_information['GGDM 3.0']['RecreationSrf']['ZI039S_UFI'] = ('StructuredText',('AK020','AK030','AK040','AK060','AK061','AK070','AK090','AK100','AK101','AK110','AK130','AK155','AK160','AK164','AK170','AK180','AL170'))
    field_information['GGDM 3.0']['RecreationSrf']['ZSAX_RS0'] = ('CodeList',('AK020','AK030','AK040','AK060','AK061','AK070','AK090','AK100','AK101','AK110','AK130','AK155','AK160','AK164','AK170','AK180','AL170'))
    field_information['GGDM 3.0']['RecreationSrf']['ZSAX_RX0'] = ('StructuredText',('AK020','AK030','AK040','AK060','AK061','AK070','AK090','AK100','AK101','AK110','AK130','AK155','AK160','AK164','AK170','AK180','AL170'))
    field_information['GGDM 3.0']['RecreationSrf']['ZSAX_RX3'] = ('StructuredText',('AK020','AK030','AK040','AK060','AK061','AK070','AK090','AK100','AK101','AK110','AK130','AK155','AK160','AK164','AK170','AK180','AL170'))
    field_information['GGDM 3.0']['RecreationSrf']['ZSAX_RX4'] = ('StructuredText',('AK020','AK030','AK040','AK060','AK061','AK070','AK090','AK100','AK101','AK110','AK130','AK155','AK160','AK164','AK170','AK180','AL170'))
    field_information['GGDM 3.0']['RecreationSrf']['ZVH'] = ('Real',('AK020','AK030','AK040','AK070','AK090','AK110','AK155','AK160','AK164','AK180'))
    field_information['GGDM 3.0']['ReferenceTblExt']['RS6'] = ('Codelist',('TBCDL'))
    field_information['GGDM 3.0']['ReferenceTblExt']['RX0'] = ('Codelist',('TBCDL'))
    field_information['GGDM 3.0']['ReferenceTblExt']['RX1'] = ('Codelist',('TBCDL'))
    field_information['GGDM 3.0']['ReferenceTblExt']['RX2'] = ('Codelist',('TBCDL'))
    field_information['GGDM 3.0']['ReferenceTblExt']['RX3'] = ('Codelist',('TBCDL'))
    field_information['GGDM 3.0']['ReferenceTblExt']['RX4'] = ('Codelist',('TBCDL'))
    field_information['GGDM 3.0']['ReferenceTblExt']['RX5'] = ('Codelist',('TBCDL'))
    field_information['GGDM 3.0']['ReferenceTblExt']['RX6'] = ('Codelist',('TBCDL'))
    field_information['GGDM 3.0']['ReferenceTblExt']['RX7'] = ('Codelist',('TBCDL'))
    field_information['GGDM 3.0']['ReferenceTblExt']['RY1'] = ('Codelist',('TBCDL'))
    field_information['GGDM 3.0']['ReferenceTblExt']['RY2'] = ('Codelist',('TBCDL'))
    field_information['GGDM 3.0']['ResourceSrf']['AHA'] = ('Real',('ZI031'))
    field_information['GGDM 3.0']['ResourceSrf']['AVA'] = ('Real',('ZI031'))
    field_information['GGDM 3.0']['ResourceSrf']['CID'] = ('String',('ZI031'))
    field_information['GGDM 3.0']['ResourceSrf']['CPS'] = ('Enumeration',('ZI031'))
    field_information['GGDM 3.0']['ResourceSrf']['EnumeratedIndexValues']['CPS'] = {}
    field_information['GGDM 3.0']['ResourceSrf']['EnumeratedIndexValues']['CPS']['ZI031']  = (-999999,1,2,3,4,5,998,999)
    field_information['GGDM 3.0']['ResourceSrf']['DQS'] = ('String',('ZI031'))
    field_information['GGDM 3.0']['ResourceSrf']['EQS'] = ('Integer',('ZI031'))
    field_information['GGDM 3.0']['ResourceSrf']['ETS'] = ('Enumeration',('ZI031'))
    field_information['GGDM 3.0']['ResourceSrf']['EnumeratedIndexValues']['ETS'] = {}
    field_information['GGDM 3.0']['ResourceSrf']['EnumeratedIndexValues']['ETS']['ZI031']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,43,44,45,46,47,48,49,50,51,52,53,56,57,58,59,60,61,998,999)
    field_information['GGDM 3.0']['ResourceSrf']['ETZ'] = ('String',('ZI031'))
    field_information['GGDM 3.0']['ResourceSrf']['EVA'] = ('Real',('ZI031'))
    field_information['GGDM 3.0']['ResourceSrf']['F_CODE'] = ('CONSTRAINED_STRING',('ZI031'))
    field_information['GGDM 3.0']['ResourceSrf']['FURL'] = ('StructuredText',('ZI031'))
    field_information['GGDM 3.0']['ResourceSrf']['HVA'] = ('Real',('ZI031'))
    field_information['GGDM 3.0']['ResourceSrf']['HZD'] = ('Enumeration',('ZI031'))
    field_information['GGDM 3.0']['ResourceSrf']['EnumeratedIndexValues']['HZD'] = {}
    field_information['GGDM 3.0']['ResourceSrf']['EnumeratedIndexValues']['HZD']['ZI031']  = (-999999,2,3,4,5,6,7,8,9,10,12,13,14,15,16,17,19,20,21,22,23,24,25,26,27,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57,58,59,60,61,62,63,64,65,66,67,68,69,70,71,72,73,75,76,77,78,79,80,81,82,83,84,85,86,87,88,89,90,91,92,93,94,95,96,97,98,99,100,101,102,103,104,105,106,107,108,109,110,111,112,113,114,115,116,118,119,120,121,123,125,126,128,129,130,131,132,133,134,135,136,137,138,139,140,141,142,143,144,145,146,147,149,150,151,152,153,154,155,156,157,158,159,161,162,163,164,165,166,167,169,170,171,172,174,175,176,177,178,179,181,182,183,184,185,186,187,188,189,190,191,192,193,194,195,196,197,198,199,200,201,202,204,205,206,207,209,210,211,212,213,215,216,217,218,219,220,221,222,223,224,225,226,227,228,230,231,232,233,234,235,236,237,238,239,240,241,242,243,244,245,246,247,248,249,250,251,253,254,255,256,257,258,259,260,261,262,263,264,265,266,267,268,269,270,271,272,273,274,276,277,278,279,280,281,282,283,285,286,287,288,289,290,292,293,294,295,296,297,298,299,300,301,302,305,306,307,308,309,310,311,312,313,314,315,998,999)
    field_information['GGDM 3.0']['ResourceSrf']['MDE'] = ('StructuredText',('ZI031'))
    field_information['GGDM 3.0']['ResourceSrf']['MEM'] = ('String',('ZI031'))
    field_information['GGDM 3.0']['ResourceSrf']['OTH'] = ('StructuredText',('ZI031'))
    field_information['GGDM 3.0']['ResourceSrf']['RCG'] = ('Enumeration',('ZI031'))
    field_information['GGDM 3.0']['ResourceSrf']['EnumeratedIndexValues']['RCG'] = {}
    field_information['GGDM 3.0']['ResourceSrf']['EnumeratedIndexValues']['RCG']['ZI031']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['ResourceSrf']['RTL'] = ('String',('ZI031'))
    field_information['GGDM 3.0']['ResourceSrf']['SCVN'] = ('StructuredText',('ZI031'))
    field_information['GGDM 3.0']['ResourceSrf']['URI'] = ('StructuredText',('ZI031'))
    field_information['GGDM 3.0']['ResourceSrf']['VDT'] = ('Enumeration',('ZI031'))
    field_information['GGDM 3.0']['ResourceSrf']['EnumeratedIndexValues']['VDT'] = {}
    field_information['GGDM 3.0']['ResourceSrf']['EnumeratedIndexValues']['VDT']['ZI031']  = (-999999,1,2,3,4,5,6,7,998,999)
    field_information['GGDM 3.0']['ResourceSrf']['ZI002_UFI'] = ('StructuredText',('ZI031'))
    field_information['GGDM 3.0']['ResourceSrf']['ZI020_GE4'] = ('CodeList',('ZI031'))
    field_information['GGDM 3.0']['ResourceSrf']['ZI020_GE42'] = ('CodeList',('ZI031'))
    field_information['GGDM 3.0']['ResourceSrf']['ZI020_GE43'] = ('CodeList',('ZI031'))
    field_information['GGDM 3.0']['ResourceSrf']['ZI020_GE44'] = ('CodeList',('ZI031'))
    field_information['GGDM 3.0']['ResourceSrf']['ZSAX_RS0'] = ('CodeList',('ZI031'))
    field_information['GGDM 3.0']['ResourceSrf']['ZSAX_RX0'] = ('StructuredText',('ZI031'))
    field_information['GGDM 3.0']['ResourceSrf']['ZSAX_RX3'] = ('StructuredText',('ZI031'))
    field_information['GGDM 3.0']['ResourceSrf']['ZSAX_RX4'] = ('StructuredText',('ZI031'))
    field_information['GGDM 3.0']['DATASET_T']['AHA'] = ('Real',('ZI031'))
    field_information['GGDM 3.0']['DATASET_T']['AVA'] = ('Real',('ZI031'))
    field_information['GGDM 3.0']['DATASET_T']['CID'] = ('String',('ZI031'))
    field_information['GGDM 3.0']['DATASET_T']['CPS'] = ('Enumeration',('ZI031'))
    field_information['GGDM 3.0']['DATASET_T']['EnumeratedIndexValues']['CPS'] = {}
    field_information['GGDM 3.0']['DATASET_T']['EnumeratedIndexValues']['CPS']['ZI031']  = (-999999,1,2,3,4,5,998,999)
    field_information['GGDM 3.0']['DATASET_T']['DQS'] = ('String',('ZI031'))
    field_information['GGDM 3.0']['DATASET_T']['EQS'] = ('Integer',('ZI031'))
    field_information['GGDM 3.0']['DATASET_T']['ETS'] = ('Enumeration',('ZI031'))
    field_information['GGDM 3.0']['DATASET_T']['EnumeratedIndexValues']['ETS'] = {}
    field_information['GGDM 3.0']['DATASET_T']['EnumeratedIndexValues']['ETS']['ZI031']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,43,44,45,46,47,48,49,50,51,52,53,56,57,58,59,60,61,998,999)
    field_information['GGDM 3.0']['DATASET_T']['ETZ'] = ('String',('ZI031'))
    field_information['GGDM 3.0']['DATASET_T']['EVA'] = ('Real',('ZI031'))
    field_information['GGDM 3.0']['DATASET_T']['F_CODE'] = ('CONSTRAINED_STRING',('ZI031'))
    field_information['GGDM 3.0']['DATASET_T']['FURL'] = ('StructuredText',('ZI031'))
    field_information['GGDM 3.0']['DATASET_T']['HVA'] = ('Real',('ZI031'))
    field_information['GGDM 3.0']['DATASET_T']['HZD'] = ('Enumeration',('ZI031'))
    field_information['GGDM 3.0']['DATASET_T']['EnumeratedIndexValues']['HZD'] = {}
    field_information['GGDM 3.0']['DATASET_T']['EnumeratedIndexValues']['HZD']['ZI031']  = (-999999,2,3,4,5,6,7,8,9,10,12,13,14,15,16,17,19,20,21,22,23,24,25,26,27,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57,58,59,60,61,62,63,64,65,66,67,68,69,70,71,72,73,75,76,77,78,79,80,81,82,83,84,85,86,87,88,89,90,91,92,93,94,95,96,97,98,99,100,101,102,103,104,105,106,107,108,109,110,111,112,113,114,115,116,118,119,120,121,123,125,126,128,129,130,131,132,133,134,135,136,137,138,139,140,141,142,143,144,145,146,147,149,150,151,152,153,154,155,156,157,158,159,161,162,163,164,165,166,167,169,170,171,172,174,175,176,177,178,179,181,182,183,184,185,186,187,188,189,190,191,192,193,194,195,196,197,198,199,200,201,202,204,205,206,207,209,210,211,212,213,215,216,217,218,219,220,221,222,223,224,225,226,227,228,230,231,232,233,234,235,236,237,238,239,240,241,242,243,244,245,246,247,248,249,250,251,253,254,255,256,257,258,259,260,261,262,263,264,265,266,267,268,269,270,271,272,273,274,276,277,278,279,280,281,282,283,285,286,287,288,289,290,292,293,294,295,296,297,298,299,300,301,302,305,306,307,308,309,310,311,312,313,314,315,998,999)
    field_information['GGDM 3.0']['DATASET_T']['MDE'] = ('StructuredText',('ZI031'))
    field_information['GGDM 3.0']['DATASET_T']['MEM'] = ('String',('ZI031'))
    field_information['GGDM 3.0']['DATASET_T']['OTH'] = ('StructuredText',('ZI031'))
    field_information['GGDM 3.0']['DATASET_T']['RCG'] = ('Enumeration',('ZI031'))
    field_information['GGDM 3.0']['DATASET_T']['EnumeratedIndexValues']['RCG'] = {}
    field_information['GGDM 3.0']['DATASET_T']['EnumeratedIndexValues']['RCG']['ZI031']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['DATASET_T']['RTL'] = ('String',('ZI031'))
    field_information['GGDM 3.0']['DATASET_T']['SCVN'] = ('StructuredText',('ZI031'))
    field_information['GGDM 3.0']['DATASET_T']['URI'] = ('StructuredText',('ZI031'))
    field_information['GGDM 3.0']['DATASET_T']['VDT'] = ('Enumeration',('ZI031'))
    field_information['GGDM 3.0']['DATASET_T']['EnumeratedIndexValues']['VDT'] = {}
    field_information['GGDM 3.0']['DATASET_T']['EnumeratedIndexValues']['VDT']['ZI031']  = (-999999,1,2,3,4,5,6,7,998,999)
    field_information['GGDM 3.0']['DATASET_T']['ZI002_UFI'] = ('StructuredText',('ZI031'))
    field_information['GGDM 3.0']['DATASET_T']['ZI020_GE4'] = ('CodeList',('ZI031'))
    field_information['GGDM 3.0']['DATASET_T']['ZI020_GE42'] = ('CodeList',('ZI031'))
    field_information['GGDM 3.0']['DATASET_T']['ZI020_GE43'] = ('CodeList',('ZI031'))
    field_information['GGDM 3.0']['DATASET_T']['ZI020_GE44'] = ('CodeList',('ZI031'))
    field_information['GGDM 3.0']['DATASET_T']['ZSAX_RS0'] = ('CodeList',('ZI031'))
    field_information['GGDM 3.0']['DATASET_T']['ZSAX_RX0'] = ('StructuredText',('ZI031'))
    field_information['GGDM 3.0']['DATASET_T']['ZSAX_RX3'] = ('StructuredText',('ZI031'))
    field_information['GGDM 3.0']['DATASET_T']['ZSAX_RX4'] = ('StructuredText',('ZI031'))
    field_information['GGDM 3.0']['SettlementPnt']['ADR'] = ('String',('AI030'))
    field_information['GGDM 3.0']['SettlementPnt']['AOO'] = ('Real',('AL020'))
    field_information['GGDM 3.0']['SettlementPnt']['ARA'] = ('Real',('AI030','AL020','AL105','AL208'))
    field_information['GGDM 3.0']['SettlementPnt']['BAC'] = ('Enumeration',('AL020'))
    field_information['GGDM 3.0']['SettlementPnt']['EnumeratedIndexValues']['BAC'] = {}
    field_information['GGDM 3.0']['SettlementPnt']['EnumeratedIndexValues']['BAC']['AL020']  = (-999999,1,2,3)
    field_information['GGDM 3.0']['SettlementPnt']['BEN'] = ('StructuredText',('AI030','AL020','AL105','AL208'))
    field_information['GGDM 3.0']['SettlementPnt']['BNF'] = ('Integer',('AL020'))
    field_information['GGDM 3.0']['SettlementPnt']['CAA'] = ('Enumeration',('AI030','AL020','AL105'))
    field_information['GGDM 3.0']['SettlementPnt']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['SettlementPnt']['EnumeratedIndexValues']['CAA']['AI030']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['SettlementPnt']['EnumeratedIndexValues']['CAA']['AL020']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['SettlementPnt']['EnumeratedIndexValues']['CAA']['AL105']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['SettlementPnt']['CNCP'] = ('StructuredText',('AI030','AL020','AL105','AL208'))
    field_information['GGDM 3.0']['SettlementPnt']['COS'] = ('Enumeration',('AI030','AL020','AL105','AL208'))
    field_information['GGDM 3.0']['SettlementPnt']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['SettlementPnt']['EnumeratedIndexValues']['COS']['AI030']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['SettlementPnt']['EnumeratedIndexValues']['COS']['AL020']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['SettlementPnt']['EnumeratedIndexValues']['COS']['AL105']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['SettlementPnt']['EnumeratedIndexValues']['COS']['AL208']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['SettlementPnt']['DNE'] = ('Enumeration',('AL020'))
    field_information['GGDM 3.0']['SettlementPnt']['EnumeratedIndexValues']['DNE'] = {}
    field_information['GGDM 3.0']['SettlementPnt']['EnumeratedIndexValues']['DNE']['AL020']  = (-999999,1,2,3,4,5)
    field_information['GGDM 3.0']['SettlementPnt']['F_CODE'] = ('CONSTRAINED_STRING',('AI030','AL020','AL105','AL208'))
    field_information['GGDM 3.0']['SettlementPnt']['FFN'] = ('Enumeration',('AI030','AL020','AL105'))
    field_information['GGDM 3.0']['SettlementPnt']['EnumeratedIndexValues']['FFN'] = {}
    field_information['GGDM 3.0']['SettlementPnt']['EnumeratedIndexValues']['FFN']['AI030']  = (-999999,16,20,40,60,563,835,881,883,999)
    field_information['GGDM 3.0']['SettlementPnt']['EnumeratedIndexValues']['FFN']['AL020']  = (-999999,99,350,440,563,835,930,999)
    field_information['GGDM 3.0']['SettlementPnt']['EnumeratedIndexValues']['FFN']['AL105']  = (-999999,99,350,440,563,883,930,999)
    field_information['GGDM 3.0']['SettlementPnt']['FFN2'] = ('Enumeration',('AI030','AL020','AL105'))
    field_information['GGDM 3.0']['SettlementPnt']['EnumeratedIndexValues']['FFN2'] = {}
    field_information['GGDM 3.0']['SettlementPnt']['EnumeratedIndexValues']['FFN2']['AI030']  = (-999999,16,20,40,60,563,835,881,883,999)
    field_information['GGDM 3.0']['SettlementPnt']['EnumeratedIndexValues']['FFN2']['AL020']  = (-999999,99,350,440,563,835,930,999)
    field_information['GGDM 3.0']['SettlementPnt']['EnumeratedIndexValues']['FFN2']['AL105']  = (-999999,99,350,440,563,883,930,999)
    field_information['GGDM 3.0']['SettlementPnt']['FFN3'] = ('Enumeration',('AI030','AL020','AL105'))
    field_information['GGDM 3.0']['SettlementPnt']['EnumeratedIndexValues']['FFN3'] = {}
    field_information['GGDM 3.0']['SettlementPnt']['EnumeratedIndexValues']['FFN3']['AI030']  = (-999999,16,20,40,60,563,835,881,883,999)
    field_information['GGDM 3.0']['SettlementPnt']['EnumeratedIndexValues']['FFN3']['AL020']  = (-999999,99,350,440,563,835,930,999)
    field_information['GGDM 3.0']['SettlementPnt']['EnumeratedIndexValues']['FFN3']['AL105']  = (-999999,99,350,440,563,883,930,999)
    field_information['GGDM 3.0']['SettlementPnt']['FUFI'] = ('StructuredText',('AI030','AL020','AL105','AL208'))
    field_information['GGDM 3.0']['SettlementPnt']['FURL'] = ('StructuredText',('AI030','AL020','AL105','AL208'))
    field_information['GGDM 3.0']['SettlementPnt']['GDBV'] = ('Enumeration',('AI030','AL020','AL105','AL208'))
    field_information['GGDM 3.0']['SettlementPnt']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['SettlementPnt']['EnumeratedIndexValues']['GDBV']['AI030']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['SettlementPnt']['EnumeratedIndexValues']['GDBV']['AL020']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['SettlementPnt']['EnumeratedIndexValues']['GDBV']['AL105']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['SettlementPnt']['EnumeratedIndexValues']['GDBV']['AL208']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['SettlementPnt']['HGT'] = ('Real',('AI030','AL020','AL105','AL208'))
    field_information['GGDM 3.0']['SettlementPnt']['HHD'] = ('Boolean',('AL105'))
    field_information['GGDM 3.0']['SettlementPnt']['LMC'] = ('Boolean',('AI030','AL105','AL208'))
    field_information['GGDM 3.0']['SettlementPnt']['LZN'] = ('Real',('AI030','AL020','AL105','AL208'))
    field_information['GGDM 3.0']['SettlementPnt']['OTH'] = ('StructuredText',('AI030','AL020','AL105','AL208'))
    field_information['GGDM 3.0']['SettlementPnt']['PCF'] = ('Enumeration',('AI030','AL020','AL105','AL208'))
    field_information['GGDM 3.0']['SettlementPnt']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['SettlementPnt']['EnumeratedIndexValues']['PCF']['AI030']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['SettlementPnt']['EnumeratedIndexValues']['PCF']['AL020']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['SettlementPnt']['EnumeratedIndexValues']['PCF']['AL105']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['SettlementPnt']['EnumeratedIndexValues']['PCF']['AL208']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['SettlementPnt']['STL'] = ('Enumeration',('AI030'))
    field_information['GGDM 3.0']['SettlementPnt']['EnumeratedIndexValues']['STL'] = {}
    field_information['GGDM 3.0']['SettlementPnt']['EnumeratedIndexValues']['STL']['AI030']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['SettlementPnt']['STL2'] = ('Enumeration',('AI030'))
    field_information['GGDM 3.0']['SettlementPnt']['EnumeratedIndexValues']['STL2'] = {}
    field_information['GGDM 3.0']['SettlementPnt']['EnumeratedIndexValues']['STL2']['AI030']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['SettlementPnt']['STL3'] = ('Enumeration',('AI030'))
    field_information['GGDM 3.0']['SettlementPnt']['EnumeratedIndexValues']['STL3'] = {}
    field_information['GGDM 3.0']['SettlementPnt']['EnumeratedIndexValues']['STL3']['AI030']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['SettlementPnt']['UFI'] = ('StructuredText',('AI030','AL020','AL105','AL208'))
    field_information['GGDM 3.0']['SettlementPnt']['WID'] = ('Real',('AI030','AL020','AL105','AL208'))
    field_information['GGDM 3.0']['SettlementPnt']['WPI'] = ('String',('AL020'))
    field_information['GGDM 3.0']['SettlementPnt']['ZI001_SDV'] = ('StructuredText',('AI030','AL020','AL105','AL208'))
    field_information['GGDM 3.0']['SettlementPnt']['ZI001_SRT'] = ('Enumeration',('AI030','AL020','AL105','AL208'))
    field_information['GGDM 3.0']['SettlementPnt']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['SettlementPnt']['EnumeratedIndexValues']['ZI001_SRT']['AI030']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['SettlementPnt']['EnumeratedIndexValues']['ZI001_SRT']['AL020']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['SettlementPnt']['EnumeratedIndexValues']['ZI001_SRT']['AL105']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['SettlementPnt']['EnumeratedIndexValues']['ZI001_SRT']['AL208']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['SettlementPnt']['ZI002_UFI'] = ('StructuredText',('AI030','AL020','AL105','AL208'))
    field_information['GGDM 3.0']['SettlementPnt']['ZI004_RCG'] = ('Enumeration',('AI030','AL020','AL105','AL208'))
    field_information['GGDM 3.0']['SettlementPnt']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['SettlementPnt']['EnumeratedIndexValues']['ZI004_RCG']['AI030']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['SettlementPnt']['EnumeratedIndexValues']['ZI004_RCG']['AL020']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['SettlementPnt']['EnumeratedIndexValues']['ZI004_RCG']['AL105']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['SettlementPnt']['EnumeratedIndexValues']['ZI004_RCG']['AL208']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['SettlementPnt']['ZI005_FNA'] = ('String',('AI030','AL020','AL105','AL208'))
    field_information['GGDM 3.0']['SettlementPnt']['ZI005_FNA2'] = ('String',('AL020'))
    field_information['GGDM 3.0']['SettlementPnt']['ZI005_GNT'] = ('Enumeration',('AI030','AL020','AL105','AL208'))
    field_information['GGDM 3.0']['SettlementPnt']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['SettlementPnt']['EnumeratedIndexValues']['ZI005_GNT']['AI030']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['SettlementPnt']['EnumeratedIndexValues']['ZI005_GNT']['AL020']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['SettlementPnt']['EnumeratedIndexValues']['ZI005_GNT']['AL105']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['SettlementPnt']['EnumeratedIndexValues']['ZI005_GNT']['AL208']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['SettlementPnt']['ZI005_GNT2'] = ('Enumeration',('AL020'))
    field_information['GGDM 3.0']['SettlementPnt']['EnumeratedIndexValues']['ZI005_GNT2'] = {}
    field_information['GGDM 3.0']['SettlementPnt']['EnumeratedIndexValues']['ZI005_GNT2']['AL020']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['SettlementPnt']['ZI005_NFN'] = ('String',('AI030','AL020','AL105','AL208'))
    field_information['GGDM 3.0']['SettlementPnt']['ZI005_NFN2'] = ('String',('AL020'))
    field_information['GGDM 3.0']['SettlementPnt']['ZI006_MEM'] = ('String',('AI030','AL020','AL105','AL208'))
    field_information['GGDM 3.0']['SettlementPnt']['ZI020_GE4'] = ('CodeList',('AI030','AL020','AL105','AL208'))
    field_information['GGDM 3.0']['SettlementPnt']['ZI026_CTUC'] = ('Enumeration',('AI030','AL020','AL105','AL208'))
    field_information['GGDM 3.0']['SettlementPnt']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['SettlementPnt']['EnumeratedIndexValues']['ZI026_CTUC']['AI030']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['SettlementPnt']['EnumeratedIndexValues']['ZI026_CTUC']['AL020']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['SettlementPnt']['EnumeratedIndexValues']['ZI026_CTUC']['AL105']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['SettlementPnt']['EnumeratedIndexValues']['ZI026_CTUC']['AL208']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['SettlementPnt']['ZI026_CTUL'] = ('integer',('AI030','AL020','AL105','AL208'))
    field_information['GGDM 3.0']['SettlementPnt']['ZI026_CTUU'] = ('integer',('AI030','AL020','AL105','AL208'))
    field_information['GGDM 3.0']['SettlementPnt']['ZI031S_URI'] = ('StructuredText',('AI030','AL020','AL105','AL208'))
    field_information['GGDM 3.0']['SettlementPnt']['ZI039S_UFI'] = ('StructuredText',('AI030','AL020','AL105','AL208'))
    field_information['GGDM 3.0']['SettlementPnt']['ZSAX_RS0'] = ('CodeList',('AI030','AL020','AL105','AL208'))
    field_information['GGDM 3.0']['SettlementPnt']['ZSAX_RX0'] = ('StructuredText',('AI030','AL020','AL105','AL208'))
    field_information['GGDM 3.0']['SettlementPnt']['ZSAX_RX3'] = ('StructuredText',('AI030','AL020','AL105','AL208'))
    field_information['GGDM 3.0']['SettlementPnt']['ZSAX_RX4'] = ('StructuredText',('AI030','AL020','AL105','AL208'))
    field_information['GGDM 3.0']['SettlementPnt']['ZVH'] = ('Real',('AI030','AL020','AL105','AL208'))
    field_information['GGDM 3.0']['SettlementSrf']['ADR'] = ('String',('AI020','AI021','AI030'))
    field_information['GGDM 3.0']['SettlementSrf']['AOO'] = ('Real',('AI020','AI021','AL020'))
    field_information['GGDM 3.0']['SettlementSrf']['ARA'] = ('Real',('AI020','AI021','AI030','AL020','AL105','AL208'))
    field_information['GGDM 3.0']['SettlementSrf']['BAC'] = ('Enumeration',('AL020'))
    field_information['GGDM 3.0']['SettlementSrf']['EnumeratedIndexValues']['BAC'] = {}
    field_information['GGDM 3.0']['SettlementSrf']['EnumeratedIndexValues']['BAC']['AL020']  = (-999999,1,2,3)
    field_information['GGDM 3.0']['SettlementSrf']['BEN'] = ('StructuredText',('AI020','AI021','AI030','AL020','AL105','AL208'))
    field_information['GGDM 3.0']['SettlementSrf']['BNF'] = ('Integer',('AL020'))
    field_information['GGDM 3.0']['SettlementSrf']['CAA'] = ('Enumeration',('AI020','AI021','AI030','AL020','AL105'))
    field_information['GGDM 3.0']['SettlementSrf']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['SettlementSrf']['EnumeratedIndexValues']['CAA']['AI020']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['SettlementSrf']['EnumeratedIndexValues']['CAA']['AI021']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['SettlementSrf']['EnumeratedIndexValues']['CAA']['AI030']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['SettlementSrf']['EnumeratedIndexValues']['CAA']['AL020']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['SettlementSrf']['EnumeratedIndexValues']['CAA']['AL105']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['SettlementSrf']['CNCP'] = ('StructuredText',('AI020','AI021','AI030','AL020','AL105','AL208'))
    field_information['GGDM 3.0']['SettlementSrf']['COS'] = ('Enumeration',('AI020','AI021','AI030','AL020','AL105','AL208'))
    field_information['GGDM 3.0']['SettlementSrf']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['SettlementSrf']['EnumeratedIndexValues']['COS']['AI020']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['SettlementSrf']['EnumeratedIndexValues']['COS']['AI021']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['SettlementSrf']['EnumeratedIndexValues']['COS']['AI030']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['SettlementSrf']['EnumeratedIndexValues']['COS']['AL020']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['SettlementSrf']['EnumeratedIndexValues']['COS']['AL105']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['SettlementSrf']['EnumeratedIndexValues']['COS']['AL208']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['SettlementSrf']['DNE'] = ('Enumeration',('AL020'))
    field_information['GGDM 3.0']['SettlementSrf']['EnumeratedIndexValues']['DNE'] = {}
    field_information['GGDM 3.0']['SettlementSrf']['EnumeratedIndexValues']['DNE']['AL020']  = (-999999,1,2,3,4,5)
    field_information['GGDM 3.0']['SettlementSrf']['F_CODE'] = ('CONSTRAINED_STRING',('AI020','AI021','AI030','AL020','AL105','AL208'))
    field_information['GGDM 3.0']['SettlementSrf']['FFN'] = ('Enumeration',('AI020','AI021','AI030','AL020','AL105'))
    field_information['GGDM 3.0']['SettlementSrf']['EnumeratedIndexValues']['FFN'] = {}
    field_information['GGDM 3.0']['SettlementSrf']['EnumeratedIndexValues']['FFN']['AI020']  = (-999999,382,466,470,476,563,570,572,921,930,961,970,999)
    field_information['GGDM 3.0']['SettlementSrf']['EnumeratedIndexValues']['FFN']['AI021']  = (-999999,382,466,470,476,563,570,572,921,930,961,999)
    field_information['GGDM 3.0']['SettlementSrf']['EnumeratedIndexValues']['FFN']['AI030']  = (-999999,16,20,40,60,563,835,881,883,999)
    field_information['GGDM 3.0']['SettlementSrf']['EnumeratedIndexValues']['FFN']['AL020']  = (-999999,99,350,440,563,835,930,999)
    field_information['GGDM 3.0']['SettlementSrf']['EnumeratedIndexValues']['FFN']['AL105']  = (-999999,99,350,440,563,883,930,999)
    field_information['GGDM 3.0']['SettlementSrf']['FFN2'] = ('Enumeration',('AI020','AI021','AI030','AL020','AL105'))
    field_information['GGDM 3.0']['SettlementSrf']['EnumeratedIndexValues']['FFN2'] = {}
    field_information['GGDM 3.0']['SettlementSrf']['EnumeratedIndexValues']['FFN2']['AI020']  = (-999999,382,466,470,476,563,570,572,921,930,961,970,999)
    field_information['GGDM 3.0']['SettlementSrf']['EnumeratedIndexValues']['FFN2']['AI021']  = (-999999,382,466,470,476,563,570,572,921,930,961,999)
    field_information['GGDM 3.0']['SettlementSrf']['EnumeratedIndexValues']['FFN2']['AI030']  = (-999999,16,20,40,60,563,835,881,883,999)
    field_information['GGDM 3.0']['SettlementSrf']['EnumeratedIndexValues']['FFN2']['AL020']  = (-999999,99,350,440,563,835,930,999)
    field_information['GGDM 3.0']['SettlementSrf']['EnumeratedIndexValues']['FFN2']['AL105']  = (-999999,99,350,440,563,883,930,999)
    field_information['GGDM 3.0']['SettlementSrf']['FFN3'] = ('Enumeration',('AI020','AI021','AI030','AL020','AL105'))
    field_information['GGDM 3.0']['SettlementSrf']['EnumeratedIndexValues']['FFN3'] = {}
    field_information['GGDM 3.0']['SettlementSrf']['EnumeratedIndexValues']['FFN3']['AI020']  = (-999999,382,466,470,476,563,570,572,921,930,961,970,999)
    field_information['GGDM 3.0']['SettlementSrf']['EnumeratedIndexValues']['FFN3']['AI021']  = (-999999,382,466,470,476,563,570,572,921,930,961,999)
    field_information['GGDM 3.0']['SettlementSrf']['EnumeratedIndexValues']['FFN3']['AI030']  = (-999999,16,20,40,60,563,835,881,883,999)
    field_information['GGDM 3.0']['SettlementSrf']['EnumeratedIndexValues']['FFN3']['AL020']  = (-999999,99,350,440,563,835,930,999)
    field_information['GGDM 3.0']['SettlementSrf']['EnumeratedIndexValues']['FFN3']['AL105']  = (-999999,99,350,440,563,883,930,999)
    field_information['GGDM 3.0']['SettlementSrf']['FUFI'] = ('StructuredText',('AI020','AI021','AI030','AL020','AL105','AL208'))
    field_information['GGDM 3.0']['SettlementSrf']['FURL'] = ('StructuredText',('AI020','AI021','AI030','AL020','AL105','AL208'))
    field_information['GGDM 3.0']['SettlementSrf']['GDBV'] = ('Enumeration',('AI020','AI021','AI030','AL020','AL105','AL208'))
    field_information['GGDM 3.0']['SettlementSrf']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['SettlementSrf']['EnumeratedIndexValues']['GDBV']['AI020']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['SettlementSrf']['EnumeratedIndexValues']['GDBV']['AI021']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['SettlementSrf']['EnumeratedIndexValues']['GDBV']['AI030']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['SettlementSrf']['EnumeratedIndexValues']['GDBV']['AL020']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['SettlementSrf']['EnumeratedIndexValues']['GDBV']['AL105']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['SettlementSrf']['EnumeratedIndexValues']['GDBV']['AL208']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['SettlementSrf']['HGT'] = ('Real',('AI020','AI021','AI030','AL020','AL105','AL208'))
    field_information['GGDM 3.0']['SettlementSrf']['HHD'] = ('Boolean',('AL105'))
    field_information['GGDM 3.0']['SettlementSrf']['LMC'] = ('Boolean',('AI020','AI021','AI030','AL105','AL208'))
    field_information['GGDM 3.0']['SettlementSrf']['LZN'] = ('Real',('AI020','AI021','AI030','AL020','AL105','AL208'))
    field_information['GGDM 3.0']['SettlementSrf']['OTH'] = ('StructuredText',('AI020','AI021','AI030','AL020','AL105','AL208'))
    field_information['GGDM 3.0']['SettlementSrf']['PCF'] = ('Enumeration',('AI020','AI021','AI030','AL020','AL105','AL208'))
    field_information['GGDM 3.0']['SettlementSrf']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['SettlementSrf']['EnumeratedIndexValues']['PCF']['AI020']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['SettlementSrf']['EnumeratedIndexValues']['PCF']['AI021']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['SettlementSrf']['EnumeratedIndexValues']['PCF']['AI030']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['SettlementSrf']['EnumeratedIndexValues']['PCF']['AL020']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['SettlementSrf']['EnumeratedIndexValues']['PCF']['AL105']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['SettlementSrf']['EnumeratedIndexValues']['PCF']['AL208']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['SettlementSrf']['STL'] = ('Enumeration',('AI030'))
    field_information['GGDM 3.0']['SettlementSrf']['EnumeratedIndexValues']['STL'] = {}
    field_information['GGDM 3.0']['SettlementSrf']['EnumeratedIndexValues']['STL']['AI030']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['SettlementSrf']['STL2'] = ('Enumeration',('AI030'))
    field_information['GGDM 3.0']['SettlementSrf']['EnumeratedIndexValues']['STL2'] = {}
    field_information['GGDM 3.0']['SettlementSrf']['EnumeratedIndexValues']['STL2']['AI030']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['SettlementSrf']['STL3'] = ('Enumeration',('AI030'))
    field_information['GGDM 3.0']['SettlementSrf']['EnumeratedIndexValues']['STL3'] = {}
    field_information['GGDM 3.0']['SettlementSrf']['EnumeratedIndexValues']['STL3']['AI030']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['SettlementSrf']['UFI'] = ('StructuredText',('AI020','AI021','AI030','AL020','AL105','AL208'))
    field_information['GGDM 3.0']['SettlementSrf']['WID'] = ('Real',('AI020','AI021','AI030','AL020','AL105','AL208'))
    field_information['GGDM 3.0']['SettlementSrf']['WPI'] = ('String',('AL020'))
    field_information['GGDM 3.0']['SettlementSrf']['ZI001_SDV'] = ('StructuredText',('AI020','AI021','AI030','AL020','AL105','AL208'))
    field_information['GGDM 3.0']['SettlementSrf']['ZI001_SRT'] = ('Enumeration',('AI020','AI021','AI030','AL020','AL105','AL208'))
    field_information['GGDM 3.0']['SettlementSrf']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['SettlementSrf']['EnumeratedIndexValues']['ZI001_SRT']['AI020']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['SettlementSrf']['EnumeratedIndexValues']['ZI001_SRT']['AI021']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['SettlementSrf']['EnumeratedIndexValues']['ZI001_SRT']['AI030']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['SettlementSrf']['EnumeratedIndexValues']['ZI001_SRT']['AL020']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['SettlementSrf']['EnumeratedIndexValues']['ZI001_SRT']['AL105']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['SettlementSrf']['EnumeratedIndexValues']['ZI001_SRT']['AL208']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['SettlementSrf']['ZI002_UFI'] = ('StructuredText',('AI020','AI021','AI030','AL020','AL105','AL208'))
    field_information['GGDM 3.0']['SettlementSrf']['ZI004_RCG'] = ('Enumeration',('AI020','AI021','AI030','AL020','AL105','AL208'))
    field_information['GGDM 3.0']['SettlementSrf']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['SettlementSrf']['EnumeratedIndexValues']['ZI004_RCG']['AI020']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['SettlementSrf']['EnumeratedIndexValues']['ZI004_RCG']['AI021']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['SettlementSrf']['EnumeratedIndexValues']['ZI004_RCG']['AI030']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['SettlementSrf']['EnumeratedIndexValues']['ZI004_RCG']['AL020']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['SettlementSrf']['EnumeratedIndexValues']['ZI004_RCG']['AL105']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['SettlementSrf']['EnumeratedIndexValues']['ZI004_RCG']['AL208']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['SettlementSrf']['ZI005_FNA'] = ('String',('AI020','AI021','AI030','AL020','AL105','AL208'))
    field_information['GGDM 3.0']['SettlementSrf']['ZI005_FNA2'] = ('String',('AL020'))
    field_information['GGDM 3.0']['SettlementSrf']['ZI005_GNT'] = ('Enumeration',('AI020','AI021','AI030','AL020','AL105','AL208'))
    field_information['GGDM 3.0']['SettlementSrf']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['SettlementSrf']['EnumeratedIndexValues']['ZI005_GNT']['AI020']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['SettlementSrf']['EnumeratedIndexValues']['ZI005_GNT']['AI021']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['SettlementSrf']['EnumeratedIndexValues']['ZI005_GNT']['AI030']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['SettlementSrf']['EnumeratedIndexValues']['ZI005_GNT']['AL020']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['SettlementSrf']['EnumeratedIndexValues']['ZI005_GNT']['AL105']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['SettlementSrf']['EnumeratedIndexValues']['ZI005_GNT']['AL208']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['SettlementSrf']['ZI005_GNT2'] = ('Enumeration',('AL020'))
    field_information['GGDM 3.0']['SettlementSrf']['EnumeratedIndexValues']['ZI005_GNT2'] = {}
    field_information['GGDM 3.0']['SettlementSrf']['EnumeratedIndexValues']['ZI005_GNT2']['AL020']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['SettlementSrf']['ZI005_NFN'] = ('String',('AI020','AI021','AI030','AL020','AL105','AL208'))
    field_information['GGDM 3.0']['SettlementSrf']['ZI005_NFN2'] = ('String',('AL020'))
    field_information['GGDM 3.0']['SettlementSrf']['ZI006_MEM'] = ('String',('AI020','AI021','AI030','AL020','AL105','AL208'))
    field_information['GGDM 3.0']['SettlementSrf']['ZI020_GE4'] = ('CodeList',('AI020','AI021','AI030','AL020','AL105','AL208'))
    field_information['GGDM 3.0']['SettlementSrf']['ZI026_CTUC'] = ('Enumeration',('AI020','AI021','AI030','AL020','AL105','AL208'))
    field_information['GGDM 3.0']['SettlementSrf']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['SettlementSrf']['EnumeratedIndexValues']['ZI026_CTUC']['AI020']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['SettlementSrf']['EnumeratedIndexValues']['ZI026_CTUC']['AI021']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['SettlementSrf']['EnumeratedIndexValues']['ZI026_CTUC']['AI030']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['SettlementSrf']['EnumeratedIndexValues']['ZI026_CTUC']['AL020']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['SettlementSrf']['EnumeratedIndexValues']['ZI026_CTUC']['AL105']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['SettlementSrf']['EnumeratedIndexValues']['ZI026_CTUC']['AL208']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['SettlementSrf']['ZI026_CTUL'] = ('integer',('AI020','AI021','AI030','AL020','AL105','AL208'))
    field_information['GGDM 3.0']['SettlementSrf']['ZI026_CTUU'] = ('integer',('AI020','AI021','AI030','AL020','AL105','AL208'))
    field_information['GGDM 3.0']['SettlementSrf']['ZI031S_URI'] = ('StructuredText',('AI020','AI021','AI030','AL020','AL105','AL208'))
    field_information['GGDM 3.0']['SettlementSrf']['ZI039S_UFI'] = ('StructuredText',('AI020','AI021','AI030','AL020','AL105','AL208'))
    field_information['GGDM 3.0']['SettlementSrf']['ZSAX_RS0'] = ('CodeList',('AI020','AI021','AI030','AL020','AL105','AL208'))
    field_information['GGDM 3.0']['SettlementSrf']['ZSAX_RX0'] = ('StructuredText',('AI020','AI021','AI030','AL020','AL105','AL208'))
    field_information['GGDM 3.0']['SettlementSrf']['ZSAX_RX3'] = ('StructuredText',('AI020','AI021','AI030','AL020','AL105','AL208'))
    field_information['GGDM 3.0']['SettlementSrf']['ZSAX_RX4'] = ('StructuredText',('AI020','AI021','AI030','AL020','AL105','AL208'))
    field_information['GGDM 3.0']['SettlementSrf']['ZVH'] = ('Real',('AI020','AI021','AI030','AL020','AL105','AL208'))
    field_information['GGDM 3.0']['SettlementSrfExt']['ARA'] = ('Real',('AL024'))
    field_information['GGDM 3.0']['SettlementSrfExt']['BEN'] = ('StructuredText',('AL024'))
    field_information['GGDM 3.0']['SettlementSrfExt']['F_CODE'] = ('CONSTRAINED_STRING',('AL024'))
    field_information['GGDM 3.0']['SettlementSrfExt']['FUFI'] = ('StructuredText',('AL024'))
    field_information['GGDM 3.0']['SettlementSrfExt']['FURL'] = ('StructuredText',('AL024'))
    field_information['GGDM 3.0']['SettlementSrfExt']['GDBV'] = ('Enumeration',('AL024'))
    field_information['GGDM 3.0']['SettlementSrfExt']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['SettlementSrfExt']['EnumeratedIndexValues']['GDBV']['AL024']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['SettlementSrfExt']['NDX'] = ('Enumeration',('AL024'))
    field_information['GGDM 3.0']['SettlementSrfExt']['EnumeratedIndexValues']['NDX'] = {}
    field_information['GGDM 3.0']['SettlementSrfExt']['EnumeratedIndexValues']['NDX']['AL024']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['SettlementSrfExt']['NDX2'] = ('Enumeration',('AL024'))
    field_information['GGDM 3.0']['SettlementSrfExt']['EnumeratedIndexValues']['NDX2'] = {}
    field_information['GGDM 3.0']['SettlementSrfExt']['EnumeratedIndexValues']['NDX2']['AL024']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['SettlementSrfExt']['NDX3'] = ('Enumeration',('AL024'))
    field_information['GGDM 3.0']['SettlementSrfExt']['EnumeratedIndexValues']['NDX3'] = {}
    field_information['GGDM 3.0']['SettlementSrfExt']['EnumeratedIndexValues']['NDX3']['AL024']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['SettlementSrfExt']['OTH'] = ('StructuredText',('AL024'))
    field_information['GGDM 3.0']['SettlementSrfExt']['UFI'] = ('StructuredText',('AL024'))
    field_information['GGDM 3.0']['SettlementSrfExt']['ZI001_SDV'] = ('StructuredText',('AL024'))
    field_information['GGDM 3.0']['SettlementSrfExt']['ZI001_SRT'] = ('Enumeration',('AL024'))
    field_information['GGDM 3.0']['SettlementSrfExt']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['SettlementSrfExt']['EnumeratedIndexValues']['ZI001_SRT']['AL024']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['SettlementSrfExt']['ZI002_UFI'] = ('StructuredText',('AL024'))
    field_information['GGDM 3.0']['SettlementSrfExt']['ZI004_RCG'] = ('Enumeration',('AL024'))
    field_information['GGDM 3.0']['SettlementSrfExt']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['SettlementSrfExt']['EnumeratedIndexValues']['ZI004_RCG']['AL024']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['SettlementSrfExt']['ZI005_FNA'] = ('String',('AL024'))
    field_information['GGDM 3.0']['SettlementSrfExt']['ZI005_GNT'] = ('Enumeration',('AL024'))
    field_information['GGDM 3.0']['SettlementSrfExt']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['SettlementSrfExt']['EnumeratedIndexValues']['ZI005_GNT']['AL024']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['SettlementSrfExt']['ZI005_NFN'] = ('String',('AL024'))
    field_information['GGDM 3.0']['SettlementSrfExt']['ZI006_MEM'] = ('String',('AL024'))
    field_information['GGDM 3.0']['SettlementSrfExt']['ZI020_GE4'] = ('CodeList',('AL024'))
    field_information['GGDM 3.0']['SettlementSrfExt']['ZI026_CTUC'] = ('Enumeration',('AL024'))
    field_information['GGDM 3.0']['SettlementSrfExt']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['SettlementSrfExt']['EnumeratedIndexValues']['ZI026_CTUC']['AL024']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['SettlementSrfExt']['ZI026_CTUL'] = ('integer',('AL024'))
    field_information['GGDM 3.0']['SettlementSrfExt']['ZI026_CTUU'] = ('integer',('AL024'))
    field_information['GGDM 3.0']['SettlementSrfExt']['ZI031S_URI'] = ('StructuredText',('AL024'))
    field_information['GGDM 3.0']['SettlementSrfExt']['ZI039S_UFI'] = ('StructuredText',('AL024'))
    field_information['GGDM 3.0']['SettlementSrfExt']['ZSAX_RS0'] = ('CodeList',('AL024'))
    field_information['GGDM 3.0']['SettlementSrfExt']['ZSAX_RX0'] = ('StructuredText',('AL024'))
    field_information['GGDM 3.0']['SettlementSrfExt']['ZSAX_RX3'] = ('StructuredText',('AL024'))
    field_information['GGDM 3.0']['SettlementSrfExt']['ZSAX_RX4'] = ('StructuredText',('AL024'))
    field_information['GGDM 3.0']['StorageAONExt']['ARA'] = ('Real',('NU070'))
    field_information['GGDM 3.0']['StorageAONExt']['AWP'] = ('Boolean',('NU070'))
    field_information['GGDM 3.0']['StorageAONExt']['BEN'] = ('StructuredText',('NU070'))
    field_information['GGDM 3.0']['StorageAONExt']['CAA'] = ('Enumeration',('NU070'))
    field_information['GGDM 3.0']['StorageAONExt']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['StorageAONExt']['EnumeratedIndexValues']['CAA']['NU070']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['StorageAONExt']['CBP'] = ('Boolean',('NU070'))
    field_information['GGDM 3.0']['StorageAONExt']['CNCP'] = ('StructuredText',('NU070'))
    field_information['GGDM 3.0']['StorageAONExt']['COS'] = ('Enumeration',('NU070'))
    field_information['GGDM 3.0']['StorageAONExt']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['StorageAONExt']['EnumeratedIndexValues']['COS']['NU070']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['StorageAONExt']['DMF'] = ('Integer',('NU070'))
    field_information['GGDM 3.0']['StorageAONExt']['F_CODE'] = ('CONSTRAINED_STRING',('NU070'))
    field_information['GGDM 3.0']['StorageAONExt']['FUFI'] = ('StructuredText',('NU070'))
    field_information['GGDM 3.0']['StorageAONExt']['FURL'] = ('StructuredText',('NU070'))
    field_information['GGDM 3.0']['StorageAONExt']['GDBV'] = ('Enumeration',('NU070'))
    field_information['GGDM 3.0']['StorageAONExt']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['StorageAONExt']['EnumeratedIndexValues']['GDBV']['NU070']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['StorageAONExt']['HEI'] = ('Real',('NU070'))
    field_information['GGDM 3.0']['StorageAONExt']['HGT'] = ('Real',('NU070'))
    field_information['GGDM 3.0']['StorageAONExt']['LMC'] = ('Boolean',('NU070'))
    field_information['GGDM 3.0']['StorageAONExt']['LUN'] = ('Boolean',('NU070'))
    field_information['GGDM 3.0']['StorageAONExt']['LZN'] = ('Real',('NU070'))
    field_information['GGDM 3.0']['StorageAONExt']['OTH'] = ('StructuredText',('NU070'))
    field_information['GGDM 3.0']['StorageAONExt']['PCF'] = ('Enumeration',('NU070'))
    field_information['GGDM 3.0']['StorageAONExt']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['StorageAONExt']['EnumeratedIndexValues']['PCF']['NU070']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['StorageAONExt']['PPO'] = ('Enumeration',('NU070'))
    field_information['GGDM 3.0']['StorageAONExt']['EnumeratedIndexValues']['PPO'] = {}
    field_information['GGDM 3.0']['StorageAONExt']['EnumeratedIndexValues']['PPO']['NU070']  = (-999999,16,45,46,61,62,83,90,101,122,170,214,999)
    field_information['GGDM 3.0']['StorageAONExt']['PPO2'] = ('Enumeration',('NU070'))
    field_information['GGDM 3.0']['StorageAONExt']['EnumeratedIndexValues']['PPO2'] = {}
    field_information['GGDM 3.0']['StorageAONExt']['EnumeratedIndexValues']['PPO2']['NU070']  = (-999999,16,45,46,61,62,83,90,101,122,170,214,999)
    field_information['GGDM 3.0']['StorageAONExt']['PPO3'] = ('Enumeration',('NU070'))
    field_information['GGDM 3.0']['StorageAONExt']['EnumeratedIndexValues']['PPO3'] = {}
    field_information['GGDM 3.0']['StorageAONExt']['EnumeratedIndexValues']['PPO3']['NU070']  = (-999999,16,45,46,61,62,83,90,101,122,170,214,999)
    field_information['GGDM 3.0']['StorageAONExt']['SPT'] = ('Boolean',('NU070'))
    field_information['GGDM 3.0']['StorageAONExt']['SSC'] = ('Enumeration',('NU070'))
    field_information['GGDM 3.0']['StorageAONExt']['EnumeratedIndexValues']['SSC'] = {}
    field_information['GGDM 3.0']['StorageAONExt']['EnumeratedIndexValues']['SSC']['NU070']  = (-999999,2,4,12,17,59,65,66,71,87,88,89,91,92,94,99,100,101,999)
    field_information['GGDM 3.0']['StorageAONExt']['UFI'] = ('StructuredText',('NU070'))
    field_information['GGDM 3.0']['StorageAONExt']['VCM'] = ('Enumeration',('NU070'))
    field_information['GGDM 3.0']['StorageAONExt']['EnumeratedIndexValues']['VCM'] = {}
    field_information['GGDM 3.0']['StorageAONExt']['EnumeratedIndexValues']['VCM']['NU070']  = (-999999,2,4,7,8,9,12,13,15,999)
    field_information['GGDM 3.0']['StorageAONExt']['VCM2'] = ('Enumeration',('NU070'))
    field_information['GGDM 3.0']['StorageAONExt']['EnumeratedIndexValues']['VCM2'] = {}
    field_information['GGDM 3.0']['StorageAONExt']['EnumeratedIndexValues']['VCM2']['NU070']  = (-999999,2,4,7,8,9,12,13,15,999)
    field_information['GGDM 3.0']['StorageAONExt']['VCM3'] = ('Enumeration',('NU070'))
    field_information['GGDM 3.0']['StorageAONExt']['EnumeratedIndexValues']['VCM3'] = {}
    field_information['GGDM 3.0']['StorageAONExt']['EnumeratedIndexValues']['VCM3']['NU070']  = (-999999,2,4,7,8,9,12,13,15,999)
    field_information['GGDM 3.0']['StorageAONExt']['VLM'] = ('Real',('NU070'))
    field_information['GGDM 3.0']['StorageAONExt']['VOI'] = ('StructuredText',('NU070'))
    field_information['GGDM 3.0']['StorageAONExt']['WID'] = ('Real',('NU070'))
    field_information['GGDM 3.0']['StorageAONExt']['YWQ'] = ('Enumeration',('NU070'))
    field_information['GGDM 3.0']['StorageAONExt']['EnumeratedIndexValues']['YWQ'] = {}
    field_information['GGDM 3.0']['StorageAONExt']['EnumeratedIndexValues']['YWQ']['NU070']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['StorageAONExt']['ZI001_SDV'] = ('StructuredText',('NU070'))
    field_information['GGDM 3.0']['StorageAONExt']['ZI001_SRT'] = ('Enumeration',('NU070'))
    field_information['GGDM 3.0']['StorageAONExt']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['StorageAONExt']['EnumeratedIndexValues']['ZI001_SRT']['NU070']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['StorageAONExt']['ZI002_UFI'] = ('StructuredText',('NU070'))
    field_information['GGDM 3.0']['StorageAONExt']['ZI004_RCG'] = ('Enumeration',('NU070'))
    field_information['GGDM 3.0']['StorageAONExt']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['StorageAONExt']['EnumeratedIndexValues']['ZI004_RCG']['NU070']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['StorageAONExt']['ZI005_FNA'] = ('String',('NU070'))
    field_information['GGDM 3.0']['StorageAONExt']['ZI005_FNA2'] = ('String',('NU070'))
    field_information['GGDM 3.0']['StorageAONExt']['ZI005_GNT'] = ('Enumeration',('NU070'))
    field_information['GGDM 3.0']['StorageAONExt']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['StorageAONExt']['EnumeratedIndexValues']['ZI005_GNT']['NU070']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['StorageAONExt']['ZI005_GNT2'] = ('Enumeration',('NU070'))
    field_information['GGDM 3.0']['StorageAONExt']['EnumeratedIndexValues']['ZI005_GNT2'] = {}
    field_information['GGDM 3.0']['StorageAONExt']['EnumeratedIndexValues']['ZI005_GNT2']['NU070']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['StorageAONExt']['ZI005_NFN'] = ('String',('NU070'))
    field_information['GGDM 3.0']['StorageAONExt']['ZI005_NFN2'] = ('String',('NU070'))
    field_information['GGDM 3.0']['StorageAONExt']['ZI006_MEM'] = ('String',('NU070'))
    field_information['GGDM 3.0']['StorageAONExt']['ZI020_GE4'] = ('CodeList',('NU070'))
    field_information['GGDM 3.0']['StorageAONExt']['ZI024_ASE'] = ('Real',('NU070'))
    field_information['GGDM 3.0']['StorageAONExt']['ZI024_CFR'] = ('Real',('NU070'))
    field_information['GGDM 3.0']['StorageAONExt']['ZI024_CLO'] = ('Real',('NU070'))
    field_information['GGDM 3.0']['StorageAONExt']['ZI024_CYN'] = ('Real',('NU070'))
    field_information['GGDM 3.0']['StorageAONExt']['ZI024_FMR'] = ('Real',('NU070'))
    field_information['GGDM 3.0']['StorageAONExt']['ZI024_FRR'] = ('Real',('NU070'))
    field_information['GGDM 3.0']['StorageAONExt']['ZI024_HAR'] = ('Real',('NU070'))
    field_information['GGDM 3.0']['StorageAONExt']['ZI024_MGN'] = ('Real',('NU070'))
    field_information['GGDM 3.0']['StorageAONExt']['ZI024_PHW'] = ('Real',('NU070'))
    field_information['GGDM 3.0']['StorageAONExt']['ZI024_SCC'] = ('Enumeration',('NU070'))
    field_information['GGDM 3.0']['StorageAONExt']['EnumeratedIndexValues']['ZI024_SCC'] = {}
    field_information['GGDM 3.0']['StorageAONExt']['EnumeratedIndexValues']['ZI024_SCC']['NU070']  = (-999999,1,4,10,11,12,13,14,998,999)
    field_information['GGDM 3.0']['StorageAONExt']['ZI024_SUL'] = ('Real',('NU070'))
    field_information['GGDM 3.0']['StorageAONExt']['ZI024_TDS'] = ('Real',('NU070'))
    field_information['GGDM 3.0']['StorageAONExt']['ZI024_TEP'] = ('Real',('NU070'))
    field_information['GGDM 3.0']['StorageAONExt']['ZI024_TUR'] = ('Real',('NU070'))
    field_information['GGDM 3.0']['StorageAONExt']['ZI024_WAC'] = ('Real',('NU070'))
    field_information['GGDM 3.0']['StorageAONExt']['ZI024_WTNO'] = ('Real',('NU070'))
    field_information['GGDM 3.0']['StorageAONExt']['ZI024_WUR'] = ('Enumeration',('NU070'))
    field_information['GGDM 3.0']['StorageAONExt']['EnumeratedIndexValues']['ZI024_WUR'] = {}
    field_information['GGDM 3.0']['StorageAONExt']['EnumeratedIndexValues']['ZI024_WUR']['NU070']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['StorageAONExt']['ZI024_WUR2'] = ('Enumeration',('NU070'))
    field_information['GGDM 3.0']['StorageAONExt']['EnumeratedIndexValues']['ZI024_WUR2'] = {}
    field_information['GGDM 3.0']['StorageAONExt']['EnumeratedIndexValues']['ZI024_WUR2']['NU070']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['StorageAONExt']['ZI024_WUR3'] = ('Enumeration',('NU070'))
    field_information['GGDM 3.0']['StorageAONExt']['EnumeratedIndexValues']['ZI024_WUR3'] = {}
    field_information['GGDM 3.0']['StorageAONExt']['EnumeratedIndexValues']['ZI024_WUR3']['NU070']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['StorageAONExt']['ZI024_WUR4'] = ('Enumeration',('NU070'))
    field_information['GGDM 3.0']['StorageAONExt']['EnumeratedIndexValues']['ZI024_WUR4'] = {}
    field_information['GGDM 3.0']['StorageAONExt']['EnumeratedIndexValues']['ZI024_WUR4']['NU070']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['StorageAONExt']['ZI026_CTUC'] = ('Enumeration',('NU070'))
    field_information['GGDM 3.0']['StorageAONExt']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['StorageAONExt']['EnumeratedIndexValues']['ZI026_CTUC']['NU070']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['StorageAONExt']['ZI026_CTUL'] = ('integer',('NU070'))
    field_information['GGDM 3.0']['StorageAONExt']['ZI026_CTUU'] = ('integer',('NU070'))
    field_information['GGDM 3.0']['StorageAONExt']['ZI031S_URI'] = ('StructuredText',('NU070'))
    field_information['GGDM 3.0']['StorageAONExt']['ZI039S_UFI'] = ('StructuredText',('NU070'))
    field_information['GGDM 3.0']['StorageAONExt']['ZSAX_RS0'] = ('CodeList',('NU070'))
    field_information['GGDM 3.0']['StorageAONExt']['ZSAX_RX0'] = ('StructuredText',('NU070'))
    field_information['GGDM 3.0']['StorageAONExt']['ZSAX_RX3'] = ('StructuredText',('NU070'))
    field_information['GGDM 3.0']['StorageAONExt']['ZSAX_RX4'] = ('StructuredText',('NU070'))
    field_information['GGDM 3.0']['StorageAONExt']['ZVH'] = ('Real',('NU070'))
    field_information['GGDM 3.0']['StoragePnt']['ADR'] = ('String',('AM010','AM030','AM065','AM071','AM075'))
    field_information['GGDM 3.0']['StoragePnt']['AOO'] = ('Real',('AM010','AM011','AM030','AM065','AM070','AM071','AM075','AM080'))
    field_information['GGDM 3.0']['StoragePnt']['ARA'] = ('Real',('AM010','AM011','AM030','AM065','AM070','AM071','AM075','AM080'))
    field_information['GGDM 3.0']['StoragePnt']['AWP'] = ('Boolean',('AM030','AM070','AM080'))
    field_information['GGDM 3.0']['StoragePnt']['BEN'] = ('StructuredText',('AM010','AM011','AM030','AM065','AM070','AM071','AM075','AM080'))
    field_information['GGDM 3.0']['StoragePnt']['CAA'] = ('Enumeration',('AM010','AM011','AM030','AM065','AM070','AM071','AM075','AM080'))
    field_information['GGDM 3.0']['StoragePnt']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['StoragePnt']['EnumeratedIndexValues']['CAA']['AM010']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['StoragePnt']['EnumeratedIndexValues']['CAA']['AM011']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['StoragePnt']['EnumeratedIndexValues']['CAA']['AM030']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['StoragePnt']['EnumeratedIndexValues']['CAA']['AM065']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['StoragePnt']['EnumeratedIndexValues']['CAA']['AM070']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['StoragePnt']['EnumeratedIndexValues']['CAA']['AM071']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['StoragePnt']['EnumeratedIndexValues']['CAA']['AM075']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['StoragePnt']['EnumeratedIndexValues']['CAA']['AM080']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['StoragePnt']['CBP'] = ('Boolean',('AM070'))
    field_information['GGDM 3.0']['StoragePnt']['CNCP'] = ('StructuredText',('AM010','AM011','AM030','AM065','AM070','AM071','AM075','AM080'))
    field_information['GGDM 3.0']['StoragePnt']['COS'] = ('Enumeration',('AM010','AM011','AM030','AM065','AM070','AM071','AM075','AM080'))
    field_information['GGDM 3.0']['StoragePnt']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['StoragePnt']['EnumeratedIndexValues']['COS']['AM010']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['StoragePnt']['EnumeratedIndexValues']['COS']['AM011']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['StoragePnt']['EnumeratedIndexValues']['COS']['AM030']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['StoragePnt']['EnumeratedIndexValues']['COS']['AM065']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['StoragePnt']['EnumeratedIndexValues']['COS']['AM070']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['StoragePnt']['EnumeratedIndexValues']['COS']['AM071']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['StoragePnt']['EnumeratedIndexValues']['COS']['AM075']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['StoragePnt']['EnumeratedIndexValues']['COS']['AM080']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['StoragePnt']['F_CODE'] = ('CONSTRAINED_STRING',('AM010','AM011','AM030','AM065','AM070','AM071','AM075','AM080'))
    field_information['GGDM 3.0']['StoragePnt']['FFN'] = ('Enumeration',('AM010','AM011','AM071','AM075'))
    field_information['GGDM 3.0']['StoragePnt']['EnumeratedIndexValues']['FFN'] = {}
    field_information['GGDM 3.0']['StoragePnt']['EnumeratedIndexValues']['FFN']['AM010']  = (-999999,2,40,60,99,351,385,440,459,473,480,484,490,495,497,530,835,847,999)
    field_information['GGDM 3.0']['StoragePnt']['EnumeratedIndexValues']['FFN']['AM011']  = (-999999,2,99,330,334,383,475,480,490,497,505,529,530,536,550,781,843,881,999)
    field_information['GGDM 3.0']['StoragePnt']['EnumeratedIndexValues']['FFN']['AM071']  = (-999999,60,192,195,350,351,484,497,500,999)
    field_information['GGDM 3.0']['StoragePnt']['EnumeratedIndexValues']['FFN']['AM075']  = (-999999,40,192,350,470,480,484,490,495,505,508,520,811,835,841,999)
    field_information['GGDM 3.0']['StoragePnt']['FFN2'] = ('Enumeration',('AM010','AM011','AM071','AM075'))
    field_information['GGDM 3.0']['StoragePnt']['EnumeratedIndexValues']['FFN2'] = {}
    field_information['GGDM 3.0']['StoragePnt']['EnumeratedIndexValues']['FFN2']['AM010']  = (-999999,2,40,60,99,351,385,440,459,473,480,484,490,495,497,530,835,847,999)
    field_information['GGDM 3.0']['StoragePnt']['EnumeratedIndexValues']['FFN2']['AM011']  = (-999999,2,99,330,334,383,475,480,490,497,505,529,530,536,550,781,843,881,999)
    field_information['GGDM 3.0']['StoragePnt']['EnumeratedIndexValues']['FFN2']['AM071']  = (-999999,60,192,195,350,351,484,497,500,999)
    field_information['GGDM 3.0']['StoragePnt']['EnumeratedIndexValues']['FFN2']['AM075']  = (-999999,40,192,350,470,480,484,490,495,505,508,520,811,835,841,999)
    field_information['GGDM 3.0']['StoragePnt']['FFN3'] = ('Enumeration',('AM010','AM011','AM071','AM075'))
    field_information['GGDM 3.0']['StoragePnt']['EnumeratedIndexValues']['FFN3'] = {}
    field_information['GGDM 3.0']['StoragePnt']['EnumeratedIndexValues']['FFN3']['AM010']  = (-999999,2,40,60,99,351,385,440,459,473,480,484,490,495,497,530,835,847,999)
    field_information['GGDM 3.0']['StoragePnt']['EnumeratedIndexValues']['FFN3']['AM011']  = (-999999,2,99,330,334,383,475,480,490,497,505,529,530,536,550,781,843,881,999)
    field_information['GGDM 3.0']['StoragePnt']['EnumeratedIndexValues']['FFN3']['AM071']  = (-999999,60,192,195,350,351,484,497,500,999)
    field_information['GGDM 3.0']['StoragePnt']['EnumeratedIndexValues']['FFN3']['AM075']  = (-999999,40,192,350,470,480,484,490,495,505,508,520,811,835,841,999)
    field_information['GGDM 3.0']['StoragePnt']['FUFI'] = ('StructuredText',('AM010','AM011','AM030','AM065','AM070','AM071','AM075','AM080'))
    field_information['GGDM 3.0']['StoragePnt']['FURL'] = ('StructuredText',('AM010','AM011','AM030','AM065','AM070','AM071','AM075','AM080'))
    field_information['GGDM 3.0']['StoragePnt']['GDBV'] = ('Enumeration',('AM010','AM011','AM030','AM065','AM070','AM071','AM075','AM080'))
    field_information['GGDM 3.0']['StoragePnt']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['StoragePnt']['EnumeratedIndexValues']['GDBV']['AM010']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['StoragePnt']['EnumeratedIndexValues']['GDBV']['AM011']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['StoragePnt']['EnumeratedIndexValues']['GDBV']['AM030']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['StoragePnt']['EnumeratedIndexValues']['GDBV']['AM065']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['StoragePnt']['EnumeratedIndexValues']['GDBV']['AM070']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['StoragePnt']['EnumeratedIndexValues']['GDBV']['AM071']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['StoragePnt']['EnumeratedIndexValues']['GDBV']['AM075']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['StoragePnt']['EnumeratedIndexValues']['GDBV']['AM080']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['StoragePnt']['HEI'] = ('Real',('AM070'))
    field_information['GGDM 3.0']['StoragePnt']['HGT'] = ('Real',('AM010','AM011','AM030','AM065','AM070','AM071','AM075','AM080'))
    field_information['GGDM 3.0']['StoragePnt']['LMC'] = ('Boolean',('AM010','AM011','AM030','AM065','AM070','AM071','AM075','AM080'))
    field_information['GGDM 3.0']['StoragePnt']['LOC'] = ('Enumeration',('AM070'))
    field_information['GGDM 3.0']['StoragePnt']['EnumeratedIndexValues']['LOC'] = {}
    field_information['GGDM 3.0']['StoragePnt']['EnumeratedIndexValues']['LOC']['AM070']  = (-999999,40,44,45,48)
    field_information['GGDM 3.0']['StoragePnt']['LUN'] = ('Boolean',('AM010','AM065','AM070','AM075'))
    field_information['GGDM 3.0']['StoragePnt']['LZN'] = ('Real',('AM010','AM011','AM030','AM065','AM070','AM071','AM075','AM080'))
    field_information['GGDM 3.0']['StoragePnt']['OTH'] = ('StructuredText',('AM010','AM011','AM030','AM065','AM070','AM071','AM075','AM080'))
    field_information['GGDM 3.0']['StoragePnt']['PCF'] = ('Enumeration',('AM010','AM011','AM030','AM065','AM070','AM071','AM075','AM080'))
    field_information['GGDM 3.0']['StoragePnt']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['StoragePnt']['EnumeratedIndexValues']['PCF']['AM010']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['StoragePnt']['EnumeratedIndexValues']['PCF']['AM011']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['StoragePnt']['EnumeratedIndexValues']['PCF']['AM030']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['StoragePnt']['EnumeratedIndexValues']['PCF']['AM065']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['StoragePnt']['EnumeratedIndexValues']['PCF']['AM070']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['StoragePnt']['EnumeratedIndexValues']['PCF']['AM071']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['StoragePnt']['EnumeratedIndexValues']['PCF']['AM075']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['StoragePnt']['EnumeratedIndexValues']['PCF']['AM080']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['StoragePnt']['PMPR'] = ('Boolean',('AM070','AM080'))
    field_information['GGDM 3.0']['StoragePnt']['PPO'] = ('Enumeration',('AM010','AM070','AM071'))
    field_information['GGDM 3.0']['StoragePnt']['EnumeratedIndexValues']['PPO'] = {}
    field_information['GGDM 3.0']['StoragePnt']['EnumeratedIndexValues']['PPO']['AM010']  = (-999999,1,3,16,18,19,21,38,45,46,53,63,83,90,95,96,110,116,117,120,122,214,999)
    field_information['GGDM 3.0']['StoragePnt']['EnumeratedIndexValues']['PPO']['AM070']  = (-999999,16,45,46,61,62,83,90,101,122,170,214,999)
    field_information['GGDM 3.0']['StoragePnt']['EnumeratedIndexValues']['PPO']['AM071']  = (-999999,16,45,46,61,62,83,214,999)
    field_information['GGDM 3.0']['StoragePnt']['PPO2'] = ('Enumeration',('AM010','AM070','AM071'))
    field_information['GGDM 3.0']['StoragePnt']['EnumeratedIndexValues']['PPO2'] = {}
    field_information['GGDM 3.0']['StoragePnt']['EnumeratedIndexValues']['PPO2']['AM010']  = (-999999,1,3,16,18,19,21,38,45,46,53,63,83,90,95,96,110,116,117,120,122,214,999)
    field_information['GGDM 3.0']['StoragePnt']['EnumeratedIndexValues']['PPO2']['AM070']  = (-999999,16,45,46,61,62,83,90,101,122,170,214,999)
    field_information['GGDM 3.0']['StoragePnt']['EnumeratedIndexValues']['PPO2']['AM071']  = (-999999,16,45,46,61,62,83,214,999)
    field_information['GGDM 3.0']['StoragePnt']['PPO3'] = ('Enumeration',('AM010','AM070','AM071'))
    field_information['GGDM 3.0']['StoragePnt']['EnumeratedIndexValues']['PPO3'] = {}
    field_information['GGDM 3.0']['StoragePnt']['EnumeratedIndexValues']['PPO3']['AM010']  = (-999999,1,3,16,18,19,21,38,45,46,53,63,83,90,95,96,110,116,117,120,122,214,999)
    field_information['GGDM 3.0']['StoragePnt']['EnumeratedIndexValues']['PPO3']['AM070']  = (-999999,16,45,46,61,62,83,90,101,122,170,214,999)
    field_information['GGDM 3.0']['StoragePnt']['EnumeratedIndexValues']['PPO3']['AM071']  = (-999999,16,45,46,61,62,83,214,999)
    field_information['GGDM 3.0']['StoragePnt']['SHT'] = ('Enumeration',('AM011'))
    field_information['GGDM 3.0']['StoragePnt']['EnumeratedIndexValues']['SHT'] = {}
    field_information['GGDM 3.0']['StoragePnt']['EnumeratedIndexValues']['SHT']['AM011']  = (-999999,1,2,3,4,5,999)
    field_information['GGDM 3.0']['StoragePnt']['SPT'] = ('Boolean',('AM011','AM070','AM080'))
    field_information['GGDM 3.0']['StoragePnt']['SSC'] = ('Enumeration',('AM070','AM080'))
    field_information['GGDM 3.0']['StoragePnt']['EnumeratedIndexValues']['SSC'] = {}
    field_information['GGDM 3.0']['StoragePnt']['EnumeratedIndexValues']['SSC']['AM070']  = (-999999,2,4,12,17,59,65,66,71,87,88,89,91,92,94,99,100,101,999)
    field_information['GGDM 3.0']['StoragePnt']['EnumeratedIndexValues']['SSC']['AM080']  = (-999999,17,65,66,71,88,89,92,94,100,999)
    field_information['GGDM 3.0']['StoragePnt']['SSR'] = ('Enumeration',('AM030'))
    field_information['GGDM 3.0']['StoragePnt']['EnumeratedIndexValues']['SSR'] = {}
    field_information['GGDM 3.0']['StoragePnt']['EnumeratedIndexValues']['SSR']['AM030']  = (-999999,6,7,38,40,41,42,999)
    field_information['GGDM 3.0']['StoragePnt']['SSR2'] = ('Enumeration',('AM030'))
    field_information['GGDM 3.0']['StoragePnt']['EnumeratedIndexValues']['SSR2'] = {}
    field_information['GGDM 3.0']['StoragePnt']['EnumeratedIndexValues']['SSR2']['AM030']  = (-999999,6,7,38,40,41,42,999)
    field_information['GGDM 3.0']['StoragePnt']['SSR3'] = ('Enumeration',('AM030'))
    field_information['GGDM 3.0']['StoragePnt']['EnumeratedIndexValues']['SSR3'] = {}
    field_information['GGDM 3.0']['StoragePnt']['EnumeratedIndexValues']['SSR3']['AM030']  = (-999999,6,7,38,40,41,42,999)
    field_information['GGDM 3.0']['StoragePnt']['UFI'] = ('StructuredText',('AM010','AM011','AM030','AM065','AM070','AM071','AM075','AM080'))
    field_information['GGDM 3.0']['StoragePnt']['VCM'] = ('Enumeration',('AM011','AM030','AM070'))
    field_information['GGDM 3.0']['StoragePnt']['EnumeratedIndexValues']['VCM'] = {}
    field_information['GGDM 3.0']['StoragePnt']['EnumeratedIndexValues']['VCM']['AM011']  = (-999999,2,4,7,8,9,12,13,15,17,18,999)
    field_information['GGDM 3.0']['StoragePnt']['EnumeratedIndexValues']['VCM']['AM030']  = (-999999,2,4,7,8,9,12,13,15,18,999)
    field_information['GGDM 3.0']['StoragePnt']['EnumeratedIndexValues']['VCM']['AM070']  = (-999999,2,4,7,8,9,12,13,15,999)
    field_information['GGDM 3.0']['StoragePnt']['VCM2'] = ('Enumeration',('AM011','AM030','AM070'))
    field_information['GGDM 3.0']['StoragePnt']['EnumeratedIndexValues']['VCM2'] = {}
    field_information['GGDM 3.0']['StoragePnt']['EnumeratedIndexValues']['VCM2']['AM011']  = (-999999,2,4,7,8,9,12,13,15,17,18,999)
    field_information['GGDM 3.0']['StoragePnt']['EnumeratedIndexValues']['VCM2']['AM030']  = (-999999,2,4,7,8,9,12,13,15,18,999)
    field_information['GGDM 3.0']['StoragePnt']['EnumeratedIndexValues']['VCM2']['AM070']  = (-999999,2,4,7,8,9,12,13,15,999)
    field_information['GGDM 3.0']['StoragePnt']['VCM3'] = ('Enumeration',('AM011','AM030','AM070'))
    field_information['GGDM 3.0']['StoragePnt']['EnumeratedIndexValues']['VCM3'] = {}
    field_information['GGDM 3.0']['StoragePnt']['EnumeratedIndexValues']['VCM3']['AM011']  = (-999999,2,4,7,8,9,12,13,15,17,18,999)
    field_information['GGDM 3.0']['StoragePnt']['EnumeratedIndexValues']['VCM3']['AM030']  = (-999999,2,4,7,8,9,12,13,15,18,999)
    field_information['GGDM 3.0']['StoragePnt']['EnumeratedIndexValues']['VCM3']['AM070']  = (-999999,2,4,7,8,9,12,13,15,999)
    field_information['GGDM 3.0']['StoragePnt']['VLM'] = ('Real',('AM070','AM080'))
    field_information['GGDM 3.0']['StoragePnt']['VOI'] = ('StructuredText',('AM010','AM030','AM070','AM080'))
    field_information['GGDM 3.0']['StoragePnt']['WDST'] = ('Enumeration',('AM080'))
    field_information['GGDM 3.0']['StoragePnt']['EnumeratedIndexValues']['WDST'] = {}
    field_information['GGDM 3.0']['StoragePnt']['EnumeratedIndexValues']['WDST']['AM080']  = (-999999,1,2,3,4,5,6,7,8,998,999)
    field_information['GGDM 3.0']['StoragePnt']['WID'] = ('Real',('AM010','AM011','AM030','AM065','AM070','AM071','AM075','AM080'))
    field_information['GGDM 3.0']['StoragePnt']['YWQ'] = ('Enumeration',('AM070','AM080'))
    field_information['GGDM 3.0']['StoragePnt']['EnumeratedIndexValues']['YWQ'] = {}
    field_information['GGDM 3.0']['StoragePnt']['EnumeratedIndexValues']['YWQ']['AM070']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['StoragePnt']['EnumeratedIndexValues']['YWQ']['AM080']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['StoragePnt']['ZI001_SDV'] = ('StructuredText',('AM010','AM011','AM030','AM065','AM070','AM071','AM075','AM080'))
    field_information['GGDM 3.0']['StoragePnt']['ZI001_SRT'] = ('Enumeration',('AM010','AM011','AM030','AM065','AM070','AM071','AM075','AM080'))
    field_information['GGDM 3.0']['StoragePnt']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['StoragePnt']['EnumeratedIndexValues']['ZI001_SRT']['AM010']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['StoragePnt']['EnumeratedIndexValues']['ZI001_SRT']['AM011']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['StoragePnt']['EnumeratedIndexValues']['ZI001_SRT']['AM030']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['StoragePnt']['EnumeratedIndexValues']['ZI001_SRT']['AM065']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['StoragePnt']['EnumeratedIndexValues']['ZI001_SRT']['AM070']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['StoragePnt']['EnumeratedIndexValues']['ZI001_SRT']['AM071']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['StoragePnt']['EnumeratedIndexValues']['ZI001_SRT']['AM075']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['StoragePnt']['EnumeratedIndexValues']['ZI001_SRT']['AM080']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['StoragePnt']['ZI002_UFI'] = ('StructuredText',('AM010','AM011','AM030','AM065','AM070','AM071','AM075','AM080'))
    field_information['GGDM 3.0']['StoragePnt']['ZI004_RCG'] = ('Enumeration',('AM010','AM011','AM030','AM065','AM070','AM071','AM075','AM080'))
    field_information['GGDM 3.0']['StoragePnt']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['StoragePnt']['EnumeratedIndexValues']['ZI004_RCG']['AM010']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['StoragePnt']['EnumeratedIndexValues']['ZI004_RCG']['AM011']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['StoragePnt']['EnumeratedIndexValues']['ZI004_RCG']['AM030']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['StoragePnt']['EnumeratedIndexValues']['ZI004_RCG']['AM065']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['StoragePnt']['EnumeratedIndexValues']['ZI004_RCG']['AM070']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['StoragePnt']['EnumeratedIndexValues']['ZI004_RCG']['AM071']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['StoragePnt']['EnumeratedIndexValues']['ZI004_RCG']['AM075']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['StoragePnt']['EnumeratedIndexValues']['ZI004_RCG']['AM080']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['StoragePnt']['ZI005_FNA'] = ('String',('AM010','AM011','AM030','AM065','AM070','AM071','AM075','AM080'))
    field_information['GGDM 3.0']['StoragePnt']['ZI005_FNA2'] = ('String',('AM070','AM080'))
    field_information['GGDM 3.0']['StoragePnt']['ZI005_GNT'] = ('Enumeration',('AM010','AM011','AM030','AM065','AM070','AM071','AM075','AM080'))
    field_information['GGDM 3.0']['StoragePnt']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['StoragePnt']['EnumeratedIndexValues']['ZI005_GNT']['AM010']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['StoragePnt']['EnumeratedIndexValues']['ZI005_GNT']['AM011']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['StoragePnt']['EnumeratedIndexValues']['ZI005_GNT']['AM030']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['StoragePnt']['EnumeratedIndexValues']['ZI005_GNT']['AM065']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['StoragePnt']['EnumeratedIndexValues']['ZI005_GNT']['AM070']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['StoragePnt']['EnumeratedIndexValues']['ZI005_GNT']['AM071']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['StoragePnt']['EnumeratedIndexValues']['ZI005_GNT']['AM075']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['StoragePnt']['EnumeratedIndexValues']['ZI005_GNT']['AM080']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['StoragePnt']['ZI005_GNT2'] = ('Enumeration',('AM070','AM080'))
    field_information['GGDM 3.0']['StoragePnt']['EnumeratedIndexValues']['ZI005_GNT2'] = {}
    field_information['GGDM 3.0']['StoragePnt']['EnumeratedIndexValues']['ZI005_GNT2']['AM070']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['StoragePnt']['EnumeratedIndexValues']['ZI005_GNT2']['AM080']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['StoragePnt']['ZI005_NFN'] = ('String',('AM010','AM011','AM030','AM065','AM070','AM071','AM075','AM080'))
    field_information['GGDM 3.0']['StoragePnt']['ZI005_NFN2'] = ('String',('AM070','AM080'))
    field_information['GGDM 3.0']['StoragePnt']['ZI006_MEM'] = ('String',('AM010','AM011','AM030','AM065','AM070','AM071','AM075','AM080'))
    field_information['GGDM 3.0']['StoragePnt']['ZI020_GE4'] = ('CodeList',('AM010','AM011','AM030','AM065','AM070','AM071','AM075','AM080'))
    field_information['GGDM 3.0']['StoragePnt']['ZI024_ASE'] = ('Real',('AM070','AM080'))
    field_information['GGDM 3.0']['StoragePnt']['ZI024_CFR'] = ('Real',('AM070','AM080'))
    field_information['GGDM 3.0']['StoragePnt']['ZI024_CLO'] = ('Real',('AM070','AM080'))
    field_information['GGDM 3.0']['StoragePnt']['ZI024_CYN'] = ('Real',('AM070','AM080'))
    field_information['GGDM 3.0']['StoragePnt']['ZI024_FMR'] = ('Real',('AM070','AM080'))
    field_information['GGDM 3.0']['StoragePnt']['ZI024_FRR'] = ('Real',('AM070','AM080'))
    field_information['GGDM 3.0']['StoragePnt']['ZI024_HAR'] = ('Real',('AM070','AM080'))
    field_information['GGDM 3.0']['StoragePnt']['ZI024_HYP'] = ('Enumeration',('AM080'))
    field_information['GGDM 3.0']['StoragePnt']['EnumeratedIndexValues']['ZI024_HYP'] = {}
    field_information['GGDM 3.0']['StoragePnt']['EnumeratedIndexValues']['ZI024_HYP']['AM080']  = (-999999,1,2,4)
    field_information['GGDM 3.0']['StoragePnt']['ZI024_MGN'] = ('Real',('AM070','AM080'))
    field_information['GGDM 3.0']['StoragePnt']['ZI024_PHW'] = ('Real',('AM070','AM080'))
    field_information['GGDM 3.0']['StoragePnt']['ZI024_SCC'] = ('Enumeration',('AM070','AM080'))
    field_information['GGDM 3.0']['StoragePnt']['EnumeratedIndexValues']['ZI024_SCC'] = {}
    field_information['GGDM 3.0']['StoragePnt']['EnumeratedIndexValues']['ZI024_SCC']['AM070']  = (-999999,1,4,10,11,12,13,14,998,999)
    field_information['GGDM 3.0']['StoragePnt']['EnumeratedIndexValues']['ZI024_SCC']['AM080']  = (-999999,1,4,10,11,12,13,14,998,999)
    field_information['GGDM 3.0']['StoragePnt']['ZI024_SUL'] = ('Real',('AM070','AM080'))
    field_information['GGDM 3.0']['StoragePnt']['ZI024_TDS'] = ('Real',('AM070','AM080'))
    field_information['GGDM 3.0']['StoragePnt']['ZI024_TEP'] = ('Real',('AM070','AM080'))
    field_information['GGDM 3.0']['StoragePnt']['ZI024_TUR'] = ('Real',('AM070','AM080'))
    field_information['GGDM 3.0']['StoragePnt']['ZI024_WAC'] = ('Real',('AM070','AM080'))
    field_information['GGDM 3.0']['StoragePnt']['ZI024_WTNO'] = ('Real',('AM070','AM080'))
    field_information['GGDM 3.0']['StoragePnt']['ZI024_WUR'] = ('Enumeration',('AM070','AM080'))
    field_information['GGDM 3.0']['StoragePnt']['EnumeratedIndexValues']['ZI024_WUR'] = {}
    field_information['GGDM 3.0']['StoragePnt']['EnumeratedIndexValues']['ZI024_WUR']['AM070']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['StoragePnt']['EnumeratedIndexValues']['ZI024_WUR']['AM080']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['StoragePnt']['ZI024_WUR2'] = ('Enumeration',('AM070','AM080'))
    field_information['GGDM 3.0']['StoragePnt']['EnumeratedIndexValues']['ZI024_WUR2'] = {}
    field_information['GGDM 3.0']['StoragePnt']['EnumeratedIndexValues']['ZI024_WUR2']['AM070']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['StoragePnt']['EnumeratedIndexValues']['ZI024_WUR2']['AM080']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['StoragePnt']['ZI024_WUR3'] = ('Enumeration',('AM070','AM080'))
    field_information['GGDM 3.0']['StoragePnt']['EnumeratedIndexValues']['ZI024_WUR3'] = {}
    field_information['GGDM 3.0']['StoragePnt']['EnumeratedIndexValues']['ZI024_WUR3']['AM070']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['StoragePnt']['EnumeratedIndexValues']['ZI024_WUR3']['AM080']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['StoragePnt']['ZI024_WUR4'] = ('Enumeration',('AM070','AM080'))
    field_information['GGDM 3.0']['StoragePnt']['EnumeratedIndexValues']['ZI024_WUR4'] = {}
    field_information['GGDM 3.0']['StoragePnt']['EnumeratedIndexValues']['ZI024_WUR4']['AM070']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['StoragePnt']['EnumeratedIndexValues']['ZI024_WUR4']['AM080']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['StoragePnt']['ZI026_CTUC'] = ('Enumeration',('AM010','AM011','AM030','AM065','AM070','AM071','AM075','AM080'))
    field_information['GGDM 3.0']['StoragePnt']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['StoragePnt']['EnumeratedIndexValues']['ZI026_CTUC']['AM010']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['StoragePnt']['EnumeratedIndexValues']['ZI026_CTUC']['AM011']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['StoragePnt']['EnumeratedIndexValues']['ZI026_CTUC']['AM030']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['StoragePnt']['EnumeratedIndexValues']['ZI026_CTUC']['AM065']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['StoragePnt']['EnumeratedIndexValues']['ZI026_CTUC']['AM070']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['StoragePnt']['EnumeratedIndexValues']['ZI026_CTUC']['AM071']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['StoragePnt']['EnumeratedIndexValues']['ZI026_CTUC']['AM075']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['StoragePnt']['EnumeratedIndexValues']['ZI026_CTUC']['AM080']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['StoragePnt']['ZI026_CTUL'] = ('integer',('AM010','AM011','AM030','AM065','AM070','AM071','AM075','AM080'))
    field_information['GGDM 3.0']['StoragePnt']['ZI026_CTUU'] = ('integer',('AM010','AM011','AM030','AM065','AM070','AM071','AM075','AM080'))
    field_information['GGDM 3.0']['StoragePnt']['ZI031S_URI'] = ('StructuredText',('AM010','AM011','AM030','AM065','AM070','AM071','AM075','AM080'))
    field_information['GGDM 3.0']['StoragePnt']['ZI039S_UFI'] = ('StructuredText',('AM010','AM011','AM030','AM065','AM070','AM071','AM075','AM080'))
    field_information['GGDM 3.0']['StoragePnt']['ZSAX_RS0'] = ('CodeList',('AM010','AM011','AM030','AM065','AM070','AM071','AM075','AM080'))
    field_information['GGDM 3.0']['StoragePnt']['ZSAX_RX0'] = ('StructuredText',('AM010','AM011','AM030','AM065','AM070','AM071','AM075','AM080'))
    field_information['GGDM 3.0']['StoragePnt']['ZSAX_RX3'] = ('StructuredText',('AM010','AM011','AM030','AM065','AM070','AM071','AM075','AM080'))
    field_information['GGDM 3.0']['StoragePnt']['ZSAX_RX4'] = ('StructuredText',('AM010','AM011','AM030','AM065','AM070','AM071','AM075','AM080'))
    field_information['GGDM 3.0']['StoragePnt']['ZVH'] = ('Real',('AM010','AM011','AM030','AM065','AM070','AM071','AM075','AM080'))
    field_information['GGDM 3.0']['StorageSrf']['ADR'] = ('String',('AM010','AM030','AM065','AM071','AM075'))
    field_information['GGDM 3.0']['StorageSrf']['AOO'] = ('Real',('AM010','AM011','AM030','AM065','AM070','AM071','AM075','AM080'))
    field_information['GGDM 3.0']['StorageSrf']['ARA'] = ('Real',('AM010','AM011','AM030','AM065','AM070','AM071','AM075','AM080'))
    field_information['GGDM 3.0']['StorageSrf']['AWP'] = ('Boolean',('AM030','AM070','AM080'))
    field_information['GGDM 3.0']['StorageSrf']['BEN'] = ('StructuredText',('AM010','AM011','AM030','AM065','AM070','AM071','AM075','AM080'))
    field_information['GGDM 3.0']['StorageSrf']['CAA'] = ('Enumeration',('AM010','AM011','AM030','AM065','AM070','AM071','AM075','AM080'))
    field_information['GGDM 3.0']['StorageSrf']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['StorageSrf']['EnumeratedIndexValues']['CAA']['AM010']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['StorageSrf']['EnumeratedIndexValues']['CAA']['AM011']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['StorageSrf']['EnumeratedIndexValues']['CAA']['AM030']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['StorageSrf']['EnumeratedIndexValues']['CAA']['AM065']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['StorageSrf']['EnumeratedIndexValues']['CAA']['AM070']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['StorageSrf']['EnumeratedIndexValues']['CAA']['AM071']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['StorageSrf']['EnumeratedIndexValues']['CAA']['AM075']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['StorageSrf']['EnumeratedIndexValues']['CAA']['AM080']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['StorageSrf']['CBP'] = ('Boolean',('AM070'))
    field_information['GGDM 3.0']['StorageSrf']['CNCP'] = ('StructuredText',('AM010','AM011','AM030','AM065','AM070','AM071','AM075','AM080'))
    field_information['GGDM 3.0']['StorageSrf']['COS'] = ('Enumeration',('AM010','AM011','AM030','AM065','AM070','AM071','AM075','AM080'))
    field_information['GGDM 3.0']['StorageSrf']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['StorageSrf']['EnumeratedIndexValues']['COS']['AM010']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['StorageSrf']['EnumeratedIndexValues']['COS']['AM011']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['StorageSrf']['EnumeratedIndexValues']['COS']['AM030']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['StorageSrf']['EnumeratedIndexValues']['COS']['AM065']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['StorageSrf']['EnumeratedIndexValues']['COS']['AM070']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['StorageSrf']['EnumeratedIndexValues']['COS']['AM071']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['StorageSrf']['EnumeratedIndexValues']['COS']['AM075']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['StorageSrf']['EnumeratedIndexValues']['COS']['AM080']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['StorageSrf']['F_CODE'] = ('CONSTRAINED_STRING',('AM010','AM011','AM030','AM065','AM070','AM071','AM075','AM080'))
    field_information['GGDM 3.0']['StorageSrf']['FFN'] = ('Enumeration',('AM010','AM011','AM071','AM075'))
    field_information['GGDM 3.0']['StorageSrf']['EnumeratedIndexValues']['FFN'] = {}
    field_information['GGDM 3.0']['StorageSrf']['EnumeratedIndexValues']['FFN']['AM010']  = (-999999,2,40,60,99,351,385,440,459,473,480,484,490,495,497,530,835,847,999)
    field_information['GGDM 3.0']['StorageSrf']['EnumeratedIndexValues']['FFN']['AM011']  = (-999999,2,99,330,334,383,475,480,490,497,505,529,530,536,550,781,843,881,999)
    field_information['GGDM 3.0']['StorageSrf']['EnumeratedIndexValues']['FFN']['AM071']  = (-999999,60,192,195,350,351,484,497,500,999)
    field_information['GGDM 3.0']['StorageSrf']['EnumeratedIndexValues']['FFN']['AM075']  = (-999999,40,192,350,470,480,484,490,495,505,508,520,811,835,841,999)
    field_information['GGDM 3.0']['StorageSrf']['FFN2'] = ('Enumeration',('AM010','AM011','AM071','AM075'))
    field_information['GGDM 3.0']['StorageSrf']['EnumeratedIndexValues']['FFN2'] = {}
    field_information['GGDM 3.0']['StorageSrf']['EnumeratedIndexValues']['FFN2']['AM010']  = (-999999,2,40,60,99,351,385,440,459,473,480,484,490,495,497,530,835,847,999)
    field_information['GGDM 3.0']['StorageSrf']['EnumeratedIndexValues']['FFN2']['AM011']  = (-999999,2,99,330,334,383,475,480,490,497,505,529,530,536,550,781,843,881,999)
    field_information['GGDM 3.0']['StorageSrf']['EnumeratedIndexValues']['FFN2']['AM071']  = (-999999,60,192,195,350,351,484,497,500,999)
    field_information['GGDM 3.0']['StorageSrf']['EnumeratedIndexValues']['FFN2']['AM075']  = (-999999,40,192,350,470,480,484,490,495,505,508,520,811,835,841,999)
    field_information['GGDM 3.0']['StorageSrf']['FFN3'] = ('Enumeration',('AM010','AM011','AM071','AM075'))
    field_information['GGDM 3.0']['StorageSrf']['EnumeratedIndexValues']['FFN3'] = {}
    field_information['GGDM 3.0']['StorageSrf']['EnumeratedIndexValues']['FFN3']['AM010']  = (-999999,2,40,60,99,351,385,440,459,473,480,484,490,495,497,530,835,847,999)
    field_information['GGDM 3.0']['StorageSrf']['EnumeratedIndexValues']['FFN3']['AM011']  = (-999999,2,99,330,334,383,475,480,490,497,505,529,530,536,550,781,843,881,999)
    field_information['GGDM 3.0']['StorageSrf']['EnumeratedIndexValues']['FFN3']['AM071']  = (-999999,60,192,195,350,351,484,497,500,999)
    field_information['GGDM 3.0']['StorageSrf']['EnumeratedIndexValues']['FFN3']['AM075']  = (-999999,40,192,350,470,480,484,490,495,505,508,520,811,835,841,999)
    field_information['GGDM 3.0']['StorageSrf']['FUFI'] = ('StructuredText',('AM010','AM011','AM030','AM065','AM070','AM071','AM075','AM080'))
    field_information['GGDM 3.0']['StorageSrf']['FURL'] = ('StructuredText',('AM010','AM011','AM030','AM065','AM070','AM071','AM075','AM080'))
    field_information['GGDM 3.0']['StorageSrf']['GDBV'] = ('Enumeration',('AM010','AM011','AM030','AM065','AM070','AM071','AM075','AM080'))
    field_information['GGDM 3.0']['StorageSrf']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['StorageSrf']['EnumeratedIndexValues']['GDBV']['AM010']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['StorageSrf']['EnumeratedIndexValues']['GDBV']['AM011']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['StorageSrf']['EnumeratedIndexValues']['GDBV']['AM030']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['StorageSrf']['EnumeratedIndexValues']['GDBV']['AM065']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['StorageSrf']['EnumeratedIndexValues']['GDBV']['AM070']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['StorageSrf']['EnumeratedIndexValues']['GDBV']['AM071']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['StorageSrf']['EnumeratedIndexValues']['GDBV']['AM075']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['StorageSrf']['EnumeratedIndexValues']['GDBV']['AM080']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['StorageSrf']['HEI'] = ('Real',('AM070'))
    field_information['GGDM 3.0']['StorageSrf']['HGT'] = ('Real',('AM010','AM011','AM030','AM065','AM070','AM071','AM075','AM080'))
    field_information['GGDM 3.0']['StorageSrf']['LMC'] = ('Boolean',('AM010','AM011','AM030','AM065','AM070','AM071','AM075','AM080'))
    field_information['GGDM 3.0']['StorageSrf']['LOC'] = ('Enumeration',('AM070'))
    field_information['GGDM 3.0']['StorageSrf']['EnumeratedIndexValues']['LOC'] = {}
    field_information['GGDM 3.0']['StorageSrf']['EnumeratedIndexValues']['LOC']['AM070']  = (-999999,40,44,45,48)
    field_information['GGDM 3.0']['StorageSrf']['LUN'] = ('Boolean',('AM010','AM065','AM070','AM075'))
    field_information['GGDM 3.0']['StorageSrf']['LZN'] = ('Real',('AM010','AM011','AM030','AM065','AM070','AM071','AM075','AM080'))
    field_information['GGDM 3.0']['StorageSrf']['OTH'] = ('StructuredText',('AM010','AM011','AM030','AM065','AM070','AM071','AM075','AM080'))
    field_information['GGDM 3.0']['StorageSrf']['PCF'] = ('Enumeration',('AM010','AM011','AM030','AM065','AM070','AM071','AM075','AM080'))
    field_information['GGDM 3.0']['StorageSrf']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['StorageSrf']['EnumeratedIndexValues']['PCF']['AM010']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['StorageSrf']['EnumeratedIndexValues']['PCF']['AM011']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['StorageSrf']['EnumeratedIndexValues']['PCF']['AM030']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['StorageSrf']['EnumeratedIndexValues']['PCF']['AM065']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['StorageSrf']['EnumeratedIndexValues']['PCF']['AM070']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['StorageSrf']['EnumeratedIndexValues']['PCF']['AM071']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['StorageSrf']['EnumeratedIndexValues']['PCF']['AM075']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['StorageSrf']['EnumeratedIndexValues']['PCF']['AM080']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['StorageSrf']['PMPR'] = ('Boolean',('AM070','AM080'))
    field_information['GGDM 3.0']['StorageSrf']['PPO'] = ('Enumeration',('AM010','AM070','AM071'))
    field_information['GGDM 3.0']['StorageSrf']['EnumeratedIndexValues']['PPO'] = {}
    field_information['GGDM 3.0']['StorageSrf']['EnumeratedIndexValues']['PPO']['AM010']  = (-999999,1,3,16,18,19,21,38,45,46,53,63,83,90,95,96,110,116,117,120,122,214,999)
    field_information['GGDM 3.0']['StorageSrf']['EnumeratedIndexValues']['PPO']['AM070']  = (-999999,16,45,46,61,62,83,90,101,122,170,214,999)
    field_information['GGDM 3.0']['StorageSrf']['EnumeratedIndexValues']['PPO']['AM071']  = (-999999,16,45,46,61,62,83,214,999)
    field_information['GGDM 3.0']['StorageSrf']['PPO2'] = ('Enumeration',('AM010','AM070','AM071'))
    field_information['GGDM 3.0']['StorageSrf']['EnumeratedIndexValues']['PPO2'] = {}
    field_information['GGDM 3.0']['StorageSrf']['EnumeratedIndexValues']['PPO2']['AM010']  = (-999999,1,3,16,18,19,21,38,45,46,53,63,83,90,95,96,110,116,117,120,122,214,999)
    field_information['GGDM 3.0']['StorageSrf']['EnumeratedIndexValues']['PPO2']['AM070']  = (-999999,16,45,46,61,62,83,90,101,122,170,214,999)
    field_information['GGDM 3.0']['StorageSrf']['EnumeratedIndexValues']['PPO2']['AM071']  = (-999999,16,45,46,61,62,83,214,999)
    field_information['GGDM 3.0']['StorageSrf']['PPO3'] = ('Enumeration',('AM010','AM070','AM071'))
    field_information['GGDM 3.0']['StorageSrf']['EnumeratedIndexValues']['PPO3'] = {}
    field_information['GGDM 3.0']['StorageSrf']['EnumeratedIndexValues']['PPO3']['AM010']  = (-999999,1,3,16,18,19,21,38,45,46,53,63,83,90,95,96,110,116,117,120,122,214,999)
    field_information['GGDM 3.0']['StorageSrf']['EnumeratedIndexValues']['PPO3']['AM070']  = (-999999,16,45,46,61,62,83,90,101,122,170,214,999)
    field_information['GGDM 3.0']['StorageSrf']['EnumeratedIndexValues']['PPO3']['AM071']  = (-999999,16,45,46,61,62,83,214,999)
    field_information['GGDM 3.0']['StorageSrf']['SHT'] = ('Enumeration',('AM011'))
    field_information['GGDM 3.0']['StorageSrf']['EnumeratedIndexValues']['SHT'] = {}
    field_information['GGDM 3.0']['StorageSrf']['EnumeratedIndexValues']['SHT']['AM011']  = (-999999,1,2,3,4,5,999)
    field_information['GGDM 3.0']['StorageSrf']['SPT'] = ('Boolean',('AM011','AM070','AM080'))
    field_information['GGDM 3.0']['StorageSrf']['SSC'] = ('Enumeration',('AM070','AM080'))
    field_information['GGDM 3.0']['StorageSrf']['EnumeratedIndexValues']['SSC'] = {}
    field_information['GGDM 3.0']['StorageSrf']['EnumeratedIndexValues']['SSC']['AM070']  = (-999999,2,4,12,17,59,65,66,71,87,88,89,91,92,94,99,100,101,999)
    field_information['GGDM 3.0']['StorageSrf']['EnumeratedIndexValues']['SSC']['AM080']  = (-999999,17,65,66,71,88,89,92,94,100,999)
    field_information['GGDM 3.0']['StorageSrf']['SSR'] = ('Enumeration',('AM030'))
    field_information['GGDM 3.0']['StorageSrf']['EnumeratedIndexValues']['SSR'] = {}
    field_information['GGDM 3.0']['StorageSrf']['EnumeratedIndexValues']['SSR']['AM030']  = (-999999,6,7,38,40,41,42,999)
    field_information['GGDM 3.0']['StorageSrf']['SSR2'] = ('Enumeration',('AM030'))
    field_information['GGDM 3.0']['StorageSrf']['EnumeratedIndexValues']['SSR2'] = {}
    field_information['GGDM 3.0']['StorageSrf']['EnumeratedIndexValues']['SSR2']['AM030']  = (-999999,6,7,38,40,41,42,999)
    field_information['GGDM 3.0']['StorageSrf']['SSR3'] = ('Enumeration',('AM030'))
    field_information['GGDM 3.0']['StorageSrf']['EnumeratedIndexValues']['SSR3'] = {}
    field_information['GGDM 3.0']['StorageSrf']['EnumeratedIndexValues']['SSR3']['AM030']  = (-999999,6,7,38,40,41,42,999)
    field_information['GGDM 3.0']['StorageSrf']['UFI'] = ('StructuredText',('AM010','AM011','AM030','AM065','AM070','AM071','AM075','AM080'))
    field_information['GGDM 3.0']['StorageSrf']['VCM'] = ('Enumeration',('AM011','AM030','AM070'))
    field_information['GGDM 3.0']['StorageSrf']['EnumeratedIndexValues']['VCM'] = {}
    field_information['GGDM 3.0']['StorageSrf']['EnumeratedIndexValues']['VCM']['AM011']  = (-999999,2,4,7,8,9,12,13,15,17,18,999)
    field_information['GGDM 3.0']['StorageSrf']['EnumeratedIndexValues']['VCM']['AM030']  = (-999999,2,4,7,8,9,12,13,15,18,999)
    field_information['GGDM 3.0']['StorageSrf']['EnumeratedIndexValues']['VCM']['AM070']  = (-999999,2,4,7,8,9,12,13,15,999)
    field_information['GGDM 3.0']['StorageSrf']['VCM2'] = ('Enumeration',('AM011','AM030','AM070'))
    field_information['GGDM 3.0']['StorageSrf']['EnumeratedIndexValues']['VCM2'] = {}
    field_information['GGDM 3.0']['StorageSrf']['EnumeratedIndexValues']['VCM2']['AM011']  = (-999999,2,4,7,8,9,12,13,15,17,18,999)
    field_information['GGDM 3.0']['StorageSrf']['EnumeratedIndexValues']['VCM2']['AM030']  = (-999999,2,4,7,8,9,12,13,15,18,999)
    field_information['GGDM 3.0']['StorageSrf']['EnumeratedIndexValues']['VCM2']['AM070']  = (-999999,2,4,7,8,9,12,13,15,999)
    field_information['GGDM 3.0']['StorageSrf']['VCM3'] = ('Enumeration',('AM011','AM030','AM070'))
    field_information['GGDM 3.0']['StorageSrf']['EnumeratedIndexValues']['VCM3'] = {}
    field_information['GGDM 3.0']['StorageSrf']['EnumeratedIndexValues']['VCM3']['AM011']  = (-999999,2,4,7,8,9,12,13,15,17,18,999)
    field_information['GGDM 3.0']['StorageSrf']['EnumeratedIndexValues']['VCM3']['AM030']  = (-999999,2,4,7,8,9,12,13,15,18,999)
    field_information['GGDM 3.0']['StorageSrf']['EnumeratedIndexValues']['VCM3']['AM070']  = (-999999,2,4,7,8,9,12,13,15,999)
    field_information['GGDM 3.0']['StorageSrf']['VLM'] = ('Real',('AM070','AM080'))
    field_information['GGDM 3.0']['StorageSrf']['VOI'] = ('StructuredText',('AM010','AM030','AM070','AM080'))
    field_information['GGDM 3.0']['StorageSrf']['WDST'] = ('Enumeration',('AM080'))
    field_information['GGDM 3.0']['StorageSrf']['EnumeratedIndexValues']['WDST'] = {}
    field_information['GGDM 3.0']['StorageSrf']['EnumeratedIndexValues']['WDST']['AM080']  = (-999999,1,2,3,4,5,6,7,8,998,999)
    field_information['GGDM 3.0']['StorageSrf']['WID'] = ('Real',('AM010','AM011','AM030','AM065','AM070','AM071','AM075','AM080'))
    field_information['GGDM 3.0']['StorageSrf']['YWQ'] = ('Enumeration',('AM070','AM080'))
    field_information['GGDM 3.0']['StorageSrf']['EnumeratedIndexValues']['YWQ'] = {}
    field_information['GGDM 3.0']['StorageSrf']['EnumeratedIndexValues']['YWQ']['AM070']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['StorageSrf']['EnumeratedIndexValues']['YWQ']['AM080']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['StorageSrf']['ZI001_SDV'] = ('StructuredText',('AM010','AM011','AM030','AM065','AM070','AM071','AM075','AM080'))
    field_information['GGDM 3.0']['StorageSrf']['ZI001_SRT'] = ('Enumeration',('AM010','AM011','AM030','AM065','AM070','AM071','AM075','AM080'))
    field_information['GGDM 3.0']['StorageSrf']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['StorageSrf']['EnumeratedIndexValues']['ZI001_SRT']['AM010']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['StorageSrf']['EnumeratedIndexValues']['ZI001_SRT']['AM011']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['StorageSrf']['EnumeratedIndexValues']['ZI001_SRT']['AM030']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['StorageSrf']['EnumeratedIndexValues']['ZI001_SRT']['AM065']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['StorageSrf']['EnumeratedIndexValues']['ZI001_SRT']['AM070']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['StorageSrf']['EnumeratedIndexValues']['ZI001_SRT']['AM071']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['StorageSrf']['EnumeratedIndexValues']['ZI001_SRT']['AM075']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['StorageSrf']['EnumeratedIndexValues']['ZI001_SRT']['AM080']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['StorageSrf']['ZI002_UFI'] = ('StructuredText',('AM010','AM011','AM030','AM065','AM070','AM071','AM075','AM080'))
    field_information['GGDM 3.0']['StorageSrf']['ZI004_RCG'] = ('Enumeration',('AM010','AM011','AM030','AM065','AM070','AM071','AM075','AM080'))
    field_information['GGDM 3.0']['StorageSrf']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['StorageSrf']['EnumeratedIndexValues']['ZI004_RCG']['AM010']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['StorageSrf']['EnumeratedIndexValues']['ZI004_RCG']['AM011']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['StorageSrf']['EnumeratedIndexValues']['ZI004_RCG']['AM030']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['StorageSrf']['EnumeratedIndexValues']['ZI004_RCG']['AM065']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['StorageSrf']['EnumeratedIndexValues']['ZI004_RCG']['AM070']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['StorageSrf']['EnumeratedIndexValues']['ZI004_RCG']['AM071']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['StorageSrf']['EnumeratedIndexValues']['ZI004_RCG']['AM075']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['StorageSrf']['EnumeratedIndexValues']['ZI004_RCG']['AM080']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['StorageSrf']['ZI005_FNA'] = ('String',('AM010','AM011','AM030','AM065','AM070','AM071','AM075','AM080'))
    field_information['GGDM 3.0']['StorageSrf']['ZI005_FNA2'] = ('String',('AM070','AM080'))
    field_information['GGDM 3.0']['StorageSrf']['ZI005_GNT'] = ('Enumeration',('AM010','AM011','AM030','AM065','AM070','AM071','AM075','AM080'))
    field_information['GGDM 3.0']['StorageSrf']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['StorageSrf']['EnumeratedIndexValues']['ZI005_GNT']['AM010']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['StorageSrf']['EnumeratedIndexValues']['ZI005_GNT']['AM011']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['StorageSrf']['EnumeratedIndexValues']['ZI005_GNT']['AM030']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['StorageSrf']['EnumeratedIndexValues']['ZI005_GNT']['AM065']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['StorageSrf']['EnumeratedIndexValues']['ZI005_GNT']['AM070']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['StorageSrf']['EnumeratedIndexValues']['ZI005_GNT']['AM071']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['StorageSrf']['EnumeratedIndexValues']['ZI005_GNT']['AM075']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['StorageSrf']['EnumeratedIndexValues']['ZI005_GNT']['AM080']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['StorageSrf']['ZI005_GNT2'] = ('Enumeration',('AM070','AM080'))
    field_information['GGDM 3.0']['StorageSrf']['EnumeratedIndexValues']['ZI005_GNT2'] = {}
    field_information['GGDM 3.0']['StorageSrf']['EnumeratedIndexValues']['ZI005_GNT2']['AM070']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['StorageSrf']['EnumeratedIndexValues']['ZI005_GNT2']['AM080']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['StorageSrf']['ZI005_NFN'] = ('String',('AM010','AM011','AM030','AM065','AM070','AM071','AM075','AM080'))
    field_information['GGDM 3.0']['StorageSrf']['ZI005_NFN2'] = ('String',('AM070','AM080'))
    field_information['GGDM 3.0']['StorageSrf']['ZI006_MEM'] = ('String',('AM010','AM011','AM030','AM065','AM070','AM071','AM075','AM080'))
    field_information['GGDM 3.0']['StorageSrf']['ZI020_GE4'] = ('CodeList',('AM010','AM011','AM030','AM065','AM070','AM071','AM075','AM080'))
    field_information['GGDM 3.0']['StorageSrf']['ZI024_ASE'] = ('Real',('AM070','AM080'))
    field_information['GGDM 3.0']['StorageSrf']['ZI024_CFR'] = ('Real',('AM070','AM080'))
    field_information['GGDM 3.0']['StorageSrf']['ZI024_CLO'] = ('Real',('AM070','AM080'))
    field_information['GGDM 3.0']['StorageSrf']['ZI024_CYN'] = ('Real',('AM070','AM080'))
    field_information['GGDM 3.0']['StorageSrf']['ZI024_FMR'] = ('Real',('AM070','AM080'))
    field_information['GGDM 3.0']['StorageSrf']['ZI024_FRR'] = ('Real',('AM070','AM080'))
    field_information['GGDM 3.0']['StorageSrf']['ZI024_HAR'] = ('Real',('AM070','AM080'))
    field_information['GGDM 3.0']['StorageSrf']['ZI024_HYP'] = ('Enumeration',('AM080'))
    field_information['GGDM 3.0']['StorageSrf']['EnumeratedIndexValues']['ZI024_HYP'] = {}
    field_information['GGDM 3.0']['StorageSrf']['EnumeratedIndexValues']['ZI024_HYP']['AM080']  = (-999999,1,2,4)
    field_information['GGDM 3.0']['StorageSrf']['ZI024_MGN'] = ('Real',('AM070','AM080'))
    field_information['GGDM 3.0']['StorageSrf']['ZI024_PHW'] = ('Real',('AM070','AM080'))
    field_information['GGDM 3.0']['StorageSrf']['ZI024_SCC'] = ('Enumeration',('AM070','AM080'))
    field_information['GGDM 3.0']['StorageSrf']['EnumeratedIndexValues']['ZI024_SCC'] = {}
    field_information['GGDM 3.0']['StorageSrf']['EnumeratedIndexValues']['ZI024_SCC']['AM070']  = (-999999,1,4,10,11,12,13,14,998,999)
    field_information['GGDM 3.0']['StorageSrf']['EnumeratedIndexValues']['ZI024_SCC']['AM080']  = (-999999,1,4,10,11,12,13,14,998,999)
    field_information['GGDM 3.0']['StorageSrf']['ZI024_SUL'] = ('Real',('AM070','AM080'))
    field_information['GGDM 3.0']['StorageSrf']['ZI024_TDS'] = ('Real',('AM070','AM080'))
    field_information['GGDM 3.0']['StorageSrf']['ZI024_TEP'] = ('Real',('AM070','AM080'))
    field_information['GGDM 3.0']['StorageSrf']['ZI024_TUR'] = ('Real',('AM070','AM080'))
    field_information['GGDM 3.0']['StorageSrf']['ZI024_WAC'] = ('Real',('AM070','AM080'))
    field_information['GGDM 3.0']['StorageSrf']['ZI024_WTNO'] = ('Real',('AM070','AM080'))
    field_information['GGDM 3.0']['StorageSrf']['ZI024_WUR'] = ('Enumeration',('AM070','AM080'))
    field_information['GGDM 3.0']['StorageSrf']['EnumeratedIndexValues']['ZI024_WUR'] = {}
    field_information['GGDM 3.0']['StorageSrf']['EnumeratedIndexValues']['ZI024_WUR']['AM070']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['StorageSrf']['EnumeratedIndexValues']['ZI024_WUR']['AM080']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['StorageSrf']['ZI024_WUR2'] = ('Enumeration',('AM070','AM080'))
    field_information['GGDM 3.0']['StorageSrf']['EnumeratedIndexValues']['ZI024_WUR2'] = {}
    field_information['GGDM 3.0']['StorageSrf']['EnumeratedIndexValues']['ZI024_WUR2']['AM070']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['StorageSrf']['EnumeratedIndexValues']['ZI024_WUR2']['AM080']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['StorageSrf']['ZI024_WUR3'] = ('Enumeration',('AM070','AM080'))
    field_information['GGDM 3.0']['StorageSrf']['EnumeratedIndexValues']['ZI024_WUR3'] = {}
    field_information['GGDM 3.0']['StorageSrf']['EnumeratedIndexValues']['ZI024_WUR3']['AM070']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['StorageSrf']['EnumeratedIndexValues']['ZI024_WUR3']['AM080']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['StorageSrf']['ZI024_WUR4'] = ('Enumeration',('AM070','AM080'))
    field_information['GGDM 3.0']['StorageSrf']['EnumeratedIndexValues']['ZI024_WUR4'] = {}
    field_information['GGDM 3.0']['StorageSrf']['EnumeratedIndexValues']['ZI024_WUR4']['AM070']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['StorageSrf']['EnumeratedIndexValues']['ZI024_WUR4']['AM080']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['StorageSrf']['ZI026_CTUC'] = ('Enumeration',('AM010','AM011','AM030','AM065','AM070','AM071','AM075','AM080'))
    field_information['GGDM 3.0']['StorageSrf']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['StorageSrf']['EnumeratedIndexValues']['ZI026_CTUC']['AM010']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['StorageSrf']['EnumeratedIndexValues']['ZI026_CTUC']['AM011']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['StorageSrf']['EnumeratedIndexValues']['ZI026_CTUC']['AM030']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['StorageSrf']['EnumeratedIndexValues']['ZI026_CTUC']['AM065']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['StorageSrf']['EnumeratedIndexValues']['ZI026_CTUC']['AM070']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['StorageSrf']['EnumeratedIndexValues']['ZI026_CTUC']['AM071']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['StorageSrf']['EnumeratedIndexValues']['ZI026_CTUC']['AM075']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['StorageSrf']['EnumeratedIndexValues']['ZI026_CTUC']['AM080']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['StorageSrf']['ZI026_CTUL'] = ('integer',('AM010','AM011','AM030','AM065','AM070','AM071','AM075','AM080'))
    field_information['GGDM 3.0']['StorageSrf']['ZI026_CTUU'] = ('integer',('AM010','AM011','AM030','AM065','AM070','AM071','AM075','AM080'))
    field_information['GGDM 3.0']['StorageSrf']['ZI031S_URI'] = ('StructuredText',('AM010','AM011','AM030','AM065','AM070','AM071','AM075','AM080'))
    field_information['GGDM 3.0']['StorageSrf']['ZI039S_UFI'] = ('StructuredText',('AM010','AM011','AM030','AM065','AM070','AM071','AM075','AM080'))
    field_information['GGDM 3.0']['StorageSrf']['ZSAX_RS0'] = ('CodeList',('AM010','AM011','AM030','AM065','AM070','AM071','AM075','AM080'))
    field_information['GGDM 3.0']['StorageSrf']['ZSAX_RX0'] = ('StructuredText',('AM010','AM011','AM030','AM065','AM070','AM071','AM075','AM080'))
    field_information['GGDM 3.0']['StorageSrf']['ZSAX_RX3'] = ('StructuredText',('AM010','AM011','AM030','AM065','AM070','AM071','AM075','AM080'))
    field_information['GGDM 3.0']['StorageSrf']['ZSAX_RX4'] = ('StructuredText',('AM010','AM011','AM030','AM065','AM070','AM071','AM075','AM080'))
    field_information['GGDM 3.0']['StorageSrf']['ZVH'] = ('Real',('AM010','AM011','AM030','AM065','AM070','AM071','AM075','AM080'))
    field_information['GGDM 3.0']['StructureCrv']['AOO'] = ('Real',('AL018','AL080'))
    field_information['GGDM 3.0']['StructureCrv']['ARA'] = ('Real',('AL018','AL080','AL140','AQ150'))
    field_information['GGDM 3.0']['StructureCrv']['AWP'] = ('Boolean',('AL018','AL080'))
    field_information['GGDM 3.0']['StructureCrv']['BAT'] = ('Enumeration',('AL070','AL260'))
    field_information['GGDM 3.0']['StructureCrv']['EnumeratedIndexValues']['BAT'] = {}
    field_information['GGDM 3.0']['StructureCrv']['EnumeratedIndexValues']['BAT']['AL070']  = (-999999,1,2,3,4,5,999)
    field_information['GGDM 3.0']['StructureCrv']['EnumeratedIndexValues']['BAT']['AL260']  = (-999999,1,2,3,4,5,999)
    field_information['GGDM 3.0']['StructureCrv']['BEN'] = ('StructuredText',('AL018','AL070','AL080','AL140','AL260','AQ150'))
    field_information['GGDM 3.0']['StructureCrv']['BSU'] = ('Enumeration',('AL018'))
    field_information['GGDM 3.0']['StructureCrv']['EnumeratedIndexValues']['BSU'] = {}
    field_information['GGDM 3.0']['StructureCrv']['EnumeratedIndexValues']['BSU']['AL018']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,13,14,15,16,17,18,999)
    field_information['GGDM 3.0']['StructureCrv']['CAA'] = ('Enumeration',('AL070','AL080','AL260'))
    field_information['GGDM 3.0']['StructureCrv']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['StructureCrv']['EnumeratedIndexValues']['CAA']['AL070']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['StructureCrv']['EnumeratedIndexValues']['CAA']['AL080']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['StructureCrv']['EnumeratedIndexValues']['CAA']['AL260']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['StructureCrv']['CNCP'] = ('StructuredText',('AL018','AL080','AL140','AQ150'))
    field_information['GGDM 3.0']['StructureCrv']['COS'] = ('Enumeration',('AL018','AL080','AL140','AQ150'))
    field_information['GGDM 3.0']['StructureCrv']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['StructureCrv']['EnumeratedIndexValues']['COS']['AL018']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['StructureCrv']['EnumeratedIndexValues']['COS']['AL080']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['StructureCrv']['EnumeratedIndexValues']['COS']['AL140']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['StructureCrv']['EnumeratedIndexValues']['COS']['AQ150']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['StructureCrv']['CRM'] = ('Enumeration',('AL080'))
    field_information['GGDM 3.0']['StructureCrv']['EnumeratedIndexValues']['CRM'] = {}
    field_information['GGDM 3.0']['StructureCrv']['EnumeratedIndexValues']['CRM']['AL080']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['StructureCrv']['F_CODE'] = ('CONSTRAINED_STRING',('AL018','AL070','AL080','AL140','AL260','AQ150'))
    field_information['GGDM 3.0']['StructureCrv']['FEF'] = ('Enumeration',('AL070'))
    field_information['GGDM 3.0']['StructureCrv']['EnumeratedIndexValues']['FEF'] = {}
    field_information['GGDM 3.0']['StructureCrv']['EnumeratedIndexValues']['FEF']['AL070']  = (-999999,1,2,3,4,5,999)
    field_information['GGDM 3.0']['StructureCrv']['FFN'] = ('Enumeration',('AL080'))
    field_information['GGDM 3.0']['StructureCrv']['EnumeratedIndexValues']['FFN'] = {}
    field_information['GGDM 3.0']['StructureCrv']['EnumeratedIndexValues']['FFN']['AL080']  = (-999999,99,480,486,490,495,505,999)
    field_information['GGDM 3.0']['StructureCrv']['FFN2'] = ('Enumeration',('AL080'))
    field_information['GGDM 3.0']['StructureCrv']['EnumeratedIndexValues']['FFN2'] = {}
    field_information['GGDM 3.0']['StructureCrv']['EnumeratedIndexValues']['FFN2']['AL080']  = (-999999,99,480,486,490,495,505,999)
    field_information['GGDM 3.0']['StructureCrv']['FFN3'] = ('Enumeration',('AL080'))
    field_information['GGDM 3.0']['StructureCrv']['EnumeratedIndexValues']['FFN3'] = {}
    field_information['GGDM 3.0']['StructureCrv']['EnumeratedIndexValues']['FFN3']['AL080']  = (-999999,99,480,486,490,495,505,999)
    field_information['GGDM 3.0']['StructureCrv']['FTI'] = ('Enumeration',('AL070'))
    field_information['GGDM 3.0']['StructureCrv']['EnumeratedIndexValues']['FTI'] = {}
    field_information['GGDM 3.0']['StructureCrv']['EnumeratedIndexValues']['FTI']['AL070']  = (-999999,1,2,5,6,7,8,9,999)
    field_information['GGDM 3.0']['StructureCrv']['FUFI'] = ('StructuredText',('AL018','AL070','AL080','AL140','AL260','AQ150'))
    field_information['GGDM 3.0']['StructureCrv']['FURL'] = ('StructuredText',('AL018','AL070','AL080','AL140','AL260','AQ150'))
    field_information['GGDM 3.0']['StructureCrv']['GDBV'] = ('Enumeration',('AL018','AL070','AL080','AL140','AL260','AQ150'))
    field_information['GGDM 3.0']['StructureCrv']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['StructureCrv']['EnumeratedIndexValues']['GDBV']['AL018']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['StructureCrv']['EnumeratedIndexValues']['GDBV']['AL070']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['StructureCrv']['EnumeratedIndexValues']['GDBV']['AL080']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['StructureCrv']['EnumeratedIndexValues']['GDBV']['AL140']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['StructureCrv']['EnumeratedIndexValues']['GDBV']['AL260']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['StructureCrv']['EnumeratedIndexValues']['GDBV']['AQ150']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['StructureCrv']['HEI'] = ('Real',('AL018'))
    field_information['GGDM 3.0']['StructureCrv']['HGT'] = ('Real',('AL018','AL070','AL080','AL260','AQ150'))
    field_information['GGDM 3.0']['StructureCrv']['LMC'] = ('Boolean',('AL018','AL070','AL080','AL140','AL260'))
    field_information['GGDM 3.0']['StructureCrv']['LZN'] = ('Real',('AL018','AL070','AL080','AL140','AL260','AQ150'))
    field_information['GGDM 3.0']['StructureCrv']['MCC'] = ('Enumeration',('AL070','AL260'))
    field_information['GGDM 3.0']['StructureCrv']['EnumeratedIndexValues']['MCC'] = {}
    field_information['GGDM 3.0']['StructureCrv']['EnumeratedIndexValues']['MCC']['AL070']  = (-999999,9,21,62,64,108,117,999)
    field_information['GGDM 3.0']['StructureCrv']['EnumeratedIndexValues']['MCC']['AL260']  = (-999999,8,9,21,62,64,77,83,107,108,117,150,999)
    field_information['GGDM 3.0']['StructureCrv']['MCC2'] = ('Enumeration',('AL070','AL260'))
    field_information['GGDM 3.0']['StructureCrv']['EnumeratedIndexValues']['MCC2'] = {}
    field_information['GGDM 3.0']['StructureCrv']['EnumeratedIndexValues']['MCC2']['AL070']  = (-999999,9,21,62,64,108,117,999)
    field_information['GGDM 3.0']['StructureCrv']['EnumeratedIndexValues']['MCC2']['AL260']  = (-999999,8,9,21,62,64,77,83,107,108,117,150,999)
    field_information['GGDM 3.0']['StructureCrv']['MCC3'] = ('Enumeration',('AL070','AL260'))
    field_information['GGDM 3.0']['StructureCrv']['EnumeratedIndexValues']['MCC3'] = {}
    field_information['GGDM 3.0']['StructureCrv']['EnumeratedIndexValues']['MCC3']['AL070']  = (-999999,9,21,62,64,108,117,999)
    field_information['GGDM 3.0']['StructureCrv']['EnumeratedIndexValues']['MCC3']['AL260']  = (-999999,8,9,21,62,64,77,83,107,108,117,150,999)
    field_information['GGDM 3.0']['StructureCrv']['OTH'] = ('StructuredText',('AL018','AL070','AL080','AL140','AL260','AQ150'))
    field_information['GGDM 3.0']['StructureCrv']['PCF'] = ('Enumeration',('AL018','AL070','AL080','AL140','AL260','AQ150'))
    field_information['GGDM 3.0']['StructureCrv']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['StructureCrv']['EnumeratedIndexValues']['PCF']['AL018']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['StructureCrv']['EnumeratedIndexValues']['PCF']['AL070']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['StructureCrv']['EnumeratedIndexValues']['PCF']['AL080']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['StructureCrv']['EnumeratedIndexValues']['PCF']['AL140']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['StructureCrv']['EnumeratedIndexValues']['PCF']['AL260']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['StructureCrv']['EnumeratedIndexValues']['PCF']['AQ150']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['StructureCrv']['PFHC'] = ('Enumeration',('AL070','AL260'))
    field_information['GGDM 3.0']['StructureCrv']['EnumeratedIndexValues']['PFHC'] = {}
    field_information['GGDM 3.0']['StructureCrv']['EnumeratedIndexValues']['PFHC']['AL070']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['StructureCrv']['EnumeratedIndexValues']['PFHC']['AL260']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['StructureCrv']['PFHL'] = ('real',('AL070','AL260'))
    field_information['GGDM 3.0']['StructureCrv']['PFHU'] = ('real',('AL070','AL260'))
    field_information['GGDM 3.0']['StructureCrv']['THI'] = ('Real',('AL070','AL260'))
    field_information['GGDM 3.0']['StructureCrv']['UFI'] = ('StructuredText',('AL018','AL070','AL080','AL140','AL260','AQ150'))
    field_information['GGDM 3.0']['StructureCrv']['VCM'] = ('Enumeration',('AL080'))
    field_information['GGDM 3.0']['StructureCrv']['EnumeratedIndexValues']['VCM'] = {}
    field_information['GGDM 3.0']['StructureCrv']['EnumeratedIndexValues']['VCM']['AL080']  = (-999999,2,7,9,15,999)
    field_information['GGDM 3.0']['StructureCrv']['VCM2'] = ('Enumeration',('AL080'))
    field_information['GGDM 3.0']['StructureCrv']['EnumeratedIndexValues']['VCM2'] = {}
    field_information['GGDM 3.0']['StructureCrv']['EnumeratedIndexValues']['VCM2']['AL080']  = (-999999,2,7,9,15,999)
    field_information['GGDM 3.0']['StructureCrv']['VCM3'] = ('Enumeration',('AL080'))
    field_information['GGDM 3.0']['StructureCrv']['EnumeratedIndexValues']['VCM3'] = {}
    field_information['GGDM 3.0']['StructureCrv']['EnumeratedIndexValues']['VCM3']['AL080']  = (-999999,2,7,9,15,999)
    field_information['GGDM 3.0']['StructureCrv']['VOI'] = ('StructuredText',('AL018','AL080'))
    field_information['GGDM 3.0']['StructureCrv']['WID'] = ('Real',('AL018','AL080','AL140','AQ150'))
    field_information['GGDM 3.0']['StructureCrv']['WTI'] = ('Enumeration',('AL260'))
    field_information['GGDM 3.0']['StructureCrv']['EnumeratedIndexValues']['WTI'] = {}
    field_information['GGDM 3.0']['StructureCrv']['EnumeratedIndexValues']['WTI']['AL260']  = (-999999,1,2,999)
    field_information['GGDM 3.0']['StructureCrv']['ZI001_SDV'] = ('StructuredText',('AL018','AL070','AL080','AL140','AL260','AQ150'))
    field_information['GGDM 3.0']['StructureCrv']['ZI001_SRT'] = ('Enumeration',('AL018','AL070','AL080','AL140','AL260','AQ150'))
    field_information['GGDM 3.0']['StructureCrv']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['StructureCrv']['EnumeratedIndexValues']['ZI001_SRT']['AL018']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['StructureCrv']['EnumeratedIndexValues']['ZI001_SRT']['AL070']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['StructureCrv']['EnumeratedIndexValues']['ZI001_SRT']['AL080']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['StructureCrv']['EnumeratedIndexValues']['ZI001_SRT']['AL140']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['StructureCrv']['EnumeratedIndexValues']['ZI001_SRT']['AL260']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['StructureCrv']['EnumeratedIndexValues']['ZI001_SRT']['AQ150']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['StructureCrv']['ZI002_UFI'] = ('StructuredText',('AL018','AL070','AL080','AL140','AL260','AQ150'))
    field_information['GGDM 3.0']['StructureCrv']['ZI004_RCG'] = ('Enumeration',('AL018','AL070','AL080','AL140','AL260','AQ150'))
    field_information['GGDM 3.0']['StructureCrv']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['StructureCrv']['EnumeratedIndexValues']['ZI004_RCG']['AL018']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['StructureCrv']['EnumeratedIndexValues']['ZI004_RCG']['AL070']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['StructureCrv']['EnumeratedIndexValues']['ZI004_RCG']['AL080']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['StructureCrv']['EnumeratedIndexValues']['ZI004_RCG']['AL140']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['StructureCrv']['EnumeratedIndexValues']['ZI004_RCG']['AL260']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['StructureCrv']['EnumeratedIndexValues']['ZI004_RCG']['AQ150']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['StructureCrv']['ZI005_FNA'] = ('String',('AL018','AL140','AL260','AQ150'))
    field_information['GGDM 3.0']['StructureCrv']['ZI005_GNT'] = ('Enumeration',('AL018','AL140','AL260','AQ150'))
    field_information['GGDM 3.0']['StructureCrv']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['StructureCrv']['EnumeratedIndexValues']['ZI005_GNT']['AL018']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['StructureCrv']['EnumeratedIndexValues']['ZI005_GNT']['AL140']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['StructureCrv']['EnumeratedIndexValues']['ZI005_GNT']['AL260']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['StructureCrv']['EnumeratedIndexValues']['ZI005_GNT']['AQ150']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['StructureCrv']['ZI005_NFN'] = ('String',('AL018','AL140','AL260','AQ150'))
    field_information['GGDM 3.0']['StructureCrv']['ZI006_MEM'] = ('String',('AL018','AL070','AL080','AL140','AL260','AQ150'))
    field_information['GGDM 3.0']['StructureCrv']['ZI018_WIT'] = ('Enumeration',('AL018'))
    field_information['GGDM 3.0']['StructureCrv']['EnumeratedIndexValues']['ZI018_WIT'] = {}
    field_information['GGDM 3.0']['StructureCrv']['EnumeratedIndexValues']['ZI018_WIT']['AL018']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['StructureCrv']['ZI020_GE4'] = ('CodeList',('AL018','AL070','AL080','AL140','AL260','AQ150'))
    field_information['GGDM 3.0']['StructureCrv']['ZI026_CTUC'] = ('Enumeration',('AL018','AL070','AL080','AL140','AL260','AQ150'))
    field_information['GGDM 3.0']['StructureCrv']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['StructureCrv']['EnumeratedIndexValues']['ZI026_CTUC']['AL018']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['StructureCrv']['EnumeratedIndexValues']['ZI026_CTUC']['AL070']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['StructureCrv']['EnumeratedIndexValues']['ZI026_CTUC']['AL080']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['StructureCrv']['EnumeratedIndexValues']['ZI026_CTUC']['AL140']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['StructureCrv']['EnumeratedIndexValues']['ZI026_CTUC']['AL260']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['StructureCrv']['EnumeratedIndexValues']['ZI026_CTUC']['AQ150']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['StructureCrv']['ZI026_CTUL'] = ('integer',('AL018','AL070','AL080','AL140','AL260','AQ150'))
    field_information['GGDM 3.0']['StructureCrv']['ZI026_CTUU'] = ('integer',('AL018','AL070','AL080','AL140','AL260','AQ150'))
    field_information['GGDM 3.0']['StructureCrv']['ZI031S_URI'] = ('StructuredText',('AL018','AL070','AL080','AL140','AL260','AQ150'))
    field_information['GGDM 3.0']['StructureCrv']['ZI039S_UFI'] = ('StructuredText',('AL018','AL070','AL080','AL140','AL260','AQ150'))
    field_information['GGDM 3.0']['StructureCrv']['ZSAX_RS0'] = ('CodeList',('AL018','AL070','AL080','AL140','AL260','AQ150'))
    field_information['GGDM 3.0']['StructureCrv']['ZSAX_RX0'] = ('StructuredText',('AL018','AL070','AL080','AL140','AL260','AQ150'))
    field_information['GGDM 3.0']['StructureCrv']['ZSAX_RX3'] = ('StructuredText',('AL018','AL070','AL080','AL140','AL260','AQ150'))
    field_information['GGDM 3.0']['StructureCrv']['ZSAX_RX4'] = ('StructuredText',('AL018','AL070','AL080','AL140','AL260','AQ150'))
    field_information['GGDM 3.0']['StructureCrv']['ZVH'] = ('Real',('AL018','AL070','AL080','AL260','AQ150'))
    field_information['GGDM 3.0']['StructurePnt']['ADR'] = ('String',('AL013','AL019','AL099','AL142','AL250','AL371'))
    field_information['GGDM 3.0']['StructurePnt']['AOO'] = ('Real',('AF060','AG050','AL013','AL014','AL018','AL019','AL080','AL099','AL110','AL142','AL241','AL371'))
    field_information['GGDM 3.0']['StructurePnt']['ARA'] = ('Real',('AF060','AG050','AL013','AL014','AL018','AL019','AL080','AL099','AL142','AL241','AL250','AL371'))
    field_information['GGDM 3.0']['StructurePnt']['ATB'] = ('Boolean',('AL013'))
    field_information['GGDM 3.0']['StructurePnt']['AWP'] = ('Boolean',('AF060','AG050','AL013','AL014','AL018','AL073','AL080','AL110','AL142','AL241'))
    field_information['GGDM 3.0']['StructurePnt']['BEN'] = ('StructuredText',('AF060','AG050','AL013','AL014','AL018','AL019','AL073','AL080','AL099','AL110','AL142','AL241','AL250','AL371'))
    field_information['GGDM 3.0']['StructurePnt']['BNF'] = ('Integer',('AL013','AL019','AL371'))
    field_information['GGDM 3.0']['StructurePnt']['BSU'] = ('Enumeration',('AL018'))
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['BSU'] = {}
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['BSU']['AL018']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,13,14,15,16,17,18,999)
    field_information['GGDM 3.0']['StructurePnt']['CAA'] = ('Enumeration',('AF060','AG050','AL013','AL014','AL019','AL080','AL099','AL110','AL142','AL241','AL371'))
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['CAA']['AF060']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['CAA']['AG050']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['CAA']['AL013']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['CAA']['AL014']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['CAA']['AL019']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['CAA']['AL080']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['CAA']['AL099']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['CAA']['AL110']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['CAA']['AL142']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['CAA']['AL241']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['CAA']['AL371']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['StructurePnt']['CNCP'] = ('StructuredText',('AF060','AG050','AL013','AL014','AL018','AL019','AL080','AL099','AL142','AL241','AL250','AL371'))
    field_information['GGDM 3.0']['StructurePnt']['COS'] = ('Enumeration',('AF060','AG050','AL013','AL014','AL018','AL019','AL080','AL099','AL142','AL241','AL250','AL371'))
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['COS']['AF060']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['COS']['AG050']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['COS']['AL013']  = (-999999,1,2,3,4,6,8,9,13,14)
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['COS']['AL014']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['COS']['AL018']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['COS']['AL019']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['COS']['AL080']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['COS']['AL099']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['COS']['AL142']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['COS']['AL241']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['COS']['AL250']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['COS']['AL371']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['StructurePnt']['CRM'] = ('Enumeration',('AL080'))
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['CRM'] = {}
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['CRM']['AL080']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['StructurePnt']['DZP'] = ('Real',('AL250'))
    field_information['GGDM 3.0']['StructurePnt']['ETY'] = ('Enumeration',('AF060'))
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['ETY'] = {}
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['ETY']['AF060']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['StructurePnt']['F_CODE'] = ('CONSTRAINED_STRING',('AF060','AG050','AL013','AL014','AL018','AL019','AL073','AL080','AL099','AL110','AL142','AL241','AL250','AL371'))
    field_information['GGDM 3.0']['StructurePnt']['FFN'] = ('Enumeration',('AG050','AL013','AL019','AL080','AL099','AL110','AL142'))
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['FFN'] = {}
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['FFN']['AG050']  = (-999999,343,382,466,470,476,488,548,570,580,610,640,680,681,760,808,830,850,860,887,890,900,930,950,999)
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['FFN']['AL013']  = (-999999,2,3,9,14,15,19,20,21,27,30,35,40,50,60,70,83,87,91,95,99,100,101,102,103,104,105,106,107,110,111,112,113,114,115,116,118,119,120,121,122,123,124,125,129,130,140,150,155,160,161,165,171,181,190,191,192,195,210,221,225,230,231,232,233,234,235,236,237,240,241,242,243,250,251,255,257,260,270,272,280,289,290,301,304,305,306,310,320,321,322,323,324,325,330,331,332,333,334,340,341,342,343,350,351,352,355,356,360,361,362,363,370,372,382,383,385,440,459,460,464,465,466,470,473,474,475,476,477,478,480,481,482,483,484,486,487,488,489,490,491,494,495,496,497,500,501,505,507,508,510,511,512,513,520,525,529,530,535,536,537,538,539,540,541,545,548,549,550,551,552,553,554,555,556,557,558,559,563,570,572,573,574,578,579,580,582,594,601,604,610,612,614,615,616,617,620,621,622,625,626,632,633,640,642,643,651,662,663,671,680,681,691,696,701,706,711,714,717,720,721,722,725,730,741,752,757,760,761,770,775,780,781,791,795,801,807,808,809,810,811,812,813,814,815,817,818,819,821,822,825,826,827,828,829,830,831,832,833,835,836,837,838,839,840,841,842,843,844,845,846,847,848,850,851,852,855,857,860,861,862,863,864,865,866,871,873,875,881,882,883,884,885,887,888,890,891,892,893,894,895,900,902,905,906,907,909,912,913,914,919,921,922,923,930,931,950,954,955,961,962,963,964,965,966,967,970,980,999)
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['FFN']['AL019']  = (-999999,2,480,490,494,495,500,505,508,520,530,722,847,970,999)
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['FFN']['AL080']  = (-999999,99,480,486,490,495,505,999)
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['FFN']['AL099']  = (-999999,2,9,14,557,563,721,722,847,866,881,883,930,970,999)
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['FFN']['AL110']  = (-999999,480,490,495,900,999)
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['FFN']['AL142']  = (-999999,720,721,850,923,999)
    field_information['GGDM 3.0']['StructurePnt']['FFN2'] = ('Enumeration',('AG050','AL013','AL019','AL080','AL099','AL110','AL142'))
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['FFN2'] = {}
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['FFN2']['AG050']  = (-999999,343,382,466,470,476,488,548,570,580,610,640,680,681,760,808,830,850,860,887,890,900,930,950,999)
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['FFN2']['AL013']  = (-999999,2,3,9,14,15,19,20,21,27,30,35,40,50,60,70,83,87,91,95,99,100,101,102,103,104,105,106,107,110,111,112,113,114,115,116,118,119,120,121,122,123,124,125,129,130,140,150,155,160,161,165,171,181,190,191,192,195,210,221,225,230,231,232,233,234,235,236,237,240,241,242,243,250,251,255,257,260,270,272,280,289,290,301,304,305,306,310,320,321,322,323,324,325,330,331,332,333,334,340,341,342,343,350,351,352,355,356,360,361,362,363,370,372,382,383,385,440,459,460,464,465,466,470,473,474,475,476,477,478,480,481,482,483,484,486,487,488,489,490,491,494,495,496,497,500,501,505,507,508,510,511,512,513,520,525,529,530,535,536,537,538,539,540,541,545,548,549,550,551,552,553,554,555,556,557,558,559,563,570,572,573,574,578,579,580,582,594,601,604,610,612,614,615,616,617,620,621,622,625,626,632,633,640,642,643,651,662,663,671,680,681,691,696,701,706,711,714,717,720,721,722,725,730,741,752,757,760,761,770,775,780,781,791,795,801,807,808,809,810,811,812,813,814,815,817,818,819,821,822,825,826,827,828,829,830,831,832,833,835,836,837,838,839,840,841,842,843,844,845,846,847,848,850,851,852,855,857,860,861,862,863,864,865,866,871,873,875,881,882,883,884,885,887,888,890,891,892,893,894,895,900,902,905,906,907,909,912,913,914,919,921,922,923,930,931,950,954,955,961,962,963,964,965,966,967,970,980,999)
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['FFN2']['AL019']  = (-999999,2,480,490,494,495,500,505,508,520,530,722,847,970,999)
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['FFN2']['AL080']  = (-999999,99,480,486,490,495,505,999)
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['FFN2']['AL099']  = (-999999,2,9,14,557,563,721,722,847,866,881,883,930,970,999)
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['FFN2']['AL110']  = (-999999,480,490,495,900,999)
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['FFN2']['AL142']  = (-999999,720,721,850,923,999)
    field_information['GGDM 3.0']['StructurePnt']['FFN3'] = ('Enumeration',('AG050','AL013','AL019','AL080','AL099','AL110','AL142'))
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['FFN3'] = {}
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['FFN3']['AG050']  = (-999999,343,382,466,470,476,488,548,570,580,610,640,680,681,760,808,830,850,860,887,890,900,930,950,999)
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['FFN3']['AL013']  = (-999999,2,3,9,14,15,19,20,21,27,30,35,40,50,60,70,83,87,91,95,99,100,101,102,103,104,105,106,107,110,111,112,113,114,115,116,118,119,120,121,122,123,124,125,129,130,140,150,155,160,161,165,171,181,190,191,192,195,210,221,225,230,231,232,233,234,235,236,237,240,241,242,243,250,251,255,257,260,270,272,280,289,290,301,304,305,306,310,320,321,322,323,324,325,330,331,332,333,334,340,341,342,343,350,351,352,355,356,360,361,362,363,370,372,382,383,385,440,459,460,464,465,466,470,473,474,475,476,477,478,480,481,482,483,484,486,487,488,489,490,491,494,495,496,497,500,501,505,507,508,510,511,512,513,520,525,529,530,535,536,537,538,539,540,541,545,548,549,550,551,552,553,554,555,556,557,558,559,563,570,572,573,574,578,579,580,582,594,601,604,610,612,614,615,616,617,620,621,622,625,626,632,633,640,642,643,651,662,663,671,680,681,691,696,701,706,711,714,717,720,721,722,725,730,741,752,757,760,761,770,775,780,781,791,795,801,807,808,809,810,811,812,813,814,815,817,818,819,821,822,825,826,827,828,829,830,831,832,833,835,836,837,838,839,840,841,842,843,844,845,846,847,848,850,851,852,855,857,860,861,862,863,864,865,866,871,873,875,881,882,883,884,885,887,888,890,891,892,893,894,895,900,902,905,906,907,909,912,913,914,919,921,922,923,930,931,950,954,955,961,962,963,964,965,966,967,970,980,999)
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['FFN3']['AL019']  = (-999999,2,480,490,494,495,500,505,508,520,530,722,847,970,999)
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['FFN3']['AL080']  = (-999999,99,480,486,490,495,505,999)
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['FFN3']['AL099']  = (-999999,2,9,14,557,563,721,722,847,866,881,883,930,970,999)
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['FFN3']['AL110']  = (-999999,480,490,495,900,999)
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['FFN3']['AL142']  = (-999999,720,721,850,923,999)
    field_information['GGDM 3.0']['StructurePnt']['FUFI'] = ('StructuredText',('AF060','AG050','AL013','AL014','AL018','AL019','AL073','AL080','AL099','AL110','AL142','AL241','AL250','AL371'))
    field_information['GGDM 3.0']['StructurePnt']['FURL'] = ('StructuredText',('AF060','AG050','AL013','AL014','AL018','AL019','AL073','AL080','AL099','AL110','AL142','AL241','AL250','AL371'))
    field_information['GGDM 3.0']['StructurePnt']['GDBV'] = ('Enumeration',('AF060','AG050','AL013','AL014','AL018','AL019','AL073','AL080','AL099','AL110','AL142','AL241','AL250','AL371'))
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['GDBV']['AF060']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['GDBV']['AG050']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['GDBV']['AL013']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['GDBV']['AL014']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['GDBV']['AL018']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['GDBV']['AL019']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['GDBV']['AL073']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['GDBV']['AL080']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['GDBV']['AL099']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['GDBV']['AL110']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['GDBV']['AL142']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['GDBV']['AL241']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['GDBV']['AL250']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['GDBV']['AL371']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['StructurePnt']['GUG'] = ('Boolean',('AL241'))
    field_information['GGDM 3.0']['StructurePnt']['HEI'] = ('Real',('AG050','AL018','AL073','AL241'))
    field_information['GGDM 3.0']['StructurePnt']['HGT'] = ('Real',('AF060','AG050','AL013','AL014','AL018','AL019','AL073','AL080','AL099','AL110','AL142','AL241','AL371'))
    field_information['GGDM 3.0']['StructurePnt']['HSC'] = ('Integer',('AL013'))
    field_information['GGDM 3.0']['StructurePnt']['HST'] = ('Enumeration',('AL013','AL250'))
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['HST'] = {}
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['HST']['AL013']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['HST']['AL250']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['StructurePnt']['HST2'] = ('Enumeration',('AL013','AL250'))
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['HST2'] = {}
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['HST2']['AL013']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['HST2']['AL250']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['StructurePnt']['HST3'] = ('Enumeration',('AL013','AL250'))
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['HST3'] = {}
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['HST3']['AL013']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['HST3']['AL250']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['StructurePnt']['LEA'] = ('Real',('AL250'))
    field_information['GGDM 3.0']['StructurePnt']['LMC'] = ('Boolean',('AF060','AG050','AL013','AL014','AL018','AL019','AL073','AL080','AL099','AL110','AL142','AL241','AL250','AL371'))
    field_information['GGDM 3.0']['StructurePnt']['LZN'] = ('Real',('AF060','AG050','AL013','AL014','AL018','AL019','AL080','AL099','AL110','AL142','AL241','AL250','AL371'))
    field_information['GGDM 3.0']['StructurePnt']['MEL'] = ('Enumeration',('AL013'))
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['MEL'] = {}
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['MEL']['AL013']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,999)
    field_information['GGDM 3.0']['StructurePnt']['MFB'] = ('Boolean',('AL013'))
    field_information['GGDM 3.0']['StructurePnt']['MFY'] = ('Enumeration',('AL013'))
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['MFY'] = {}
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['MFY']['AL013']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,999)
    field_information['GGDM 3.0']['StructurePnt']['MKSZ'] = ('Enumeration',('AL013'))
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['MKSZ'] = {}
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['MKSZ']['AL013']  = (-999999,1,2,3,998)
    field_information['GGDM 3.0']['StructurePnt']['MUB'] = ('Boolean',('AL013'))
    field_information['GGDM 3.0']['StructurePnt']['NOR'] = ('Integer',('AL013'))
    field_information['GGDM 3.0']['StructurePnt']['OTH'] = ('StructuredText',('AF060','AG050','AL013','AL014','AL018','AL019','AL073','AL080','AL099','AL110','AL142','AL241','AL250','AL371'))
    field_information['GGDM 3.0']['StructurePnt']['PCF'] = ('Enumeration',('AF060','AG050','AL013','AL014','AL018','AL019','AL073','AL080','AL099','AL110','AL142','AL241','AL250','AL371'))
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['PCF']['AF060']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['PCF']['AG050']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['PCF']['AL013']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['PCF']['AL014']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['PCF']['AL018']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['PCF']['AL019']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['PCF']['AL073']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['PCF']['AL080']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['PCF']['AL099']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['PCF']['AL110']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['PCF']['AL142']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['PCF']['AL241']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['PCF']['AL250']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['PCF']['AL371']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['StructurePnt']['PYC'] = ('Enumeration',('AL110','AL241'))
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['PYC'] = {}
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['PYC']['AL110']  = (-999999,1,2,3,4,5,999)
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['PYC']['AL241']  = (-999999,1,2,3,4,5,999)
    field_information['GGDM 3.0']['StructurePnt']['PYM'] = ('Enumeration',('AL110','AL241'))
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['PYM'] = {}
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['PYM']['AL110']  = (-999999,1,3,4,5,7,8,9,10,999)
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['PYM']['AL241']  = (-999999,1,3,4,5,7,8,9,10,999)
    field_information['GGDM 3.0']['StructurePnt']['RLE'] = ('Enumeration',('AL013'))
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['RLE'] = {}
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['RLE']['AL013']  = (-999999,1,2,3)
    field_information['GGDM 3.0']['StructurePnt']['SPT'] = ('Boolean',('AL241'))
    field_information['GGDM 3.0']['StructurePnt']['SRL'] = ('Enumeration',('AF060'))
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['SRL'] = {}
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['SRL']['AF060']  = (-999999,1,2,3)
    field_information['GGDM 3.0']['StructurePnt']['SSR'] = ('Enumeration',('AL013','AL019','AL142','AL241','AL371'))
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['SSR'] = {}
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['SSR']['AL013']  = (-999999,6,7,38,40,41,42,47,50,55,64,999)
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['SSR']['AL019']  = (-999999,6,7,38,40,41,42,47,50,55,64,999)
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['SSR']['AL142']  = (-999999,6,7,38,40,41,42,47,50,55,64,999)
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['SSR']['AL241']  = (-999999,6,7,38,40,41,42,999)
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['SSR']['AL371']  = (-999999,6,7,38,40,41,42,47,50,55,64,999)
    field_information['GGDM 3.0']['StructurePnt']['SSR2'] = ('Enumeration',('AL013','AL019','AL142','AL241','AL371'))
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['SSR2'] = {}
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['SSR2']['AL013']  = (-999999,6,7,38,40,41,42,47,50,55,64,999)
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['SSR2']['AL019']  = (-999999,6,7,38,40,41,42,47,50,55,64,999)
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['SSR2']['AL142']  = (-999999,6,7,38,40,41,42,47,50,55,64,999)
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['SSR2']['AL241']  = (-999999,6,7,38,40,41,42,999)
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['SSR2']['AL371']  = (-999999,6,7,38,40,41,42,47,50,55,64,999)
    field_information['GGDM 3.0']['StructurePnt']['SSR3'] = ('Enumeration',('AL013','AL019','AL142','AL241','AL371'))
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['SSR3'] = {}
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['SSR3']['AL013']  = (-999999,6,7,38,40,41,42,47,50,55,64,999)
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['SSR3']['AL019']  = (-999999,6,7,38,40,41,42,47,50,55,64,999)
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['SSR3']['AL142']  = (-999999,6,7,38,40,41,42,47,50,55,64,999)
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['SSR3']['AL241']  = (-999999,6,7,38,40,41,42,999)
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['SSR3']['AL371']  = (-999999,6,7,38,40,41,42,47,50,55,64,999)
    field_information['GGDM 3.0']['StructurePnt']['STAF'] = ('Integer',('AL013'))
    field_information['GGDM 3.0']['StructurePnt']['TEL'] = ('Enumeration',('AL142'))
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['TEL'] = {}
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['TEL']['AL142']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['StructurePnt']['TOS'] = ('Enumeration',('AL110','AL241'))
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['TOS'] = {}
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['TOS']['AL110']  = (-999999,6,8,12,13,999)
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['TOS']['AL241']  = (-999999,6,8,12,13,999)
    field_information['GGDM 3.0']['StructurePnt']['TTC'] = ('Enumeration',('AL241'))
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['TTC'] = {}
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['TTC']['AL241']  = (-999999,2,10,12,20,21,22,23,24,999)
    field_information['GGDM 3.0']['StructurePnt']['TTC2'] = ('Enumeration',('AL241'))
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['TTC2'] = {}
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['TTC2']['AL241']  = (-999999,2,10,12,20,21,22,23,24,999)
    field_information['GGDM 3.0']['StructurePnt']['TTC3'] = ('Enumeration',('AL241'))
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['TTC3'] = {}
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['TTC3']['AL241']  = (-999999,2,10,12,20,21,22,23,24,999)
    field_information['GGDM 3.0']['StructurePnt']['UFI'] = ('StructuredText',('AF060','AG050','AL013','AL014','AL018','AL019','AL073','AL080','AL099','AL110','AL142','AL241','AL250','AL371'))
    field_information['GGDM 3.0']['StructurePnt']['VCM'] = ('Enumeration',('AL013','AL019','AL080','AL371'))
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['VCM'] = {}
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['VCM']['AL013']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,999)
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['VCM']['AL019']  = (-999999,1,2,4,5,7,8,9,10,11,14,15,16,18,999)
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['VCM']['AL080']  = (-999999,2,7,9,15,999)
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['VCM']['AL371']  = (-999999,3,4,6,8,12,13,15,16,18,999)
    field_information['GGDM 3.0']['StructurePnt']['VCM2'] = ('Enumeration',('AL013','AL019','AL080','AL371'))
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['VCM2'] = {}
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['VCM2']['AL013']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,999)
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['VCM2']['AL019']  = (-999999,1,2,4,5,7,8,9,10,11,14,15,16,18,999)
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['VCM2']['AL080']  = (-999999,2,7,9,15,999)
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['VCM2']['AL371']  = (-999999,3,4,6,8,12,13,15,16,18,999)
    field_information['GGDM 3.0']['StructurePnt']['VCM3'] = ('Enumeration',('AL013','AL019','AL080','AL371'))
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['VCM3'] = {}
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['VCM3']['AL013']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,999)
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['VCM3']['AL019']  = (-999999,1,2,4,5,7,8,9,10,11,14,15,16,18,999)
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['VCM3']['AL080']  = (-999999,2,7,9,15,999)
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['VCM3']['AL371']  = (-999999,3,4,6,8,12,13,15,16,18,999)
    field_information['GGDM 3.0']['StructurePnt']['VEC'] = ('Integer',('AL013'))
    field_information['GGDM 3.0']['StructurePnt']['VOI'] = ('StructuredText',('AF060','AG050','AL013','AL014','AL018','AL073','AL080','AL110','AL142','AL241'))
    field_information['GGDM 3.0']['StructurePnt']['WID'] = ('Real',('AF060','AL013','AL014','AL018','AL019','AL080','AL099','AL110','AL142','AL241','AL250','AL371'))
    field_information['GGDM 3.0']['StructurePnt']['WPST'] = ('Integer',('AL013'))
    field_information['GGDM 3.0']['StructurePnt']['WTYP'] = ('Enumeration',('AL013'))
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['WTYP'] = {}
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['WTYP']['AL013']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['StructurePnt']['ZI001_SDV'] = ('StructuredText',('AF060','AG050','AL013','AL014','AL018','AL019','AL073','AL080','AL099','AL110','AL142','AL241','AL250','AL371'))
    field_information['GGDM 3.0']['StructurePnt']['ZI001_SRT'] = ('Enumeration',('AF060','AG050','AL013','AL014','AL018','AL019','AL073','AL080','AL099','AL110','AL142','AL241','AL250','AL371'))
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['ZI001_SRT']['AF060']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['ZI001_SRT']['AG050']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['ZI001_SRT']['AL013']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['ZI001_SRT']['AL014']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['ZI001_SRT']['AL018']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['ZI001_SRT']['AL019']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['ZI001_SRT']['AL073']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['ZI001_SRT']['AL080']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['ZI001_SRT']['AL099']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['ZI001_SRT']['AL110']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['ZI001_SRT']['AL142']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['ZI001_SRT']['AL241']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['ZI001_SRT']['AL250']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['ZI001_SRT']['AL371']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['StructurePnt']['ZI002_UFI'] = ('StructuredText',('AF060','AG050','AL013','AL014','AL018','AL019','AL073','AL080','AL099','AL110','AL142','AL241','AL250','AL371'))
    field_information['GGDM 3.0']['StructurePnt']['ZI004_RCG'] = ('Enumeration',('AF060','AG050','AL013','AL014','AL018','AL019','AL073','AL080','AL099','AL110','AL142','AL241','AL250','AL371'))
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['ZI004_RCG']['AF060']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['ZI004_RCG']['AG050']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['ZI004_RCG']['AL013']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['ZI004_RCG']['AL014']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['ZI004_RCG']['AL018']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['ZI004_RCG']['AL019']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['ZI004_RCG']['AL073']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['ZI004_RCG']['AL080']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['ZI004_RCG']['AL099']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['ZI004_RCG']['AL110']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['ZI004_RCG']['AL142']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['ZI004_RCG']['AL241']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['ZI004_RCG']['AL250']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['ZI004_RCG']['AL371']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['StructurePnt']['ZI005_FNA'] = ('String',('AF060','AG050','AL013','AL014','AL018','AL019','AL073','AL099','AL110','AL142','AL241','AL250','AL371'))
    field_information['GGDM 3.0']['StructurePnt']['ZI005_FNA2'] = ('String',('AL013'))
    field_information['GGDM 3.0']['StructurePnt']['ZI005_FNA3'] = ('String',('AL013'))
    field_information['GGDM 3.0']['StructurePnt']['ZI005_GNT'] = ('Enumeration',('AF060','AG050','AL013','AL014','AL018','AL019','AL073','AL099','AL110','AL142','AL241','AL250'))
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['ZI005_GNT']['AF060']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['ZI005_GNT']['AG050']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['ZI005_GNT']['AL013']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['ZI005_GNT']['AL014']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['ZI005_GNT']['AL018']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['ZI005_GNT']['AL019']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['ZI005_GNT']['AL073']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['ZI005_GNT']['AL099']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['ZI005_GNT']['AL110']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['ZI005_GNT']['AL142']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['ZI005_GNT']['AL241']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['ZI005_GNT']['AL250']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['StructurePnt']['ZI005_GNT2'] = ('Enumeration',('AL013'))
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['ZI005_GNT2'] = {}
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['ZI005_GNT2']['AL013']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['StructurePnt']['ZI005_GNT3'] = ('Enumeration',('AL013'))
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['ZI005_GNT3'] = {}
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['ZI005_GNT3']['AL013']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['StructurePnt']['ZI005_NFN'] = ('String',('AF060','AG050','AL013','AL014','AL018','AL019','AL073','AL099','AL110','AL142','AL241','AL250','AL371'))
    field_information['GGDM 3.0']['StructurePnt']['ZI005_NFN2'] = ('String',('AL013'))
    field_information['GGDM 3.0']['StructurePnt']['ZI005_NFN3'] = ('String',('AL013'))
    field_information['GGDM 3.0']['StructurePnt']['ZI006_MEM'] = ('String',('AF060','AG050','AL013','AL014','AL018','AL019','AL073','AL080','AL099','AL110','AL142','AL241','AL250','AL371'))
    field_information['GGDM 3.0']['StructurePnt']['ZI014_PBY'] = ('Enumeration',('AL013','AL014','AL019'))
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['ZI014_PBY'] = {}
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['ZI014_PBY']['AL013']  = (-999999,1,2,6,7,8,12,13,15,89,999)
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['ZI014_PBY']['AL014']  = (-999999,1,2,6,7,8,12,13,15,89,999)
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['ZI014_PBY']['AL019']  = (-999999,1,2,6,7,8,12,13,15,89,999)
    field_information['GGDM 3.0']['StructurePnt']['ZI014_PBY2'] = ('Enumeration',('AL013','AL014','AL019'))
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['ZI014_PBY2'] = {}
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['ZI014_PBY2']['AL013']  = (-999999,1,2,6,7,8,12,13,15,89,999)
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['ZI014_PBY2']['AL014']  = (-999999,1,2,6,7,8,12,13,15,89,999)
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['ZI014_PBY2']['AL019']  = (-999999,1,2,6,7,8,12,13,15,89,999)
    field_information['GGDM 3.0']['StructurePnt']['ZI014_PBY3'] = ('Enumeration',('AL013','AL014','AL019'))
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['ZI014_PBY3'] = {}
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['ZI014_PBY3']['AL013']  = (-999999,1,2,6,7,8,12,13,15,89,999)
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['ZI014_PBY3']['AL014']  = (-999999,1,2,6,7,8,12,13,15,89,999)
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['ZI014_PBY3']['AL019']  = (-999999,1,2,6,7,8,12,13,15,89,999)
    field_information['GGDM 3.0']['StructurePnt']['ZI014_PPO'] = ('Enumeration',('AL013','AL014','AL019'))
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['ZI014_PPO'] = {}
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['ZI014_PPO']['AL013']  = (-999999,1,2,3,4,5,13,15,16,18,20,21,23,25,26,28,32,37,38,39,41,43,44,45,46,47,48,57,58,59,60,61,62,63,65,69,70,73,74,80,83,84,87,90,92,94,95,101,105,106,109,111,114,117,120,121,122,123,126,136,137,146,147,148,150,154,155,156,157,160,165,192,200,214,279,325,435,999)
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['ZI014_PPO']['AL014']  = (-999999,1,2,3,4,5,13,15,16,18,20,21,23,25,26,28,32,37,38,39,41,43,44,45,46,47,48,57,58,59,60,61,62,63,65,69,70,73,74,80,83,84,87,90,92,94,95,101,105,106,109,111,114,117,120,121,122,123,126,136,137,146,147,148,150,154,155,156,157,160,165,192,200,214,279,325,435,999)
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['ZI014_PPO']['AL019']  = (-999999,1,2,3,4,5,13,15,16,18,20,21,23,25,26,28,32,37,38,39,41,43,44,45,46,47,48,57,58,59,60,61,62,63,65,69,70,73,74,80,83,84,87,90,92,94,95,101,105,106,109,111,114,117,120,121,122,123,126,136,137,146,147,148,150,154,155,156,157,160,165,192,200,214,279,325,435,999)
    field_information['GGDM 3.0']['StructurePnt']['ZI014_PPO2'] = ('Enumeration',('AL013','AL014','AL019'))
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['ZI014_PPO2'] = {}
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['ZI014_PPO2']['AL013']  = (-999999,1,2,3,4,5,13,15,16,18,20,21,23,25,26,28,32,37,38,39,41,43,44,45,46,47,48,57,58,59,60,61,62,63,65,69,70,73,74,80,83,84,87,90,92,94,95,101,105,106,109,111,114,117,120,121,122,123,126,136,137,146,147,148,150,154,155,156,157,160,165,192,200,214,279,325,435,999)
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['ZI014_PPO2']['AL014']  = (-999999,1,2,3,4,5,13,15,16,18,20,21,23,25,26,28,32,37,38,39,41,43,44,45,46,47,48,57,58,59,60,61,62,63,65,69,70,73,74,80,83,84,87,90,92,94,95,101,105,106,109,111,114,117,120,121,122,123,126,136,137,146,147,148,150,154,155,156,157,160,165,192,200,214,279,325,435,999)
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['ZI014_PPO2']['AL019']  = (-999999,1,2,3,4,5,13,15,16,18,20,21,23,25,26,28,32,37,38,39,41,43,44,45,46,47,48,57,58,59,60,61,62,63,65,69,70,73,74,80,83,84,87,90,92,94,95,101,105,106,109,111,114,117,120,121,122,123,126,136,137,146,147,148,150,154,155,156,157,160,165,192,200,214,279,325,435,999)
    field_information['GGDM 3.0']['StructurePnt']['ZI014_PPO3'] = ('Enumeration',('AL013','AL014','AL019'))
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['ZI014_PPO3'] = {}
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['ZI014_PPO3']['AL013']  = (-999999,1,2,3,4,5,13,15,16,18,20,21,23,25,26,28,32,37,38,39,41,43,44,45,46,47,48,57,58,59,60,61,62,63,65,69,70,73,74,80,83,84,87,90,92,94,95,101,105,106,109,111,114,117,120,121,122,123,126,136,137,146,147,148,150,154,155,156,157,160,165,192,200,214,279,325,435,999)
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['ZI014_PPO3']['AL014']  = (-999999,1,2,3,4,5,13,15,16,18,20,21,23,25,26,28,32,37,38,39,41,43,44,45,46,47,48,57,58,59,60,61,62,63,65,69,70,73,74,80,83,84,87,90,92,94,95,101,105,106,109,111,114,117,120,121,122,123,126,136,137,146,147,148,150,154,155,156,157,160,165,192,200,214,279,325,435,999)
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['ZI014_PPO3']['AL019']  = (-999999,1,2,3,4,5,13,15,16,18,20,21,23,25,26,28,32,37,38,39,41,43,44,45,46,47,48,57,58,59,60,61,62,63,65,69,70,73,74,80,83,84,87,90,92,94,95,101,105,106,109,111,114,117,120,121,122,123,126,136,137,146,147,148,150,154,155,156,157,160,165,192,200,214,279,325,435,999)
    field_information['GGDM 3.0']['StructurePnt']['ZI014_PRW'] = ('Enumeration',('AL013','AL014','AL019'))
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['ZI014_PRW'] = {}
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['ZI014_PRW']['AL013']  = (-999999,1,2,5,9,10,11,12,14,16,18,27,28,29,30,33,38,39,41,45,46,48,50,52,54,57,60,64,66,68,70,75,78,79,83,84,85,87,90,93,94,96,97,99,118,119,999)
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['ZI014_PRW']['AL014']  = (-999999,1,2,5,9,10,11,12,14,16,18,27,28,29,30,33,38,39,41,45,46,48,50,52,54,57,60,64,66,68,70,75,78,79,83,84,85,87,90,93,94,96,97,99,118,119,999)
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['ZI014_PRW']['AL019']  = (-999999,1,2,5,9,10,11,12,14,16,18,27,28,29,30,33,38,39,41,45,46,48,50,52,54,57,60,64,66,68,70,75,78,79,83,84,85,87,90,93,94,96,97,99,118,119,999)
    field_information['GGDM 3.0']['StructurePnt']['ZI014_PRW2'] = ('Enumeration',('AL013','AL014','AL019'))
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['ZI014_PRW2'] = {}
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['ZI014_PRW2']['AL013']  = (-999999,1,2,5,9,10,11,12,14,16,18,27,28,29,30,33,38,39,41,45,46,48,50,52,54,57,60,64,66,68,70,75,78,79,83,84,85,87,90,93,94,96,97,99,118,119,999)
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['ZI014_PRW2']['AL014']  = (-999999,1,2,5,9,10,11,12,14,16,18,27,28,29,30,33,38,39,41,45,46,48,50,52,54,57,60,64,66,68,70,75,78,79,83,84,85,87,90,93,94,96,97,99,118,119,999)
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['ZI014_PRW2']['AL019']  = (-999999,1,2,5,9,10,11,12,14,16,18,27,28,29,30,33,38,39,41,45,46,48,50,52,54,57,60,64,66,68,70,75,78,79,83,84,85,87,90,93,94,96,97,99,118,119,999)
    field_information['GGDM 3.0']['StructurePnt']['ZI014_PRW3'] = ('Enumeration',('AL013','AL014','AL019'))
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['ZI014_PRW3'] = {}
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['ZI014_PRW3']['AL013']  = (-999999,1,2,5,9,10,11,12,14,16,18,27,28,29,30,33,38,39,41,45,46,48,50,52,54,57,60,64,66,68,70,75,78,79,83,84,85,87,90,93,94,96,97,99,118,119,999)
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['ZI014_PRW3']['AL014']  = (-999999,1,2,5,9,10,11,12,14,16,18,27,28,29,30,33,38,39,41,45,46,48,50,52,54,57,60,64,66,68,70,75,78,79,83,84,85,87,90,93,94,96,97,99,118,119,999)
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['ZI014_PRW3']['AL019']  = (-999999,1,2,5,9,10,11,12,14,16,18,27,28,29,30,33,38,39,41,45,46,48,50,52,54,57,60,64,66,68,70,75,78,79,83,84,85,87,90,93,94,96,97,99,118,119,999)
    field_information['GGDM 3.0']['StructurePnt']['ZI018_WIT'] = ('Enumeration',('AL013','AL018','AL241'))
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['ZI018_WIT'] = {}
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['ZI018_WIT']['AL013']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['ZI018_WIT']['AL018']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['ZI018_WIT']['AL241']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['StructurePnt']['ZI020_GE4'] = ('CodeList',('AF060','AG050','AL013','AL014','AL018','AL019','AL073','AL080','AL099','AL110','AL142','AL241','AL250','AL371'))
    field_information['GGDM 3.0']['StructurePnt']['ZI026_CTUC'] = ('Enumeration',('AF060','AG050','AL013','AL014','AL018','AL019','AL073','AL080','AL099','AL110','AL142','AL241','AL250','AL371'))
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['ZI026_CTUC']['AF060']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['ZI026_CTUC']['AG050']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['ZI026_CTUC']['AL013']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['ZI026_CTUC']['AL014']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['ZI026_CTUC']['AL018']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['ZI026_CTUC']['AL019']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['ZI026_CTUC']['AL073']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['ZI026_CTUC']['AL080']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['ZI026_CTUC']['AL099']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['ZI026_CTUC']['AL110']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['ZI026_CTUC']['AL142']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['ZI026_CTUC']['AL241']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['ZI026_CTUC']['AL250']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['ZI026_CTUC']['AL371']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['StructurePnt']['ZI026_CTUL'] = ('integer',('AF060','AG050','AL013','AL014','AL018','AL019','AL073','AL080','AL099','AL110','AL142','AL241','AL250','AL371'))
    field_information['GGDM 3.0']['StructurePnt']['ZI026_CTUU'] = ('integer',('AF060','AG050','AL013','AL014','AL018','AL019','AL073','AL080','AL099','AL110','AL142','AL241','AL250','AL371'))
    field_information['GGDM 3.0']['StructurePnt']['ZI031S_URI'] = ('StructuredText',('AF060','AG050','AL013','AL014','AL018','AL019','AL073','AL080','AL099','AL110','AL142','AL241','AL250','AL371'))
    field_information['GGDM 3.0']['StructurePnt']['ZI037_REL'] = ('Enumeration',('AL013'))
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['ZI037_REL'] = {}
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['ZI037_REL']['AL013']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,999)
    field_information['GGDM 3.0']['StructurePnt']['ZI037_RFA'] = ('Enumeration',('AL013'))
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['ZI037_RFA'] = {}
    field_information['GGDM 3.0']['StructurePnt']['EnumeratedIndexValues']['ZI037_RFA']['AL013']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,18,19,20,21,22,23,25,999)
    field_information['GGDM 3.0']['StructurePnt']['ZI039S_UFI'] = ('StructuredText',('AF060','AG050','AL013','AL014','AL018','AL019','AL073','AL080','AL099','AL110','AL142','AL241','AL250','AL371'))
    field_information['GGDM 3.0']['StructurePnt']['ZSAX_RS0'] = ('CodeList',('AF060','AG050','AL013','AL014','AL018','AL019','AL073','AL080','AL099','AL110','AL142','AL241','AL250','AL371'))
    field_information['GGDM 3.0']['StructurePnt']['ZSAX_RX0'] = ('StructuredText',('AF060','AG050','AL013','AL014','AL018','AL019','AL073','AL080','AL099','AL110','AL142','AL241','AL250','AL371'))
    field_information['GGDM 3.0']['StructurePnt']['ZSAX_RX3'] = ('StructuredText',('AF060','AG050','AL013','AL014','AL018','AL019','AL073','AL080','AL099','AL110','AL142','AL241','AL250','AL371'))
    field_information['GGDM 3.0']['StructurePnt']['ZSAX_RX4'] = ('StructuredText',('AF060','AG050','AL013','AL014','AL018','AL019','AL073','AL080','AL099','AL110','AL142','AL241','AL250','AL371'))
    field_information['GGDM 3.0']['StructurePnt']['ZVH'] = ('Real',('AF060','AG050','AL013','AL014','AL018','AL019','AL073','AL080','AL099','AL110','AL142','AL241','AL371'))
    field_information['GGDM 3.0']['StructurePntExt']['ARA'] = ('Real',('AL140'))
    field_information['GGDM 3.0']['StructurePntExt']['BEN'] = ('StructuredText',('AL140'))
    field_information['GGDM 3.0']['StructurePntExt']['CNCP'] = ('StructuredText',('AL140'))
    field_information['GGDM 3.0']['StructurePntExt']['COS'] = ('Enumeration',('AL140'))
    field_information['GGDM 3.0']['StructurePntExt']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['StructurePntExt']['EnumeratedIndexValues']['COS']['AL140']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['StructurePntExt']['F_CODE'] = ('CONSTRAINED_STRING',('AL140'))
    field_information['GGDM 3.0']['StructurePntExt']['FUFI'] = ('StructuredText',('AL140'))
    field_information['GGDM 3.0']['StructurePntExt']['FURL'] = ('StructuredText',('AL140'))
    field_information['GGDM 3.0']['StructurePntExt']['GDBV'] = ('Enumeration',('AL140'))
    field_information['GGDM 3.0']['StructurePntExt']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['StructurePntExt']['EnumeratedIndexValues']['GDBV']['AL140']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['StructurePntExt']['LMC'] = ('Boolean',('AL140'))
    field_information['GGDM 3.0']['StructurePntExt']['LZN'] = ('Real',('AL140'))
    field_information['GGDM 3.0']['StructurePntExt']['OTH'] = ('StructuredText',('AL140'))
    field_information['GGDM 3.0']['StructurePntExt']['PCF'] = ('Enumeration',('AL140'))
    field_information['GGDM 3.0']['StructurePntExt']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['StructurePntExt']['EnumeratedIndexValues']['PCF']['AL140']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['StructurePntExt']['UFI'] = ('StructuredText',('AL140'))
    field_information['GGDM 3.0']['StructurePntExt']['WID'] = ('Real',('AL140'))
    field_information['GGDM 3.0']['StructurePntExt']['ZI001_SDV'] = ('StructuredText',('AL140'))
    field_information['GGDM 3.0']['StructurePntExt']['ZI001_SRT'] = ('Enumeration',('AL140'))
    field_information['GGDM 3.0']['StructurePntExt']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['StructurePntExt']['EnumeratedIndexValues']['ZI001_SRT']['AL140']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['StructurePntExt']['ZI002_UFI'] = ('StructuredText',('AL140'))
    field_information['GGDM 3.0']['StructurePntExt']['ZI004_RCG'] = ('Enumeration',('AL140'))
    field_information['GGDM 3.0']['StructurePntExt']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['StructurePntExt']['EnumeratedIndexValues']['ZI004_RCG']['AL140']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['StructurePntExt']['ZI005_FNA'] = ('String',('AL140'))
    field_information['GGDM 3.0']['StructurePntExt']['ZI005_GNT'] = ('Enumeration',('AL140'))
    field_information['GGDM 3.0']['StructurePntExt']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['StructurePntExt']['EnumeratedIndexValues']['ZI005_GNT']['AL140']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['StructurePntExt']['ZI005_NFN'] = ('String',('AL140'))
    field_information['GGDM 3.0']['StructurePntExt']['ZI006_MEM'] = ('String',('AL140'))
    field_information['GGDM 3.0']['StructurePntExt']['ZI020_GE4'] = ('CodeList',('AL140'))
    field_information['GGDM 3.0']['StructurePntExt']['ZI026_CTUC'] = ('Enumeration',('AL140'))
    field_information['GGDM 3.0']['StructurePntExt']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['StructurePntExt']['EnumeratedIndexValues']['ZI026_CTUC']['AL140']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['StructurePntExt']['ZI026_CTUL'] = ('integer',('AL140'))
    field_information['GGDM 3.0']['StructurePntExt']['ZI026_CTUU'] = ('integer',('AL140'))
    field_information['GGDM 3.0']['StructurePntExt']['ZI031S_URI'] = ('StructuredText',('AL140'))
    field_information['GGDM 3.0']['StructurePntExt']['ZI039S_UFI'] = ('StructuredText',('AL140'))
    field_information['GGDM 3.0']['StructurePntExt']['ZSAX_RS0'] = ('CodeList',('AL140'))
    field_information['GGDM 3.0']['StructurePntExt']['ZSAX_RX0'] = ('StructuredText',('AL140'))
    field_information['GGDM 3.0']['StructurePntExt']['ZSAX_RX3'] = ('StructuredText',('AL140'))
    field_information['GGDM 3.0']['StructurePntExt']['ZSAX_RX4'] = ('StructuredText',('AL140'))
    field_information['GGDM 3.0']['StructureSrf']['ADR'] = ('String',('AL013','AL019','AL099','AL142','AL371'))
    field_information['GGDM 3.0']['StructureSrf']['AOO'] = ('Real',('AF060','AL013','AL014','AL018','AL019','AL099','AL142','AL241','AL371'))
    field_information['GGDM 3.0']['StructureSrf']['ARA'] = ('Real',('AF060','AL013','AL014','AL018','AL019','AL099','AL140','AL142','AL241','AL371','AQ150'))
    field_information['GGDM 3.0']['StructureSrf']['ATB'] = ('Boolean',('AL013'))
    field_information['GGDM 3.0']['StructureSrf']['AWP'] = ('Boolean',('AF060','AL013','AL014','AL018','AL142','AL241'))
    field_information['GGDM 3.0']['StructureSrf']['BEN'] = ('StructuredText',('AF060','AL013','AL014','AL018','AL019','AL099','AL140','AL142','AL241','AL371','AQ150'))
    field_information['GGDM 3.0']['StructureSrf']['BNF'] = ('Integer',('AL013','AL019','AL371'))
    field_information['GGDM 3.0']['StructureSrf']['BSU'] = ('Enumeration',('AL018'))
    field_information['GGDM 3.0']['StructureSrf']['EnumeratedIndexValues']['BSU'] = {}
    field_information['GGDM 3.0']['StructureSrf']['EnumeratedIndexValues']['BSU']['AL018']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,13,14,15,16,17,18,999)
    field_information['GGDM 3.0']['StructureSrf']['CAA'] = ('Enumeration',('AF060','AL013','AL014','AL019','AL099','AL142','AL241','AL371'))
    field_information['GGDM 3.0']['StructureSrf']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['StructureSrf']['EnumeratedIndexValues']['CAA']['AF060']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['StructureSrf']['EnumeratedIndexValues']['CAA']['AL013']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['StructureSrf']['EnumeratedIndexValues']['CAA']['AL014']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['StructureSrf']['EnumeratedIndexValues']['CAA']['AL019']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['StructureSrf']['EnumeratedIndexValues']['CAA']['AL099']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['StructureSrf']['EnumeratedIndexValues']['CAA']['AL142']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['StructureSrf']['EnumeratedIndexValues']['CAA']['AL241']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['StructureSrf']['EnumeratedIndexValues']['CAA']['AL371']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['StructureSrf']['CNCP'] = ('StructuredText',('AF060','AL013','AL014','AL018','AL019','AL099','AL140','AL142','AL241','AL371','AQ150'))
    field_information['GGDM 3.0']['StructureSrf']['COS'] = ('Enumeration',('AF060','AL013','AL014','AL018','AL019','AL099','AL140','AL142','AL241','AL371','AQ150'))
    field_information['GGDM 3.0']['StructureSrf']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['StructureSrf']['EnumeratedIndexValues']['COS']['AF060']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['StructureSrf']['EnumeratedIndexValues']['COS']['AL013']  = (-999999,1,2,3,4,6,8,9,13,14)
    field_information['GGDM 3.0']['StructureSrf']['EnumeratedIndexValues']['COS']['AL014']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['StructureSrf']['EnumeratedIndexValues']['COS']['AL018']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['StructureSrf']['EnumeratedIndexValues']['COS']['AL019']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['StructureSrf']['EnumeratedIndexValues']['COS']['AL099']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['StructureSrf']['EnumeratedIndexValues']['COS']['AL140']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['StructureSrf']['EnumeratedIndexValues']['COS']['AL142']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['StructureSrf']['EnumeratedIndexValues']['COS']['AL241']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['StructureSrf']['EnumeratedIndexValues']['COS']['AL371']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['StructureSrf']['EnumeratedIndexValues']['COS']['AQ150']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['StructureSrf']['ETY'] = ('Enumeration',('AF060'))
    field_information['GGDM 3.0']['StructureSrf']['EnumeratedIndexValues']['ETY'] = {}
    field_information['GGDM 3.0']['StructureSrf']['EnumeratedIndexValues']['ETY']['AF060']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['StructureSrf']['F_CODE'] = ('CONSTRAINED_STRING',('AF060','AL013','AL014','AL018','AL019','AL099','AL140','AL142','AL241','AL371','AQ150'))
    field_information['GGDM 3.0']['StructureSrf']['FFN'] = ('Enumeration',('AL013','AL019','AL099','AL142'))
    field_information['GGDM 3.0']['StructureSrf']['EnumeratedIndexValues']['FFN'] = {}
    field_information['GGDM 3.0']['StructureSrf']['EnumeratedIndexValues']['FFN']['AL013']  = (-999999,2,3,9,14,15,19,20,21,27,30,35,40,50,60,70,83,87,91,95,99,100,101,102,103,104,105,106,107,110,111,112,113,114,115,116,118,119,120,121,122,123,124,125,129,130,140,150,155,160,161,165,171,181,190,191,192,195,210,221,225,230,231,232,233,234,235,236,237,240,241,242,243,250,251,255,257,260,270,272,280,289,290,301,304,305,306,310,320,321,322,323,324,325,330,331,332,333,334,340,341,342,343,350,351,352,355,356,360,361,362,363,370,372,382,383,385,440,459,460,464,465,466,470,473,474,475,476,477,478,480,481,482,483,484,486,487,488,489,490,491,494,495,496,497,500,501,505,507,508,510,511,512,513,520,525,529,530,535,536,537,538,539,540,541,545,548,549,550,551,552,553,554,555,556,557,558,559,563,570,572,573,574,578,579,580,582,594,601,604,610,612,614,615,616,617,620,621,622,625,626,632,633,640,642,643,651,662,663,671,680,681,691,696,701,706,711,714,717,720,721,722,725,730,741,752,757,760,761,770,775,780,781,791,795,801,807,808,809,810,811,812,813,814,815,817,818,819,821,822,825,826,827,828,829,830,831,832,833,835,836,837,838,839,840,841,842,843,844,845,846,847,848,850,851,852,855,857,860,861,862,863,864,865,866,871,873,875,881,882,883,884,885,887,888,890,891,892,893,894,895,900,902,905,906,907,909,912,913,914,919,921,922,923,930,931,950,954,955,961,962,963,964,965,966,967,970,980,999)
    field_information['GGDM 3.0']['StructureSrf']['EnumeratedIndexValues']['FFN']['AL019']  = (-999999,2,480,490,494,495,500,505,508,520,530,722,847,970,999)
    field_information['GGDM 3.0']['StructureSrf']['EnumeratedIndexValues']['FFN']['AL099']  = (-999999,2,9,14,557,563,721,722,847,866,881,883,930,970,999)
    field_information['GGDM 3.0']['StructureSrf']['EnumeratedIndexValues']['FFN']['AL142']  = (-999999,720,721,850,923,999)
    field_information['GGDM 3.0']['StructureSrf']['FFN2'] = ('Enumeration',('AL013','AL019','AL099','AL142'))
    field_information['GGDM 3.0']['StructureSrf']['EnumeratedIndexValues']['FFN2'] = {}
    field_information['GGDM 3.0']['StructureSrf']['EnumeratedIndexValues']['FFN2']['AL013']  = (-999999,2,3,9,14,15,19,20,21,27,30,35,40,50,60,70,83,87,91,95,99,100,101,102,103,104,105,106,107,110,111,112,113,114,115,116,118,119,120,121,122,123,124,125,129,130,140,150,155,160,161,165,171,181,190,191,192,195,210,221,225,230,231,232,233,234,235,236,237,240,241,242,243,250,251,255,257,260,270,272,280,289,290,301,304,305,306,310,320,321,322,323,324,325,330,331,332,333,334,340,341,342,343,350,351,352,355,356,360,361,362,363,370,372,382,383,385,440,459,460,464,465,466,470,473,474,475,476,477,478,480,481,482,483,484,486,487,488,489,490,491,494,495,496,497,500,501,505,507,508,510,511,512,513,520,525,529,530,535,536,537,538,539,540,541,545,548,549,550,551,552,553,554,555,556,557,558,559,563,570,572,573,574,578,579,580,582,594,601,604,610,612,614,615,616,617,620,621,622,625,626,632,633,640,642,643,651,662,663,671,680,681,691,696,701,706,711,714,717,720,721,722,725,730,741,752,757,760,761,770,775,780,781,791,795,801,807,808,809,810,811,812,813,814,815,817,818,819,821,822,825,826,827,828,829,830,831,832,833,835,836,837,838,839,840,841,842,843,844,845,846,847,848,850,851,852,855,857,860,861,862,863,864,865,866,871,873,875,881,882,883,884,885,887,888,890,891,892,893,894,895,900,902,905,906,907,909,912,913,914,919,921,922,923,930,931,950,954,955,961,962,963,964,965,966,967,970,980,999)
    field_information['GGDM 3.0']['StructureSrf']['EnumeratedIndexValues']['FFN2']['AL019']  = (-999999,2,480,490,494,495,500,505,508,520,530,722,847,970,999)
    field_information['GGDM 3.0']['StructureSrf']['EnumeratedIndexValues']['FFN2']['AL099']  = (-999999,2,9,14,557,563,721,722,847,866,881,883,930,970,999)
    field_information['GGDM 3.0']['StructureSrf']['EnumeratedIndexValues']['FFN2']['AL142']  = (-999999,720,721,850,923,999)
    field_information['GGDM 3.0']['StructureSrf']['FFN3'] = ('Enumeration',('AL013','AL019','AL099','AL142'))
    field_information['GGDM 3.0']['StructureSrf']['EnumeratedIndexValues']['FFN3'] = {}
    field_information['GGDM 3.0']['StructureSrf']['EnumeratedIndexValues']['FFN3']['AL013']  = (-999999,2,3,9,14,15,19,20,21,27,30,35,40,50,60,70,83,87,91,95,99,100,101,102,103,104,105,106,107,110,111,112,113,114,115,116,118,119,120,121,122,123,124,125,129,130,140,150,155,160,161,165,171,181,190,191,192,195,210,221,225,230,231,232,233,234,235,236,237,240,241,242,243,250,251,255,257,260,270,272,280,289,290,301,304,305,306,310,320,321,322,323,324,325,330,331,332,333,334,340,341,342,343,350,351,352,355,356,360,361,362,363,370,372,382,383,385,440,459,460,464,465,466,470,473,474,475,476,477,478,480,481,482,483,484,486,487,488,489,490,491,494,495,496,497,500,501,505,507,508,510,511,512,513,520,525,529,530,535,536,537,538,539,540,541,545,548,549,550,551,552,553,554,555,556,557,558,559,563,570,572,573,574,578,579,580,582,594,601,604,610,612,614,615,616,617,620,621,622,625,626,632,633,640,642,643,651,662,663,671,680,681,691,696,701,706,711,714,717,720,721,722,725,730,741,752,757,760,761,770,775,780,781,791,795,801,807,808,809,810,811,812,813,814,815,817,818,819,821,822,825,826,827,828,829,830,831,832,833,835,836,837,838,839,840,841,842,843,844,845,846,847,848,850,851,852,855,857,860,861,862,863,864,865,866,871,873,875,881,882,883,884,885,887,888,890,891,892,893,894,895,900,902,905,906,907,909,912,913,914,919,921,922,923,930,931,950,954,955,961,962,963,964,965,966,967,970,980,999)
    field_information['GGDM 3.0']['StructureSrf']['EnumeratedIndexValues']['FFN3']['AL019']  = (-999999,2,480,490,494,495,500,505,508,520,530,722,847,970,999)
    field_information['GGDM 3.0']['StructureSrf']['EnumeratedIndexValues']['FFN3']['AL099']  = (-999999,2,9,14,557,563,721,722,847,866,881,883,930,970,999)
    field_information['GGDM 3.0']['StructureSrf']['EnumeratedIndexValues']['FFN3']['AL142']  = (-999999,720,721,850,923,999)
    field_information['GGDM 3.0']['StructureSrf']['FUFI'] = ('StructuredText',('AF060','AL013','AL014','AL018','AL019','AL099','AL140','AL142','AL241','AL371','AQ150'))
    field_information['GGDM 3.0']['StructureSrf']['FURL'] = ('StructuredText',('AF060','AL013','AL014','AL018','AL019','AL099','AL140','AL142','AL241','AL371','AQ150'))
    field_information['GGDM 3.0']['StructureSrf']['GDBV'] = ('Enumeration',('AF060','AL013','AL014','AL018','AL019','AL099','AL140','AL142','AL241','AL371','AQ150'))
    field_information['GGDM 3.0']['StructureSrf']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['StructureSrf']['EnumeratedIndexValues']['GDBV']['AF060']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['StructureSrf']['EnumeratedIndexValues']['GDBV']['AL013']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['StructureSrf']['EnumeratedIndexValues']['GDBV']['AL014']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['StructureSrf']['EnumeratedIndexValues']['GDBV']['AL018']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['StructureSrf']['EnumeratedIndexValues']['GDBV']['AL019']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['StructureSrf']['EnumeratedIndexValues']['GDBV']['AL099']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['StructureSrf']['EnumeratedIndexValues']['GDBV']['AL140']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['StructureSrf']['EnumeratedIndexValues']['GDBV']['AL142']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['StructureSrf']['EnumeratedIndexValues']['GDBV']['AL241']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['StructureSrf']['EnumeratedIndexValues']['GDBV']['AL371']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['StructureSrf']['EnumeratedIndexValues']['GDBV']['AQ150']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['StructureSrf']['GUG'] = ('Boolean',('AL241'))
    field_information['GGDM 3.0']['StructureSrf']['HEI'] = ('Real',('AL018','AL241'))
    field_information['GGDM 3.0']['StructureSrf']['HGT'] = ('Real',('AF060','AL013','AL014','AL018','AL019','AL099','AL142','AL241','AL371','AQ150'))
    field_information['GGDM 3.0']['StructureSrf']['HSC'] = ('Integer',('AL013'))
    field_information['GGDM 3.0']['StructureSrf']['HST'] = ('Enumeration',('AL013'))
    field_information['GGDM 3.0']['StructureSrf']['EnumeratedIndexValues']['HST'] = {}
    field_information['GGDM 3.0']['StructureSrf']['EnumeratedIndexValues']['HST']['AL013']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['StructureSrf']['HST2'] = ('Enumeration',('AL013'))
    field_information['GGDM 3.0']['StructureSrf']['EnumeratedIndexValues']['HST2'] = {}
    field_information['GGDM 3.0']['StructureSrf']['EnumeratedIndexValues']['HST2']['AL013']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['StructureSrf']['HST3'] = ('Enumeration',('AL013'))
    field_information['GGDM 3.0']['StructureSrf']['EnumeratedIndexValues']['HST3'] = {}
    field_information['GGDM 3.0']['StructureSrf']['EnumeratedIndexValues']['HST3']['AL013']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['StructureSrf']['LMC'] = ('Boolean',('AF060','AL013','AL014','AL018','AL019','AL099','AL140','AL142','AL241','AL371'))
    field_information['GGDM 3.0']['StructureSrf']['LZN'] = ('Real',('AF060','AL013','AL014','AL018','AL019','AL099','AL140','AL142','AL241','AL371','AQ150'))
    field_information['GGDM 3.0']['StructureSrf']['MEL'] = ('Enumeration',('AL013'))
    field_information['GGDM 3.0']['StructureSrf']['EnumeratedIndexValues']['MEL'] = {}
    field_information['GGDM 3.0']['StructureSrf']['EnumeratedIndexValues']['MEL']['AL013']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,999)
    field_information['GGDM 3.0']['StructureSrf']['MFB'] = ('Boolean',('AL013'))
    field_information['GGDM 3.0']['StructureSrf']['MFY'] = ('Enumeration',('AL013'))
    field_information['GGDM 3.0']['StructureSrf']['EnumeratedIndexValues']['MFY'] = {}
    field_information['GGDM 3.0']['StructureSrf']['EnumeratedIndexValues']['MFY']['AL013']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,999)
    field_information['GGDM 3.0']['StructureSrf']['MKSZ'] = ('Enumeration',('AL013'))
    field_information['GGDM 3.0']['StructureSrf']['EnumeratedIndexValues']['MKSZ'] = {}
    field_information['GGDM 3.0']['StructureSrf']['EnumeratedIndexValues']['MKSZ']['AL013']  = (-999999,1,2,3,998)
    field_information['GGDM 3.0']['StructureSrf']['MUB'] = ('Boolean',('AL013'))
    field_information['GGDM 3.0']['StructureSrf']['NOR'] = ('Integer',('AL013'))
    field_information['GGDM 3.0']['StructureSrf']['OTH'] = ('StructuredText',('AF060','AL013','AL014','AL018','AL019','AL099','AL140','AL142','AL241','AL371','AQ150'))
    field_information['GGDM 3.0']['StructureSrf']['PCF'] = ('Enumeration',('AF060','AL013','AL014','AL018','AL019','AL099','AL140','AL142','AL241','AL371','AQ150'))
    field_information['GGDM 3.0']['StructureSrf']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['StructureSrf']['EnumeratedIndexValues']['PCF']['AF060']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['StructureSrf']['EnumeratedIndexValues']['PCF']['AL013']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['StructureSrf']['EnumeratedIndexValues']['PCF']['AL014']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['StructureSrf']['EnumeratedIndexValues']['PCF']['AL018']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['StructureSrf']['EnumeratedIndexValues']['PCF']['AL019']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['StructureSrf']['EnumeratedIndexValues']['PCF']['AL099']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['StructureSrf']['EnumeratedIndexValues']['PCF']['AL140']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['StructureSrf']['EnumeratedIndexValues']['PCF']['AL142']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['StructureSrf']['EnumeratedIndexValues']['PCF']['AL241']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['StructureSrf']['EnumeratedIndexValues']['PCF']['AL371']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['StructureSrf']['EnumeratedIndexValues']['PCF']['AQ150']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['StructureSrf']['PYC'] = ('Enumeration',('AL241'))
    field_information['GGDM 3.0']['StructureSrf']['EnumeratedIndexValues']['PYC'] = {}
    field_information['GGDM 3.0']['StructureSrf']['EnumeratedIndexValues']['PYC']['AL241']  = (-999999,1,2,3,4,5,999)
    field_information['GGDM 3.0']['StructureSrf']['PYM'] = ('Enumeration',('AL241'))
    field_information['GGDM 3.0']['StructureSrf']['EnumeratedIndexValues']['PYM'] = {}
    field_information['GGDM 3.0']['StructureSrf']['EnumeratedIndexValues']['PYM']['AL241']  = (-999999,1,3,4,5,7,8,9,10,999)
    field_information['GGDM 3.0']['StructureSrf']['RLE'] = ('Enumeration',('AL013'))
    field_information['GGDM 3.0']['StructureSrf']['EnumeratedIndexValues']['RLE'] = {}
    field_information['GGDM 3.0']['StructureSrf']['EnumeratedIndexValues']['RLE']['AL013']  = (-999999,1,2,3)
    field_information['GGDM 3.0']['StructureSrf']['SPT'] = ('Boolean',('AL241'))
    field_information['GGDM 3.0']['StructureSrf']['SRL'] = ('Enumeration',('AF060'))
    field_information['GGDM 3.0']['StructureSrf']['EnumeratedIndexValues']['SRL'] = {}
    field_information['GGDM 3.0']['StructureSrf']['EnumeratedIndexValues']['SRL']['AF060']  = (-999999,1,2,3)
    field_information['GGDM 3.0']['StructureSrf']['SSR'] = ('Enumeration',('AL013','AL019','AL142','AL241','AL371'))
    field_information['GGDM 3.0']['StructureSrf']['EnumeratedIndexValues']['SSR'] = {}
    field_information['GGDM 3.0']['StructureSrf']['EnumeratedIndexValues']['SSR']['AL013']  = (-999999,6,7,38,40,41,42,47,50,55,64,999)
    field_information['GGDM 3.0']['StructureSrf']['EnumeratedIndexValues']['SSR']['AL019']  = (-999999,6,7,38,40,41,42,47,50,55,64,999)
    field_information['GGDM 3.0']['StructureSrf']['EnumeratedIndexValues']['SSR']['AL142']  = (-999999,6,7,38,40,41,42,47,50,55,64,999)
    field_information['GGDM 3.0']['StructureSrf']['EnumeratedIndexValues']['SSR']['AL241']  = (-999999,6,7,38,40,41,42,999)
    field_information['GGDM 3.0']['StructureSrf']['EnumeratedIndexValues']['SSR']['AL371']  = (-999999,6,7,38,40,41,42,47,50,55,64,999)
    field_information['GGDM 3.0']['StructureSrf']['SSR2'] = ('Enumeration',('AL013','AL019','AL142','AL241','AL371'))
    field_information['GGDM 3.0']['StructureSrf']['EnumeratedIndexValues']['SSR2'] = {}
    field_information['GGDM 3.0']['StructureSrf']['EnumeratedIndexValues']['SSR2']['AL013']  = (-999999,6,7,38,40,41,42,47,50,55,64,999)
    field_information['GGDM 3.0']['StructureSrf']['EnumeratedIndexValues']['SSR2']['AL019']  = (-999999,6,7,38,40,41,42,47,50,55,64,999)
    field_information['GGDM 3.0']['StructureSrf']['EnumeratedIndexValues']['SSR2']['AL142']  = (-999999,6,7,38,40,41,42,47,50,55,64,999)
    field_information['GGDM 3.0']['StructureSrf']['EnumeratedIndexValues']['SSR2']['AL241']  = (-999999,6,7,38,40,41,42,999)
    field_information['GGDM 3.0']['StructureSrf']['EnumeratedIndexValues']['SSR2']['AL371']  = (-999999,6,7,38,40,41,42,47,50,55,64,999)
    field_information['GGDM 3.0']['StructureSrf']['SSR3'] = ('Enumeration',('AL013','AL019','AL142','AL241','AL371'))
    field_information['GGDM 3.0']['StructureSrf']['EnumeratedIndexValues']['SSR3'] = {}
    field_information['GGDM 3.0']['StructureSrf']['EnumeratedIndexValues']['SSR3']['AL013']  = (-999999,6,7,38,40,41,42,47,50,55,64,999)
    field_information['GGDM 3.0']['StructureSrf']['EnumeratedIndexValues']['SSR3']['AL019']  = (-999999,6,7,38,40,41,42,47,50,55,64,999)
    field_information['GGDM 3.0']['StructureSrf']['EnumeratedIndexValues']['SSR3']['AL142']  = (-999999,6,7,38,40,41,42,47,50,55,64,999)
    field_information['GGDM 3.0']['StructureSrf']['EnumeratedIndexValues']['SSR3']['AL241']  = (-999999,6,7,38,40,41,42,999)
    field_information['GGDM 3.0']['StructureSrf']['EnumeratedIndexValues']['SSR3']['AL371']  = (-999999,6,7,38,40,41,42,47,50,55,64,999)
    field_information['GGDM 3.0']['StructureSrf']['STAF'] = ('Integer',('AL013'))
    field_information['GGDM 3.0']['StructureSrf']['TEL'] = ('Enumeration',('AL142'))
    field_information['GGDM 3.0']['StructureSrf']['EnumeratedIndexValues']['TEL'] = {}
    field_information['GGDM 3.0']['StructureSrf']['EnumeratedIndexValues']['TEL']['AL142']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['StructureSrf']['TOS'] = ('Enumeration',('AL241'))
    field_information['GGDM 3.0']['StructureSrf']['EnumeratedIndexValues']['TOS'] = {}
    field_information['GGDM 3.0']['StructureSrf']['EnumeratedIndexValues']['TOS']['AL241']  = (-999999,6,8,12,13,999)
    field_information['GGDM 3.0']['StructureSrf']['TTC'] = ('Enumeration',('AL241'))
    field_information['GGDM 3.0']['StructureSrf']['EnumeratedIndexValues']['TTC'] = {}
    field_information['GGDM 3.0']['StructureSrf']['EnumeratedIndexValues']['TTC']['AL241']  = (-999999,2,10,12,20,21,22,23,24,999)
    field_information['GGDM 3.0']['StructureSrf']['TTC2'] = ('Enumeration',('AL241'))
    field_information['GGDM 3.0']['StructureSrf']['EnumeratedIndexValues']['TTC2'] = {}
    field_information['GGDM 3.0']['StructureSrf']['EnumeratedIndexValues']['TTC2']['AL241']  = (-999999,2,10,12,20,21,22,23,24,999)
    field_information['GGDM 3.0']['StructureSrf']['TTC3'] = ('Enumeration',('AL241'))
    field_information['GGDM 3.0']['StructureSrf']['EnumeratedIndexValues']['TTC3'] = {}
    field_information['GGDM 3.0']['StructureSrf']['EnumeratedIndexValues']['TTC3']['AL241']  = (-999999,2,10,12,20,21,22,23,24,999)
    field_information['GGDM 3.0']['StructureSrf']['UFI'] = ('StructuredText',('AF060','AL013','AL014','AL018','AL019','AL099','AL140','AL142','AL241','AL371','AQ150'))
    field_information['GGDM 3.0']['StructureSrf']['VCM'] = ('Enumeration',('AL013','AL019','AL371'))
    field_information['GGDM 3.0']['StructureSrf']['EnumeratedIndexValues']['VCM'] = {}
    field_information['GGDM 3.0']['StructureSrf']['EnumeratedIndexValues']['VCM']['AL013']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,999)
    field_information['GGDM 3.0']['StructureSrf']['EnumeratedIndexValues']['VCM']['AL019']  = (-999999,1,2,4,5,7,8,9,10,11,14,15,16,18,999)
    field_information['GGDM 3.0']['StructureSrf']['EnumeratedIndexValues']['VCM']['AL371']  = (-999999,3,4,6,8,12,13,15,16,18,999)
    field_information['GGDM 3.0']['StructureSrf']['VCM2'] = ('Enumeration',('AL013','AL019','AL371'))
    field_information['GGDM 3.0']['StructureSrf']['EnumeratedIndexValues']['VCM2'] = {}
    field_information['GGDM 3.0']['StructureSrf']['EnumeratedIndexValues']['VCM2']['AL013']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,999)
    field_information['GGDM 3.0']['StructureSrf']['EnumeratedIndexValues']['VCM2']['AL019']  = (-999999,1,2,4,5,7,8,9,10,11,14,15,16,18,999)
    field_information['GGDM 3.0']['StructureSrf']['EnumeratedIndexValues']['VCM2']['AL371']  = (-999999,3,4,6,8,12,13,15,16,18,999)
    field_information['GGDM 3.0']['StructureSrf']['VCM3'] = ('Enumeration',('AL013','AL019','AL371'))
    field_information['GGDM 3.0']['StructureSrf']['EnumeratedIndexValues']['VCM3'] = {}
    field_information['GGDM 3.0']['StructureSrf']['EnumeratedIndexValues']['VCM3']['AL013']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,999)
    field_information['GGDM 3.0']['StructureSrf']['EnumeratedIndexValues']['VCM3']['AL019']  = (-999999,1,2,4,5,7,8,9,10,11,14,15,16,18,999)
    field_information['GGDM 3.0']['StructureSrf']['EnumeratedIndexValues']['VCM3']['AL371']  = (-999999,3,4,6,8,12,13,15,16,18,999)
    field_information['GGDM 3.0']['StructureSrf']['VEC'] = ('Integer',('AL013'))
    field_information['GGDM 3.0']['StructureSrf']['VOI'] = ('StructuredText',('AF060','AL013','AL014','AL018','AL142','AL241'))
    field_information['GGDM 3.0']['StructureSrf']['WID'] = ('Real',('AF060','AL013','AL014','AL018','AL019','AL099','AL140','AL142','AL241','AL371','AQ150'))
    field_information['GGDM 3.0']['StructureSrf']['WPST'] = ('Integer',('AL013'))
    field_information['GGDM 3.0']['StructureSrf']['WTYP'] = ('Enumeration',('AL013'))
    field_information['GGDM 3.0']['StructureSrf']['EnumeratedIndexValues']['WTYP'] = {}
    field_information['GGDM 3.0']['StructureSrf']['EnumeratedIndexValues']['WTYP']['AL013']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['StructureSrf']['ZI001_SDV'] = ('StructuredText',('AF060','AL013','AL014','AL018','AL019','AL099','AL140','AL142','AL241','AL371','AQ150'))
    field_information['GGDM 3.0']['StructureSrf']['ZI001_SRT'] = ('Enumeration',('AF060','AL013','AL014','AL018','AL019','AL099','AL140','AL142','AL241','AL371','AQ150'))
    field_information['GGDM 3.0']['StructureSrf']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['StructureSrf']['EnumeratedIndexValues']['ZI001_SRT']['AF060']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['StructureSrf']['EnumeratedIndexValues']['ZI001_SRT']['AL013']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['StructureSrf']['EnumeratedIndexValues']['ZI001_SRT']['AL014']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['StructureSrf']['EnumeratedIndexValues']['ZI001_SRT']['AL018']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['StructureSrf']['EnumeratedIndexValues']['ZI001_SRT']['AL019']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['StructureSrf']['EnumeratedIndexValues']['ZI001_SRT']['AL099']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['StructureSrf']['EnumeratedIndexValues']['ZI001_SRT']['AL140']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['StructureSrf']['EnumeratedIndexValues']['ZI001_SRT']['AL142']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['StructureSrf']['EnumeratedIndexValues']['ZI001_SRT']['AL241']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['StructureSrf']['EnumeratedIndexValues']['ZI001_SRT']['AL371']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['StructureSrf']['EnumeratedIndexValues']['ZI001_SRT']['AQ150']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['StructureSrf']['ZI002_UFI'] = ('StructuredText',('AF060','AL013','AL014','AL018','AL019','AL099','AL140','AL142','AL241','AL371','AQ150'))
    field_information['GGDM 3.0']['StructureSrf']['ZI004_RCG'] = ('Enumeration',('AF060','AL013','AL014','AL018','AL019','AL099','AL140','AL142','AL241','AL371','AQ150'))
    field_information['GGDM 3.0']['StructureSrf']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['StructureSrf']['EnumeratedIndexValues']['ZI004_RCG']['AF060']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['StructureSrf']['EnumeratedIndexValues']['ZI004_RCG']['AL013']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['StructureSrf']['EnumeratedIndexValues']['ZI004_RCG']['AL014']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['StructureSrf']['EnumeratedIndexValues']['ZI004_RCG']['AL018']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['StructureSrf']['EnumeratedIndexValues']['ZI004_RCG']['AL019']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['StructureSrf']['EnumeratedIndexValues']['ZI004_RCG']['AL099']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['StructureSrf']['EnumeratedIndexValues']['ZI004_RCG']['AL140']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['StructureSrf']['EnumeratedIndexValues']['ZI004_RCG']['AL142']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['StructureSrf']['EnumeratedIndexValues']['ZI004_RCG']['AL241']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['StructureSrf']['EnumeratedIndexValues']['ZI004_RCG']['AL371']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['StructureSrf']['EnumeratedIndexValues']['ZI004_RCG']['AQ150']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['StructureSrf']['ZI005_FNA'] = ('String',('AF060','AL013','AL014','AL018','AL019','AL099','AL140','AL142','AL241','AL371','AQ150'))
    field_information['GGDM 3.0']['StructureSrf']['ZI005_FNA2'] = ('String',('AL013'))
    field_information['GGDM 3.0']['StructureSrf']['ZI005_FNA3'] = ('String',('AL013'))
    field_information['GGDM 3.0']['StructureSrf']['ZI005_GNT'] = ('Enumeration',('AF060','AL013','AL014','AL018','AL019','AL099','AL140','AL142','AL241','AQ150'))
    field_information['GGDM 3.0']['StructureSrf']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['StructureSrf']['EnumeratedIndexValues']['ZI005_GNT']['AF060']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['StructureSrf']['EnumeratedIndexValues']['ZI005_GNT']['AL013']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['StructureSrf']['EnumeratedIndexValues']['ZI005_GNT']['AL014']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['StructureSrf']['EnumeratedIndexValues']['ZI005_GNT']['AL018']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['StructureSrf']['EnumeratedIndexValues']['ZI005_GNT']['AL019']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['StructureSrf']['EnumeratedIndexValues']['ZI005_GNT']['AL099']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['StructureSrf']['EnumeratedIndexValues']['ZI005_GNT']['AL140']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['StructureSrf']['EnumeratedIndexValues']['ZI005_GNT']['AL142']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['StructureSrf']['EnumeratedIndexValues']['ZI005_GNT']['AL241']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['StructureSrf']['EnumeratedIndexValues']['ZI005_GNT']['AQ150']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['StructureSrf']['ZI005_GNT2'] = ('Enumeration',('AL013'))
    field_information['GGDM 3.0']['StructureSrf']['EnumeratedIndexValues']['ZI005_GNT2'] = {}
    field_information['GGDM 3.0']['StructureSrf']['EnumeratedIndexValues']['ZI005_GNT2']['AL013']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['StructureSrf']['ZI005_GNT3'] = ('Enumeration',('AL013'))
    field_information['GGDM 3.0']['StructureSrf']['EnumeratedIndexValues']['ZI005_GNT3'] = {}
    field_information['GGDM 3.0']['StructureSrf']['EnumeratedIndexValues']['ZI005_GNT3']['AL013']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['StructureSrf']['ZI005_NFN'] = ('String',('AF060','AL013','AL014','AL018','AL019','AL099','AL140','AL142','AL241','AL371','AQ150'))
    field_information['GGDM 3.0']['StructureSrf']['ZI005_NFN2'] = ('String',('AL013'))
    field_information['GGDM 3.0']['StructureSrf']['ZI005_NFN3'] = ('String',('AL013'))
    field_information['GGDM 3.0']['StructureSrf']['ZI006_MEM'] = ('String',('AF060','AL013','AL014','AL018','AL019','AL099','AL140','AL142','AL241','AL371','AQ150'))
    field_information['GGDM 3.0']['StructureSrf']['ZI014_PBY'] = ('Enumeration',('AL013','AL014','AL019'))
    field_information['GGDM 3.0']['StructureSrf']['EnumeratedIndexValues']['ZI014_PBY'] = {}
    field_information['GGDM 3.0']['StructureSrf']['EnumeratedIndexValues']['ZI014_PBY']['AL013']  = (-999999,1,2,6,7,8,12,13,15,89,999)
    field_information['GGDM 3.0']['StructureSrf']['EnumeratedIndexValues']['ZI014_PBY']['AL014']  = (-999999,1,2,6,7,8,12,13,15,89,999)
    field_information['GGDM 3.0']['StructureSrf']['EnumeratedIndexValues']['ZI014_PBY']['AL019']  = (-999999,1,2,6,7,8,12,13,15,89,999)
    field_information['GGDM 3.0']['StructureSrf']['ZI014_PBY2'] = ('Enumeration',('AL013','AL014','AL019'))
    field_information['GGDM 3.0']['StructureSrf']['EnumeratedIndexValues']['ZI014_PBY2'] = {}
    field_information['GGDM 3.0']['StructureSrf']['EnumeratedIndexValues']['ZI014_PBY2']['AL013']  = (-999999,1,2,6,7,8,12,13,15,89,999)
    field_information['GGDM 3.0']['StructureSrf']['EnumeratedIndexValues']['ZI014_PBY2']['AL014']  = (-999999,1,2,6,7,8,12,13,15,89,999)
    field_information['GGDM 3.0']['StructureSrf']['EnumeratedIndexValues']['ZI014_PBY2']['AL019']  = (-999999,1,2,6,7,8,12,13,15,89,999)
    field_information['GGDM 3.0']['StructureSrf']['ZI014_PBY3'] = ('Enumeration',('AL013','AL014','AL019'))
    field_information['GGDM 3.0']['StructureSrf']['EnumeratedIndexValues']['ZI014_PBY3'] = {}
    field_information['GGDM 3.0']['StructureSrf']['EnumeratedIndexValues']['ZI014_PBY3']['AL013']  = (-999999,1,2,6,7,8,12,13,15,89,999)
    field_information['GGDM 3.0']['StructureSrf']['EnumeratedIndexValues']['ZI014_PBY3']['AL014']  = (-999999,1,2,6,7,8,12,13,15,89,999)
    field_information['GGDM 3.0']['StructureSrf']['EnumeratedIndexValues']['ZI014_PBY3']['AL019']  = (-999999,1,2,6,7,8,12,13,15,89,999)
    field_information['GGDM 3.0']['StructureSrf']['ZI014_PPO'] = ('Enumeration',('AL013','AL014','AL019'))
    field_information['GGDM 3.0']['StructureSrf']['EnumeratedIndexValues']['ZI014_PPO'] = {}
    field_information['GGDM 3.0']['StructureSrf']['EnumeratedIndexValues']['ZI014_PPO']['AL013']  = (-999999,1,2,3,4,5,13,15,16,18,20,21,23,25,26,28,32,37,38,39,41,43,44,45,46,47,48,57,58,59,60,61,62,63,65,69,70,73,74,80,83,84,87,90,92,94,95,101,105,106,109,111,114,117,120,121,122,123,126,136,137,146,147,148,150,154,155,156,157,160,165,192,200,214,279,325,435,999)
    field_information['GGDM 3.0']['StructureSrf']['EnumeratedIndexValues']['ZI014_PPO']['AL014']  = (-999999,1,2,3,4,5,13,15,16,18,20,21,23,25,26,28,32,37,38,39,41,43,44,45,46,47,48,57,58,59,60,61,62,63,65,69,70,73,74,80,83,84,87,90,92,94,95,101,105,106,109,111,114,117,120,121,122,123,126,136,137,146,147,148,150,154,155,156,157,160,165,192,200,214,279,325,435,999)
    field_information['GGDM 3.0']['StructureSrf']['EnumeratedIndexValues']['ZI014_PPO']['AL019']  = (-999999,1,2,3,4,5,13,15,16,18,20,21,23,25,26,28,32,37,38,39,41,43,44,45,46,47,48,57,58,59,60,61,62,63,65,69,70,73,74,80,83,84,87,90,92,94,95,101,105,106,109,111,114,117,120,121,122,123,126,136,137,146,147,148,150,154,155,156,157,160,165,192,200,214,279,325,435,999)
    field_information['GGDM 3.0']['StructureSrf']['ZI014_PPO2'] = ('Enumeration',('AL013','AL014','AL019'))
    field_information['GGDM 3.0']['StructureSrf']['EnumeratedIndexValues']['ZI014_PPO2'] = {}
    field_information['GGDM 3.0']['StructureSrf']['EnumeratedIndexValues']['ZI014_PPO2']['AL013']  = (-999999,1,2,3,4,5,13,15,16,18,20,21,23,25,26,28,32,37,38,39,41,43,44,45,46,47,48,57,58,59,60,61,62,63,65,69,70,73,74,80,83,84,87,90,92,94,95,101,105,106,109,111,114,117,120,121,122,123,126,136,137,146,147,148,150,154,155,156,157,160,165,192,200,214,279,325,435,999)
    field_information['GGDM 3.0']['StructureSrf']['EnumeratedIndexValues']['ZI014_PPO2']['AL014']  = (-999999,1,2,3,4,5,13,15,16,18,20,21,23,25,26,28,32,37,38,39,41,43,44,45,46,47,48,57,58,59,60,61,62,63,65,69,70,73,74,80,83,84,87,90,92,94,95,101,105,106,109,111,114,117,120,121,122,123,126,136,137,146,147,148,150,154,155,156,157,160,165,192,200,214,279,325,435,999)
    field_information['GGDM 3.0']['StructureSrf']['EnumeratedIndexValues']['ZI014_PPO2']['AL019']  = (-999999,1,2,3,4,5,13,15,16,18,20,21,23,25,26,28,32,37,38,39,41,43,44,45,46,47,48,57,58,59,60,61,62,63,65,69,70,73,74,80,83,84,87,90,92,94,95,101,105,106,109,111,114,117,120,121,122,123,126,136,137,146,147,148,150,154,155,156,157,160,165,192,200,214,279,325,435,999)
    field_information['GGDM 3.0']['StructureSrf']['ZI014_PPO3'] = ('Enumeration',('AL013','AL014','AL019'))
    field_information['GGDM 3.0']['StructureSrf']['EnumeratedIndexValues']['ZI014_PPO3'] = {}
    field_information['GGDM 3.0']['StructureSrf']['EnumeratedIndexValues']['ZI014_PPO3']['AL013']  = (-999999,1,2,3,4,5,13,15,16,18,20,21,23,25,26,28,32,37,38,39,41,43,44,45,46,47,48,57,58,59,60,61,62,63,65,69,70,73,74,80,83,84,87,90,92,94,95,101,105,106,109,111,114,117,120,121,122,123,126,136,137,146,147,148,150,154,155,156,157,160,165,192,200,214,279,325,435,999)
    field_information['GGDM 3.0']['StructureSrf']['EnumeratedIndexValues']['ZI014_PPO3']['AL014']  = (-999999,1,2,3,4,5,13,15,16,18,20,21,23,25,26,28,32,37,38,39,41,43,44,45,46,47,48,57,58,59,60,61,62,63,65,69,70,73,74,80,83,84,87,90,92,94,95,101,105,106,109,111,114,117,120,121,122,123,126,136,137,146,147,148,150,154,155,156,157,160,165,192,200,214,279,325,435,999)
    field_information['GGDM 3.0']['StructureSrf']['EnumeratedIndexValues']['ZI014_PPO3']['AL019']  = (-999999,1,2,3,4,5,13,15,16,18,20,21,23,25,26,28,32,37,38,39,41,43,44,45,46,47,48,57,58,59,60,61,62,63,65,69,70,73,74,80,83,84,87,90,92,94,95,101,105,106,109,111,114,117,120,121,122,123,126,136,137,146,147,148,150,154,155,156,157,160,165,192,200,214,279,325,435,999)
    field_information['GGDM 3.0']['StructureSrf']['ZI014_PRW'] = ('Enumeration',('AL013','AL014','AL019'))
    field_information['GGDM 3.0']['StructureSrf']['EnumeratedIndexValues']['ZI014_PRW'] = {}
    field_information['GGDM 3.0']['StructureSrf']['EnumeratedIndexValues']['ZI014_PRW']['AL013']  = (-999999,1,2,5,9,10,11,12,14,16,18,27,28,29,30,33,38,39,41,45,46,48,50,52,54,57,60,64,66,68,70,75,78,79,83,84,85,87,90,93,94,96,97,99,118,119,999)
    field_information['GGDM 3.0']['StructureSrf']['EnumeratedIndexValues']['ZI014_PRW']['AL014']  = (-999999,1,2,5,9,10,11,12,14,16,18,27,28,29,30,33,38,39,41,45,46,48,50,52,54,57,60,64,66,68,70,75,78,79,83,84,85,87,90,93,94,96,97,99,118,119,999)
    field_information['GGDM 3.0']['StructureSrf']['EnumeratedIndexValues']['ZI014_PRW']['AL019']  = (-999999,1,2,5,9,10,11,12,14,16,18,27,28,29,30,33,38,39,41,45,46,48,50,52,54,57,60,64,66,68,70,75,78,79,83,84,85,87,90,93,94,96,97,99,118,119,999)
    field_information['GGDM 3.0']['StructureSrf']['ZI014_PRW2'] = ('Enumeration',('AL013','AL014','AL019'))
    field_information['GGDM 3.0']['StructureSrf']['EnumeratedIndexValues']['ZI014_PRW2'] = {}
    field_information['GGDM 3.0']['StructureSrf']['EnumeratedIndexValues']['ZI014_PRW2']['AL013']  = (-999999,1,2,5,9,10,11,12,14,16,18,27,28,29,30,33,38,39,41,45,46,48,50,52,54,57,60,64,66,68,70,75,78,79,83,84,85,87,90,93,94,96,97,99,118,119,999)
    field_information['GGDM 3.0']['StructureSrf']['EnumeratedIndexValues']['ZI014_PRW2']['AL014']  = (-999999,1,2,5,9,10,11,12,14,16,18,27,28,29,30,33,38,39,41,45,46,48,50,52,54,57,60,64,66,68,70,75,78,79,83,84,85,87,90,93,94,96,97,99,118,119,999)
    field_information['GGDM 3.0']['StructureSrf']['EnumeratedIndexValues']['ZI014_PRW2']['AL019']  = (-999999,1,2,5,9,10,11,12,14,16,18,27,28,29,30,33,38,39,41,45,46,48,50,52,54,57,60,64,66,68,70,75,78,79,83,84,85,87,90,93,94,96,97,99,118,119,999)
    field_information['GGDM 3.0']['StructureSrf']['ZI014_PRW3'] = ('Enumeration',('AL013','AL014','AL019'))
    field_information['GGDM 3.0']['StructureSrf']['EnumeratedIndexValues']['ZI014_PRW3'] = {}
    field_information['GGDM 3.0']['StructureSrf']['EnumeratedIndexValues']['ZI014_PRW3']['AL013']  = (-999999,1,2,5,9,10,11,12,14,16,18,27,28,29,30,33,38,39,41,45,46,48,50,52,54,57,60,64,66,68,70,75,78,79,83,84,85,87,90,93,94,96,97,99,118,119,999)
    field_information['GGDM 3.0']['StructureSrf']['EnumeratedIndexValues']['ZI014_PRW3']['AL014']  = (-999999,1,2,5,9,10,11,12,14,16,18,27,28,29,30,33,38,39,41,45,46,48,50,52,54,57,60,64,66,68,70,75,78,79,83,84,85,87,90,93,94,96,97,99,118,119,999)
    field_information['GGDM 3.0']['StructureSrf']['EnumeratedIndexValues']['ZI014_PRW3']['AL019']  = (-999999,1,2,5,9,10,11,12,14,16,18,27,28,29,30,33,38,39,41,45,46,48,50,52,54,57,60,64,66,68,70,75,78,79,83,84,85,87,90,93,94,96,97,99,118,119,999)
    field_information['GGDM 3.0']['StructureSrf']['ZI018_WIT'] = ('Enumeration',('AL013','AL018','AL241'))
    field_information['GGDM 3.0']['StructureSrf']['EnumeratedIndexValues']['ZI018_WIT'] = {}
    field_information['GGDM 3.0']['StructureSrf']['EnumeratedIndexValues']['ZI018_WIT']['AL013']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['StructureSrf']['EnumeratedIndexValues']['ZI018_WIT']['AL018']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['StructureSrf']['EnumeratedIndexValues']['ZI018_WIT']['AL241']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['StructureSrf']['ZI020_GE4'] = ('CodeList',('AF060','AL013','AL014','AL018','AL019','AL099','AL140','AL142','AL241','AL371','AQ150'))
    field_information['GGDM 3.0']['StructureSrf']['ZI026_CTUC'] = ('Enumeration',('AF060','AL013','AL014','AL018','AL019','AL099','AL140','AL142','AL241','AL371','AQ150'))
    field_information['GGDM 3.0']['StructureSrf']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['StructureSrf']['EnumeratedIndexValues']['ZI026_CTUC']['AF060']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['StructureSrf']['EnumeratedIndexValues']['ZI026_CTUC']['AL013']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['StructureSrf']['EnumeratedIndexValues']['ZI026_CTUC']['AL014']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['StructureSrf']['EnumeratedIndexValues']['ZI026_CTUC']['AL018']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['StructureSrf']['EnumeratedIndexValues']['ZI026_CTUC']['AL019']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['StructureSrf']['EnumeratedIndexValues']['ZI026_CTUC']['AL099']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['StructureSrf']['EnumeratedIndexValues']['ZI026_CTUC']['AL140']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['StructureSrf']['EnumeratedIndexValues']['ZI026_CTUC']['AL142']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['StructureSrf']['EnumeratedIndexValues']['ZI026_CTUC']['AL241']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['StructureSrf']['EnumeratedIndexValues']['ZI026_CTUC']['AL371']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['StructureSrf']['EnumeratedIndexValues']['ZI026_CTUC']['AQ150']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['StructureSrf']['ZI026_CTUL'] = ('integer',('AF060','AL013','AL014','AL018','AL019','AL099','AL140','AL142','AL241','AL371','AQ150'))
    field_information['GGDM 3.0']['StructureSrf']['ZI026_CTUU'] = ('integer',('AF060','AL013','AL014','AL018','AL019','AL099','AL140','AL142','AL241','AL371','AQ150'))
    field_information['GGDM 3.0']['StructureSrf']['ZI031S_URI'] = ('StructuredText',('AF060','AL013','AL014','AL018','AL019','AL099','AL140','AL142','AL241','AL371','AQ150'))
    field_information['GGDM 3.0']['StructureSrf']['ZI037_REL'] = ('Enumeration',('AL013'))
    field_information['GGDM 3.0']['StructureSrf']['EnumeratedIndexValues']['ZI037_REL'] = {}
    field_information['GGDM 3.0']['StructureSrf']['EnumeratedIndexValues']['ZI037_REL']['AL013']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,999)
    field_information['GGDM 3.0']['StructureSrf']['ZI037_RFA'] = ('Enumeration',('AL013'))
    field_information['GGDM 3.0']['StructureSrf']['EnumeratedIndexValues']['ZI037_RFA'] = {}
    field_information['GGDM 3.0']['StructureSrf']['EnumeratedIndexValues']['ZI037_RFA']['AL013']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,18,19,20,21,22,23,25,999)
    field_information['GGDM 3.0']['StructureSrf']['ZI039S_UFI'] = ('StructuredText',('AF060','AL013','AL014','AL018','AL019','AL099','AL140','AL142','AL241','AL371','AQ150'))
    field_information['GGDM 3.0']['StructureSrf']['ZSAX_RS0'] = ('CodeList',('AF060','AL013','AL014','AL018','AL019','AL099','AL140','AL142','AL241','AL371','AQ150'))
    field_information['GGDM 3.0']['StructureSrf']['ZSAX_RX0'] = ('StructuredText',('AF060','AL013','AL014','AL018','AL019','AL099','AL140','AL142','AL241','AL371','AQ150'))
    field_information['GGDM 3.0']['StructureSrf']['ZSAX_RX3'] = ('StructuredText',('AF060','AL013','AL014','AL018','AL019','AL099','AL140','AL142','AL241','AL371','AQ150'))
    field_information['GGDM 3.0']['StructureSrf']['ZSAX_RX4'] = ('StructuredText',('AF060','AL013','AL014','AL018','AL019','AL099','AL140','AL142','AL241','AL371','AQ150'))
    field_information['GGDM 3.0']['StructureSrf']['ZVH'] = ('Real',('AF060','AL013','AL014','AL018','AL019','AL099','AL142','AL241','AL371','AQ150'))
    field_information['GGDM 3.0']['SubterraneanSrf']['AQN'] = ('String',('BH116'))
    field_information['GGDM 3.0']['SubterraneanSrf']['AQO'] = ('Enumeration',('BH116'))
    field_information['GGDM 3.0']['SubterraneanSrf']['EnumeratedIndexValues']['AQO'] = {}
    field_information['GGDM 3.0']['SubterraneanSrf']['EnumeratedIndexValues']['AQO']['BH116']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,999)
    field_information['GGDM 3.0']['SubterraneanSrf']['AQO2'] = ('Enumeration',('BH116'))
    field_information['GGDM 3.0']['SubterraneanSrf']['EnumeratedIndexValues']['AQO2'] = {}
    field_information['GGDM 3.0']['SubterraneanSrf']['EnumeratedIndexValues']['AQO2']['BH116']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,999)
    field_information['GGDM 3.0']['SubterraneanSrf']['AQO3'] = ('Enumeration',('BH116'))
    field_information['GGDM 3.0']['SubterraneanSrf']['EnumeratedIndexValues']['AQO3'] = {}
    field_information['GGDM 3.0']['SubterraneanSrf']['EnumeratedIndexValues']['AQO3']['BH116']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,999)
    field_information['GGDM 3.0']['SubterraneanSrf']['AQP'] = ('Enumeration',('BH116'))
    field_information['GGDM 3.0']['SubterraneanSrf']['EnumeratedIndexValues']['AQP'] = {}
    field_information['GGDM 3.0']['SubterraneanSrf']['EnumeratedIndexValues']['AQP']['BH116']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,999)
    field_information['GGDM 3.0']['SubterraneanSrf']['AQP2'] = ('Enumeration',('BH116'))
    field_information['GGDM 3.0']['SubterraneanSrf']['EnumeratedIndexValues']['AQP2'] = {}
    field_information['GGDM 3.0']['SubterraneanSrf']['EnumeratedIndexValues']['AQP2']['BH116']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,999)
    field_information['GGDM 3.0']['SubterraneanSrf']['AQP3'] = ('Enumeration',('BH116'))
    field_information['GGDM 3.0']['SubterraneanSrf']['EnumeratedIndexValues']['AQP3'] = {}
    field_information['GGDM 3.0']['SubterraneanSrf']['EnumeratedIndexValues']['AQP3']['BH116']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,999)
    field_information['GGDM 3.0']['SubterraneanSrf']['AQTC'] = ('Enumeration',('BH116'))
    field_information['GGDM 3.0']['SubterraneanSrf']['EnumeratedIndexValues']['AQTC'] = {}
    field_information['GGDM 3.0']['SubterraneanSrf']['EnumeratedIndexValues']['AQTC']['BH116']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['SubterraneanSrf']['AQTL'] = ('real',('BH116'))
    field_information['GGDM 3.0']['SubterraneanSrf']['AQTU'] = ('real',('BH116'))
    field_information['GGDM 3.0']['SubterraneanSrf']['ARA'] = ('Real',('BH116'))
    field_information['GGDM 3.0']['SubterraneanSrf']['AYRC'] = ('Enumeration',('BH116'))
    field_information['GGDM 3.0']['SubterraneanSrf']['EnumeratedIndexValues']['AYRC'] = {}
    field_information['GGDM 3.0']['SubterraneanSrf']['EnumeratedIndexValues']['AYRC']['BH116']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['SubterraneanSrf']['AYRL'] = ('real',('BH116'))
    field_information['GGDM 3.0']['SubterraneanSrf']['AYRU'] = ('real',('BH116'))
    field_information['GGDM 3.0']['SubterraneanSrf']['BEN'] = ('StructuredText',('BH116','DB028'))
    field_information['GGDM 3.0']['SubterraneanSrf']['CAA'] = ('Enumeration',('BH116','DB028'))
    field_information['GGDM 3.0']['SubterraneanSrf']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['SubterraneanSrf']['EnumeratedIndexValues']['CAA']['BH116']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['SubterraneanSrf']['EnumeratedIndexValues']['CAA']['DB028']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['SubterraneanSrf']['CNCP'] = ('StructuredText',('DB028'))
    field_information['GGDM 3.0']['SubterraneanSrf']['CNF'] = ('Boolean',('BH116'))
    field_information['GGDM 3.0']['SubterraneanSrf']['COS'] = ('Enumeration',('DB028'))
    field_information['GGDM 3.0']['SubterraneanSrf']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['SubterraneanSrf']['EnumeratedIndexValues']['COS']['DB028']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['SubterraneanSrf']['DPAC'] = ('Enumeration',('BH116'))
    field_information['GGDM 3.0']['SubterraneanSrf']['EnumeratedIndexValues']['DPAC'] = {}
    field_information['GGDM 3.0']['SubterraneanSrf']['EnumeratedIndexValues']['DPAC']['BH116']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['SubterraneanSrf']['DPAL'] = ('real',('BH116'))
    field_information['GGDM 3.0']['SubterraneanSrf']['DPAU'] = ('real',('BH116'))
    field_information['GGDM 3.0']['SubterraneanSrf']['DZP'] = ('Real',('DB028'))
    field_information['GGDM 3.0']['SubterraneanSrf']['F_CODE'] = ('CONSTRAINED_STRING',('BH116','DB028'))
    field_information['GGDM 3.0']['SubterraneanSrf']['FUFI'] = ('StructuredText',('BH116','DB028'))
    field_information['GGDM 3.0']['SubterraneanSrf']['FURL'] = ('StructuredText',('BH116','DB028'))
    field_information['GGDM 3.0']['SubterraneanSrf']['GDBV'] = ('Enumeration',('BH116','DB028'))
    field_information['GGDM 3.0']['SubterraneanSrf']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['SubterraneanSrf']['EnumeratedIndexValues']['GDBV']['BH116']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['SubterraneanSrf']['EnumeratedIndexValues']['GDBV']['DB028']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['SubterraneanSrf']['GWS'] = ('Enumeration',('BH116'))
    field_information['GGDM 3.0']['SubterraneanSrf']['EnumeratedIndexValues']['GWS'] = {}
    field_information['GGDM 3.0']['SubterraneanSrf']['EnumeratedIndexValues']['GWS']['BH116']  = (-999999,1,2,3,4)
    field_information['GGDM 3.0']['SubterraneanSrf']['GWTR'] = ('Real',('BH116'))
    field_information['GGDM 3.0']['SubterraneanSrf']['HYCD'] = ('Real',('BH116'))
    field_information['GGDM 3.0']['SubterraneanSrf']['LEA'] = ('Real',('DB028'))
    field_information['GGDM 3.0']['SubterraneanSrf']['LZN'] = ('Real',('BH116'))
    field_information['GGDM 3.0']['SubterraneanSrf']['OTH'] = ('StructuredText',('BH116','DB028'))
    field_information['GGDM 3.0']['SubterraneanSrf']['PCF'] = ('Enumeration',('DB028'))
    field_information['GGDM 3.0']['SubterraneanSrf']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['SubterraneanSrf']['EnumeratedIndexValues']['PCF']['DB028']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['SubterraneanSrf']['SWCP'] = ('Real',('BH116'))
    field_information['GGDM 3.0']['SubterraneanSrf']['UFI'] = ('StructuredText',('BH116','DB028'))
    field_information['GGDM 3.0']['SubterraneanSrf']['WID'] = ('Real',('BH116'))
    field_information['GGDM 3.0']['SubterraneanSrf']['WRCC'] = ('Enumeration',('BH116'))
    field_information['GGDM 3.0']['SubterraneanSrf']['EnumeratedIndexValues']['WRCC'] = {}
    field_information['GGDM 3.0']['SubterraneanSrf']['EnumeratedIndexValues']['WRCC']['BH116']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['SubterraneanSrf']['WRCL'] = ('real',('BH116'))
    field_information['GGDM 3.0']['SubterraneanSrf']['WRCU'] = ('real',('BH116'))
    field_information['GGDM 3.0']['SubterraneanSrf']['WWRC'] = ('Enumeration',('BH116'))
    field_information['GGDM 3.0']['SubterraneanSrf']['EnumeratedIndexValues']['WWRC'] = {}
    field_information['GGDM 3.0']['SubterraneanSrf']['EnumeratedIndexValues']['WWRC']['BH116']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['SubterraneanSrf']['WWRL'] = ('real',('BH116'))
    field_information['GGDM 3.0']['SubterraneanSrf']['WWRU'] = ('real',('BH116'))
    field_information['GGDM 3.0']['SubterraneanSrf']['ZI001_SDV'] = ('StructuredText',('BH116','DB028'))
    field_information['GGDM 3.0']['SubterraneanSrf']['ZI001_SRT'] = ('Enumeration',('BH116','DB028'))
    field_information['GGDM 3.0']['SubterraneanSrf']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['SubterraneanSrf']['EnumeratedIndexValues']['ZI001_SRT']['BH116']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['SubterraneanSrf']['EnumeratedIndexValues']['ZI001_SRT']['DB028']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['SubterraneanSrf']['ZI002_UFI'] = ('StructuredText',('BH116','DB028'))
    field_information['GGDM 3.0']['SubterraneanSrf']['ZI004_RCG'] = ('Enumeration',('BH116','DB028'))
    field_information['GGDM 3.0']['SubterraneanSrf']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['SubterraneanSrf']['EnumeratedIndexValues']['ZI004_RCG']['BH116']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['SubterraneanSrf']['EnumeratedIndexValues']['ZI004_RCG']['DB028']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['SubterraneanSrf']['ZI005_FNA'] = ('String',('BH116','DB028'))
    field_information['GGDM 3.0']['SubterraneanSrf']['ZI005_FNA2'] = ('String',('BH116'))
    field_information['GGDM 3.0']['SubterraneanSrf']['ZI005_FNA3'] = ('String',('BH116'))
    field_information['GGDM 3.0']['SubterraneanSrf']['ZI005_GNT'] = ('Enumeration',('BH116','DB028'))
    field_information['GGDM 3.0']['SubterraneanSrf']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['SubterraneanSrf']['EnumeratedIndexValues']['ZI005_GNT']['BH116']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['SubterraneanSrf']['EnumeratedIndexValues']['ZI005_GNT']['DB028']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['SubterraneanSrf']['ZI005_GNT2'] = ('Enumeration',('BH116'))
    field_information['GGDM 3.0']['SubterraneanSrf']['EnumeratedIndexValues']['ZI005_GNT2'] = {}
    field_information['GGDM 3.0']['SubterraneanSrf']['EnumeratedIndexValues']['ZI005_GNT2']['BH116']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['SubterraneanSrf']['ZI005_GNT3'] = ('Enumeration',('BH116'))
    field_information['GGDM 3.0']['SubterraneanSrf']['EnumeratedIndexValues']['ZI005_GNT3'] = {}
    field_information['GGDM 3.0']['SubterraneanSrf']['EnumeratedIndexValues']['ZI005_GNT3']['BH116']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['SubterraneanSrf']['ZI005_NFN'] = ('String',('BH116','DB028'))
    field_information['GGDM 3.0']['SubterraneanSrf']['ZI005_NFN2'] = ('String',('BH116'))
    field_information['GGDM 3.0']['SubterraneanSrf']['ZI005_NFN3'] = ('String',('BH116'))
    field_information['GGDM 3.0']['SubterraneanSrf']['ZI006_MEM'] = ('String',('BH116','DB028'))
    field_information['GGDM 3.0']['SubterraneanSrf']['ZI020_GE4'] = ('CodeList',('BH116','DB028'))
    field_information['GGDM 3.0']['SubterraneanSrf']['ZI024_ASE'] = ('Real',('BH116'))
    field_information['GGDM 3.0']['SubterraneanSrf']['ZI024_CFR'] = ('Real',('BH116'))
    field_information['GGDM 3.0']['SubterraneanSrf']['ZI024_CLO'] = ('Real',('BH116'))
    field_information['GGDM 3.0']['SubterraneanSrf']['ZI024_CYN'] = ('Real',('BH116'))
    field_information['GGDM 3.0']['SubterraneanSrf']['ZI024_FMR'] = ('Real',('BH116'))
    field_information['GGDM 3.0']['SubterraneanSrf']['ZI024_FRR'] = ('Real',('BH116'))
    field_information['GGDM 3.0']['SubterraneanSrf']['ZI024_HAR'] = ('Real',('BH116'))
    field_information['GGDM 3.0']['SubterraneanSrf']['ZI024_MGN'] = ('Real',('BH116'))
    field_information['GGDM 3.0']['SubterraneanSrf']['ZI024_PHW'] = ('Real',('BH116'))
    field_information['GGDM 3.0']['SubterraneanSrf']['ZI024_SCC'] = ('Enumeration',('BH116'))
    field_information['GGDM 3.0']['SubterraneanSrf']['EnumeratedIndexValues']['ZI024_SCC'] = {}
    field_information['GGDM 3.0']['SubterraneanSrf']['EnumeratedIndexValues']['ZI024_SCC']['BH116']  = (-999999,1,4,10,11,12,13,14,998)
    field_information['GGDM 3.0']['SubterraneanSrf']['ZI024_SUL'] = ('Real',('BH116'))
    field_information['GGDM 3.0']['SubterraneanSrf']['ZI024_TDS'] = ('Real',('BH116'))
    field_information['GGDM 3.0']['SubterraneanSrf']['ZI024_TEP'] = ('Real',('BH116'))
    field_information['GGDM 3.0']['SubterraneanSrf']['ZI024_TUR'] = ('Real',('BH116'))
    field_information['GGDM 3.0']['SubterraneanSrf']['ZI024_WAC'] = ('Real',('BH116'))
    field_information['GGDM 3.0']['SubterraneanSrf']['ZI024_WTNO'] = ('Real',('BH116'))
    field_information['GGDM 3.0']['SubterraneanSrf']['ZI024_WUR'] = ('Enumeration',('BH116'))
    field_information['GGDM 3.0']['SubterraneanSrf']['EnumeratedIndexValues']['ZI024_WUR'] = {}
    field_information['GGDM 3.0']['SubterraneanSrf']['EnumeratedIndexValues']['ZI024_WUR']['BH116']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['SubterraneanSrf']['ZI024_WUR2'] = ('Enumeration',('BH116'))
    field_information['GGDM 3.0']['SubterraneanSrf']['EnumeratedIndexValues']['ZI024_WUR2'] = {}
    field_information['GGDM 3.0']['SubterraneanSrf']['EnumeratedIndexValues']['ZI024_WUR2']['BH116']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['SubterraneanSrf']['ZI024_WUR3'] = ('Enumeration',('BH116'))
    field_information['GGDM 3.0']['SubterraneanSrf']['EnumeratedIndexValues']['ZI024_WUR3'] = {}
    field_information['GGDM 3.0']['SubterraneanSrf']['EnumeratedIndexValues']['ZI024_WUR3']['BH116']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['SubterraneanSrf']['ZI024_WUR4'] = ('Enumeration',('BH116'))
    field_information['GGDM 3.0']['SubterraneanSrf']['EnumeratedIndexValues']['ZI024_WUR4'] = {}
    field_information['GGDM 3.0']['SubterraneanSrf']['EnumeratedIndexValues']['ZI024_WUR4']['BH116']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['SubterraneanSrf']['ZI024_YWQ'] = ('Enumeration',('BH116'))
    field_information['GGDM 3.0']['SubterraneanSrf']['EnumeratedIndexValues']['ZI024_YWQ'] = {}
    field_information['GGDM 3.0']['SubterraneanSrf']['EnumeratedIndexValues']['ZI024_YWQ']['BH116']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['SubterraneanSrf']['ZI026_CTUC'] = ('Enumeration',('BH116','DB028'))
    field_information['GGDM 3.0']['SubterraneanSrf']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['SubterraneanSrf']['EnumeratedIndexValues']['ZI026_CTUC']['BH116']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['SubterraneanSrf']['EnumeratedIndexValues']['ZI026_CTUC']['DB028']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['SubterraneanSrf']['ZI026_CTUL'] = ('integer',('BH116','DB028'))
    field_information['GGDM 3.0']['SubterraneanSrf']['ZI026_CTUU'] = ('integer',('BH116','DB028'))
    field_information['GGDM 3.0']['SubterraneanSrf']['ZI031S_URI'] = ('StructuredText',('BH116','DB028'))
    field_information['GGDM 3.0']['SubterraneanSrf']['ZI039S_UFI'] = ('StructuredText',('BH116','DB028'))
    field_information['GGDM 3.0']['SubterraneanSrf']['ZI071_CTX'] = ('Enumeration',('DB028'))
    field_information['GGDM 3.0']['SubterraneanSrf']['EnumeratedIndexValues']['ZI071_CTX'] = {}
    field_information['GGDM 3.0']['SubterraneanSrf']['EnumeratedIndexValues']['ZI071_CTX']['DB028']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['SubterraneanSrf']['ZI071_FFN'] = ('Enumeration',('DB028'))
    field_information['GGDM 3.0']['SubterraneanSrf']['EnumeratedIndexValues']['ZI071_FFN'] = {}
    field_information['GGDM 3.0']['SubterraneanSrf']['EnumeratedIndexValues']['ZI071_FFN']['DB028']  = (-999999,530,563,835,930,999)
    field_information['GGDM 3.0']['SubterraneanSrf']['ZI071_FFN2'] = ('Enumeration',('DB028'))
    field_information['GGDM 3.0']['SubterraneanSrf']['EnumeratedIndexValues']['ZI071_FFN2'] = {}
    field_information['GGDM 3.0']['SubterraneanSrf']['EnumeratedIndexValues']['ZI071_FFN2']['DB028']  = (-999999,530,563,835,930,999)
    field_information['GGDM 3.0']['SubterraneanSrf']['ZI071_FFN3'] = ('Enumeration',('DB028'))
    field_information['GGDM 3.0']['SubterraneanSrf']['EnumeratedIndexValues']['ZI071_FFN3'] = {}
    field_information['GGDM 3.0']['SubterraneanSrf']['EnumeratedIndexValues']['ZI071_FFN3']['DB028']  = (-999999,530,563,835,930,999)
    field_information['GGDM 3.0']['SubterraneanSrf']['ZI071_UAO'] = ('Enumeration',('DB028'))
    field_information['GGDM 3.0']['SubterraneanSrf']['EnumeratedIndexValues']['ZI071_UAO'] = {}
    field_information['GGDM 3.0']['SubterraneanSrf']['EnumeratedIndexValues']['ZI071_UAO']['DB028']  = (-999999,1,2,3,4,5)
    field_information['GGDM 3.0']['SubterraneanSrf']['ZSAX_RS0'] = ('CodeList',('BH116','DB028'))
    field_information['GGDM 3.0']['SubterraneanSrf']['ZSAX_RX0'] = ('StructuredText',('BH116','DB028'))
    field_information['GGDM 3.0']['SubterraneanSrf']['ZSAX_RX3'] = ('StructuredText',('BH116','DB028'))
    field_information['GGDM 3.0']['SubterraneanSrf']['ZSAX_RX4'] = ('StructuredText',('BH116','DB028'))
    field_information['GGDM 3.0']['TransportationGroundCrv']['AOO'] = ('Real',('AL195','AL211','AP040','AP041','AQ040','AQ045','AQ050','AQ065','AQ130','AQ151'))
    field_information['GGDM 3.0']['TransportationGroundCrv']['ARA'] = ('Real',('AL155','AL195','AL211','AP010','AP030','AP041','AP050','AP055','AQ035','AQ040','AQ045','AQ050','AQ056','AQ063','AQ065','AQ130','AQ151','BH070'))
    field_information['GGDM 3.0']['TransportationGroundCrv']['AWP'] = ('Boolean',('AQ040','AQ050','AT041'))
    field_information['GGDM 3.0']['TransportationGroundCrv']['BCC'] = ('Enumeration',('AL155','AQ040','AQ059','AQ130'))
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['BCC'] = {}
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['BCC']['AL155']  = (-999999,1,2,3)
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['BCC']['AQ040']  = (-999999,1,2,3)
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['BCC']['AQ059']  = (-999999,1,2,3)
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['BCC']['AQ130']  = (-999999,1,2,3)
    field_information['GGDM 3.0']['TransportationGroundCrv']['BEN'] = ('StructuredText',('AL155','AL195','AL211','AN010','AN050','AP010','AP030','AP040','AP041','AP050','AP055','AQ035','AQ040','AQ045','AQ050','AQ056','AQ059','AQ063','AQ065','AQ075','AQ120','AQ130','AQ151','AT041','BH070'))
    field_information['GGDM 3.0']['TransportationGroundCrv']['BMC'] = ('Enumeration',('BH070'))
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['BMC'] = {}
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['BMC']['BH070']  = (-999999,1,2,3,4,5,6,7,9,14,15,18,999)
    field_information['GGDM 3.0']['TransportationGroundCrv']['BMC2'] = ('Enumeration',('BH070'))
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['BMC2'] = {}
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['BMC2']['BH070']  = (-999999,1,2,3,4,5,6,7,9,14,15,18,999)
    field_information['GGDM 3.0']['TransportationGroundCrv']['BMC3'] = ('Enumeration',('BH070'))
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['BMC3'] = {}
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['BMC3']['BH070']  = (-999999,1,2,3,4,5,6,7,9,14,15,18,999)
    field_information['GGDM 3.0']['TransportationGroundCrv']['BOT'] = ('Enumeration',('AQ040','AQ045'))
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['BOT'] = {}
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['BOT']['AQ040']  = (-999999,4,10,11,12,14,15,16,17,999)
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['BOT']['AQ045']  = (-999999,4,10,11,12,14,15,16,17,999)
    field_information['GGDM 3.0']['TransportationGroundCrv']['BRN'] = ('String',('AQ040','AQ045','AQ050'))
    field_information['GGDM 3.0']['TransportationGroundCrv']['BSC'] = ('Enumeration',('AQ040','AQ045','AQ050'))
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['BSC'] = {}
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['BSC']['AQ040']  = (-999999,1,2,5,6,7,8,9,12,15,16,19,22,26,27,31,32,999)
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['BSC']['AQ045']  = (-999999,1,2,5,6,7,8,9,12,15,16,19,26,27,31,32,999)
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['BSC']['AQ050']  = (-999999,1,2,3,5,6,7,8,9,12,15,16,19,22,26,27,28,31,32,999)
    field_information['GGDM 3.0']['TransportationGroundCrv']['BSC2'] = ('Enumeration',('AQ040','AQ045'))
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['BSC2'] = {}
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['BSC2']['AQ040']  = (-999999,1,2,5,6,7,8,9,12,15,16,19,22,26,27,31,32,999)
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['BSC2']['AQ045']  = (-999999,1,2,5,6,7,8,9,12,15,16,19,26,27,31,32,999)
    field_information['GGDM 3.0']['TransportationGroundCrv']['BSC3'] = ('Enumeration',('AQ040','AQ045'))
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['BSC3'] = {}
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['BSC3']['AQ040']  = (-999999,1,2,5,6,7,8,9,12,15,16,19,22,26,27,31,32,999)
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['BSC3']['AQ045']  = (-999999,1,2,5,6,7,8,9,12,15,16,19,26,27,31,32,999)
    field_information['GGDM 3.0']['TransportationGroundCrv']['BSM'] = ('Boolean',('AQ040'))
    field_information['GGDM 3.0']['TransportationGroundCrv']['CAA'] = ('Enumeration',('AL211','AN010','AP030','AP040','AP050','AQ040','AQ063','AQ130','AQ151'))
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['CAA']['AL211']  = (-999999,3,17,999)
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['CAA']['AN010']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['CAA']['AP030']  = (-999999,3,4,5,6,7,16,17,999)
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['CAA']['AP040']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['CAA']['AP050']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['CAA']['AQ040']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['CAA']['AQ063']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['CAA']['AQ130']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['CAA']['AQ151']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['TransportationGroundCrv']['CAT'] = ('Enumeration',('AT041'))
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['CAT'] = {}
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['CAT']['AT041']  = (-999999,2,3,5,6,7,8,9,999)
    field_information['GGDM 3.0']['TransportationGroundCrv']['CIW'] = ('Boolean',('AP010','AP030','AP050','AP055','AQ035','AQ130','BH070'))
    field_information['GGDM 3.0']['TransportationGroundCrv']['CNCP'] = ('StructuredText',('AL195','AL211','AN010','AN050','AP010','AP030','AP040','AP041','AP050','AQ035','AQ040','AQ045','AQ063','AQ065','AQ075','AQ130','AQ151','AT041','BH070'))
    field_information['GGDM 3.0']['TransportationGroundCrv']['CON'] = ('Enumeration',('AQ059'))
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['CON'] = {}
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['CON']['AQ059']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,999)
    field_information['GGDM 3.0']['TransportationGroundCrv']['COS'] = ('Enumeration',('AL195','AL211','AN010','AN050','AP010','AP030','AP040','AP041','AP050','AQ035','AQ040','AQ045','AQ063','AQ065','AQ075','AQ130','AQ151','AT041','BH070'))
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['COS']['AL195']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['COS']['AL211']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['COS']['AN010']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['COS']['AN050']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['COS']['AP010']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['COS']['AP030']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['COS']['AP040']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['COS']['AP041']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['COS']['AP050']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['COS']['AQ035']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['COS']['AQ040']  = (-999999,2,4,6,9,13,14)
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['COS']['AQ045']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['COS']['AQ063']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['COS']['AQ065']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['COS']['AQ075']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['COS']['AQ130']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['COS']['AQ151']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['COS']['AT041']  = (-999999,2,4,6,9,13,14)
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['COS']['BH070']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['TransportationGroundCrv']['CTC'] = ('Enumeration',('AQ065'))
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['CTC'] = {}
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['CTC']['AQ065']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['TransportationGroundCrv']['CTL'] = ('Real',('AN050'))
    field_information['GGDM 3.0']['TransportationGroundCrv']['CWT'] = ('Boolean',('AN010','AN050','AP010','AP030','AP050','AP055','AQ035'))
    field_information['GGDM 3.0']['TransportationGroundCrv']['DEV'] = ('Integer',('AL155','AN010','AP010','AP030','AP050'))
    field_information['GGDM 3.0']['TransportationGroundCrv']['DZC'] = ('Integer',('AQ040','AQ130'))
    field_information['GGDM 3.0']['TransportationGroundCrv']['DZP'] = ('Real',('AQ130'))
    field_information['GGDM 3.0']['TransportationGroundCrv']['EXP'] = ('Enumeration',('AQ059'))
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['EXP'] = {}
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['EXP']['AQ059']  = (-999999,1,2,3,4,5,999)
    field_information['GGDM 3.0']['TransportationGroundCrv']['F_CODE'] = ('CONSTRAINED_STRING',('AL155','AL195','AL211','AN010','AN050','AP010','AP030','AP040','AP041','AP050','AP055','AQ035','AQ040','AQ045','AQ050','AQ056','AQ059','AQ063','AQ065','AQ075','AQ120','AQ130','AQ151','AT041','BH070'))
    field_information['GGDM 3.0']['TransportationGroundCrv']['FCO'] = ('Enumeration',('AP030'))
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['FCO'] = {}
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['FCO']['AP030']  = (-999999,5,6,7)
    field_information['GGDM 3.0']['TransportationGroundCrv']['FFN'] = ('Enumeration',('AP040','AT041'))
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['FFN'] = {}
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['FFN']['AP040']  = (-999999,2,480,830,831,833,842,907,999)
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['FFN']['AT041']  = (-999999,99,480,921,999)
    field_information['GGDM 3.0']['TransportationGroundCrv']['FFN2'] = ('Enumeration',('AP040','AT041'))
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['FFN2'] = {}
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['FFN2']['AP040']  = (-999999,2,480,830,831,833,842,907,999)
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['FFN2']['AT041']  = (-999999,99,480,921,999)
    field_information['GGDM 3.0']['TransportationGroundCrv']['FFN3'] = ('Enumeration',('AP040','AT041'))
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['FFN3'] = {}
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['FFN3']['AP040']  = (-999999,2,480,830,831,833,842,907,999)
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['FFN3']['AT041']  = (-999999,99,480,921,999)
    field_information['GGDM 3.0']['TransportationGroundCrv']['FSC'] = ('Boolean',('AP030'))
    field_information['GGDM 3.0']['TransportationGroundCrv']['FUFI'] = ('StructuredText',('AL155','AL195','AL211','AN010','AN050','AP010','AP030','AP040','AP041','AP050','AP055','AQ035','AQ040','AQ045','AQ050','AQ056','AQ059','AQ063','AQ065','AQ075','AQ120','AQ130','AQ151','AT041','BH070'))
    field_information['GGDM 3.0']['TransportationGroundCrv']['FURL'] = ('StructuredText',('AL155','AL195','AL211','AN010','AN050','AP010','AP030','AP040','AP041','AP050','AP055','AQ035','AQ040','AQ045','AQ050','AQ056','AQ059','AQ063','AQ065','AQ075','AQ120','AQ130','AQ151','AT041','BH070'))
    field_information['GGDM 3.0']['TransportationGroundCrv']['GDBV'] = ('Enumeration',('AL155','AL195','AL211','AN010','AN050','AP010','AP030','AP040','AP041','AP050','AP055','AQ035','AQ040','AQ045','AQ050','AQ056','AQ059','AQ063','AQ065','AQ075','AQ120','AQ130','AQ151','AT041','BH070'))
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['GDBV']['AL155']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['GDBV']['AL195']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['GDBV']['AL211']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['GDBV']['AN010']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['GDBV']['AN050']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['GDBV']['AP010']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['GDBV']['AP030']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['GDBV']['AP040']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['GDBV']['AP041']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['GDBV']['AP050']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['GDBV']['AP055']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['GDBV']['AQ035']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['GDBV']['AQ040']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['GDBV']['AQ045']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['GDBV']['AQ050']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['GDBV']['AQ056']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['GDBV']['AQ059']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['GDBV']['AQ063']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['GDBV']['AQ065']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['GDBV']['AQ075']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['GDBV']['AQ120']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['GDBV']['AQ130']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['GDBV']['AQ151']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['GDBV']['AT041']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['GDBV']['BH070']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['TransportationGroundCrv']['GTC'] = ('Enumeration',('AP040'))
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['GTC'] = {}
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['GTC']['AP040']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['TransportationGroundCrv']['HCA'] = ('Real',('AL211','AQ040','AQ059','AQ130'))
    field_information['GGDM 3.0']['TransportationGroundCrv']['HEI'] = ('Real',('AQ050'))
    field_information['GGDM 3.0']['TransportationGroundCrv']['HGT'] = ('Real',('AL211','AP040','AP041','AQ040','AQ045','AQ050','AQ056','AQ063','AQ130','AQ151','AT041'))
    field_information['GGDM 3.0']['TransportationGroundCrv']['HST'] = ('Enumeration',('AQ130'))
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['HST'] = {}
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['HST']['AQ130']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['TransportationGroundCrv']['HST2'] = ('Enumeration',('AQ130'))
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['HST2'] = {}
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['HST2']['AQ130']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['TransportationGroundCrv']['HST3'] = ('Enumeration',('AQ130'))
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['HST3'] = {}
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['HST3']['AQ130']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['TransportationGroundCrv']['LC1'] = ('Integer',('AQ040','AQ045'))
    field_information['GGDM 3.0']['TransportationGroundCrv']['LC2'] = ('Integer',('AQ040','AQ045'))
    field_information['GGDM 3.0']['TransportationGroundCrv']['LC3'] = ('Integer',('AQ040','AQ045'))
    field_information['GGDM 3.0']['TransportationGroundCrv']['LC4'] = ('Integer',('AQ040','AQ045'))
    field_information['GGDM 3.0']['TransportationGroundCrv']['LEA'] = ('Real',('AQ130'))
    field_information['GGDM 3.0']['TransportationGroundCrv']['LMC'] = ('Boolean',('AL211','AN010','AP050','AQ035','AQ040','AQ050','AQ056','AQ063','AQ120','AQ151','AT041'))
    field_information['GGDM 3.0']['TransportationGroundCrv']['LOC'] = ('Enumeration',('AN010','AN050','AP010','AP030','AP050'))
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['LOC'] = {}
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['LOC']['AN010']  = (-999999,17,40,44)
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['LOC']['AN050']  = (-999999,17,40,44)
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['LOC']['AP010']  = (-999999,17,40,44)
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['LOC']['AP030']  = (-999999,17,40,44)
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['LOC']['AP050']  = (-999999,17,40,44)
    field_information['GGDM 3.0']['TransportationGroundCrv']['LOG'] = ('Real',('AQ120'))
    field_information['GGDM 3.0']['TransportationGroundCrv']['LTN'] = ('Integer',('AN010','AN050','AP030'))
    field_information['GGDM 3.0']['TransportationGroundCrv']['LZN'] = ('Real',('AL155','AL195','AL211','AN010','AN050','AP010','AP030','AP040','AP041','AP050','AP055','AQ035','AQ040','AQ045','AQ050','AQ056','AQ059','AQ063','AQ065','AQ075','AQ120','AQ130','AQ151','AT041','BH070'))
    field_information['GGDM 3.0']['TransportationGroundCrv']['MCC'] = ('Enumeration',('AP041','AQ063','AQ065'))
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['MCC'] = {}
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['MCC']['AP041']  = (-999999,21,62,64,77,83,104,117,999)
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['MCC']['AQ063']  = (-999999,8,46,52,55,62,64,65,84,86,88,104,117,999)
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['MCC']['AQ065']  = (-999999,21,62,64,999)
    field_information['GGDM 3.0']['TransportationGroundCrv']['MCC2'] = ('Enumeration',('AP041','AQ063','AQ065'))
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['MCC2'] = {}
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['MCC2']['AP041']  = (-999999,21,62,64,77,83,104,117,999)
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['MCC2']['AQ063']  = (-999999,8,46,52,55,62,64,65,84,86,88,104,117,999)
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['MCC2']['AQ065']  = (-999999,21,62,64,999)
    field_information['GGDM 3.0']['TransportationGroundCrv']['MCC3'] = ('Enumeration',('AP041','AQ063','AQ065'))
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['MCC3'] = {}
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['MCC3']['AP041']  = (-999999,21,62,64,77,83,104,117,999)
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['MCC3']['AQ063']  = (-999999,8,46,52,55,62,64,65,84,86,88,104,117,999)
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['MCC3']['AQ065']  = (-999999,21,62,64,999)
    field_information['GGDM 3.0']['TransportationGroundCrv']['MES'] = ('Boolean',('AP030'))
    field_information['GGDM 3.0']['TransportationGroundCrv']['MWG'] = ('Real',('AP030'))
    field_information['GGDM 3.0']['TransportationGroundCrv']['NOS'] = ('Integer',('AQ040'))
    field_information['GGDM 3.0']['TransportationGroundCrv']['OHC'] = ('Real',('AL155','AL211','AQ040','AQ045','AQ130'))
    field_information['GGDM 3.0']['TransportationGroundCrv']['ONE'] = ('Boolean',('AP030'))
    field_information['GGDM 3.0']['TransportationGroundCrv']['OOC'] = ('Enumeration',('AL155'))
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['OOC'] = {}
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['OOC']['AL155']  = (-999999,1,2,3,4,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,999)
    field_information['GGDM 3.0']['TransportationGroundCrv']['OTH'] = ('StructuredText',('AL155','AL195','AL211','AN010','AN050','AP010','AP030','AP040','AP041','AP050','AP055','AQ035','AQ040','AQ045','AQ050','AQ056','AQ059','AQ063','AQ065','AQ075','AQ120','AQ130','AQ151','AT041','BH070'))
    field_information['GGDM 3.0']['TransportationGroundCrv']['OWO'] = ('Boolean',('AT041'))
    field_information['GGDM 3.0']['TransportationGroundCrv']['PCF'] = ('Enumeration',('AL155','AL195','AL211','AN010','AN050','AP010','AP030','AP040','AP041','AP050','AP055','AQ035','AQ040','AQ045','AQ050','AQ056','AQ063','AQ065','AQ075','AQ130','AQ151','AT041','BH070'))
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['PCF']['AL155']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['PCF']['AL195']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['PCF']['AL211']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['PCF']['AN010']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['PCF']['AN050']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['PCF']['AP010']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['PCF']['AP030']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['PCF']['AP040']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['PCF']['AP041']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['PCF']['AP050']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['PCF']['AP055']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['PCF']['AQ035']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['PCF']['AQ040']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['PCF']['AQ045']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['PCF']['AQ050']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['PCF']['AQ056']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['PCF']['AQ063']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['PCF']['AQ065']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['PCF']['AQ075']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['PCF']['AQ130']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['PCF']['AQ151']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['PCF']['AT041']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['PCF']['BH070']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['TransportationGroundCrv']['PFH'] = ('Real',('AT041'))
    field_information['GGDM 3.0']['TransportationGroundCrv']['PSN'] = ('Real',('AP010','AP030','AP055','AQ075'))
    field_information['GGDM 3.0']['TransportationGroundCrv']['PTG'] = ('Boolean',('AP010','AP030','AP050'))
    field_information['GGDM 3.0']['TransportationGroundCrv']['RFD'] = ('Boolean',('AQ040'))
    field_information['GGDM 3.0']['TransportationGroundCrv']['RIN_ROI'] = ('Enumeration',('AP030','AQ075'))
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['RIN_ROI'] = {}
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['RIN_ROI']['AP030']  = (-999999,1,2,3,4,5,999)
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['RIN_ROI']['AQ075']  = (-999999,1,2,3,4,5,999)
    field_information['GGDM 3.0']['TransportationGroundCrv']['RIN_ROI2'] = ('Enumeration',('AP030','AQ075'))
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['RIN_ROI2'] = {}
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['RIN_ROI2']['AP030']  = (-999999,1,2,3,4,5,999)
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['RIN_ROI2']['AQ075']  = (-999999,1,2,3,4,5,999)
    field_information['GGDM 3.0']['TransportationGroundCrv']['RIN_ROI3'] = ('Enumeration',('AP030','AQ075'))
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['RIN_ROI3'] = {}
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['RIN_ROI3']['AP030']  = (-999999,1,2,3,4,5,999)
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['RIN_ROI3']['AQ075']  = (-999999,1,2,3,4,5,999)
    field_information['GGDM 3.0']['TransportationGroundCrv']['RIN_RTN'] = ('String',('AP030','AQ075'))
    field_information['GGDM 3.0']['TransportationGroundCrv']['RIN_RTN2'] = ('String',('AP030','AQ075'))
    field_information['GGDM 3.0']['TransportationGroundCrv']['RIN_RTN3'] = ('String',('AP030','AQ075'))
    field_information['GGDM 3.0']['TransportationGroundCrv']['RLE'] = ('Enumeration',('AN010','AN050','AP010','AP030','AP050','AP055'))
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['RLE'] = {}
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['RLE']['AN010']  = (-999999,1,2,3,998)
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['RLE']['AN050']  = (-999999,1,2,3,998)
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['RLE']['AP010']  = (-999999,1,2,3)
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['RLE']['AP030']  = (-999999,1,2,3,998)
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['RLE']['AP050']  = (-999999,1,2,3)
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['RLE']['AP055']  = (-999999,1,2,3)
    field_information['GGDM 3.0']['TransportationGroundCrv']['RMWC'] = ('Enumeration',('AP030'))
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['RMWC'] = {}
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['RMWC']['AP030']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['TransportationGroundCrv']['RMWL'] = ('real',('AP030'))
    field_information['GGDM 3.0']['TransportationGroundCrv']['RMWU'] = ('real',('AP030'))
    field_information['GGDM 3.0']['TransportationGroundCrv']['ROR'] = ('Boolean',('AP030'))
    field_information['GGDM 3.0']['TransportationGroundCrv']['RRC'] = ('Enumeration',('AN010','AN050'))
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['RRC'] = {}
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['RRC']['AN010']  = (-999999,2,6,8,11,13,14,15,24,32,33,999)
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['RRC']['AN050']  = (-999999,2,6,8,11,13,14,15,24,32,33,999)
    field_information['GGDM 3.0']['TransportationGroundCrv']['RRC2'] = ('Enumeration',('AN010','AN050'))
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['RRC2'] = {}
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['RRC2']['AN010']  = (-999999,2,6,8,11,13,14,15,24,32,33,999)
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['RRC2']['AN050']  = (-999999,2,6,8,11,13,14,15,24,32,33,999)
    field_information['GGDM 3.0']['TransportationGroundCrv']['RRC3'] = ('Enumeration',('AN010','AN050'))
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['RRC3'] = {}
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['RRC3']['AN010']  = (-999999,2,6,8,11,13,14,15,24,32,33,999)
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['RRC3']['AN050']  = (-999999,2,6,8,11,13,14,15,24,32,33,999)
    field_information['GGDM 3.0']['TransportationGroundCrv']['RSA'] = ('Enumeration',('AN050'))
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['RSA'] = {}
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['RSA']['AN050']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['TransportationGroundCrv']['RTA'] = ('Enumeration',('AN010'))
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['RTA'] = {}
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['RTA']['AN010']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['TransportationGroundCrv']['RTN'] = ('String',('AP010','AP055'))
    field_information['GGDM 3.0']['TransportationGroundCrv']['RTN2'] = ('String',('AP010','AP055'))
    field_information['GGDM 3.0']['TransportationGroundCrv']['RTN3'] = ('String',('AP010','AP055'))
    field_information['GGDM 3.0']['TransportationGroundCrv']['RTY'] = ('Enumeration',('AP030'))
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['RTY'] = {}
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['RTY']['AP030']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['TransportationGroundCrv']['RWC'] = ('Enumeration',('AN010'))
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['RWC'] = {}
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['RWC']['AN010']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['TransportationGroundCrv']['SBB'] = ('Boolean',('AN010','AN050','AP010','AP030','AP050','AP055','AQ035'))
    field_information['GGDM 3.0']['TransportationGroundCrv']['SEP'] = ('Boolean',('AP030'))
    field_information['GGDM 3.0']['TransportationGroundCrv']['SGCC'] = ('Enumeration',('AN010','AN050','AP030','AQ035','AQ063','AQ120'))
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['SGCC'] = {}
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['SGCC']['AN010']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['SGCC']['AN050']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['SGCC']['AP030']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['SGCC']['AQ035']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['SGCC']['AQ063']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['SGCC']['AQ120']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['TransportationGroundCrv']['SGCL'] = ('real',('AN010','AN050','AP030','AQ035','AQ063','AQ120'))
    field_information['GGDM 3.0']['TransportationGroundCrv']['SGCU'] = ('real',('AN010','AN050','AP030','AQ035','AQ063','AQ120'))
    field_information['GGDM 3.0']['TransportationGroundCrv']['SHC'] = ('Real',('AQ059'))
    field_information['GGDM 3.0']['TransportationGroundCrv']['SPD'] = ('Real',('AP010','AP030','AP055','AQ075'))
    field_information['GGDM 3.0']['TransportationGroundCrv']['SPM'] = ('Real',('AP010','AP030','AP055','AQ075'))
    field_information['GGDM 3.0']['TransportationGroundCrv']['SRE'] = ('Enumeration',('AQ059'))
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['SRE'] = {}
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['SRE']['AQ059']  = (-999999,1,2,3,8,9,999)
    field_information['GGDM 3.0']['TransportationGroundCrv']['TCS'] = ('Enumeration',('AQ065'))
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['TCS'] = {}
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['TCS']['AQ065']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['TransportationGroundCrv']['THI'] = ('Real',('AP040'))
    field_information['GGDM 3.0']['TransportationGroundCrv']['THR'] = ('Boolean',('AP010','AP030','AP050'))
    field_information['GGDM 3.0']['TransportationGroundCrv']['TRA'] = ('Boolean',('AQ130'))
    field_information['GGDM 3.0']['TransportationGroundCrv']['TRP'] = ('Enumeration',('AL211'))
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['TRP'] = {}
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['TRP']['AL211']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['TransportationGroundCrv']['TRS'] = ('Enumeration',('AL155','AL211','AP010','AP040','AP041','AP050','AQ040','AQ059','AQ063','AQ120','AQ130','BH070'))
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['TRS'] = {}
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['TRS']['AL155']  = (-999999,5,9,12,13,17,999)
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['TRS']['AL211']  = (-999999,5,12,13,999)
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['TRS']['AP010']  = (-999999,3,4,6,11,999)
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['TRS']['AP040']  = (-999999,3,9,12,13,16,999)
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['TRS']['AP041']  = (-999999,5,9,12,13,16,999)
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['TRS']['AP050']  = (-999999,9,18,23,999)
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['TRS']['AQ040']  = (-999999,2,5,9,10,12,13,20,25,999)
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['TRS']['AQ059']  = (-999999,5,9,12,13,17,999)
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['TRS']['AQ063']  = (-999999,2,5,9,10,12,13,999)
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['TRS']['AQ120']  = (-999999,9,12,13,999)
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['TRS']['AQ130']  = (-999999,2,5,8,9,10,12,13,16,20,999)
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['TRS']['BH070']  = (-999999,9,13,18,23,999)
    field_information['GGDM 3.0']['TransportationGroundCrv']['TRS2'] = ('Enumeration',('AL155','AL211','AP010','AP040','AP041','AQ040','AQ059','AQ063','AQ120','AQ130','BH070'))
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['TRS2'] = {}
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['TRS2']['AL155']  = (-999999,5,9,12,13,17,999)
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['TRS2']['AL211']  = (-999999,5,12,13,999)
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['TRS2']['AP010']  = (-999999,3,4,6,11,999)
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['TRS2']['AP040']  = (-999999,3,9,12,13,16,999)
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['TRS2']['AP041']  = (-999999,5,9,12,13,16,999)
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['TRS2']['AQ040']  = (-999999,2,5,9,10,12,13,20,25,999)
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['TRS2']['AQ059']  = (-999999,5,9,12,13,17,999)
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['TRS2']['AQ063']  = (-999999,2,5,9,10,12,13,999)
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['TRS2']['AQ120']  = (-999999,9,12,13,999)
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['TRS2']['AQ130']  = (-999999,2,5,8,9,10,12,13,16,20,999)
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['TRS2']['BH070']  = (-999999,9,13,18,23,999)
    field_information['GGDM 3.0']['TransportationGroundCrv']['TRS3'] = ('Enumeration',('AL155','AL211','AP010','AP040','AP041','AQ040','AQ059','AQ063','AQ120','AQ130','BH070'))
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['TRS3'] = {}
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['TRS3']['AL155']  = (-999999,5,9,12,13,17,999)
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['TRS3']['AL211']  = (-999999,5,12,13,999)
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['TRS3']['AP010']  = (-999999,3,4,6,11,999)
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['TRS3']['AP040']  = (-999999,3,9,12,13,16,999)
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['TRS3']['AP041']  = (-999999,5,9,12,13,16,999)
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['TRS3']['AQ040']  = (-999999,2,5,9,10,12,13,20,25,999)
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['TRS3']['AQ059']  = (-999999,5,9,12,13,17,999)
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['TRS3']['AQ063']  = (-999999,2,5,9,10,12,13,999)
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['TRS3']['AQ120']  = (-999999,9,12,13,999)
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['TRS3']['AQ130']  = (-999999,2,5,8,9,10,12,13,16,20,999)
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['TRS3']['BH070']  = (-999999,9,13,18,23,999)
    field_information['GGDM 3.0']['TransportationGroundCrv']['TST'] = ('Enumeration',('AT041'))
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['TST'] = {}
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['TST']['AT041']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['TransportationGroundCrv']['UBC'] = ('Real',('AQ040'))
    field_information['GGDM 3.0']['TransportationGroundCrv']['UFI'] = ('StructuredText',('AL155','AL195','AL211','AN010','AN050','AP010','AP030','AP040','AP041','AP050','AP055','AQ035','AQ040','AQ045','AQ050','AQ056','AQ059','AQ063','AQ065','AQ075','AQ120','AQ130','AQ151','AT041','BH070'))
    field_information['GGDM 3.0']['TransportationGroundCrv']['VCM'] = ('Enumeration',('AQ040','AQ045'))
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['VCM'] = {}
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['VCM']['AQ040']  = (-999999,2,3,4,7,8,9,12,13,15,16,17,18,999)
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['VCM']['AQ045']  = (-999999,2,3,4,7,8,9,12,13,15,16,17,18,999)
    field_information['GGDM 3.0']['TransportationGroundCrv']['VCM2'] = ('Enumeration',('AQ040','AQ045'))
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['VCM2'] = {}
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['VCM2']['AQ040']  = (-999999,2,3,4,7,8,9,12,13,15,16,17,18,999)
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['VCM2']['AQ045']  = (-999999,2,3,4,7,8,9,12,13,15,16,17,18,999)
    field_information['GGDM 3.0']['TransportationGroundCrv']['VCM3'] = ('Enumeration',('AQ040','AQ045'))
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['VCM3'] = {}
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['VCM3']['AQ040']  = (-999999,2,3,4,7,8,9,12,13,15,16,17,18,999)
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['VCM3']['AQ045']  = (-999999,2,3,4,7,8,9,12,13,15,16,17,18,999)
    field_information['GGDM 3.0']['TransportationGroundCrv']['VCO'] = ('Real',('AQ040','AQ045','AT041'))
    field_information['GGDM 3.0']['TransportationGroundCrv']['VCS'] = ('Real',('AQ040'))
    field_information['GGDM 3.0']['TransportationGroundCrv']['VCS_VCD'] = ('Enumeration',('AQ040'))
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['VCS_VCD'] = {}
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['VCS_VCD']['AQ040']  = (-999999,7,9,10,15,24,28,30,999)
    field_information['GGDM 3.0']['TransportationGroundCrv']['VCS_VCR'] = ('String',('AQ040'))
    field_information['GGDM 3.0']['TransportationGroundCrv']['VOI'] = ('StructuredText',('AQ040','AQ050','AT041'))
    field_information['GGDM 3.0']['TransportationGroundCrv']['WBD'] = ('Real',('BH070'))
    field_information['GGDM 3.0']['TransportationGroundCrv']['WD1'] = ('Real',('AQ059'))
    field_information['GGDM 3.0']['TransportationGroundCrv']['WD2'] = ('Real',('AP030','AP040','AQ130'))
    field_information['GGDM 3.0']['TransportationGroundCrv']['WID'] = ('Real',('AL155','AL195','AL211','AN010','AN050','AP010','AP030','AP041','AP050','AP055','AQ035','AQ040','AQ045','AQ050','AQ056','AQ063','AQ065','AQ075','AQ130','AQ151','AT041','BH070'))
    field_information['GGDM 3.0']['TransportationGroundCrv']['WLE'] = ('Enumeration',('AQ063'))
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['WLE'] = {}
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['WLE']['AQ063']  = (-999999,1,2,3,4,5,999)
    field_information['GGDM 3.0']['TransportationGroundCrv']['WT2'] = ('Real',('AP030'))
    field_information['GGDM 3.0']['TransportationGroundCrv']['WVA'] = ('Real',('BH070'))
    field_information['GGDM 3.0']['TransportationGroundCrv']['ZI001_SDV'] = ('StructuredText',('AL155','AL195','AL211','AN010','AN050','AP010','AP030','AP040','AP041','AP050','AP055','AQ035','AQ040','AQ045','AQ050','AQ056','AQ059','AQ063','AQ065','AQ075','AQ120','AQ130','AQ151','AT041','BH070'))
    field_information['GGDM 3.0']['TransportationGroundCrv']['ZI001_SRT'] = ('Enumeration',('AL155','AL195','AL211','AN010','AN050','AP010','AP030','AP040','AP041','AP050','AP055','AQ035','AQ040','AQ045','AQ050','AQ056','AQ059','AQ063','AQ065','AQ075','AQ120','AQ130','AQ151','AT041','BH070'))
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['ZI001_SRT']['AL155']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['ZI001_SRT']['AL195']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['ZI001_SRT']['AL211']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['ZI001_SRT']['AN010']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['ZI001_SRT']['AN050']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['ZI001_SRT']['AP010']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['ZI001_SRT']['AP030']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['ZI001_SRT']['AP040']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['ZI001_SRT']['AP041']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['ZI001_SRT']['AP050']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['ZI001_SRT']['AP055']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['ZI001_SRT']['AQ035']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['ZI001_SRT']['AQ040']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['ZI001_SRT']['AQ045']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['ZI001_SRT']['AQ050']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['ZI001_SRT']['AQ056']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['ZI001_SRT']['AQ059']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['ZI001_SRT']['AQ063']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['ZI001_SRT']['AQ065']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['ZI001_SRT']['AQ075']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['ZI001_SRT']['AQ120']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['ZI001_SRT']['AQ130']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['ZI001_SRT']['AQ151']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['ZI001_SRT']['AT041']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['ZI001_SRT']['BH070']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['TransportationGroundCrv']['ZI002_UFI'] = ('StructuredText',('AL155','AL195','AL211','AN010','AN050','AP010','AP030','AP040','AP041','AP050','AP055','AQ035','AQ040','AQ045','AQ050','AQ056','AQ059','AQ063','AQ065','AQ075','AQ120','AQ130','AQ151','AT041','BH070'))
    field_information['GGDM 3.0']['TransportationGroundCrv']['ZI004_RCG'] = ('Enumeration',('AL155','AL195','AL211','AN010','AN050','AP010','AP030','AP040','AP041','AP050','AP055','AQ035','AQ040','AQ045','AQ050','AQ056','AQ059','AQ063','AQ065','AQ075','AQ120','AQ130','AQ151','AT041','BH070'))
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['ZI004_RCG']['AL155']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['ZI004_RCG']['AL195']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['ZI004_RCG']['AL211']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['ZI004_RCG']['AN010']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['ZI004_RCG']['AN050']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['ZI004_RCG']['AP010']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['ZI004_RCG']['AP030']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['ZI004_RCG']['AP040']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['ZI004_RCG']['AP041']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['ZI004_RCG']['AP050']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['ZI004_RCG']['AP055']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['ZI004_RCG']['AQ035']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['ZI004_RCG']['AQ040']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['ZI004_RCG']['AQ045']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['ZI004_RCG']['AQ050']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['ZI004_RCG']['AQ056']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['ZI004_RCG']['AQ059']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['ZI004_RCG']['AQ063']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['ZI004_RCG']['AQ065']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['ZI004_RCG']['AQ075']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['ZI004_RCG']['AQ120']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['ZI004_RCG']['AQ130']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['ZI004_RCG']['AQ151']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['ZI004_RCG']['AT041']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['ZI004_RCG']['BH070']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['TransportationGroundCrv']['ZI005_FNA'] = ('String',('AL195','AN010','AN050','AP010','AP030','AP040','AP041','AP050','AP055','AQ035','AQ040','AQ045','AQ056','AQ063','AQ075','AQ130','AQ151','AT041','BH070'))
    field_information['GGDM 3.0']['TransportationGroundCrv']['ZI005_GNT'] = ('Enumeration',('AL195','AN010','AN050','AP010','AP030','AP040','AP041','AP050','AQ035','AQ040','AQ045','AQ056','AQ063','AQ075','AQ130','AQ151','AT041','BH070'))
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['ZI005_GNT']['AL195']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['ZI005_GNT']['AN010']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['ZI005_GNT']['AN050']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['ZI005_GNT']['AP010']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['ZI005_GNT']['AP030']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['ZI005_GNT']['AP040']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['ZI005_GNT']['AP041']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['ZI005_GNT']['AP050']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['ZI005_GNT']['AQ035']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['ZI005_GNT']['AQ040']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['ZI005_GNT']['AQ045']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['ZI005_GNT']['AQ056']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['ZI005_GNT']['AQ063']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['ZI005_GNT']['AQ075']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['ZI005_GNT']['AQ130']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['ZI005_GNT']['AQ151']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['ZI005_GNT']['AT041']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['ZI005_GNT']['BH070']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['TransportationGroundCrv']['ZI005_NFN'] = ('String',('AL195','AN010','AN050','AP010','AP030','AP040','AP041','AP050','AP055','AQ035','AQ040','AQ045','AQ056','AQ063','AQ075','AQ130','AQ151','AT041','BH070'))
    field_information['GGDM 3.0']['TransportationGroundCrv']['ZI006_MEM'] = ('String',('AL155','AL195','AL211','AN010','AN050','AP010','AP030','AP040','AP041','AP050','AP055','AQ035','AQ040','AQ045','AQ050','AQ056','AQ059','AQ063','AQ065','AQ075','AQ120','AQ130','AQ151','AT041','BH070'))
    field_information['GGDM 3.0']['TransportationGroundCrv']['ZI016_ROC'] = ('Enumeration',('AP030','AP055','AQ035','BH070'))
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['ZI016_ROC'] = {}
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['ZI016_ROC']['AP030']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,999)
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['ZI016_ROC']['AP055']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,999)
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['ZI016_ROC']['AQ035']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,999)
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['ZI016_ROC']['BH070']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,999)
    field_information['GGDM 3.0']['TransportationGroundCrv']['ZI016_WD1'] = ('Real',('AP010','AP030','AQ035'))
    field_information['GGDM 3.0']['TransportationGroundCrv']['ZI016_WTC'] = ('Enumeration',('AP010','AP030','AP050','AQ035'))
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['ZI016_WTC'] = {}
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['ZI016_WTC']['AP010']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['ZI016_WTC']['AP030']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['ZI016_WTC']['AP050']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['ZI016_WTC']['AQ035']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['TransportationGroundCrv']['ZI017_GAW'] = ('Real',('AN010','AN050'))
    field_information['GGDM 3.0']['TransportationGroundCrv']['ZI017_RGC'] = ('Enumeration',('AN010','AN050'))
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['ZI017_RGC'] = {}
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['ZI017_RGC']['AN010']  = (-999999,1,2,3)
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['ZI017_RGC']['AN050']  = (-999999,1,2,3)
    field_information['GGDM 3.0']['TransportationGroundCrv']['ZI017_RIR'] = ('Boolean',('AN010','AN050'))
    field_information['GGDM 3.0']['TransportationGroundCrv']['ZI017_RRA'] = ('Enumeration',('AN010','AN050'))
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['ZI017_RRA'] = {}
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['ZI017_RRA']['AN010']  = (-999999,1,3,4,999)
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['ZI017_RRA']['AN050']  = (-999999,1,3,4,999)
    field_information['GGDM 3.0']['TransportationGroundCrv']['ZI017_TRT'] = ('Enumeration',('AN010','AN050'))
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['ZI017_TRT'] = {}
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['ZI017_TRT']['AN010']  = (-999999,1,2,3,4,5,6,7,9,10,12,13,999)
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['ZI017_TRT']['AN050']  = (-999999,1,2,3,4,5,6,7,9,10,12,13,999)
    field_information['GGDM 3.0']['TransportationGroundCrv']['ZI020_GE4'] = ('CodeList',('AL155','AL195','AL211','AN010','AN050','AP010','AP030','AP040','AP041','AP050','AP055','AQ035','AQ040','AQ045','AQ050','AQ056','AQ059','AQ063','AQ065','AQ075','AQ120','AQ130','AQ151','AT041','BH070'))
    field_information['GGDM 3.0']['TransportationGroundCrv']['ZI025_HDP'] = ('Real',('AQ130'))
    field_information['GGDM 3.0']['TransportationGroundCrv']['ZI026_CTUC'] = ('Enumeration',('AL155','AL195','AL211','AN010','AN050','AP010','AP030','AP040','AP041','AP050','AP055','AQ035','AQ040','AQ045','AQ050','AQ056','AQ059','AQ063','AQ065','AQ075','AQ120','AQ130','AQ151','AT041','BH070'))
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['ZI026_CTUC']['AL155']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['ZI026_CTUC']['AL195']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['ZI026_CTUC']['AL211']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['ZI026_CTUC']['AN010']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['ZI026_CTUC']['AN050']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['ZI026_CTUC']['AP010']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['ZI026_CTUC']['AP030']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['ZI026_CTUC']['AP040']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['ZI026_CTUC']['AP041']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['ZI026_CTUC']['AP050']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['ZI026_CTUC']['AP055']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['ZI026_CTUC']['AQ035']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['ZI026_CTUC']['AQ040']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['ZI026_CTUC']['AQ045']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['ZI026_CTUC']['AQ050']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['ZI026_CTUC']['AQ056']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['ZI026_CTUC']['AQ059']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['ZI026_CTUC']['AQ063']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['ZI026_CTUC']['AQ065']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['ZI026_CTUC']['AQ075']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['ZI026_CTUC']['AQ120']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['ZI026_CTUC']['AQ130']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['ZI026_CTUC']['AQ151']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['ZI026_CTUC']['AT041']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['ZI026_CTUC']['BH070']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['TransportationGroundCrv']['ZI026_CTUL'] = ('integer',('AL155','AL195','AL211','AN010','AN050','AP010','AP030','AP040','AP041','AP050','AP055','AQ035','AQ040','AQ045','AQ050','AQ056','AQ059','AQ063','AQ065','AQ075','AQ120','AQ130','AQ151','AT041','BH070'))
    field_information['GGDM 3.0']['TransportationGroundCrv']['ZI026_CTUU'] = ('integer',('AL155','AL195','AL211','AN010','AN050','AP010','AP030','AP040','AP041','AP050','AP055','AQ035','AQ040','AQ045','AQ050','AQ056','AQ059','AQ063','AQ065','AQ075','AQ120','AQ130','AQ151','AT041','BH070'))
    field_information['GGDM 3.0']['TransportationGroundCrv']['ZI026_SUR'] = ('Enumeration',('AN010','AP030'))
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['ZI026_SUR'] = {}
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['ZI026_SUR']['AN010']  = (-999999,1,2,3)
    field_information['GGDM 3.0']['TransportationGroundCrv']['EnumeratedIndexValues']['ZI026_SUR']['AP030']  = (-999999,1,2,3)
    field_information['GGDM 3.0']['TransportationGroundCrv']['ZI031S_URI'] = ('StructuredText',('AL155','AL195','AL211','AN010','AN050','AP010','AP030','AP040','AP041','AP050','AP055','AQ035','AQ040','AQ045','AQ050','AQ056','AQ059','AQ063','AQ065','AQ075','AQ120','AQ130','AQ151','AT041','BH070'))
    field_information['GGDM 3.0']['TransportationGroundCrv']['ZI039S_UFI'] = ('StructuredText',('AL155','AL195','AL211','AN010','AN050','AP010','AP030','AP040','AP041','AP050','AP055','AQ035','AQ040','AQ045','AQ050','AQ056','AQ059','AQ063','AQ065','AQ075','AQ120','AQ130','AQ151','AT041','BH070'))
    field_information['GGDM 3.0']['TransportationGroundCrv']['ZSAX_RS0'] = ('CodeList',('AL155','AL195','AL211','AN010','AN050','AP010','AP030','AP040','AP041','AP050','AP055','AQ035','AQ040','AQ045','AQ050','AQ056','AQ059','AQ063','AQ065','AQ075','AQ120','AQ130','AQ151','AT041','BH070'))
    field_information['GGDM 3.0']['TransportationGroundCrv']['ZSAX_RX0'] = ('StructuredText',('AL155','AL195','AL211','AN010','AN050','AP010','AP030','AP040','AP041','AP050','AP055','AQ035','AQ040','AQ045','AQ050','AQ056','AQ059','AQ063','AQ065','AQ075','AQ120','AQ130','AQ151','AT041','BH070'))
    field_information['GGDM 3.0']['TransportationGroundCrv']['ZSAX_RX3'] = ('StructuredText',('AL155','AL195','AL211','AN010','AN050','AP010','AP030','AP040','AP041','AP050','AP055','AQ035','AQ040','AQ045','AQ050','AQ056','AQ059','AQ063','AQ065','AQ075','AQ120','AQ130','AQ151','AT041','BH070'))
    field_information['GGDM 3.0']['TransportationGroundCrv']['ZSAX_RX4'] = ('StructuredText',('AL155','AL195','AL211','AN010','AN050','AP010','AP030','AP040','AP041','AP050','AP055','AQ035','AQ040','AQ045','AQ050','AQ056','AQ059','AQ063','AQ065','AQ075','AQ120','AQ130','AQ151','AT041','BH070'))
    field_information['GGDM 3.0']['TransportationGroundCrv']['ZVH'] = ('Real',('AL211','AP041','AQ035','AQ040','AQ045','AQ050','AQ056','AQ063','AQ151','AT041'))
    field_information['GGDM 3.0']['TransportationGroundPnt']['ADI'] = ('Enumeration',('AQ162'))
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['ADI'] = {}
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['ADI']['AQ162']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['ADR'] = ('String',('AN076','AQ125','AQ135','AQ141','AQ170'))
    field_information['GGDM 3.0']['TransportationGroundPnt']['AOO'] = ('Real',('AL211','AN076','AP020','AP040','AP041','AQ040','AQ045','AQ055','AQ065','AQ068','AQ095','AQ125','AQ135','AQ141','AQ162','AQ170'))
    field_information['GGDM 3.0']['TransportationGroundPnt']['ARA'] = ('Real',('AH070','AL155','AL165','AL211','AN075','AN076','AN085','AP033','AP041','AP056','AQ040','AQ045','AQ056','AQ062','AQ065','AQ068','AQ125','AQ135','AQ141','AQ170','BH070'))
    field_information['GGDM 3.0']['TransportationGroundPnt']['ATB'] = ('Boolean',('AQ125'))
    field_information['GGDM 3.0']['TransportationGroundPnt']['AWP'] = ('Boolean',('AN076','AQ040','AQ055','AQ141'))
    field_information['GGDM 3.0']['TransportationGroundPnt']['BCC'] = ('Enumeration',('AL155','AQ040','AQ059'))
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['BCC'] = {}
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['BCC']['AL155']  = (-999999,1,2,3)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['BCC']['AQ040']  = (-999999,1,2,3)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['BCC']['AQ059']  = (-999999,1,2,3)
    field_information['GGDM 3.0']['TransportationGroundPnt']['BEN'] = ('StructuredText',('AH070','AL155','AL165','AL211','AN075','AN076','AN085','AP020','AP033','AP040','AP041','AP056','AQ040','AQ045','AQ055','AQ056','AQ059','AQ062','AQ065','AQ068','AQ095','AQ118','AQ125','AQ135','AQ141','AQ160','AQ161','AQ162','AQ170','BH070'))
    field_information['GGDM 3.0']['TransportationGroundPnt']['BMC'] = ('Enumeration',('BH070'))
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['BMC'] = {}
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['BMC']['BH070']  = (-999999,1,2,3,4,5,6,7,9,14,15,18,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['BMC2'] = ('Enumeration',('BH070'))
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['BMC2'] = {}
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['BMC2']['BH070']  = (-999999,1,2,3,4,5,6,7,9,14,15,18,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['BMC3'] = ('Enumeration',('BH070'))
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['BMC3'] = {}
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['BMC3']['BH070']  = (-999999,1,2,3,4,5,6,7,9,14,15,18,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['BNF'] = ('Integer',('AQ141'))
    field_information['GGDM 3.0']['TransportationGroundPnt']['BOT'] = ('Enumeration',('AQ040','AQ045'))
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['BOT'] = {}
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['BOT']['AQ040']  = (-999999,4,10,11,12,14,15,16,17,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['BOT']['AQ045']  = (-999999,4,10,11,12,14,15,16,17,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['BRN'] = ('String',('AQ040','AQ045','AQ055'))
    field_information['GGDM 3.0']['TransportationGroundPnt']['BSC'] = ('Enumeration',('AQ040','AQ045'))
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['BSC'] = {}
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['BSC']['AQ040']  = (-999999,1,2,5,6,7,8,9,12,15,16,19,22,26,27,31,32,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['BSC']['AQ045']  = (-999999,1,2,5,6,7,8,9,12,15,16,19,26,27,31,32,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['BSC2'] = ('Enumeration',('AQ040','AQ045'))
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['BSC2'] = {}
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['BSC2']['AQ040']  = (-999999,1,2,5,6,7,8,9,12,15,16,19,22,26,27,31,32,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['BSC2']['AQ045']  = (-999999,1,2,5,6,7,8,9,12,15,16,19,26,27,31,32,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['BSC3'] = ('Enumeration',('AQ040','AQ045'))
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['BSC3'] = {}
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['BSC3']['AQ040']  = (-999999,1,2,5,6,7,8,9,12,15,16,19,22,26,27,31,32,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['BSC3']['AQ045']  = (-999999,1,2,5,6,7,8,9,12,15,16,19,26,27,31,32,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['BSM'] = ('Boolean',('AQ040'))
    field_information['GGDM 3.0']['TransportationGroundPnt']['CAA'] = ('Enumeration',('AL211','AN076','AP020','AP040','AQ040','AQ095','AQ125','AQ135','AQ141','AQ162','AQ170'))
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['CAA']['AL211']  = (-999999,3,17,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['CAA']['AN076']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['CAA']['AP020']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['CAA']['AP040']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['CAA']['AQ040']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['CAA']['AQ095']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['CAA']['AQ125']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['CAA']['AQ135']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['CAA']['AQ141']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['CAA']['AQ162']  = (-999999,3,4,5,6,7,16,17,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['CAA']['AQ170']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['CIW'] = ('Boolean',('AP033','AQ135','BH070'))
    field_information['GGDM 3.0']['TransportationGroundPnt']['CNCP'] = ('StructuredText',('AH070','AL165','AL211','AN075','AN076','AN085','AP020','AP040','AP041','AQ040','AQ045','AQ065','AQ068','AQ095','AQ125','AQ135','AQ141','AQ160','AQ161','AQ162','AQ170','BH070'))
    field_information['GGDM 3.0']['TransportationGroundPnt']['CON'] = ('Enumeration',('AQ059'))
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['CON'] = {}
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['CON']['AQ059']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['COS'] = ('Enumeration',('AH070','AL165','AL211','AN075','AN076','AN085','AP020','AP040','AP041','AQ040','AQ045','AQ065','AQ068','AQ095','AQ125','AQ135','AQ141','AQ160','AQ161','AQ162','AQ170','BH070'))
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['COS']['AH070']  = (-999999,2,4,6,9,13,14)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['COS']['AL165']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['COS']['AL211']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['COS']['AN075']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['COS']['AN076']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['COS']['AN085']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['COS']['AP020']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['COS']['AP040']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['COS']['AP041']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['COS']['AQ040']  = (-999999,2,4,6,9,13,14)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['COS']['AQ045']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['COS']['AQ065']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['COS']['AQ068']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['COS']['AQ095']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['COS']['AQ125']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['COS']['AQ135']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['COS']['AQ141']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['COS']['AQ160']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['COS']['AQ161']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['COS']['AQ162']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['COS']['AQ170']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['COS']['BH070']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['TransportationGroundPnt']['CSC'] = ('Enumeration',('AP056','AQ062'))
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['CSC'] = {}
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['CSC']['AP056']  = (-999999,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['CSC']['AQ062']  = (-999999,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['CSC2'] = ('Enumeration',('AP056','AQ062'))
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['CSC2'] = {}
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['CSC2']['AP056']  = (-999999,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['CSC2']['AQ062']  = (-999999,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['CSC3'] = ('Enumeration',('AP056','AQ062'))
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['CSC3'] = {}
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['CSC3']['AP056']  = (-999999,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['CSC3']['AQ062']  = (-999999,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['CTC'] = ('Enumeration',('AQ065'))
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['CTC'] = {}
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['CTC']['AQ065']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['CWT'] = ('Boolean',('AP020'))
    field_information['GGDM 3.0']['TransportationGroundPnt']['DEV'] = ('Integer',('AL155'))
    field_information['GGDM 3.0']['TransportationGroundPnt']['DGC'] = ('Enumeration',('AQ068'))
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['DGC'] = {}
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['DGC']['AQ068']  = (-999999,1,2,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['DZC'] = ('Integer',('AQ040'))
    field_information['GGDM 3.0']['TransportationGroundPnt']['EXP'] = ('Enumeration',('AQ059'))
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['EXP'] = {}
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['EXP']['AQ059']  = (-999999,1,2,3,4,5,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['F_CODE'] = ('CONSTRAINED_STRING',('AH070','AL155','AL165','AL211','AN075','AN076','AN085','AP020','AP033','AP040','AP041','AP056','AQ040','AQ045','AQ055','AQ056','AQ059','AQ062','AQ065','AQ068','AQ095','AQ118','AQ125','AQ135','AQ141','AQ160','AQ161','AQ162','AQ170','BH070'))
    field_information['GGDM 3.0']['TransportationGroundPnt']['FFN'] = ('Enumeration',('AH070','AN076','AP040','AQ125','AQ135','AQ141','AQ170'))
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['FFN'] = {}
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['FFN']['AH070']  = (-999999,537,538,539,830,831,833,842,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['FFN']['AN076']  = (-999999,342,490,530,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['FFN']['AP040']  = (-999999,2,480,830,831,833,842,907,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['FFN']['AQ125']  = (-999999,382,481,482,483,484,489,490,491,494,495,500,505,507,508,520,525,530,535,537,538,539,540,551,570,572,573,775,833,841,842,847,970,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['FFN']['AQ135']  = (-999999,382,466,470,488,570,572,612,970,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['FFN']['AQ141']  = (-999999,343,470,483,495,530,535,761,847,970,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['FFN']['AQ170']  = (-999999,343,382,466,470,970,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['FFN2'] = ('Enumeration',('AH070','AN076','AP040','AQ125','AQ135','AQ141','AQ170'))
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['FFN2'] = {}
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['FFN2']['AH070']  = (-999999,537,538,539,830,831,833,842,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['FFN2']['AN076']  = (-999999,342,490,530,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['FFN2']['AP040']  = (-999999,2,480,830,831,833,842,907,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['FFN2']['AQ125']  = (-999999,382,481,482,483,484,489,490,491,494,495,500,505,507,508,520,525,530,535,537,538,539,540,551,570,572,573,775,833,841,842,847,970,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['FFN2']['AQ135']  = (-999999,382,466,470,488,570,572,612,970,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['FFN2']['AQ141']  = (-999999,343,470,483,495,530,535,761,847,970,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['FFN2']['AQ170']  = (-999999,343,382,466,470,970,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['FFN3'] = ('Enumeration',('AH070','AN076','AP040','AQ125','AQ135','AQ141','AQ170'))
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['FFN3'] = {}
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['FFN3']['AH070']  = (-999999,537,538,539,830,831,833,842,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['FFN3']['AN076']  = (-999999,342,490,530,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['FFN3']['AP040']  = (-999999,2,480,830,831,833,842,907,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['FFN3']['AQ125']  = (-999999,382,481,482,483,484,489,490,491,494,495,500,505,507,508,520,525,530,535,537,538,539,540,551,570,572,573,775,833,841,842,847,970,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['FFN3']['AQ135']  = (-999999,382,466,470,488,570,572,612,970,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['FFN3']['AQ141']  = (-999999,343,470,483,495,530,535,761,847,970,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['FFN3']['AQ170']  = (-999999,343,382,466,470,970,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['FUFI'] = ('StructuredText',('AH070','AL155','AL165','AL211','AN075','AN076','AN085','AP020','AP033','AP040','AP041','AP056','AQ040','AQ045','AQ055','AQ056','AQ059','AQ062','AQ065','AQ068','AQ095','AQ118','AQ125','AQ135','AQ141','AQ160','AQ161','AQ162','AQ170','BH070'))
    field_information['GGDM 3.0']['TransportationGroundPnt']['FURL'] = ('StructuredText',('AH070','AL155','AL165','AL211','AN075','AN076','AN085','AP020','AP033','AP040','AP041','AP056','AQ040','AQ045','AQ055','AQ056','AQ059','AQ062','AQ065','AQ068','AQ095','AQ118','AQ125','AQ135','AQ141','AQ160','AQ161','AQ162','AQ170','BH070'))
    field_information['GGDM 3.0']['TransportationGroundPnt']['GDBV'] = ('Enumeration',('AH070','AL155','AL165','AL211','AN075','AN076','AN085','AP020','AP033','AP040','AP041','AP056','AQ040','AQ045','AQ055','AQ056','AQ059','AQ062','AQ065','AQ068','AQ095','AQ118','AQ125','AQ135','AQ141','AQ160','AQ161','AQ162','AQ170','BH070'))
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['GDBV']['AH070']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['GDBV']['AL155']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['GDBV']['AL165']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['GDBV']['AL211']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['GDBV']['AN075']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['GDBV']['AN076']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['GDBV']['AN085']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['GDBV']['AP020']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['GDBV']['AP033']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['GDBV']['AP040']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['GDBV']['AP041']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['GDBV']['AP056']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['GDBV']['AQ040']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['GDBV']['AQ045']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['GDBV']['AQ055']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['GDBV']['AQ056']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['GDBV']['AQ059']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['GDBV']['AQ062']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['GDBV']['AQ065']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['GDBV']['AQ068']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['GDBV']['AQ095']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['GDBV']['AQ118']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['GDBV']['AQ125']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['GDBV']['AQ135']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['GDBV']['AQ141']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['GDBV']['AQ160']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['GDBV']['AQ161']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['GDBV']['AQ162']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['GDBV']['AQ170']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['GDBV']['BH070']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['GTC'] = ('Enumeration',('AP040'))
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['GTC'] = {}
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['GTC']['AP040']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['HCA'] = ('Real',('AL211','AQ040','AQ059','AQ095'))
    field_information['GGDM 3.0']['TransportationGroundPnt']['HEI'] = ('Real',('AQ162'))
    field_information['GGDM 3.0']['TransportationGroundPnt']['HGT'] = ('Real',('AL211','AN076','AP040','AP041','AQ040','AQ045','AQ055','AQ056','AQ125','AQ135','AQ141','AQ160','AQ161','AQ162','AQ170'))
    field_information['GGDM 3.0']['TransportationGroundPnt']['HST'] = ('Enumeration',('AQ125'))
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['HST'] = {}
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['HST']['AQ125']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['HST2'] = ('Enumeration',('AQ125'))
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['HST2'] = {}
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['HST2']['AQ125']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['HST3'] = ('Enumeration',('AQ125'))
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['HST3'] = {}
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['HST3']['AQ125']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['LC1'] = ('Integer',('AQ040','AQ045'))
    field_information['GGDM 3.0']['TransportationGroundPnt']['LC2'] = ('Integer',('AQ040','AQ045'))
    field_information['GGDM 3.0']['TransportationGroundPnt']['LC3'] = ('Integer',('AQ040','AQ045'))
    field_information['GGDM 3.0']['TransportationGroundPnt']['LC4'] = ('Integer',('AQ040','AQ045'))
    field_information['GGDM 3.0']['TransportationGroundPnt']['LMC'] = ('Boolean',('AH070','AL211','AN075','AN076','AP020','AQ040','AQ055','AQ056','AQ118','AQ125','AQ135','AQ141','AQ170'))
    field_information['GGDM 3.0']['TransportationGroundPnt']['LUN'] = ('Boolean',('AQ125','AQ141'))
    field_information['GGDM 3.0']['TransportationGroundPnt']['LZN'] = ('Real',('AH070','AL155','AL165','AL211','AN075','AN076','AN085','AP033','AP040','AP041','AP056','AQ040','AQ045','AQ055','AQ056','AQ059','AQ062','AQ065','AQ068','AQ095','AQ118','AQ125','AQ135','AQ141','AQ160','AQ161','AQ162','AQ170','BH070'))
    field_information['GGDM 3.0']['TransportationGroundPnt']['MCC'] = ('Enumeration',('AP041','AQ065','AQ162'))
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['MCC'] = {}
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['MCC']['AP041']  = (-999999,21,62,64,77,83,104,117,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['MCC']['AQ065']  = (-999999,21,62,64,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['MCC']['AQ162']  = (-999999,64,74,117,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['MCC2'] = ('Enumeration',('AP041','AQ065','AQ162'))
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['MCC2'] = {}
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['MCC2']['AP041']  = (-999999,21,62,64,77,83,104,117,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['MCC2']['AQ065']  = (-999999,21,62,64,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['MCC2']['AQ162']  = (-999999,64,74,117,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['MCC3'] = ('Enumeration',('AP041','AQ065','AQ162'))
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['MCC3'] = {}
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['MCC3']['AP041']  = (-999999,21,62,64,77,83,104,117,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['MCC3']['AQ065']  = (-999999,21,62,64,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['MCC3']['AQ162']  = (-999999,64,74,117,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['MES'] = ('Boolean',('AP033'))
    field_information['GGDM 3.0']['TransportationGroundPnt']['MUB'] = ('Boolean',('AQ125'))
    field_information['GGDM 3.0']['TransportationGroundPnt']['NOS'] = ('Integer',('AQ040'))
    field_information['GGDM 3.0']['TransportationGroundPnt']['OHC'] = ('Real',('AL155','AL211','AQ040','AQ045','AQ095'))
    field_information['GGDM 3.0']['TransportationGroundPnt']['OOC'] = ('Enumeration',('AL155'))
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['OOC'] = {}
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['OOC']['AL155']  = (-999999,1,2,3,4,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['OTH'] = ('StructuredText',('AH070','AL155','AL165','AL211','AN075','AN076','AN085','AP020','AP033','AP040','AP041','AP056','AQ040','AQ045','AQ055','AQ056','AQ059','AQ062','AQ065','AQ068','AQ095','AQ118','AQ125','AQ135','AQ141','AQ160','AQ161','AQ162','AQ170','BH070'))
    field_information['GGDM 3.0']['TransportationGroundPnt']['PCF'] = ('Enumeration',('AL155','AL165','AL211','AN075','AN076','AN085','AP033','AP040','AP041','AP056','AQ040','AQ045','AQ055','AQ056','AQ065','AQ068','AQ095','AQ125','AQ135','AQ141','AQ160','AQ161','AQ162','AQ170','BH070'))
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['PCF']['AL155']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['PCF']['AL165']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['PCF']['AL211']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['PCF']['AN075']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['PCF']['AN076']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['PCF']['AN085']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['PCF']['AP033']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['PCF']['AP040']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['PCF']['AP041']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['PCF']['AP056']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['PCF']['AQ040']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['PCF']['AQ045']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['PCF']['AQ055']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['PCF']['AQ056']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['PCF']['AQ065']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['PCF']['AQ068']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['PCF']['AQ095']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['PCF']['AQ125']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['PCF']['AQ135']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['PCF']['AQ141']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['PCF']['AQ160']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['PCF']['AQ161']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['PCF']['AQ162']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['PCF']['AQ170']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['PCF']['BH070']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['TransportationGroundPnt']['PYM'] = ('Enumeration',('AQ055'))
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['PYM'] = {}
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['PYM']['AQ055']  = (-999999,1,3,4,5,7,8,9,10,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['RAD'] = ('Real',('AQ118'))
    field_information['GGDM 3.0']['TransportationGroundPnt']['RFD'] = ('Boolean',('AQ040'))
    field_information['GGDM 3.0']['TransportationGroundPnt']['RIN_ROI'] = ('Enumeration',('AP020'))
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['RIN_ROI'] = {}
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['RIN_ROI']['AP020']  = (-999999,1,2,3,4,5,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['RIN_ROI2'] = ('Enumeration',('AP020'))
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['RIN_ROI2'] = {}
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['RIN_ROI2']['AP020']  = (-999999,1,2,3,4,5,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['RIN_ROI3'] = ('Enumeration',('AP020'))
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['RIN_ROI3'] = {}
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['RIN_ROI3']['AP020']  = (-999999,1,2,3,4,5,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['RIN_RTN'] = ('String',('AP020'))
    field_information['GGDM 3.0']['TransportationGroundPnt']['RIN_RTN2'] = ('String',('AP020'))
    field_information['GGDM 3.0']['TransportationGroundPnt']['RIN_RTN3'] = ('String',('AP020'))
    field_information['GGDM 3.0']['TransportationGroundPnt']['RIT'] = ('Enumeration',('AP020'))
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['RIT'] = {}
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['RIT']['AP020']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['SHC'] = ('Real',('AQ059'))
    field_information['GGDM 3.0']['TransportationGroundPnt']['SPT'] = ('Boolean',('AQ125'))
    field_information['GGDM 3.0']['TransportationGroundPnt']['SRE'] = ('Enumeration',('AQ059'))
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['SRE'] = {}
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['SRE']['AQ059']  = (-999999,1,2,3,8,9,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['SSG'] = ('Enumeration',('AQ162'))
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['SSG'] = {}
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['SSG']['AQ162']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['SSR'] = ('Enumeration',('AN076','AQ125','AQ141','AQ170'))
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['SSR'] = {}
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['SSR']['AN076']  = (-999999,6,7,38,40,41,42,47,50,55,64,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['SSR']['AQ125']  = (-999999,6,7,38,40,41,42,47,50,55,64,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['SSR']['AQ141']  = (-999999,6,7,38,40,41,42,47,50,55,64,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['SSR']['AQ170']  = (-999999,6,7,38,40,41,42,47,50,55,64,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['SSR2'] = ('Enumeration',('AN076','AQ125','AQ141','AQ170'))
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['SSR2'] = {}
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['SSR2']['AN076']  = (-999999,6,7,38,40,41,42,47,50,55,64,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['SSR2']['AQ125']  = (-999999,6,7,38,40,41,42,47,50,55,64,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['SSR2']['AQ141']  = (-999999,6,7,38,40,41,42,47,50,55,64,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['SSR2']['AQ170']  = (-999999,6,7,38,40,41,42,47,50,55,64,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['SSR3'] = ('Enumeration',('AN076','AQ125','AQ141','AQ170'))
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['SSR3'] = {}
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['SSR3']['AN076']  = (-999999,6,7,38,40,41,42,47,50,55,64,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['SSR3']['AQ125']  = (-999999,6,7,38,40,41,42,47,50,55,64,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['SSR3']['AQ141']  = (-999999,6,7,38,40,41,42,47,50,55,64,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['SSR3']['AQ170']  = (-999999,6,7,38,40,41,42,47,50,55,64,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['TCS'] = ('Enumeration',('AQ065'))
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['TCS'] = {}
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['TCS']['AQ065']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['THI'] = ('Real',('AP040'))
    field_information['GGDM 3.0']['TransportationGroundPnt']['TRP'] = ('Enumeration',('AL211'))
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['TRP'] = {}
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['TRP']['AL211']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['TRS'] = ('Enumeration',('AH070','AL155','AL211','AP040','AP041','AP056','AQ040','AQ059','AQ062','AQ068','AQ095','AQ125','BH070'))
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['TRS'] = {}
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['TRS']['AH070']  = (-999999,1,7,8,9,12,13,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['TRS']['AL155']  = (-999999,5,9,12,13,17,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['TRS']['AL211']  = (-999999,5,12,13,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['TRS']['AP040']  = (-999999,3,9,12,13,16,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['TRS']['AP041']  = (-999999,5,9,12,13,16,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['TRS']['AP056']  = (-999999,5,12,13,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['TRS']['AQ040']  = (-999999,2,5,9,10,12,13,20,25,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['TRS']['AQ059']  = (-999999,5,9,12,13,17,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['TRS']['AQ062']  = (-999999,5,12,13,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['TRS']['AQ068']  = (-999999,5,9,12,13,16,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['TRS']['AQ095']  = (-999999,2,5,7,8,9,12,13,17,20,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['TRS']['AQ125']  = (-999999,2,5,7,8,9,12,13,17,20,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['TRS']['BH070']  = (-999999,9,13,18,23,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['TRS2'] = ('Enumeration',('AH070','AL155','AL211','AP040','AP041','AP056','AQ040','AQ059','AQ062','AQ068','AQ095','AQ125','BH070'))
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['TRS2'] = {}
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['TRS2']['AH070']  = (-999999,1,7,8,9,12,13,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['TRS2']['AL155']  = (-999999,5,9,12,13,17,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['TRS2']['AL211']  = (-999999,5,12,13,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['TRS2']['AP040']  = (-999999,3,9,12,13,16,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['TRS2']['AP041']  = (-999999,5,9,12,13,16,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['TRS2']['AP056']  = (-999999,5,12,13,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['TRS2']['AQ040']  = (-999999,2,5,9,10,12,13,20,25,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['TRS2']['AQ059']  = (-999999,5,9,12,13,17,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['TRS2']['AQ062']  = (-999999,5,12,13,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['TRS2']['AQ068']  = (-999999,5,9,12,13,16,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['TRS2']['AQ095']  = (-999999,2,5,7,8,9,12,13,17,20,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['TRS2']['AQ125']  = (-999999,2,5,7,8,9,12,13,17,20,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['TRS2']['BH070']  = (-999999,9,13,18,23,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['TRS3'] = ('Enumeration',('AH070','AL155','AL211','AP040','AP041','AP056','AQ040','AQ059','AQ062','AQ068','AQ095','AQ125','BH070'))
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['TRS3'] = {}
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['TRS3']['AH070']  = (-999999,1,7,8,9,12,13,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['TRS3']['AL155']  = (-999999,5,9,12,13,17,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['TRS3']['AL211']  = (-999999,5,12,13,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['TRS3']['AP040']  = (-999999,3,9,12,13,16,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['TRS3']['AP041']  = (-999999,5,9,12,13,16,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['TRS3']['AP056']  = (-999999,5,12,13,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['TRS3']['AQ040']  = (-999999,2,5,9,10,12,13,20,25,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['TRS3']['AQ059']  = (-999999,5,9,12,13,17,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['TRS3']['AQ062']  = (-999999,5,12,13,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['TRS3']['AQ068']  = (-999999,5,9,12,13,16,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['TRS3']['AQ095']  = (-999999,2,5,7,8,9,12,13,17,20,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['TRS3']['AQ125']  = (-999999,2,5,7,8,9,12,13,17,20,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['TRS3']['BH070']  = (-999999,9,13,18,23,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['UBC'] = ('Real',('AQ040'))
    field_information['GGDM 3.0']['TransportationGroundPnt']['UFI'] = ('StructuredText',('AH070','AL155','AL165','AL211','AN075','AN076','AN085','AP020','AP033','AP040','AP041','AP056','AQ040','AQ045','AQ055','AQ056','AQ059','AQ062','AQ065','AQ068','AQ095','AQ118','AQ125','AQ135','AQ141','AQ160','AQ161','AQ162','AQ170','BH070'))
    field_information['GGDM 3.0']['TransportationGroundPnt']['VCM'] = ('Enumeration',('AN076','AQ040','AQ045'))
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['VCM'] = {}
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['VCM']['AN076']  = (-999999,1,4,8,12,13,15,18,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['VCM']['AQ040']  = (-999999,2,3,4,7,8,9,12,13,15,16,17,18,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['VCM']['AQ045']  = (-999999,2,3,4,7,8,9,12,13,15,16,17,18,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['VCM2'] = ('Enumeration',('AN076','AQ040','AQ045'))
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['VCM2'] = {}
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['VCM2']['AN076']  = (-999999,1,4,8,12,13,15,18,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['VCM2']['AQ040']  = (-999999,2,3,4,7,8,9,12,13,15,16,17,18,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['VCM2']['AQ045']  = (-999999,2,3,4,7,8,9,12,13,15,16,17,18,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['VCM3'] = ('Enumeration',('AN076','AQ040','AQ045'))
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['VCM3'] = {}
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['VCM3']['AN076']  = (-999999,1,4,8,12,13,15,18,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['VCM3']['AQ040']  = (-999999,2,3,4,7,8,9,12,13,15,16,17,18,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['VCM3']['AQ045']  = (-999999,2,3,4,7,8,9,12,13,15,16,17,18,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['VCO'] = ('Real',('AQ040','AQ045'))
    field_information['GGDM 3.0']['TransportationGroundPnt']['VCS'] = ('Real',('AQ040'))
    field_information['GGDM 3.0']['TransportationGroundPnt']['VCS_VCD'] = ('Enumeration',('AQ040'))
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['VCS_VCD'] = {}
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['VCS_VCD']['AQ040']  = (-999999,7,9,10,15,24,28,30,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['VCS_VCR'] = ('String',('AQ040'))
    field_information['GGDM 3.0']['TransportationGroundPnt']['VOI'] = ('StructuredText',('AN076','AQ040','AQ055','AQ141','AQ162'))
    field_information['GGDM 3.0']['TransportationGroundPnt']['WBD'] = ('Real',('BH070'))
    field_information['GGDM 3.0']['TransportationGroundPnt']['WD1'] = ('Real',('AQ059'))
    field_information['GGDM 3.0']['TransportationGroundPnt']['WD2'] = ('Real',('AP040'))
    field_information['GGDM 3.0']['TransportationGroundPnt']['WID'] = ('Real',('AH070','AL155','AL165','AL211','AN075','AN076','AN085','AP033','AP041','AP056','AQ040','AQ045','AQ055','AQ056','AQ062','AQ065','AQ068','AQ125','AQ135','AQ141','AQ170','BH070'))
    field_information['GGDM 3.0']['TransportationGroundPnt']['WVA'] = ('Real',('BH070'))
    field_information['GGDM 3.0']['TransportationGroundPnt']['ZI001_SDV'] = ('StructuredText',('AH070','AL155','AL165','AL211','AN075','AN076','AN085','AP020','AP033','AP040','AP041','AP056','AQ040','AQ045','AQ055','AQ056','AQ059','AQ062','AQ065','AQ068','AQ095','AQ118','AQ125','AQ135','AQ141','AQ160','AQ161','AQ162','AQ170','BH070'))
    field_information['GGDM 3.0']['TransportationGroundPnt']['ZI001_SRT'] = ('Enumeration',('AH070','AL155','AL165','AL211','AN075','AN076','AN085','AP020','AP033','AP040','AP041','AP056','AQ040','AQ045','AQ055','AQ056','AQ059','AQ062','AQ065','AQ068','AQ095','AQ118','AQ125','AQ135','AQ141','AQ160','AQ161','AQ162','AQ170','BH070'))
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['ZI001_SRT']['AH070']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['ZI001_SRT']['AL155']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['ZI001_SRT']['AL165']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['ZI001_SRT']['AL211']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['ZI001_SRT']['AN075']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['ZI001_SRT']['AN076']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['ZI001_SRT']['AN085']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['ZI001_SRT']['AP020']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['ZI001_SRT']['AP033']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['ZI001_SRT']['AP040']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['ZI001_SRT']['AP041']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['ZI001_SRT']['AP056']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['ZI001_SRT']['AQ040']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['ZI001_SRT']['AQ045']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['ZI001_SRT']['AQ055']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['ZI001_SRT']['AQ056']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['ZI001_SRT']['AQ059']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['ZI001_SRT']['AQ062']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['ZI001_SRT']['AQ065']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['ZI001_SRT']['AQ068']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['ZI001_SRT']['AQ095']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['ZI001_SRT']['AQ118']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['ZI001_SRT']['AQ125']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['ZI001_SRT']['AQ135']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['ZI001_SRT']['AQ141']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['ZI001_SRT']['AQ160']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['ZI001_SRT']['AQ161']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['ZI001_SRT']['AQ162']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['ZI001_SRT']['AQ170']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['ZI001_SRT']['BH070']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['ZI002_UFI'] = ('StructuredText',('AH070','AL155','AL165','AL211','AN075','AN076','AN085','AP020','AP033','AP040','AP041','AP056','AQ040','AQ045','AQ055','AQ056','AQ059','AQ062','AQ065','AQ068','AQ095','AQ118','AQ125','AQ135','AQ141','AQ160','AQ161','AQ162','AQ170','BH070'))
    field_information['GGDM 3.0']['TransportationGroundPnt']['ZI004_RCG'] = ('Enumeration',('AH070','AL155','AL165','AL211','AN075','AN076','AN085','AP020','AP033','AP040','AP041','AP056','AQ040','AQ045','AQ055','AQ056','AQ059','AQ062','AQ065','AQ068','AQ095','AQ118','AQ125','AQ135','AQ141','AQ160','AQ161','AQ162','AQ170','BH070'))
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['ZI004_RCG']['AH070']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['ZI004_RCG']['AL155']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['ZI004_RCG']['AL165']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['ZI004_RCG']['AL211']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['ZI004_RCG']['AN075']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['ZI004_RCG']['AN076']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['ZI004_RCG']['AN085']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['ZI004_RCG']['AP020']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['ZI004_RCG']['AP033']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['ZI004_RCG']['AP040']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['ZI004_RCG']['AP041']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['ZI004_RCG']['AP056']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['ZI004_RCG']['AQ040']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['ZI004_RCG']['AQ045']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['ZI004_RCG']['AQ055']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['ZI004_RCG']['AQ056']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['ZI004_RCG']['AQ059']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['ZI004_RCG']['AQ062']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['ZI004_RCG']['AQ065']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['ZI004_RCG']['AQ068']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['ZI004_RCG']['AQ095']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['ZI004_RCG']['AQ118']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['ZI004_RCG']['AQ125']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['ZI004_RCG']['AQ135']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['ZI004_RCG']['AQ141']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['ZI004_RCG']['AQ160']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['ZI004_RCG']['AQ161']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['ZI004_RCG']['AQ162']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['ZI004_RCG']['AQ170']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['ZI004_RCG']['BH070']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['ZI005_FNA'] = ('String',('AH070','AL165','AN075','AN076','AN085','AP020','AP033','AP040','AP041','AP056','AQ040','AQ045','AQ056','AQ062','AQ095','AQ125','AQ135','AQ141','AQ160','AQ161','AQ162','AQ170','BH070'))
    field_information['GGDM 3.0']['TransportationGroundPnt']['ZI005_GNT'] = ('Enumeration',('AH070','AL165','AN075','AN076','AN085','AP020','AP040','AP041','AQ040','AQ045','AQ056','AQ062','AQ095','AQ125','AQ135','AQ141','AQ160','AQ161','AQ162','AQ170','BH070'))
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['ZI005_GNT']['AH070']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['ZI005_GNT']['AL165']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['ZI005_GNT']['AN075']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['ZI005_GNT']['AN076']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['ZI005_GNT']['AN085']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['ZI005_GNT']['AP020']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['ZI005_GNT']['AP040']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['ZI005_GNT']['AP041']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['ZI005_GNT']['AQ040']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['ZI005_GNT']['AQ045']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['ZI005_GNT']['AQ056']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['ZI005_GNT']['AQ062']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['ZI005_GNT']['AQ095']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['ZI005_GNT']['AQ125']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['ZI005_GNT']['AQ135']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['ZI005_GNT']['AQ141']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['ZI005_GNT']['AQ160']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['ZI005_GNT']['AQ161']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['ZI005_GNT']['AQ162']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['ZI005_GNT']['AQ170']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['ZI005_GNT']['BH070']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['ZI005_NFN'] = ('String',('AH070','AL165','AN075','AN076','AN085','AP020','AP033','AP040','AP041','AP056','AQ040','AQ045','AQ056','AQ062','AQ095','AQ125','AQ135','AQ141','AQ160','AQ161','AQ162','AQ170','BH070'))
    field_information['GGDM 3.0']['TransportationGroundPnt']['ZI006_MEM'] = ('String',('AH070','AL155','AL165','AL211','AN075','AN076','AN085','AP020','AP033','AP040','AP041','AP056','AQ040','AQ045','AQ055','AQ056','AQ059','AQ062','AQ065','AQ068','AQ095','AQ118','AQ125','AQ135','AQ141','AQ160','AQ161','AQ162','AQ170','BH070'))
    field_information['GGDM 3.0']['TransportationGroundPnt']['ZI016_ROC'] = ('Enumeration',('AP033','AQ135','BH070'))
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['ZI016_ROC'] = {}
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['ZI016_ROC']['AP033']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['ZI016_ROC']['AQ135']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['ZI016_ROC']['BH070']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['ZI016_WTC'] = ('Enumeration',('AP033'))
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['ZI016_WTC'] = {}
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['ZI016_WTC']['AP033']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['ZI017_GAW'] = ('Real',('AN075','AN076'))
    field_information['GGDM 3.0']['TransportationGroundPnt']['ZI017_RGC'] = ('Enumeration',('AN075','AN076'))
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['ZI017_RGC'] = {}
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['ZI017_RGC']['AN075']  = (-999999,1,2,3)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['ZI017_RGC']['AN076']  = (-999999,1,2,3)
    field_information['GGDM 3.0']['TransportationGroundPnt']['ZI017_RRA'] = ('Enumeration',('AN075','AN076'))
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['ZI017_RRA'] = {}
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['ZI017_RRA']['AN075']  = (-999999,1,3,4,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['ZI017_RRA']['AN076']  = (-999999,1,3,4,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['ZI017_TRT'] = ('Enumeration',('AN075','AN076'))
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['ZI017_TRT'] = {}
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['ZI017_TRT']['AN075']  = (-999999,1,2,3,4,5,6,7,9,10,12,13,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['ZI017_TRT']['AN076']  = (-999999,1,2,3,4,5,6,7,9,10,12,13,999)
    field_information['GGDM 3.0']['TransportationGroundPnt']['ZI020_GE4'] = ('CodeList',('AH070','AL155','AL165','AL211','AN075','AN076','AN085','AP020','AP033','AP040','AP041','AP056','AQ040','AQ045','AQ055','AQ056','AQ059','AQ062','AQ065','AQ068','AQ095','AQ118','AQ125','AQ135','AQ141','AQ160','AQ161','AQ162','AQ170','BH070'))
    field_information['GGDM 3.0']['TransportationGroundPnt']['ZI026_CTUC'] = ('Enumeration',('AH070','AL155','AL165','AL211','AN075','AN076','AN085','AP020','AP033','AP040','AP041','AP056','AQ040','AQ045','AQ055','AQ056','AQ059','AQ062','AQ065','AQ068','AQ095','AQ118','AQ125','AQ135','AQ141','AQ160','AQ161','AQ162','AQ170','BH070'))
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['ZI026_CTUC']['AH070']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['ZI026_CTUC']['AL155']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['ZI026_CTUC']['AL165']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['ZI026_CTUC']['AL211']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['ZI026_CTUC']['AN075']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['ZI026_CTUC']['AN076']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['ZI026_CTUC']['AN085']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['ZI026_CTUC']['AP020']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['ZI026_CTUC']['AP033']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['ZI026_CTUC']['AP040']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['ZI026_CTUC']['AP041']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['ZI026_CTUC']['AP056']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['ZI026_CTUC']['AQ040']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['ZI026_CTUC']['AQ045']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['ZI026_CTUC']['AQ055']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['ZI026_CTUC']['AQ056']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['ZI026_CTUC']['AQ059']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['ZI026_CTUC']['AQ062']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['ZI026_CTUC']['AQ065']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['ZI026_CTUC']['AQ068']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['ZI026_CTUC']['AQ095']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['ZI026_CTUC']['AQ118']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['ZI026_CTUC']['AQ125']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['ZI026_CTUC']['AQ135']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['ZI026_CTUC']['AQ141']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['ZI026_CTUC']['AQ160']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['ZI026_CTUC']['AQ161']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['ZI026_CTUC']['AQ162']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['ZI026_CTUC']['AQ170']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['TransportationGroundPnt']['EnumeratedIndexValues']['ZI026_CTUC']['BH070']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['TransportationGroundPnt']['ZI026_CTUL'] = ('integer',('AH070','AL155','AL165','AL211','AN075','AN076','AN085','AP020','AP033','AP040','AP041','AP056','AQ040','AQ045','AQ055','AQ056','AQ059','AQ062','AQ065','AQ068','AQ095','AQ118','AQ125','AQ135','AQ141','AQ160','AQ161','AQ162','AQ170','BH070'))
    field_information['GGDM 3.0']['TransportationGroundPnt']['ZI026_CTUU'] = ('integer',('AH070','AL155','AL165','AL211','AN075','AN076','AN085','AP020','AP033','AP040','AP041','AP056','AQ040','AQ045','AQ055','AQ056','AQ059','AQ062','AQ065','AQ068','AQ095','AQ118','AQ125','AQ135','AQ141','AQ160','AQ161','AQ162','AQ170','BH070'))
    field_information['GGDM 3.0']['TransportationGroundPnt']['ZI031S_URI'] = ('StructuredText',('AH070','AL155','AL165','AL211','AN075','AN076','AN085','AP020','AP033','AP040','AP041','AP056','AQ040','AQ045','AQ055','AQ056','AQ059','AQ062','AQ065','AQ068','AQ095','AQ118','AQ125','AQ135','AQ141','AQ160','AQ161','AQ162','AQ170','BH070'))
    field_information['GGDM 3.0']['TransportationGroundPnt']['ZI039S_UFI'] = ('StructuredText',('AH070','AL155','AL165','AL211','AN075','AN076','AN085','AP020','AP033','AP040','AP041','AP056','AQ040','AQ045','AQ055','AQ056','AQ059','AQ062','AQ065','AQ068','AQ095','AQ118','AQ125','AQ135','AQ141','AQ160','AQ161','AQ162','AQ170','BH070'))
    field_information['GGDM 3.0']['TransportationGroundPnt']['ZSAX_RS0'] = ('CodeList',('AH070','AL155','AL165','AL211','AN075','AN076','AN085','AP020','AP033','AP040','AP041','AP056','AQ040','AQ045','AQ055','AQ056','AQ059','AQ062','AQ065','AQ068','AQ095','AQ118','AQ125','AQ135','AQ141','AQ160','AQ161','AQ162','AQ170','BH070'))
    field_information['GGDM 3.0']['TransportationGroundPnt']['ZSAX_RX0'] = ('StructuredText',('AH070','AL155','AL165','AL211','AN075','AN076','AN085','AP020','AP033','AP040','AP041','AP056','AQ040','AQ045','AQ055','AQ056','AQ059','AQ062','AQ065','AQ068','AQ095','AQ118','AQ125','AQ135','AQ141','AQ160','AQ161','AQ162','AQ170','BH070'))
    field_information['GGDM 3.0']['TransportationGroundPnt']['ZSAX_RX3'] = ('StructuredText',('AH070','AL155','AL165','AL211','AN075','AN076','AN085','AP020','AP033','AP040','AP041','AP056','AQ040','AQ045','AQ055','AQ056','AQ059','AQ062','AQ065','AQ068','AQ095','AQ118','AQ125','AQ135','AQ141','AQ160','AQ161','AQ162','AQ170','BH070'))
    field_information['GGDM 3.0']['TransportationGroundPnt']['ZSAX_RX4'] = ('StructuredText',('AH070','AL155','AL165','AL211','AN075','AN076','AN085','AP020','AP033','AP040','AP041','AP056','AQ040','AQ045','AQ055','AQ056','AQ059','AQ062','AQ065','AQ068','AQ095','AQ118','AQ125','AQ135','AQ141','AQ160','AQ161','AQ162','AQ170','BH070'))
    field_information['GGDM 3.0']['TransportationGroundPnt']['ZVH'] = ('Real',('AL211','AN076','AP041','AQ040','AQ045','AQ055','AQ056','AQ095','AQ125','AQ135','AQ141','AQ160','AQ161','AQ162','AQ170'))
    field_information['GGDM 3.0']['TransportationGroundPntExt']['ADR'] = ('String',('AN060'))
    field_information['GGDM 3.0']['TransportationGroundPntExt']['AOO'] = ('Real',('AN060'))
    field_information['GGDM 3.0']['TransportationGroundPntExt']['ARA'] = ('Real',('AN060'))
    field_information['GGDM 3.0']['TransportationGroundPntExt']['BEN'] = ('StructuredText',('AN060','ZB036'))
    field_information['GGDM 3.0']['TransportationGroundPntExt']['CAA'] = ('Enumeration',('AN060'))
    field_information['GGDM 3.0']['TransportationGroundPntExt']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['TransportationGroundPntExt']['EnumeratedIndexValues']['CAA']['AN060']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['TransportationGroundPntExt']['CNCP'] = ('StructuredText',('AN060'))
    field_information['GGDM 3.0']['TransportationGroundPntExt']['COS'] = ('Enumeration',('AN060'))
    field_information['GGDM 3.0']['TransportationGroundPntExt']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['TransportationGroundPntExt']['EnumeratedIndexValues']['COS']['AN060']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['TransportationGroundPntExt']['CTL'] = ('Real',('AN060'))
    field_information['GGDM 3.0']['TransportationGroundPntExt']['F_CODE'] = ('CONSTRAINED_STRING',('AN060','ZB036'))
    field_information['GGDM 3.0']['TransportationGroundPntExt']['FFN'] = ('Enumeration',('AN060'))
    field_information['GGDM 3.0']['TransportationGroundPntExt']['EnumeratedIndexValues']['FFN'] = {}
    field_information['GGDM 3.0']['TransportationGroundPntExt']['EnumeratedIndexValues']['FFN']['AN060']  = (-999999,304,342,482,484,490,530,999)
    field_information['GGDM 3.0']['TransportationGroundPntExt']['FFN2'] = ('Enumeration',('AN060'))
    field_information['GGDM 3.0']['TransportationGroundPntExt']['EnumeratedIndexValues']['FFN2'] = {}
    field_information['GGDM 3.0']['TransportationGroundPntExt']['EnumeratedIndexValues']['FFN2']['AN060']  = (-999999,304,342,482,484,490,530,999)
    field_information['GGDM 3.0']['TransportationGroundPntExt']['FFN3'] = ('Enumeration',('AN060'))
    field_information['GGDM 3.0']['TransportationGroundPntExt']['EnumeratedIndexValues']['FFN3'] = {}
    field_information['GGDM 3.0']['TransportationGroundPntExt']['EnumeratedIndexValues']['FFN3']['AN060']  = (-999999,304,342,482,484,490,530,999)
    field_information['GGDM 3.0']['TransportationGroundPntExt']['FUFI'] = ('StructuredText',('AN060','ZB036'))
    field_information['GGDM 3.0']['TransportationGroundPntExt']['FURL'] = ('StructuredText',('AN060','ZB036'))
    field_information['GGDM 3.0']['TransportationGroundPntExt']['GDBV'] = ('Enumeration',('AN060','ZB036'))
    field_information['GGDM 3.0']['TransportationGroundPntExt']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['TransportationGroundPntExt']['EnumeratedIndexValues']['GDBV']['AN060']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['TransportationGroundPntExt']['EnumeratedIndexValues']['GDBV']['ZB036']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['TransportationGroundPntExt']['HGT'] = ('Real',('AN060','ZB036'))
    field_information['GGDM 3.0']['TransportationGroundPntExt']['LMC'] = ('Boolean',('AN060'))
    field_information['GGDM 3.0']['TransportationGroundPntExt']['LTN'] = ('Integer',('AN060'))
    field_information['GGDM 3.0']['TransportationGroundPntExt']['LZN'] = ('Real',('AN060'))
    field_information['GGDM 3.0']['TransportationGroundPntExt']['MAN'] = ('Boolean',('ZB036'))
    field_information['GGDM 3.0']['TransportationGroundPntExt']['OTH'] = ('StructuredText',('AN060','ZB036'))
    field_information['GGDM 3.0']['TransportationGroundPntExt']['PCF'] = ('Enumeration',('AN060','ZB036'))
    field_information['GGDM 3.0']['TransportationGroundPntExt']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['TransportationGroundPntExt']['EnumeratedIndexValues']['PCF']['AN060']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['TransportationGroundPntExt']['EnumeratedIndexValues']['PCF']['ZB036']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['TransportationGroundPntExt']['TRS'] = ('Enumeration',('ZB036'))
    field_information['GGDM 3.0']['TransportationGroundPntExt']['EnumeratedIndexValues']['TRS'] = {}
    field_information['GGDM 3.0']['TransportationGroundPntExt']['EnumeratedIndexValues']['TRS']['ZB036']  = (-999999,5,7,9,12,13,17,999)
    field_information['GGDM 3.0']['TransportationGroundPntExt']['TRS2'] = ('Enumeration',('ZB036'))
    field_information['GGDM 3.0']['TransportationGroundPntExt']['EnumeratedIndexValues']['TRS2'] = {}
    field_information['GGDM 3.0']['TransportationGroundPntExt']['EnumeratedIndexValues']['TRS2']['ZB036']  = (-999999,5,7,9,12,13,17,999)
    field_information['GGDM 3.0']['TransportationGroundPntExt']['TRS3'] = ('Enumeration',('ZB036'))
    field_information['GGDM 3.0']['TransportationGroundPntExt']['EnumeratedIndexValues']['TRS3'] = {}
    field_information['GGDM 3.0']['TransportationGroundPntExt']['EnumeratedIndexValues']['TRS3']['ZB036']  = (-999999,5,7,9,12,13,17,999)
    field_information['GGDM 3.0']['TransportationGroundPntExt']['UFI'] = ('StructuredText',('AN060','ZB036'))
    field_information['GGDM 3.0']['TransportationGroundPntExt']['WID'] = ('Real',('AN060'))
    field_information['GGDM 3.0']['TransportationGroundPntExt']['ZI001_SDV'] = ('StructuredText',('AN060','ZB036'))
    field_information['GGDM 3.0']['TransportationGroundPntExt']['ZI001_SRT'] = ('Enumeration',('AN060','ZB036'))
    field_information['GGDM 3.0']['TransportationGroundPntExt']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['TransportationGroundPntExt']['EnumeratedIndexValues']['ZI001_SRT']['AN060']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['TransportationGroundPntExt']['EnumeratedIndexValues']['ZI001_SRT']['ZB036']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['TransportationGroundPntExt']['ZI002_UFI'] = ('StructuredText',('AN060','ZB036'))
    field_information['GGDM 3.0']['TransportationGroundPntExt']['ZI004_RCG'] = ('Enumeration',('AN060','ZB036'))
    field_information['GGDM 3.0']['TransportationGroundPntExt']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['TransportationGroundPntExt']['EnumeratedIndexValues']['ZI004_RCG']['AN060']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['TransportationGroundPntExt']['EnumeratedIndexValues']['ZI004_RCG']['ZB036']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['TransportationGroundPntExt']['ZI005_FNA'] = ('String',('AN060','ZB036'))
    field_information['GGDM 3.0']['TransportationGroundPntExt']['ZI005_GNT'] = ('Enumeration',('AN060','ZB036'))
    field_information['GGDM 3.0']['TransportationGroundPntExt']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['TransportationGroundPntExt']['EnumeratedIndexValues']['ZI005_GNT']['AN060']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['TransportationGroundPntExt']['EnumeratedIndexValues']['ZI005_GNT']['ZB036']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['TransportationGroundPntExt']['ZI005_NFN'] = ('String',('AN060','ZB036'))
    field_information['GGDM 3.0']['TransportationGroundPntExt']['ZI006_MEM'] = ('String',('AN060','ZB036'))
    field_information['GGDM 3.0']['TransportationGroundPntExt']['ZI017_GAW'] = ('Real',('AN060'))
    field_information['GGDM 3.0']['TransportationGroundPntExt']['ZI017_RGC'] = ('Enumeration',('AN060'))
    field_information['GGDM 3.0']['TransportationGroundPntExt']['EnumeratedIndexValues']['ZI017_RGC'] = {}
    field_information['GGDM 3.0']['TransportationGroundPntExt']['EnumeratedIndexValues']['ZI017_RGC']['AN060']  = (-999999,1,2,3)
    field_information['GGDM 3.0']['TransportationGroundPntExt']['ZI017_RRA'] = ('Enumeration',('AN060'))
    field_information['GGDM 3.0']['TransportationGroundPntExt']['EnumeratedIndexValues']['ZI017_RRA'] = {}
    field_information['GGDM 3.0']['TransportationGroundPntExt']['EnumeratedIndexValues']['ZI017_RRA']['AN060']  = (-999999,1,3,4,999)
    field_information['GGDM 3.0']['TransportationGroundPntExt']['ZI017_TRT'] = ('Enumeration',('AN060'))
    field_information['GGDM 3.0']['TransportationGroundPntExt']['EnumeratedIndexValues']['ZI017_TRT'] = {}
    field_information['GGDM 3.0']['TransportationGroundPntExt']['EnumeratedIndexValues']['ZI017_TRT']['AN060']  = (-999999,1,2,3,4,5,6,7,9,10,12,13,999)
    field_information['GGDM 3.0']['TransportationGroundPntExt']['ZI020_GE4'] = ('CodeList',('AN060','ZB036'))
    field_information['GGDM 3.0']['TransportationGroundPntExt']['ZI026_CTUC'] = ('Enumeration',('AN060','ZB036'))
    field_information['GGDM 3.0']['TransportationGroundPntExt']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['TransportationGroundPntExt']['EnumeratedIndexValues']['ZI026_CTUC']['AN060']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['TransportationGroundPntExt']['EnumeratedIndexValues']['ZI026_CTUC']['ZB036']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['TransportationGroundPntExt']['ZI026_CTUL'] = ('integer',('AN060','ZB036'))
    field_information['GGDM 3.0']['TransportationGroundPntExt']['ZI026_CTUU'] = ('integer',('AN060','ZB036'))
    field_information['GGDM 3.0']['TransportationGroundPntExt']['ZI031S_URI'] = ('StructuredText',('AN060','ZB036'))
    field_information['GGDM 3.0']['TransportationGroundPntExt']['ZI039S_UFI'] = ('StructuredText',('AN060','ZB036'))
    field_information['GGDM 3.0']['TransportationGroundPntExt']['ZSAX_RS0'] = ('CodeList',('AN060','ZB036'))
    field_information['GGDM 3.0']['TransportationGroundPntExt']['ZSAX_RX0'] = ('StructuredText',('AN060','ZB036'))
    field_information['GGDM 3.0']['TransportationGroundPntExt']['ZSAX_RX3'] = ('StructuredText',('AN060','ZB036'))
    field_information['GGDM 3.0']['TransportationGroundPntExt']['ZSAX_RX4'] = ('StructuredText',('AN060','ZB036'))
    field_information['GGDM 3.0']['TransportationGroundPntExt']['ZVH'] = ('Real',('AN060','ZB036'))
    field_information['GGDM 3.0']['TransportationGroundSrf']['ADR'] = ('String',('AN060','AN076','AQ125','AQ135','AQ140','AQ141','AQ170'))
    field_information['GGDM 3.0']['TransportationGroundSrf']['AOO'] = ('Real',('AL195','AL211','AN060','AN076','AQ040','AQ045','AQ050','AQ068','AQ125','AQ130','AQ135','AQ141','AQ151','AQ170'))
    field_information['GGDM 3.0']['TransportationGroundSrf']['ARA'] = ('Real',('AL195','AL211','AN060','AN075','AN076','AP030','AP055','AP056','AQ040','AQ045','AQ050','AQ056','AQ063','AQ068','AQ125','AQ130','AQ135','AQ140','AQ141','AQ151','AQ170','BH070'))
    field_information['GGDM 3.0']['TransportationGroundSrf']['ATB'] = ('Boolean',('AQ125'))
    field_information['GGDM 3.0']['TransportationGroundSrf']['AWP'] = ('Boolean',('AN076','AQ040','AQ050','AQ141'))
    field_information['GGDM 3.0']['TransportationGroundSrf']['BCC'] = ('Enumeration',('AQ040','AQ130'))
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['BCC'] = {}
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['BCC']['AQ040']  = (-999999,1,2,3)
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['BCC']['AQ130']  = (-999999,1,2,3)
    field_information['GGDM 3.0']['TransportationGroundSrf']['BEN'] = ('StructuredText',('AL195','AL211','AN060','AN075','AN076','AP030','AP055','AP056','AQ040','AQ045','AQ050','AQ056','AQ063','AQ068','AQ125','AQ130','AQ135','AQ140','AQ141','AQ151','AQ170','BH070'))
    field_information['GGDM 3.0']['TransportationGroundSrf']['BMC'] = ('Enumeration',('BH070'))
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['BMC'] = {}
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['BMC']['BH070']  = (-999999,1,2,3,4,5,6,7,9,14,15,18,999)
    field_information['GGDM 3.0']['TransportationGroundSrf']['BMC2'] = ('Enumeration',('BH070'))
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['BMC2'] = {}
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['BMC2']['BH070']  = (-999999,1,2,3,4,5,6,7,9,14,15,18,999)
    field_information['GGDM 3.0']['TransportationGroundSrf']['BMC3'] = ('Enumeration',('BH070'))
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['BMC3'] = {}
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['BMC3']['BH070']  = (-999999,1,2,3,4,5,6,7,9,14,15,18,999)
    field_information['GGDM 3.0']['TransportationGroundSrf']['BNF'] = ('Integer',('AQ141'))
    field_information['GGDM 3.0']['TransportationGroundSrf']['BOT'] = ('Enumeration',('AQ040','AQ045'))
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['BOT'] = {}
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['BOT']['AQ040']  = (-999999,4,10,11,12,14,15,16,17,999)
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['BOT']['AQ045']  = (-999999,4,10,11,12,14,15,16,17,999)
    field_information['GGDM 3.0']['TransportationGroundSrf']['BRN'] = ('String',('AQ040','AQ045','AQ050'))
    field_information['GGDM 3.0']['TransportationGroundSrf']['BSC'] = ('Enumeration',('AQ040','AQ045','AQ050'))
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['BSC'] = {}
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['BSC']['AQ040']  = (-999999,1,2,5,6,7,8,9,12,15,16,19,22,26,27,31,32,999)
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['BSC']['AQ045']  = (-999999,1,2,5,6,7,8,9,12,15,16,19,26,27,31,32,999)
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['BSC']['AQ050']  = (-999999,1,2,3,5,6,7,8,9,12,15,16,19,22,26,27,28,31,32,999)
    field_information['GGDM 3.0']['TransportationGroundSrf']['BSC2'] = ('Enumeration',('AQ040','AQ045'))
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['BSC2'] = {}
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['BSC2']['AQ040']  = (-999999,1,2,5,6,7,8,9,12,15,16,19,22,26,27,31,32,999)
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['BSC2']['AQ045']  = (-999999,1,2,5,6,7,8,9,12,15,16,19,26,27,31,32,999)
    field_information['GGDM 3.0']['TransportationGroundSrf']['BSC3'] = ('Enumeration',('AQ040','AQ045'))
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['BSC3'] = {}
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['BSC3']['AQ040']  = (-999999,1,2,5,6,7,8,9,12,15,16,19,22,26,27,31,32,999)
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['BSC3']['AQ045']  = (-999999,1,2,5,6,7,8,9,12,15,16,19,26,27,31,32,999)
    field_information['GGDM 3.0']['TransportationGroundSrf']['BSM'] = ('Boolean',('AQ040'))
    field_information['GGDM 3.0']['TransportationGroundSrf']['CAA'] = ('Enumeration',('AL211','AN060','AN076','AP030','AQ040','AQ063','AQ125','AQ130','AQ135','AQ140','AQ141','AQ151','AQ170'))
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['CAA']['AL211']  = (-999999,3,17,999)
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['CAA']['AN060']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['CAA']['AN076']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['CAA']['AP030']  = (-999999,3,4,5,6,7,16,17,999)
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['CAA']['AQ040']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['CAA']['AQ063']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['CAA']['AQ125']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['CAA']['AQ130']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['CAA']['AQ135']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['CAA']['AQ140']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['CAA']['AQ141']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['CAA']['AQ151']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['CAA']['AQ170']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['TransportationGroundSrf']['CIW'] = ('Boolean',('AP030','AP055','AQ130','AQ135','AQ140','BH070'))
    field_information['GGDM 3.0']['TransportationGroundSrf']['CNCP'] = ('StructuredText',('AL195','AL211','AN060','AN075','AN076','AP030','AQ040','AQ045','AQ063','AQ068','AQ125','AQ130','AQ135','AQ140','AQ141','AQ151','AQ170','BH070'))
    field_information['GGDM 3.0']['TransportationGroundSrf']['COS'] = ('Enumeration',('AL195','AL211','AN060','AN075','AN076','AP030','AQ040','AQ045','AQ063','AQ068','AQ125','AQ130','AQ135','AQ140','AQ141','AQ151','AQ170','BH070'))
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['COS']['AL195']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['COS']['AL211']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['COS']['AN060']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['COS']['AN075']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['COS']['AN076']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['COS']['AP030']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['COS']['AQ040']  = (-999999,2,4,6,9,13,14)
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['COS']['AQ045']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['COS']['AQ063']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['COS']['AQ068']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['COS']['AQ125']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['COS']['AQ130']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['COS']['AQ135']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['COS']['AQ140']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['COS']['AQ141']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['COS']['AQ151']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['COS']['AQ170']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['COS']['BH070']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['TransportationGroundSrf']['CSC'] = ('Enumeration',('AP056'))
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['CSC'] = {}
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['CSC']['AP056']  = (-999999,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['TransportationGroundSrf']['CSC2'] = ('Enumeration',('AP056'))
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['CSC2'] = {}
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['CSC2']['AP056']  = (-999999,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['TransportationGroundSrf']['CSC3'] = ('Enumeration',('AP056'))
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['CSC3'] = {}
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['CSC3']['AP056']  = (-999999,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['TransportationGroundSrf']['CTL'] = ('Real',('AN060'))
    field_information['GGDM 3.0']['TransportationGroundSrf']['CWT'] = ('Boolean',('AP030','AP055'))
    field_information['GGDM 3.0']['TransportationGroundSrf']['DEV'] = ('Integer',('AP030'))
    field_information['GGDM 3.0']['TransportationGroundSrf']['DGC'] = ('Enumeration',('AQ068'))
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['DGC'] = {}
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['DGC']['AQ068']  = (-999999,1,2,999)
    field_information['GGDM 3.0']['TransportationGroundSrf']['DZC'] = ('Integer',('AQ040','AQ130'))
    field_information['GGDM 3.0']['TransportationGroundSrf']['DZP'] = ('Real',('AQ130'))
    field_information['GGDM 3.0']['TransportationGroundSrf']['F_CODE'] = ('CONSTRAINED_STRING',('AL195','AL211','AN060','AN075','AN076','AP030','AP055','AP056','AQ040','AQ045','AQ050','AQ056','AQ063','AQ068','AQ125','AQ130','AQ135','AQ140','AQ141','AQ151','AQ170','BH070'))
    field_information['GGDM 3.0']['TransportationGroundSrf']['FCO'] = ('Enumeration',('AP030'))
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['FCO'] = {}
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['FCO']['AP030']  = (-999999,5,6,7)
    field_information['GGDM 3.0']['TransportationGroundSrf']['FFN'] = ('Enumeration',('AN060','AN076','AQ125','AQ135','AQ141','AQ170'))
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['FFN'] = {}
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['FFN']['AN060']  = (-999999,304,342,482,484,490,530,999)
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['FFN']['AN076']  = (-999999,342,490,530,999)
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['FFN']['AQ125']  = (-999999,382,481,482,483,484,489,490,491,494,495,500,505,507,508,520,525,530,535,537,538,539,540,551,570,572,573,775,833,841,842,847,970,999)
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['FFN']['AQ135']  = (-999999,382,466,470,488,570,572,612,970,999)
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['FFN']['AQ141']  = (-999999,343,470,483,495,530,535,761,847,970,999)
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['FFN']['AQ170']  = (-999999,343,382,466,470,970,999)
    field_information['GGDM 3.0']['TransportationGroundSrf']['FFN2'] = ('Enumeration',('AN060','AN076','AQ125','AQ135','AQ141','AQ170'))
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['FFN2'] = {}
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['FFN2']['AN060']  = (-999999,304,342,482,484,490,530,999)
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['FFN2']['AN076']  = (-999999,342,490,530,999)
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['FFN2']['AQ125']  = (-999999,382,481,482,483,484,489,490,491,494,495,500,505,507,508,520,525,530,535,537,538,539,540,551,570,572,573,775,833,841,842,847,970,999)
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['FFN2']['AQ135']  = (-999999,382,466,470,488,570,572,612,970,999)
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['FFN2']['AQ141']  = (-999999,343,470,483,495,530,535,761,847,970,999)
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['FFN2']['AQ170']  = (-999999,343,382,466,470,970,999)
    field_information['GGDM 3.0']['TransportationGroundSrf']['FFN3'] = ('Enumeration',('AN060','AN076','AQ125','AQ135','AQ141','AQ170'))
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['FFN3'] = {}
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['FFN3']['AN060']  = (-999999,304,342,482,484,490,530,999)
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['FFN3']['AN076']  = (-999999,342,490,530,999)
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['FFN3']['AQ125']  = (-999999,382,481,482,483,484,489,490,491,494,495,500,505,507,508,520,525,530,535,537,538,539,540,551,570,572,573,775,833,841,842,847,970,999)
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['FFN3']['AQ135']  = (-999999,382,466,470,488,570,572,612,970,999)
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['FFN3']['AQ141']  = (-999999,343,470,483,495,530,535,761,847,970,999)
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['FFN3']['AQ170']  = (-999999,343,382,466,470,970,999)
    field_information['GGDM 3.0']['TransportationGroundSrf']['FSC'] = ('Boolean',('AP030'))
    field_information['GGDM 3.0']['TransportationGroundSrf']['FUFI'] = ('StructuredText',('AL195','AL211','AN060','AN075','AN076','AP030','AP055','AP056','AQ040','AQ045','AQ050','AQ056','AQ063','AQ068','AQ125','AQ130','AQ135','AQ140','AQ141','AQ151','AQ170','BH070'))
    field_information['GGDM 3.0']['TransportationGroundSrf']['FURL'] = ('StructuredText',('AL195','AL211','AN060','AN075','AN076','AP030','AP055','AP056','AQ040','AQ045','AQ050','AQ056','AQ063','AQ068','AQ125','AQ130','AQ135','AQ140','AQ141','AQ151','AQ170','BH070'))
    field_information['GGDM 3.0']['TransportationGroundSrf']['GDBV'] = ('Enumeration',('AL195','AL211','AN060','AN075','AN076','AP030','AP055','AP056','AQ040','AQ045','AQ050','AQ056','AQ063','AQ068','AQ125','AQ130','AQ135','AQ140','AQ141','AQ151','AQ170','BH070'))
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['GDBV']['AL195']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['GDBV']['AL211']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['GDBV']['AN060']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['GDBV']['AN075']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['GDBV']['AN076']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['GDBV']['AP030']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['GDBV']['AP055']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['GDBV']['AP056']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['GDBV']['AQ040']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['GDBV']['AQ045']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['GDBV']['AQ050']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['GDBV']['AQ056']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['GDBV']['AQ063']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['GDBV']['AQ068']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['GDBV']['AQ125']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['GDBV']['AQ130']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['GDBV']['AQ135']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['GDBV']['AQ140']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['GDBV']['AQ141']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['GDBV']['AQ151']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['GDBV']['AQ170']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['GDBV']['BH070']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['TransportationGroundSrf']['HCA'] = ('Real',('AL211','AQ040','AQ130'))
    field_information['GGDM 3.0']['TransportationGroundSrf']['HEI'] = ('Real',('AQ050'))
    field_information['GGDM 3.0']['TransportationGroundSrf']['HGT'] = ('Real',('AL211','AN060','AN076','AQ040','AQ045','AQ050','AQ056','AQ063','AQ125','AQ130','AQ135','AQ141','AQ151','AQ170'))
    field_information['GGDM 3.0']['TransportationGroundSrf']['HST'] = ('Enumeration',('AQ125','AQ130'))
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['HST'] = {}
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['HST']['AQ125']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['HST']['AQ130']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['TransportationGroundSrf']['HST2'] = ('Enumeration',('AQ125','AQ130'))
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['HST2'] = {}
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['HST2']['AQ125']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['HST2']['AQ130']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['TransportationGroundSrf']['HST3'] = ('Enumeration',('AQ125','AQ130'))
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['HST3'] = {}
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['HST3']['AQ125']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['HST3']['AQ130']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['TransportationGroundSrf']['LC1'] = ('Integer',('AQ040','AQ045'))
    field_information['GGDM 3.0']['TransportationGroundSrf']['LC2'] = ('Integer',('AQ040','AQ045'))
    field_information['GGDM 3.0']['TransportationGroundSrf']['LC3'] = ('Integer',('AQ040','AQ045'))
    field_information['GGDM 3.0']['TransportationGroundSrf']['LC4'] = ('Integer',('AQ040','AQ045'))
    field_information['GGDM 3.0']['TransportationGroundSrf']['LEA'] = ('Real',('AQ130'))
    field_information['GGDM 3.0']['TransportationGroundSrf']['LMC'] = ('Boolean',('AL211','AN060','AN075','AN076','AQ040','AQ050','AQ056','AQ063','AQ125','AQ135','AQ140','AQ141','AQ151','AQ170'))
    field_information['GGDM 3.0']['TransportationGroundSrf']['LOC'] = ('Enumeration',('AP030'))
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['LOC'] = {}
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['LOC']['AP030']  = (-999999,17,40,44)
    field_information['GGDM 3.0']['TransportationGroundSrf']['LTN'] = ('Integer',('AN060','AP030'))
    field_information['GGDM 3.0']['TransportationGroundSrf']['LUN'] = ('Boolean',('AQ125','AQ141'))
    field_information['GGDM 3.0']['TransportationGroundSrf']['LZN'] = ('Real',('AL195','AL211','AN060','AN075','AN076','AP030','AP055','AP056','AQ040','AQ045','AQ050','AQ056','AQ063','AQ068','AQ125','AQ130','AQ135','AQ140','AQ141','AQ151','AQ170','BH070'))
    field_information['GGDM 3.0']['TransportationGroundSrf']['MCC'] = ('Enumeration',('AQ063'))
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['MCC'] = {}
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['MCC']['AQ063']  = (-999999,8,46,52,55,62,64,65,84,86,88,104,117,999)
    field_information['GGDM 3.0']['TransportationGroundSrf']['MCC2'] = ('Enumeration',('AQ063'))
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['MCC2'] = {}
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['MCC2']['AQ063']  = (-999999,8,46,52,55,62,64,65,84,86,88,104,117,999)
    field_information['GGDM 3.0']['TransportationGroundSrf']['MCC3'] = ('Enumeration',('AQ063'))
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['MCC3'] = {}
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['MCC3']['AQ063']  = (-999999,8,46,52,55,62,64,65,84,86,88,104,117,999)
    field_information['GGDM 3.0']['TransportationGroundSrf']['MES'] = ('Boolean',('AP030'))
    field_information['GGDM 3.0']['TransportationGroundSrf']['MUB'] = ('Boolean',('AQ125'))
    field_information['GGDM 3.0']['TransportationGroundSrf']['MWG'] = ('Real',('AP030'))
    field_information['GGDM 3.0']['TransportationGroundSrf']['NOS'] = ('Integer',('AQ040'))
    field_information['GGDM 3.0']['TransportationGroundSrf']['OHC'] = ('Real',('AL211','AQ040','AQ045','AQ130'))
    field_information['GGDM 3.0']['TransportationGroundSrf']['ONE'] = ('Boolean',('AP030'))
    field_information['GGDM 3.0']['TransportationGroundSrf']['OTH'] = ('StructuredText',('AL195','AL211','AN060','AN075','AN076','AP030','AP055','AP056','AQ040','AQ045','AQ050','AQ056','AQ063','AQ068','AQ125','AQ130','AQ135','AQ140','AQ141','AQ151','AQ170','BH070'))
    field_information['GGDM 3.0']['TransportationGroundSrf']['PCF'] = ('Enumeration',('AL195','AL211','AN060','AN075','AN076','AP030','AP055','AP056','AQ040','AQ045','AQ050','AQ056','AQ063','AQ068','AQ125','AQ130','AQ135','AQ140','AQ141','AQ151','AQ170','BH070'))
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['PCF']['AL195']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['PCF']['AL211']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['PCF']['AN060']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['PCF']['AN075']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['PCF']['AN076']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['PCF']['AP030']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['PCF']['AP055']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['PCF']['AP056']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['PCF']['AQ040']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['PCF']['AQ045']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['PCF']['AQ050']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['PCF']['AQ056']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['PCF']['AQ063']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['PCF']['AQ068']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['PCF']['AQ125']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['PCF']['AQ130']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['PCF']['AQ135']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['PCF']['AQ140']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['PCF']['AQ141']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['PCF']['AQ151']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['PCF']['AQ170']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['PCF']['BH070']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['TransportationGroundSrf']['PSN'] = ('Real',('AP030','AP055'))
    field_information['GGDM 3.0']['TransportationGroundSrf']['PTG'] = ('Boolean',('AP030'))
    field_information['GGDM 3.0']['TransportationGroundSrf']['RFD'] = ('Boolean',('AQ040'))
    field_information['GGDM 3.0']['TransportationGroundSrf']['RIN_ROI'] = ('Enumeration',('AP030'))
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['RIN_ROI'] = {}
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['RIN_ROI']['AP030']  = (-999999,1,2,3,4,5,999)
    field_information['GGDM 3.0']['TransportationGroundSrf']['RIN_ROI2'] = ('Enumeration',('AP030'))
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['RIN_ROI2'] = {}
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['RIN_ROI2']['AP030']  = (-999999,1,2,3,4,5,999)
    field_information['GGDM 3.0']['TransportationGroundSrf']['RIN_ROI3'] = ('Enumeration',('AP030'))
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['RIN_ROI3'] = {}
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['RIN_ROI3']['AP030']  = (-999999,1,2,3,4,5,999)
    field_information['GGDM 3.0']['TransportationGroundSrf']['RIN_RTN'] = ('String',('AP030'))
    field_information['GGDM 3.0']['TransportationGroundSrf']['RIN_RTN2'] = ('String',('AP030'))
    field_information['GGDM 3.0']['TransportationGroundSrf']['RIN_RTN3'] = ('String',('AP030'))
    field_information['GGDM 3.0']['TransportationGroundSrf']['RLE'] = ('Enumeration',('AP030','AP055'))
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['RLE'] = {}
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['RLE']['AP030']  = (-999999,1,2,3,998)
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['RLE']['AP055']  = (-999999,1,2,3)
    field_information['GGDM 3.0']['TransportationGroundSrf']['RMWC'] = ('Enumeration',('AP030'))
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['RMWC'] = {}
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['RMWC']['AP030']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['TransportationGroundSrf']['RMWL'] = ('real',('AP030'))
    field_information['GGDM 3.0']['TransportationGroundSrf']['RMWU'] = ('real',('AP030'))
    field_information['GGDM 3.0']['TransportationGroundSrf']['ROR'] = ('Boolean',('AP030'))
    field_information['GGDM 3.0']['TransportationGroundSrf']['RTN'] = ('String',('AP055'))
    field_information['GGDM 3.0']['TransportationGroundSrf']['RTN2'] = ('String',('AP055'))
    field_information['GGDM 3.0']['TransportationGroundSrf']['RTN3'] = ('String',('AP055'))
    field_information['GGDM 3.0']['TransportationGroundSrf']['RTY'] = ('Enumeration',('AP030'))
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['RTY'] = {}
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['RTY']['AP030']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['TransportationGroundSrf']['SBB'] = ('Boolean',('AP030','AP055'))
    field_information['GGDM 3.0']['TransportationGroundSrf']['SEP'] = ('Boolean',('AP030'))
    field_information['GGDM 3.0']['TransportationGroundSrf']['SGCC'] = ('Enumeration',('AP030','AQ063'))
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['SGCC'] = {}
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['SGCC']['AP030']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['SGCC']['AQ063']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['TransportationGroundSrf']['SGCL'] = ('real',('AP030','AQ063'))
    field_information['GGDM 3.0']['TransportationGroundSrf']['SGCU'] = ('real',('AP030','AQ063'))
    field_information['GGDM 3.0']['TransportationGroundSrf']['SPD'] = ('Real',('AP030','AP055'))
    field_information['GGDM 3.0']['TransportationGroundSrf']['SPM'] = ('Real',('AP030','AP055'))
    field_information['GGDM 3.0']['TransportationGroundSrf']['SPT'] = ('Boolean',('AQ125'))
    field_information['GGDM 3.0']['TransportationGroundSrf']['SSR'] = ('Enumeration',('AN076','AQ125','AQ141','AQ170'))
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['SSR'] = {}
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['SSR']['AN076']  = (-999999,6,7,38,40,41,42,47,50,55,64,999)
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['SSR']['AQ125']  = (-999999,6,7,38,40,41,42,47,50,55,64,999)
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['SSR']['AQ141']  = (-999999,6,7,38,40,41,42,47,50,55,64,999)
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['SSR']['AQ170']  = (-999999,6,7,38,40,41,42,47,50,55,64,999)
    field_information['GGDM 3.0']['TransportationGroundSrf']['SSR2'] = ('Enumeration',('AN076','AQ125','AQ141','AQ170'))
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['SSR2'] = {}
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['SSR2']['AN076']  = (-999999,6,7,38,40,41,42,47,50,55,64,999)
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['SSR2']['AQ125']  = (-999999,6,7,38,40,41,42,47,50,55,64,999)
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['SSR2']['AQ141']  = (-999999,6,7,38,40,41,42,47,50,55,64,999)
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['SSR2']['AQ170']  = (-999999,6,7,38,40,41,42,47,50,55,64,999)
    field_information['GGDM 3.0']['TransportationGroundSrf']['SSR3'] = ('Enumeration',('AN076','AQ125','AQ141','AQ170'))
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['SSR3'] = {}
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['SSR3']['AN076']  = (-999999,6,7,38,40,41,42,47,50,55,64,999)
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['SSR3']['AQ125']  = (-999999,6,7,38,40,41,42,47,50,55,64,999)
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['SSR3']['AQ141']  = (-999999,6,7,38,40,41,42,47,50,55,64,999)
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['SSR3']['AQ170']  = (-999999,6,7,38,40,41,42,47,50,55,64,999)
    field_information['GGDM 3.0']['TransportationGroundSrf']['THR'] = ('Boolean',('AP030'))
    field_information['GGDM 3.0']['TransportationGroundSrf']['TRA'] = ('Boolean',('AQ130'))
    field_information['GGDM 3.0']['TransportationGroundSrf']['TRP'] = ('Enumeration',('AL211'))
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['TRP'] = {}
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['TRP']['AL211']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['TransportationGroundSrf']['TRS'] = ('Enumeration',('AL211','AP056','AQ040','AQ063','AQ068','AQ125','AQ130','BH070'))
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['TRS'] = {}
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['TRS']['AL211']  = (-999999,5,12,13,999)
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['TRS']['AP056']  = (-999999,5,12,13,999)
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['TRS']['AQ040']  = (-999999,2,5,9,10,12,13,20,25,999)
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['TRS']['AQ063']  = (-999999,2,5,9,10,12,13,999)
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['TRS']['AQ068']  = (-999999,5,9,12,13,16,999)
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['TRS']['AQ125']  = (-999999,2,5,7,8,9,12,13,17,20,999)
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['TRS']['AQ130']  = (-999999,2,5,8,9,10,12,13,16,20,999)
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['TRS']['BH070']  = (-999999,9,13,18,23,999)
    field_information['GGDM 3.0']['TransportationGroundSrf']['TRS2'] = ('Enumeration',('AL211','AP056','AQ040','AQ063','AQ068','AQ125','AQ130','BH070'))
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['TRS2'] = {}
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['TRS2']['AL211']  = (-999999,5,12,13,999)
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['TRS2']['AP056']  = (-999999,5,12,13,999)
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['TRS2']['AQ040']  = (-999999,2,5,9,10,12,13,20,25,999)
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['TRS2']['AQ063']  = (-999999,2,5,9,10,12,13,999)
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['TRS2']['AQ068']  = (-999999,5,9,12,13,16,999)
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['TRS2']['AQ125']  = (-999999,2,5,7,8,9,12,13,17,20,999)
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['TRS2']['AQ130']  = (-999999,2,5,8,9,10,12,13,16,20,999)
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['TRS2']['BH070']  = (-999999,9,13,18,23,999)
    field_information['GGDM 3.0']['TransportationGroundSrf']['TRS3'] = ('Enumeration',('AL211','AP056','AQ040','AQ063','AQ068','AQ125','AQ130','BH070'))
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['TRS3'] = {}
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['TRS3']['AL211']  = (-999999,5,12,13,999)
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['TRS3']['AP056']  = (-999999,5,12,13,999)
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['TRS3']['AQ040']  = (-999999,2,5,9,10,12,13,20,25,999)
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['TRS3']['AQ063']  = (-999999,2,5,9,10,12,13,999)
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['TRS3']['AQ068']  = (-999999,5,9,12,13,16,999)
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['TRS3']['AQ125']  = (-999999,2,5,7,8,9,12,13,17,20,999)
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['TRS3']['AQ130']  = (-999999,2,5,8,9,10,12,13,16,20,999)
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['TRS3']['BH070']  = (-999999,9,13,18,23,999)
    field_information['GGDM 3.0']['TransportationGroundSrf']['UBC'] = ('Real',('AQ040'))
    field_information['GGDM 3.0']['TransportationGroundSrf']['UFI'] = ('StructuredText',('AL195','AL211','AN060','AN075','AN076','AP030','AP055','AP056','AQ040','AQ045','AQ050','AQ056','AQ063','AQ068','AQ125','AQ130','AQ135','AQ140','AQ141','AQ151','AQ170','BH070'))
    field_information['GGDM 3.0']['TransportationGroundSrf']['VCM'] = ('Enumeration',('AN076','AQ040','AQ045'))
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['VCM'] = {}
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['VCM']['AN076']  = (-999999,1,4,8,12,13,15,18,999)
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['VCM']['AQ040']  = (-999999,2,3,4,7,8,9,12,13,15,16,17,18,999)
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['VCM']['AQ045']  = (-999999,2,3,4,7,8,9,12,13,15,16,17,18,999)
    field_information['GGDM 3.0']['TransportationGroundSrf']['VCM2'] = ('Enumeration',('AN076','AQ040','AQ045'))
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['VCM2'] = {}
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['VCM2']['AN076']  = (-999999,1,4,8,12,13,15,18,999)
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['VCM2']['AQ040']  = (-999999,2,3,4,7,8,9,12,13,15,16,17,18,999)
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['VCM2']['AQ045']  = (-999999,2,3,4,7,8,9,12,13,15,16,17,18,999)
    field_information['GGDM 3.0']['TransportationGroundSrf']['VCM3'] = ('Enumeration',('AN076','AQ040','AQ045'))
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['VCM3'] = {}
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['VCM3']['AN076']  = (-999999,1,4,8,12,13,15,18,999)
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['VCM3']['AQ040']  = (-999999,2,3,4,7,8,9,12,13,15,16,17,18,999)
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['VCM3']['AQ045']  = (-999999,2,3,4,7,8,9,12,13,15,16,17,18,999)
    field_information['GGDM 3.0']['TransportationGroundSrf']['VCO'] = ('Real',('AQ040','AQ045'))
    field_information['GGDM 3.0']['TransportationGroundSrf']['VCS'] = ('Real',('AQ040'))
    field_information['GGDM 3.0']['TransportationGroundSrf']['VCS_VCD'] = ('Enumeration',('AQ040'))
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['VCS_VCD'] = {}
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['VCS_VCD']['AQ040']  = (-999999,7,9,10,15,24,28,30,999)
    field_information['GGDM 3.0']['TransportationGroundSrf']['VCS_VCR'] = ('String',('AQ040'))
    field_information['GGDM 3.0']['TransportationGroundSrf']['VET'] = ('Enumeration',('AQ140'))
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['VET'] = {}
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['VET']['AQ140']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['TransportationGroundSrf']['VOI'] = ('StructuredText',('AN076','AQ040','AQ050','AQ141'))
    field_information['GGDM 3.0']['TransportationGroundSrf']['WBD'] = ('Real',('BH070'))
    field_information['GGDM 3.0']['TransportationGroundSrf']['WD2'] = ('Real',('AP030','AQ130'))
    field_information['GGDM 3.0']['TransportationGroundSrf']['WID'] = ('Real',('AL195','AL211','AN060','AN075','AN076','AP030','AP055','AP056','AQ040','AQ045','AQ050','AQ056','AQ063','AQ068','AQ125','AQ130','AQ135','AQ140','AQ141','AQ151','AQ170','BH070'))
    field_information['GGDM 3.0']['TransportationGroundSrf']['WLE'] = ('Enumeration',('AQ063'))
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['WLE'] = {}
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['WLE']['AQ063']  = (-999999,1,2,3,4,5,999)
    field_information['GGDM 3.0']['TransportationGroundSrf']['WT2'] = ('Real',('AP030'))
    field_information['GGDM 3.0']['TransportationGroundSrf']['WVA'] = ('Real',('BH070'))
    field_information['GGDM 3.0']['TransportationGroundSrf']['ZI001_SDV'] = ('StructuredText',('AL195','AL211','AN060','AN075','AN076','AP030','AP055','AP056','AQ040','AQ045','AQ050','AQ056','AQ063','AQ068','AQ125','AQ130','AQ135','AQ140','AQ141','AQ151','AQ170','BH070'))
    field_information['GGDM 3.0']['TransportationGroundSrf']['ZI001_SRT'] = ('Enumeration',('AL195','AL211','AN060','AN075','AN076','AP030','AP055','AP056','AQ040','AQ045','AQ050','AQ056','AQ063','AQ068','AQ125','AQ130','AQ135','AQ140','AQ141','AQ151','AQ170','BH070'))
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['ZI001_SRT']['AL195']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['ZI001_SRT']['AL211']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['ZI001_SRT']['AN060']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['ZI001_SRT']['AN075']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['ZI001_SRT']['AN076']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['ZI001_SRT']['AP030']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['ZI001_SRT']['AP055']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['ZI001_SRT']['AP056']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['ZI001_SRT']['AQ040']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['ZI001_SRT']['AQ045']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['ZI001_SRT']['AQ050']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['ZI001_SRT']['AQ056']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['ZI001_SRT']['AQ063']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['ZI001_SRT']['AQ068']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['ZI001_SRT']['AQ125']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['ZI001_SRT']['AQ130']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['ZI001_SRT']['AQ135']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['ZI001_SRT']['AQ140']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['ZI001_SRT']['AQ141']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['ZI001_SRT']['AQ151']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['ZI001_SRT']['AQ170']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['ZI001_SRT']['BH070']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['TransportationGroundSrf']['ZI002_UFI'] = ('StructuredText',('AL195','AL211','AN060','AN075','AN076','AP030','AP055','AP056','AQ040','AQ045','AQ050','AQ056','AQ063','AQ068','AQ125','AQ130','AQ135','AQ140','AQ141','AQ151','AQ170','BH070'))
    field_information['GGDM 3.0']['TransportationGroundSrf']['ZI004_RCG'] = ('Enumeration',('AL195','AL211','AN060','AN075','AN076','AP030','AP055','AP056','AQ040','AQ045','AQ050','AQ056','AQ063','AQ068','AQ125','AQ130','AQ135','AQ140','AQ141','AQ151','AQ170','BH070'))
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['ZI004_RCG']['AL195']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['ZI004_RCG']['AL211']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['ZI004_RCG']['AN060']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['ZI004_RCG']['AN075']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['ZI004_RCG']['AN076']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['ZI004_RCG']['AP030']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['ZI004_RCG']['AP055']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['ZI004_RCG']['AP056']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['ZI004_RCG']['AQ040']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['ZI004_RCG']['AQ045']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['ZI004_RCG']['AQ050']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['ZI004_RCG']['AQ056']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['ZI004_RCG']['AQ063']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['ZI004_RCG']['AQ068']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['ZI004_RCG']['AQ125']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['ZI004_RCG']['AQ130']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['ZI004_RCG']['AQ135']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['ZI004_RCG']['AQ140']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['ZI004_RCG']['AQ141']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['ZI004_RCG']['AQ151']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['ZI004_RCG']['AQ170']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['ZI004_RCG']['BH070']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['TransportationGroundSrf']['ZI005_FNA'] = ('String',('AL195','AN060','AN075','AN076','AP030','AP055','AP056','AQ040','AQ045','AQ056','AQ063','AQ125','AQ130','AQ135','AQ140','AQ141','AQ151','AQ170','BH070'))
    field_information['GGDM 3.0']['TransportationGroundSrf']['ZI005_GNT'] = ('Enumeration',('AL195','AN060','AN075','AN076','AP030','AQ040','AQ045','AQ056','AQ063','AQ125','AQ130','AQ135','AQ140','AQ141','AQ151','AQ170','BH070'))
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['ZI005_GNT']['AL195']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['ZI005_GNT']['AN060']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['ZI005_GNT']['AN075']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['ZI005_GNT']['AN076']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['ZI005_GNT']['AP030']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['ZI005_GNT']['AQ040']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['ZI005_GNT']['AQ045']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['ZI005_GNT']['AQ056']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['ZI005_GNT']['AQ063']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['ZI005_GNT']['AQ125']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['ZI005_GNT']['AQ130']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['ZI005_GNT']['AQ135']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['ZI005_GNT']['AQ140']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['ZI005_GNT']['AQ141']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['ZI005_GNT']['AQ151']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['ZI005_GNT']['AQ170']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['ZI005_GNT']['BH070']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['TransportationGroundSrf']['ZI005_NFN'] = ('String',('AL195','AN060','AN075','AN076','AP030','AP055','AP056','AQ040','AQ045','AQ056','AQ063','AQ125','AQ130','AQ135','AQ140','AQ141','AQ151','AQ170','BH070'))
    field_information['GGDM 3.0']['TransportationGroundSrf']['ZI006_MEM'] = ('String',('AL195','AL211','AN060','AN075','AN076','AP030','AP055','AP056','AQ040','AQ045','AQ050','AQ056','AQ063','AQ068','AQ125','AQ130','AQ135','AQ140','AQ141','AQ151','AQ170','BH070'))
    field_information['GGDM 3.0']['TransportationGroundSrf']['ZI016_ROC'] = ('Enumeration',('AP030','AP055','AQ135','AQ140','BH070'))
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['ZI016_ROC'] = {}
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['ZI016_ROC']['AP030']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,999)
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['ZI016_ROC']['AP055']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,999)
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['ZI016_ROC']['AQ135']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,999)
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['ZI016_ROC']['AQ140']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,999)
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['ZI016_ROC']['BH070']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,999)
    field_information['GGDM 3.0']['TransportationGroundSrf']['ZI016_WD1'] = ('Real',('AP030'))
    field_information['GGDM 3.0']['TransportationGroundSrf']['ZI016_WTC'] = ('Enumeration',('AP030'))
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['ZI016_WTC'] = {}
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['ZI016_WTC']['AP030']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['TransportationGroundSrf']['ZI017_GAW'] = ('Real',('AN060','AN075','AN076'))
    field_information['GGDM 3.0']['TransportationGroundSrf']['ZI017_RGC'] = ('Enumeration',('AN060','AN075','AN076'))
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['ZI017_RGC'] = {}
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['ZI017_RGC']['AN060']  = (-999999,1,2,3)
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['ZI017_RGC']['AN075']  = (-999999,1,2,3)
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['ZI017_RGC']['AN076']  = (-999999,1,2,3)
    field_information['GGDM 3.0']['TransportationGroundSrf']['ZI017_RRA'] = ('Enumeration',('AN060','AN075','AN076'))
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['ZI017_RRA'] = {}
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['ZI017_RRA']['AN060']  = (-999999,1,3,4,999)
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['ZI017_RRA']['AN075']  = (-999999,1,3,4,999)
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['ZI017_RRA']['AN076']  = (-999999,1,3,4,999)
    field_information['GGDM 3.0']['TransportationGroundSrf']['ZI017_TRT'] = ('Enumeration',('AN060','AN075','AN076'))
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['ZI017_TRT'] = {}
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['ZI017_TRT']['AN060']  = (-999999,1,2,3,4,5,6,7,9,10,12,13,999)
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['ZI017_TRT']['AN075']  = (-999999,1,2,3,4,5,6,7,9,10,12,13,999)
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['ZI017_TRT']['AN076']  = (-999999,1,2,3,4,5,6,7,9,10,12,13,999)
    field_information['GGDM 3.0']['TransportationGroundSrf']['ZI020_GE4'] = ('CodeList',('AL195','AL211','AN060','AN075','AN076','AP030','AP055','AP056','AQ040','AQ045','AQ050','AQ056','AQ063','AQ068','AQ125','AQ130','AQ135','AQ140','AQ141','AQ151','AQ170','BH070'))
    field_information['GGDM 3.0']['TransportationGroundSrf']['ZI025_HDP'] = ('Real',('AQ130'))
    field_information['GGDM 3.0']['TransportationGroundSrf']['ZI026_CTUC'] = ('Enumeration',('AL195','AL211','AN060','AN075','AN076','AP030','AP055','AP056','AQ040','AQ045','AQ050','AQ056','AQ063','AQ068','AQ125','AQ130','AQ135','AQ140','AQ141','AQ151','AQ170','BH070'))
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['ZI026_CTUC']['AL195']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['ZI026_CTUC']['AL211']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['ZI026_CTUC']['AN060']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['ZI026_CTUC']['AN075']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['ZI026_CTUC']['AN076']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['ZI026_CTUC']['AP030']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['ZI026_CTUC']['AP055']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['ZI026_CTUC']['AP056']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['ZI026_CTUC']['AQ040']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['ZI026_CTUC']['AQ045']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['ZI026_CTUC']['AQ050']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['ZI026_CTUC']['AQ056']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['ZI026_CTUC']['AQ063']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['ZI026_CTUC']['AQ068']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['ZI026_CTUC']['AQ125']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['ZI026_CTUC']['AQ130']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['ZI026_CTUC']['AQ135']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['ZI026_CTUC']['AQ140']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['ZI026_CTUC']['AQ141']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['ZI026_CTUC']['AQ151']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['ZI026_CTUC']['AQ170']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['ZI026_CTUC']['BH070']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['TransportationGroundSrf']['ZI026_CTUL'] = ('integer',('AL195','AL211','AN060','AN075','AN076','AP030','AP055','AP056','AQ040','AQ045','AQ050','AQ056','AQ063','AQ068','AQ125','AQ130','AQ135','AQ140','AQ141','AQ151','AQ170','BH070'))
    field_information['GGDM 3.0']['TransportationGroundSrf']['ZI026_CTUU'] = ('integer',('AL195','AL211','AN060','AN075','AN076','AP030','AP055','AP056','AQ040','AQ045','AQ050','AQ056','AQ063','AQ068','AQ125','AQ130','AQ135','AQ140','AQ141','AQ151','AQ170','BH070'))
    field_information['GGDM 3.0']['TransportationGroundSrf']['ZI026_SUR'] = ('Enumeration',('AP030'))
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['ZI026_SUR'] = {}
    field_information['GGDM 3.0']['TransportationGroundSrf']['EnumeratedIndexValues']['ZI026_SUR']['AP030']  = (-999999,1,2,3)
    field_information['GGDM 3.0']['TransportationGroundSrf']['ZI031S_URI'] = ('StructuredText',('AL195','AL211','AN060','AN075','AN076','AP030','AP055','AP056','AQ040','AQ045','AQ050','AQ056','AQ063','AQ068','AQ125','AQ130','AQ135','AQ140','AQ141','AQ151','AQ170','BH070'))
    field_information['GGDM 3.0']['TransportationGroundSrf']['ZI039S_UFI'] = ('StructuredText',('AL195','AL211','AN060','AN075','AN076','AP030','AP055','AP056','AQ040','AQ045','AQ050','AQ056','AQ063','AQ068','AQ125','AQ130','AQ135','AQ140','AQ141','AQ151','AQ170','BH070'))
    field_information['GGDM 3.0']['TransportationGroundSrf']['ZSAX_RS0'] = ('CodeList',('AL195','AL211','AN060','AN075','AN076','AP030','AP055','AP056','AQ040','AQ045','AQ050','AQ056','AQ063','AQ068','AQ125','AQ130','AQ135','AQ140','AQ141','AQ151','AQ170','BH070'))
    field_information['GGDM 3.0']['TransportationGroundSrf']['ZSAX_RX0'] = ('StructuredText',('AL195','AL211','AN060','AN075','AN076','AP030','AP055','AP056','AQ040','AQ045','AQ050','AQ056','AQ063','AQ068','AQ125','AQ130','AQ135','AQ140','AQ141','AQ151','AQ170','BH070'))
    field_information['GGDM 3.0']['TransportationGroundSrf']['ZSAX_RX3'] = ('StructuredText',('AL195','AL211','AN060','AN075','AN076','AP030','AP055','AP056','AQ040','AQ045','AQ050','AQ056','AQ063','AQ068','AQ125','AQ130','AQ135','AQ140','AQ141','AQ151','AQ170','BH070'))
    field_information['GGDM 3.0']['TransportationGroundSrf']['ZSAX_RX4'] = ('StructuredText',('AL195','AL211','AN060','AN075','AN076','AP030','AP055','AP056','AQ040','AQ045','AQ050','AQ056','AQ063','AQ068','AQ125','AQ130','AQ135','AQ140','AQ141','AQ151','AQ170','BH070'))
    field_information['GGDM 3.0']['TransportationGroundSrf']['ZVH'] = ('Real',('AL211','AN060','AN076','AQ040','AQ045','AQ050','AQ056','AQ063','AQ125','AQ135','AQ141','AQ151','AQ170'))
    field_information['GGDM 3.0']['TransportationWaterAONExt']['ARA'] = ('Real',('NM020'))
    field_information['GGDM 3.0']['TransportationWaterAONExt']['BBMCA'] = ('Enumeration',('NM020'))
    field_information['GGDM 3.0']['TransportationWaterAONExt']['EnumeratedIndexValues']['BBMCA'] = {}
    field_information['GGDM 3.0']['TransportationWaterAONExt']['EnumeratedIndexValues']['BBMCA']['NM020']  = (-999999,1,2,3,4,5,6,7,8,9,11,14,15,16,17,18,999)
    field_information['GGDM 3.0']['TransportationWaterAONExt']['BBMCA2'] = ('Enumeration',('NM020'))
    field_information['GGDM 3.0']['TransportationWaterAONExt']['EnumeratedIndexValues']['BBMCA2'] = {}
    field_information['GGDM 3.0']['TransportationWaterAONExt']['EnumeratedIndexValues']['BBMCA2']['NM020']  = (-999999,1,2,3,4,5,6,7,8,9,11,14,15,16,17,18,999)
    field_information['GGDM 3.0']['TransportationWaterAONExt']['BBMCA3'] = ('Enumeration',('NM020'))
    field_information['GGDM 3.0']['TransportationWaterAONExt']['EnumeratedIndexValues']['BBMCA3'] = {}
    field_information['GGDM 3.0']['TransportationWaterAONExt']['EnumeratedIndexValues']['BBMCA3']['NM020']  = (-999999,1,2,3,4,5,6,7,8,9,11,14,15,16,17,18,999)
    field_information['GGDM 3.0']['TransportationWaterAONExt']['BBMCB'] = ('Enumeration',('NM020'))
    field_information['GGDM 3.0']['TransportationWaterAONExt']['EnumeratedIndexValues']['BBMCB'] = {}
    field_information['GGDM 3.0']['TransportationWaterAONExt']['EnumeratedIndexValues']['BBMCB']['NM020']  = (-999999,1,2,3,4,5,6,7,8,9,11,14,15,16,17,18,999)
    field_information['GGDM 3.0']['TransportationWaterAONExt']['BBMCB2'] = ('Enumeration',('NM020'))
    field_information['GGDM 3.0']['TransportationWaterAONExt']['EnumeratedIndexValues']['BBMCB2'] = {}
    field_information['GGDM 3.0']['TransportationWaterAONExt']['EnumeratedIndexValues']['BBMCB2']['NM020']  = (-999999,1,2,3,4,5,6,7,8,9,11,14,15,16,17,18,999)
    field_information['GGDM 3.0']['TransportationWaterAONExt']['BBMCB3'] = ('Enumeration',('NM020'))
    field_information['GGDM 3.0']['TransportationWaterAONExt']['EnumeratedIndexValues']['BBMCB3'] = {}
    field_information['GGDM 3.0']['TransportationWaterAONExt']['EnumeratedIndexValues']['BBMCB3']['NM020']  = (-999999,1,2,3,4,5,6,7,8,9,11,14,15,16,17,18,999)
    field_information['GGDM 3.0']['TransportationWaterAONExt']['BEN'] = ('StructuredText',('NM020'))
    field_information['GGDM 3.0']['TransportationWaterAONExt']['BH141_AWBA'] = ('Real',('NM020'))
    field_information['GGDM 3.0']['TransportationWaterAONExt']['BH141_AWBB'] = ('Real',('NM020'))
    field_information['GGDM 3.0']['TransportationWaterAONExt']['BH141_IBOA'] = ('Enumeration',('NM020'))
    field_information['GGDM 3.0']['TransportationWaterAONExt']['EnumeratedIndexValues']['BH141_IBOA'] = {}
    field_information['GGDM 3.0']['TransportationWaterAONExt']['EnumeratedIndexValues']['BH141_IBOA']['NM020']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['TransportationWaterAONExt']['BH141_IBOB'] = ('Enumeration',('NM020'))
    field_information['GGDM 3.0']['TransportationWaterAONExt']['EnumeratedIndexValues']['BH141_IBOB'] = {}
    field_information['GGDM 3.0']['TransportationWaterAONExt']['EnumeratedIndexValues']['BH141_IBOB']['NM020']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['TransportationWaterAONExt']['BH141_SHDA'] = ('Boolean',('NM020'))
    field_information['GGDM 3.0']['TransportationWaterAONExt']['BH141_SHDB'] = ('Boolean',('NM020'))
    field_information['GGDM 3.0']['TransportationWaterAONExt']['BH141_SLTA'] = ('Enumeration',('NM020'))
    field_information['GGDM 3.0']['TransportationWaterAONExt']['EnumeratedIndexValues']['BH141_SLTA'] = {}
    field_information['GGDM 3.0']['TransportationWaterAONExt']['EnumeratedIndexValues']['BH141_SLTA']['NM020']  = (-999999,6,8,10,11,12,13,14,17,18,999)
    field_information['GGDM 3.0']['TransportationWaterAONExt']['BH141_SLTB'] = ('Enumeration',('NM020'))
    field_information['GGDM 3.0']['TransportationWaterAONExt']['EnumeratedIndexValues']['BH141_SLTB'] = {}
    field_information['GGDM 3.0']['TransportationWaterAONExt']['EnumeratedIndexValues']['BH141_SLTB']['NM020']  = (-999999,6,8,10,11,12,13,14,17,18,999)
    field_information['GGDM 3.0']['TransportationWaterAONExt']['BH141_WBHA'] = ('Real',('NM020'))
    field_information['GGDM 3.0']['TransportationWaterAONExt']['BH141_WBHB'] = ('Real',('NM020'))
    field_information['GGDM 3.0']['TransportationWaterAONExt']['BMC'] = ('Enumeration',('NM020'))
    field_information['GGDM 3.0']['TransportationWaterAONExt']['EnumeratedIndexValues']['BMC'] = {}
    field_information['GGDM 3.0']['TransportationWaterAONExt']['EnumeratedIndexValues']['BMC']['NM020']  = (-999999,1,2,3,4,5,6,7,8,9,14,15,16,17,18,999)
    field_information['GGDM 3.0']['TransportationWaterAONExt']['BMC2'] = ('Enumeration',('NM020'))
    field_information['GGDM 3.0']['TransportationWaterAONExt']['EnumeratedIndexValues']['BMC2'] = {}
    field_information['GGDM 3.0']['TransportationWaterAONExt']['EnumeratedIndexValues']['BMC2']['NM020']  = (-999999,1,2,3,4,5,6,7,8,9,14,15,16,17,18,999)
    field_information['GGDM 3.0']['TransportationWaterAONExt']['BMC3'] = ('Enumeration',('NM020'))
    field_information['GGDM 3.0']['TransportationWaterAONExt']['EnumeratedIndexValues']['BMC3'] = {}
    field_information['GGDM 3.0']['TransportationWaterAONExt']['EnumeratedIndexValues']['BMC3']['NM020']  = (-999999,1,2,3,4,5,6,7,8,9,14,15,16,17,18,999)
    field_information['GGDM 3.0']['TransportationWaterAONExt']['BPWHAC'] = ('Enumeration',('NM020'))
    field_information['GGDM 3.0']['TransportationWaterAONExt']['EnumeratedIndexValues']['BPWHAC'] = {}
    field_information['GGDM 3.0']['TransportationWaterAONExt']['EnumeratedIndexValues']['BPWHAC']['NM020']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['TransportationWaterAONExt']['BPWHAL'] = ('real',('NM020'))
    field_information['GGDM 3.0']['TransportationWaterAONExt']['BPWHAU'] = ('real',('NM020'))
    field_information['GGDM 3.0']['TransportationWaterAONExt']['BPWHBC'] = ('Enumeration',('NM020'))
    field_information['GGDM 3.0']['TransportationWaterAONExt']['EnumeratedIndexValues']['BPWHBC'] = {}
    field_information['GGDM 3.0']['TransportationWaterAONExt']['EnumeratedIndexValues']['BPWHBC']['NM020']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['TransportationWaterAONExt']['BPWHBL'] = ('real',('NM020'))
    field_information['GGDM 3.0']['TransportationWaterAONExt']['BPWHBU'] = ('real',('NM020'))
    field_information['GGDM 3.0']['TransportationWaterAONExt']['BPWSAC'] = ('Enumeration',('NM020'))
    field_information['GGDM 3.0']['TransportationWaterAONExt']['EnumeratedIndexValues']['BPWSAC'] = {}
    field_information['GGDM 3.0']['TransportationWaterAONExt']['EnumeratedIndexValues']['BPWSAC']['NM020']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['TransportationWaterAONExt']['BPWSAL'] = ('real',('NM020'))
    field_information['GGDM 3.0']['TransportationWaterAONExt']['BPWSAU'] = ('real',('NM020'))
    field_information['GGDM 3.0']['TransportationWaterAONExt']['BPWSBC'] = ('Enumeration',('NM020'))
    field_information['GGDM 3.0']['TransportationWaterAONExt']['EnumeratedIndexValues']['BPWSBC'] = {}
    field_information['GGDM 3.0']['TransportationWaterAONExt']['EnumeratedIndexValues']['BPWSBC']['NM020']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['TransportationWaterAONExt']['BPWSBL'] = ('real',('NM020'))
    field_information['GGDM 3.0']['TransportationWaterAONExt']['BPWSBU'] = ('real',('NM020'))
    field_information['GGDM 3.0']['TransportationWaterAONExt']['BWVCAC'] = ('Enumeration',('NM020'))
    field_information['GGDM 3.0']['TransportationWaterAONExt']['EnumeratedIndexValues']['BWVCAC'] = {}
    field_information['GGDM 3.0']['TransportationWaterAONExt']['EnumeratedIndexValues']['BWVCAC']['NM020']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['TransportationWaterAONExt']['BWVCAL'] = ('real',('NM020'))
    field_information['GGDM 3.0']['TransportationWaterAONExt']['BWVCAU'] = ('real',('NM020'))
    field_information['GGDM 3.0']['TransportationWaterAONExt']['BWVCBC'] = ('Enumeration',('NM020'))
    field_information['GGDM 3.0']['TransportationWaterAONExt']['EnumeratedIndexValues']['BWVCBC'] = {}
    field_information['GGDM 3.0']['TransportationWaterAONExt']['EnumeratedIndexValues']['BWVCBC']['NM020']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['TransportationWaterAONExt']['BWVCBL'] = ('real',('NM020'))
    field_information['GGDM 3.0']['TransportationWaterAONExt']['BWVCBU'] = ('real',('NM020'))
    field_information['GGDM 3.0']['TransportationWaterAONExt']['CAA'] = ('Enumeration',('NM020'))
    field_information['GGDM 3.0']['TransportationWaterAONExt']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['TransportationWaterAONExt']['EnumeratedIndexValues']['CAA']['NM020']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['TransportationWaterAONExt']['CDA'] = ('Boolean',('NM020'))
    field_information['GGDM 3.0']['TransportationWaterAONExt']['CDL'] = ('Real',('NM020'))
    field_information['GGDM 3.0']['TransportationWaterAONExt']['CNCP'] = ('StructuredText',('NM020'))
    field_information['GGDM 3.0']['TransportationWaterAONExt']['COS'] = ('Enumeration',('NM020'))
    field_information['GGDM 3.0']['TransportationWaterAONExt']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['TransportationWaterAONExt']['EnumeratedIndexValues']['COS']['NM020']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['TransportationWaterAONExt']['CWT'] = ('Boolean',('NM020'))
    field_information['GGDM 3.0']['TransportationWaterAONExt']['DEV'] = ('Integer',('NM020'))
    field_information['GGDM 3.0']['TransportationWaterAONExt']['DMF'] = ('Integer',('NM020'))
    field_information['GGDM 3.0']['TransportationWaterAONExt']['DOXY'] = ('Real',('NM020'))
    field_information['GGDM 3.0']['TransportationWaterAONExt']['DZP'] = ('Real',('NM020'))
    field_information['GGDM 3.0']['TransportationWaterAONExt']['F_CODE'] = ('CONSTRAINED_STRING',('NM020'))
    field_information['GGDM 3.0']['TransportationWaterAONExt']['FRZ'] = ('Boolean',('NM020'))
    field_information['GGDM 3.0']['TransportationWaterAONExt']['FUFI'] = ('StructuredText',('NM020'))
    field_information['GGDM 3.0']['TransportationWaterAONExt']['FURL'] = ('StructuredText',('NM020'))
    field_information['GGDM 3.0']['TransportationWaterAONExt']['GDBV'] = ('Enumeration',('NM020'))
    field_information['GGDM 3.0']['TransportationWaterAONExt']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['TransportationWaterAONExt']['EnumeratedIndexValues']['GDBV']['NM020']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['TransportationWaterAONExt']['HDP'] = ('Real',('NM020'))
    field_information['GGDM 3.0']['TransportationWaterAONExt']['HGT'] = ('Real',('NM020'))
    field_information['GGDM 3.0']['TransportationWaterAONExt']['LEA'] = ('Real',('NM020'))
    field_information['GGDM 3.0']['TransportationWaterAONExt']['LMC'] = ('Boolean',('NM020'))
    field_information['GGDM 3.0']['TransportationWaterAONExt']['LOC'] = ('Enumeration',('NM020'))
    field_information['GGDM 3.0']['TransportationWaterAONExt']['EnumeratedIndexValues']['LOC'] = {}
    field_information['GGDM 3.0']['TransportationWaterAONExt']['EnumeratedIndexValues']['LOC']['NM020']  = (-999999,40,44,45)
    field_information['GGDM 3.0']['TransportationWaterAONExt']['LZN'] = ('Real',('NM020'))
    field_information['GGDM 3.0']['TransportationWaterAONExt']['MWD'] = ('Real',('NM020'))
    field_information['GGDM 3.0']['TransportationWaterAONExt']['NVS'] = ('Enumeration',('NM020'))
    field_information['GGDM 3.0']['TransportationWaterAONExt']['EnumeratedIndexValues']['NVS'] = {}
    field_information['GGDM 3.0']['TransportationWaterAONExt']['EnumeratedIndexValues']['NVS']['NM020']  = (-999999,1,2,3,4,5,999)
    field_information['GGDM 3.0']['TransportationWaterAONExt']['OTH'] = ('StructuredText',('NM020'))
    field_information['GGDM 3.0']['TransportationWaterAONExt']['PCF'] = ('Enumeration',('NM020'))
    field_information['GGDM 3.0']['TransportationWaterAONExt']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['TransportationWaterAONExt']['EnumeratedIndexValues']['PCF']['NM020']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['TransportationWaterAONExt']['PWA'] = ('Real',('NM020'))
    field_information['GGDM 3.0']['TransportationWaterAONExt']['RLE'] = ('Enumeration',('NM020'))
    field_information['GGDM 3.0']['TransportationWaterAONExt']['EnumeratedIndexValues']['RLE'] = {}
    field_information['GGDM 3.0']['TransportationWaterAONExt']['EnumeratedIndexValues']['RLE']['NM020']  = (-999999,1,2,3,998)
    field_information['GGDM 3.0']['TransportationWaterAONExt']['SBB'] = ('Boolean',('NM020'))
    field_information['GGDM 3.0']['TransportationWaterAONExt']['UFI'] = ('StructuredText',('NM020'))
    field_information['GGDM 3.0']['TransportationWaterAONExt']['WD3'] = ('Real',('NM020'))
    field_information['GGDM 3.0']['TransportationWaterAONExt']['WDAC'] = ('Enumeration',('NM020'))
    field_information['GGDM 3.0']['TransportationWaterAONExt']['EnumeratedIndexValues']['WDAC'] = {}
    field_information['GGDM 3.0']['TransportationWaterAONExt']['EnumeratedIndexValues']['WDAC']['NM020']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['TransportationWaterAONExt']['WDAL'] = ('real',('NM020'))
    field_information['GGDM 3.0']['TransportationWaterAONExt']['WDAU'] = ('real',('NM020'))
    field_information['GGDM 3.0']['TransportationWaterAONExt']['WDH'] = ('Real',('NM020'))
    field_information['GGDM 3.0']['TransportationWaterAONExt']['WDL'] = ('Real',('NM020'))
    field_information['GGDM 3.0']['TransportationWaterAONExt']['WID'] = ('Real',('NM020'))
    field_information['GGDM 3.0']['TransportationWaterAONExt']['WVA'] = ('Real',('NM020'))
    field_information['GGDM 3.0']['TransportationWaterAONExt']['WVH'] = ('Real',('NM020'))
    field_information['GGDM 3.0']['TransportationWaterAONExt']['WVL'] = ('Real',('NM020'))
    field_information['GGDM 3.0']['TransportationWaterAONExt']['ZI001_SDV'] = ('StructuredText',('NM020'))
    field_information['GGDM 3.0']['TransportationWaterAONExt']['ZI001_SRT'] = ('Enumeration',('NM020'))
    field_information['GGDM 3.0']['TransportationWaterAONExt']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['TransportationWaterAONExt']['EnumeratedIndexValues']['ZI001_SRT']['NM020']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['TransportationWaterAONExt']['ZI002_UFI'] = ('StructuredText',('NM020'))
    field_information['GGDM 3.0']['TransportationWaterAONExt']['ZI004_RCG'] = ('Enumeration',('NM020'))
    field_information['GGDM 3.0']['TransportationWaterAONExt']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['TransportationWaterAONExt']['EnumeratedIndexValues']['ZI004_RCG']['NM020']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['TransportationWaterAONExt']['ZI005_FNA'] = ('String',('NM020'))
    field_information['GGDM 3.0']['TransportationWaterAONExt']['ZI005_FNA2'] = ('String',('NM020'))
    field_information['GGDM 3.0']['TransportationWaterAONExt']['ZI005_FNA3'] = ('String',('NM020'))
    field_information['GGDM 3.0']['TransportationWaterAONExt']['ZI005_GNT'] = ('Enumeration',('NM020'))
    field_information['GGDM 3.0']['TransportationWaterAONExt']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['TransportationWaterAONExt']['EnumeratedIndexValues']['ZI005_GNT']['NM020']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['TransportationWaterAONExt']['ZI005_GNT2'] = ('Enumeration',('NM020'))
    field_information['GGDM 3.0']['TransportationWaterAONExt']['EnumeratedIndexValues']['ZI005_GNT2'] = {}
    field_information['GGDM 3.0']['TransportationWaterAONExt']['EnumeratedIndexValues']['ZI005_GNT2']['NM020']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['TransportationWaterAONExt']['ZI005_GNT3'] = ('Enumeration',('NM020'))
    field_information['GGDM 3.0']['TransportationWaterAONExt']['EnumeratedIndexValues']['ZI005_GNT3'] = {}
    field_information['GGDM 3.0']['TransportationWaterAONExt']['EnumeratedIndexValues']['ZI005_GNT3']['NM020']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['TransportationWaterAONExt']['ZI005_NFN'] = ('String',('NM020'))
    field_information['GGDM 3.0']['TransportationWaterAONExt']['ZI005_NFN2'] = ('String',('NM020'))
    field_information['GGDM 3.0']['TransportationWaterAONExt']['ZI005_NFN3'] = ('String',('NM020'))
    field_information['GGDM 3.0']['TransportationWaterAONExt']['ZI006_MEM'] = ('String',('NM020'))
    field_information['GGDM 3.0']['TransportationWaterAONExt']['ZI020_GE4'] = ('CodeList',('NM020'))
    field_information['GGDM 3.0']['TransportationWaterAONExt']['ZI024_ASE'] = ('Real',('NM020'))
    field_information['GGDM 3.0']['TransportationWaterAONExt']['ZI024_AWO'] = ('Real',('NM020'))
    field_information['GGDM 3.0']['TransportationWaterAONExt']['ZI024_AWOI'] = ('Real',('NM020'))
    field_information['GGDM 3.0']['TransportationWaterAONExt']['ZI024_AWOX'] = ('Real',('NM020'))
    field_information['GGDM 3.0']['TransportationWaterAONExt']['ZI024_CFR'] = ('Real',('NM020'))
    field_information['GGDM 3.0']['TransportationWaterAONExt']['ZI024_CLO'] = ('Real',('NM020'))
    field_information['GGDM 3.0']['TransportationWaterAONExt']['ZI024_CYN'] = ('Real',('NM020'))
    field_information['GGDM 3.0']['TransportationWaterAONExt']['ZI024_FMR'] = ('Real',('NM020'))
    field_information['GGDM 3.0']['TransportationWaterAONExt']['ZI024_FRR'] = ('Real',('NM020'))
    field_information['GGDM 3.0']['TransportationWaterAONExt']['ZI024_HAR'] = ('Real',('NM020'))
    field_information['GGDM 3.0']['TransportationWaterAONExt']['ZI024_HYP'] = ('Enumeration',('NM020'))
    field_information['GGDM 3.0']['TransportationWaterAONExt']['EnumeratedIndexValues']['ZI024_HYP'] = {}
    field_information['GGDM 3.0']['TransportationWaterAONExt']['EnumeratedIndexValues']['ZI024_HYP']['NM020']  = (-999999,1,2,4)
    field_information['GGDM 3.0']['TransportationWaterAONExt']['ZI024_MGN'] = ('Real',('NM020'))
    field_information['GGDM 3.0']['TransportationWaterAONExt']['ZI024_PHW'] = ('Real',('NM020'))
    field_information['GGDM 3.0']['TransportationWaterAONExt']['ZI024_SCC'] = ('Enumeration',('NM020'))
    field_information['GGDM 3.0']['TransportationWaterAONExt']['EnumeratedIndexValues']['ZI024_SCC'] = {}
    field_information['GGDM 3.0']['TransportationWaterAONExt']['EnumeratedIndexValues']['ZI024_SCC']['NM020']  = (-999999,1,4,10,11,12,13,14,998,999)
    field_information['GGDM 3.0']['TransportationWaterAONExt']['ZI024_SQN'] = ('Enumeration',('NM020'))
    field_information['GGDM 3.0']['TransportationWaterAONExt']['EnumeratedIndexValues']['ZI024_SQN'] = {}
    field_information['GGDM 3.0']['TransportationWaterAONExt']['EnumeratedIndexValues']['ZI024_SQN']['NM020']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['TransportationWaterAONExt']['ZI024_SUL'] = ('Real',('NM020'))
    field_information['GGDM 3.0']['TransportationWaterAONExt']['ZI024_TDS'] = ('Real',('NM020'))
    field_information['GGDM 3.0']['TransportationWaterAONExt']['ZI024_TEP'] = ('Real',('NM020'))
    field_information['GGDM 3.0']['TransportationWaterAONExt']['ZI024_TUR'] = ('Real',('NM020'))
    field_information['GGDM 3.0']['TransportationWaterAONExt']['ZI024_WAC'] = ('Real',('NM020'))
    field_information['GGDM 3.0']['TransportationWaterAONExt']['ZI024_WPAC'] = ('Enumeration',('NM020'))
    field_information['GGDM 3.0']['TransportationWaterAONExt']['EnumeratedIndexValues']['ZI024_WPAC'] = {}
    field_information['GGDM 3.0']['TransportationWaterAONExt']['EnumeratedIndexValues']['ZI024_WPAC']['NM020']  = (-999999,100,101,102,103,104,105,106,107)
    field_information['GGDM 3.0']['TransportationWaterAONExt']['ZI024_WSG'] = ('Enumeration',('NM020'))
    field_information['GGDM 3.0']['TransportationWaterAONExt']['EnumeratedIndexValues']['ZI024_WSG'] = {}
    field_information['GGDM 3.0']['TransportationWaterAONExt']['EnumeratedIndexValues']['ZI024_WSG']['NM020']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['TransportationWaterAONExt']['ZI024_WTNO'] = ('Real',('NM020'))
    field_information['GGDM 3.0']['TransportationWaterAONExt']['ZI024_WUR'] = ('Enumeration',('NM020'))
    field_information['GGDM 3.0']['TransportationWaterAONExt']['EnumeratedIndexValues']['ZI024_WUR'] = {}
    field_information['GGDM 3.0']['TransportationWaterAONExt']['EnumeratedIndexValues']['ZI024_WUR']['NM020']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['TransportationWaterAONExt']['ZI024_WUR2'] = ('Enumeration',('NM020'))
    field_information['GGDM 3.0']['TransportationWaterAONExt']['EnumeratedIndexValues']['ZI024_WUR2'] = {}
    field_information['GGDM 3.0']['TransportationWaterAONExt']['EnumeratedIndexValues']['ZI024_WUR2']['NM020']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['TransportationWaterAONExt']['ZI024_WUR3'] = ('Enumeration',('NM020'))
    field_information['GGDM 3.0']['TransportationWaterAONExt']['EnumeratedIndexValues']['ZI024_WUR3'] = {}
    field_information['GGDM 3.0']['TransportationWaterAONExt']['EnumeratedIndexValues']['ZI024_WUR3']['NM020']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['TransportationWaterAONExt']['ZI024_WUR4'] = ('Enumeration',('NM020'))
    field_information['GGDM 3.0']['TransportationWaterAONExt']['EnumeratedIndexValues']['ZI024_WUR4'] = {}
    field_information['GGDM 3.0']['TransportationWaterAONExt']['EnumeratedIndexValues']['ZI024_WUR4']['NM020']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['TransportationWaterAONExt']['ZI024_YWQ'] = ('Enumeration',('NM020'))
    field_information['GGDM 3.0']['TransportationWaterAONExt']['EnumeratedIndexValues']['ZI024_YWQ'] = {}
    field_information['GGDM 3.0']['TransportationWaterAONExt']['EnumeratedIndexValues']['ZI024_YWQ']['NM020']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['TransportationWaterAONExt']['ZI026_CTUC'] = ('Enumeration',('NM020'))
    field_information['GGDM 3.0']['TransportationWaterAONExt']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['TransportationWaterAONExt']['EnumeratedIndexValues']['ZI026_CTUC']['NM020']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['TransportationWaterAONExt']['ZI026_CTUL'] = ('integer',('NM020'))
    field_information['GGDM 3.0']['TransportationWaterAONExt']['ZI026_CTUU'] = ('integer',('NM020'))
    field_information['GGDM 3.0']['TransportationWaterAONExt']['ZI031S_URI'] = ('StructuredText',('NM020'))
    field_information['GGDM 3.0']['TransportationWaterAONExt']['ZI039S_UFI'] = ('StructuredText',('NM020'))
    field_information['GGDM 3.0']['TransportationWaterAONExt']['ZSAX_RS0'] = ('CodeList',('NM020'))
    field_information['GGDM 3.0']['TransportationWaterAONExt']['ZSAX_RX0'] = ('StructuredText',('NM020'))
    field_information['GGDM 3.0']['TransportationWaterAONExt']['ZSAX_RX3'] = ('StructuredText',('NM020'))
    field_information['GGDM 3.0']['TransportationWaterAONExt']['ZSAX_RX4'] = ('StructuredText',('NM020'))
    field_information['GGDM 3.0']['TransportationWaterAONExt']['ZVH'] = ('Real',('NM020'))
    field_information['GGDM 3.0']['TransportationWaterCrv']['AOO'] = ('Real',('AQ070','BI006','BI030','BI045'))
    field_information['GGDM 3.0']['TransportationWaterCrv']['ARA'] = ('Real',('BH020','BI006','BI030'))
    field_information['GGDM 3.0']['TransportationWaterCrv']['AWP'] = ('Boolean',('BI006'))
    field_information['GGDM 3.0']['TransportationWaterCrv']['BBMCA'] = ('Enumeration',('BH020'))
    field_information['GGDM 3.0']['TransportationWaterCrv']['EnumeratedIndexValues']['BBMCA'] = {}
    field_information['GGDM 3.0']['TransportationWaterCrv']['EnumeratedIndexValues']['BBMCA']['BH020']  = (-999999,1,2,3,4,5,6,7,8,9,11,14,15,16,17,18,999)
    field_information['GGDM 3.0']['TransportationWaterCrv']['BBMCA2'] = ('Enumeration',('BH020'))
    field_information['GGDM 3.0']['TransportationWaterCrv']['EnumeratedIndexValues']['BBMCA2'] = {}
    field_information['GGDM 3.0']['TransportationWaterCrv']['EnumeratedIndexValues']['BBMCA2']['BH020']  = (-999999,1,2,3,4,5,6,7,8,9,11,14,15,16,17,18,999)
    field_information['GGDM 3.0']['TransportationWaterCrv']['BBMCA3'] = ('Enumeration',('BH020'))
    field_information['GGDM 3.0']['TransportationWaterCrv']['EnumeratedIndexValues']['BBMCA3'] = {}
    field_information['GGDM 3.0']['TransportationWaterCrv']['EnumeratedIndexValues']['BBMCA3']['BH020']  = (-999999,1,2,3,4,5,6,7,8,9,11,14,15,16,17,18,999)
    field_information['GGDM 3.0']['TransportationWaterCrv']['BBMCB'] = ('Enumeration',('BH020'))
    field_information['GGDM 3.0']['TransportationWaterCrv']['EnumeratedIndexValues']['BBMCB'] = {}
    field_information['GGDM 3.0']['TransportationWaterCrv']['EnumeratedIndexValues']['BBMCB']['BH020']  = (-999999,1,2,3,4,5,6,7,8,9,11,14,15,16,17,18,999)
    field_information['GGDM 3.0']['TransportationWaterCrv']['BBMCB2'] = ('Enumeration',('BH020'))
    field_information['GGDM 3.0']['TransportationWaterCrv']['EnumeratedIndexValues']['BBMCB2'] = {}
    field_information['GGDM 3.0']['TransportationWaterCrv']['EnumeratedIndexValues']['BBMCB2']['BH020']  = (-999999,1,2,3,4,5,6,7,8,9,11,14,15,16,17,18,999)
    field_information['GGDM 3.0']['TransportationWaterCrv']['BBMCB3'] = ('Enumeration',('BH020'))
    field_information['GGDM 3.0']['TransportationWaterCrv']['EnumeratedIndexValues']['BBMCB3'] = {}
    field_information['GGDM 3.0']['TransportationWaterCrv']['EnumeratedIndexValues']['BBMCB3']['BH020']  = (-999999,1,2,3,4,5,6,7,8,9,11,14,15,16,17,18,999)
    field_information['GGDM 3.0']['TransportationWaterCrv']['BEN'] = ('StructuredText',('AQ070','BH020','BI006','BI030','BI045'))
    field_information['GGDM 3.0']['TransportationWaterCrv']['BGT'] = ('Enumeration',('BI045'))
    field_information['GGDM 3.0']['TransportationWaterCrv']['EnumeratedIndexValues']['BGT'] = {}
    field_information['GGDM 3.0']['TransportationWaterCrv']['EnumeratedIndexValues']['BGT']['BI045']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['TransportationWaterCrv']['BH141_AWBA'] = ('Real',('BH020'))
    field_information['GGDM 3.0']['TransportationWaterCrv']['BH141_AWBB'] = ('Real',('BH020'))
    field_information['GGDM 3.0']['TransportationWaterCrv']['BH141_IBOA'] = ('Enumeration',('BH020'))
    field_information['GGDM 3.0']['TransportationWaterCrv']['EnumeratedIndexValues']['BH141_IBOA'] = {}
    field_information['GGDM 3.0']['TransportationWaterCrv']['EnumeratedIndexValues']['BH141_IBOA']['BH020']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['TransportationWaterCrv']['BH141_IBOB'] = ('Enumeration',('BH020'))
    field_information['GGDM 3.0']['TransportationWaterCrv']['EnumeratedIndexValues']['BH141_IBOB'] = {}
    field_information['GGDM 3.0']['TransportationWaterCrv']['EnumeratedIndexValues']['BH141_IBOB']['BH020']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['TransportationWaterCrv']['BH141_SHDA'] = ('Boolean',('BH020'))
    field_information['GGDM 3.0']['TransportationWaterCrv']['BH141_SHDB'] = ('Boolean',('BH020'))
    field_information['GGDM 3.0']['TransportationWaterCrv']['BH141_SLTA'] = ('Enumeration',('BH020'))
    field_information['GGDM 3.0']['TransportationWaterCrv']['EnumeratedIndexValues']['BH141_SLTA'] = {}
    field_information['GGDM 3.0']['TransportationWaterCrv']['EnumeratedIndexValues']['BH141_SLTA']['BH020']  = (-999999,6,8,10,11,12,13,14,16,17,18,999)
    field_information['GGDM 3.0']['TransportationWaterCrv']['BH141_SLTB'] = ('Enumeration',('BH020'))
    field_information['GGDM 3.0']['TransportationWaterCrv']['EnumeratedIndexValues']['BH141_SLTB'] = {}
    field_information['GGDM 3.0']['TransportationWaterCrv']['EnumeratedIndexValues']['BH141_SLTB']['BH020']  = (-999999,6,8,10,11,12,13,14,17,18,999)
    field_information['GGDM 3.0']['TransportationWaterCrv']['BH141_WBHA'] = ('Real',('BH020'))
    field_information['GGDM 3.0']['TransportationWaterCrv']['BH141_WBHB'] = ('Real',('BH020'))
    field_information['GGDM 3.0']['TransportationWaterCrv']['BMC'] = ('Enumeration',('BH020'))
    field_information['GGDM 3.0']['TransportationWaterCrv']['EnumeratedIndexValues']['BMC'] = {}
    field_information['GGDM 3.0']['TransportationWaterCrv']['EnumeratedIndexValues']['BMC']['BH020']  = (-999999,1,2,3,4,5,6,7,8,9,14,15,16,17,18,999)
    field_information['GGDM 3.0']['TransportationWaterCrv']['BMC2'] = ('Enumeration',('BH020'))
    field_information['GGDM 3.0']['TransportationWaterCrv']['EnumeratedIndexValues']['BMC2'] = {}
    field_information['GGDM 3.0']['TransportationWaterCrv']['EnumeratedIndexValues']['BMC2']['BH020']  = (-999999,1,2,3,4,5,6,7,8,9,14,15,16,17,18,999)
    field_information['GGDM 3.0']['TransportationWaterCrv']['BMC3'] = ('Enumeration',('BH020'))
    field_information['GGDM 3.0']['TransportationWaterCrv']['EnumeratedIndexValues']['BMC3'] = {}
    field_information['GGDM 3.0']['TransportationWaterCrv']['EnumeratedIndexValues']['BMC3']['BH020']  = (-999999,1,2,3,4,5,6,7,8,9,14,15,16,17,18,999)
    field_information['GGDM 3.0']['TransportationWaterCrv']['BPWHAC'] = ('Enumeration',('BH020'))
    field_information['GGDM 3.0']['TransportationWaterCrv']['EnumeratedIndexValues']['BPWHAC'] = {}
    field_information['GGDM 3.0']['TransportationWaterCrv']['EnumeratedIndexValues']['BPWHAC']['BH020']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['TransportationWaterCrv']['BPWHAL'] = ('real',('BH020'))
    field_information['GGDM 3.0']['TransportationWaterCrv']['BPWHAU'] = ('real',('BH020'))
    field_information['GGDM 3.0']['TransportationWaterCrv']['BPWHBC'] = ('Enumeration',('BH020'))
    field_information['GGDM 3.0']['TransportationWaterCrv']['EnumeratedIndexValues']['BPWHBC'] = {}
    field_information['GGDM 3.0']['TransportationWaterCrv']['EnumeratedIndexValues']['BPWHBC']['BH020']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['TransportationWaterCrv']['BPWHBL'] = ('real',('BH020'))
    field_information['GGDM 3.0']['TransportationWaterCrv']['BPWHBU'] = ('real',('BH020'))
    field_information['GGDM 3.0']['TransportationWaterCrv']['BPWSAC'] = ('Enumeration',('BH020'))
    field_information['GGDM 3.0']['TransportationWaterCrv']['EnumeratedIndexValues']['BPWSAC'] = {}
    field_information['GGDM 3.0']['TransportationWaterCrv']['EnumeratedIndexValues']['BPWSAC']['BH020']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['TransportationWaterCrv']['BPWSAL'] = ('real',('BH020'))
    field_information['GGDM 3.0']['TransportationWaterCrv']['BPWSAU'] = ('real',('BH020'))
    field_information['GGDM 3.0']['TransportationWaterCrv']['BPWSBC'] = ('Enumeration',('BH020'))
    field_information['GGDM 3.0']['TransportationWaterCrv']['EnumeratedIndexValues']['BPWSBC'] = {}
    field_information['GGDM 3.0']['TransportationWaterCrv']['EnumeratedIndexValues']['BPWSBC']['BH020']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['TransportationWaterCrv']['BPWSBL'] = ('real',('BH020'))
    field_information['GGDM 3.0']['TransportationWaterCrv']['BPWSBU'] = ('real',('BH020'))
    field_information['GGDM 3.0']['TransportationWaterCrv']['BWVCAC'] = ('Enumeration',('BH020'))
    field_information['GGDM 3.0']['TransportationWaterCrv']['EnumeratedIndexValues']['BWVCAC'] = {}
    field_information['GGDM 3.0']['TransportationWaterCrv']['EnumeratedIndexValues']['BWVCAC']['BH020']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['TransportationWaterCrv']['BWVCAL'] = ('real',('BH020'))
    field_information['GGDM 3.0']['TransportationWaterCrv']['BWVCAU'] = ('real',('BH020'))
    field_information['GGDM 3.0']['TransportationWaterCrv']['BWVCBC'] = ('Enumeration',('BH020'))
    field_information['GGDM 3.0']['TransportationWaterCrv']['EnumeratedIndexValues']['BWVCBC'] = {}
    field_information['GGDM 3.0']['TransportationWaterCrv']['EnumeratedIndexValues']['BWVCBC']['BH020']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['TransportationWaterCrv']['BWVCBL'] = ('real',('BH020'))
    field_information['GGDM 3.0']['TransportationWaterCrv']['BWVCBU'] = ('real',('BH020'))
    field_information['GGDM 3.0']['TransportationWaterCrv']['CAA'] = ('Enumeration',('AQ070','BH020','BI006','BI030'))
    field_information['GGDM 3.0']['TransportationWaterCrv']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['TransportationWaterCrv']['EnumeratedIndexValues']['CAA']['AQ070']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['TransportationWaterCrv']['EnumeratedIndexValues']['CAA']['BH020']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['TransportationWaterCrv']['EnumeratedIndexValues']['CAA']['BI006']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['TransportationWaterCrv']['EnumeratedIndexValues']['CAA']['BI030']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['TransportationWaterCrv']['CDA'] = ('Boolean',('BH020'))
    field_information['GGDM 3.0']['TransportationWaterCrv']['CDL'] = ('Real',('BH020'))
    field_information['GGDM 3.0']['TransportationWaterCrv']['CNCP'] = ('StructuredText',('AQ070','BH020','BI006','BI030','BI045'))
    field_information['GGDM 3.0']['TransportationWaterCrv']['COS'] = ('Enumeration',('AQ070','BH020','BI006','BI030','BI045'))
    field_information['GGDM 3.0']['TransportationWaterCrv']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['TransportationWaterCrv']['EnumeratedIndexValues']['COS']['AQ070']  = (-999999,2,4,6,9,13,14)
    field_information['GGDM 3.0']['TransportationWaterCrv']['EnumeratedIndexValues']['COS']['BH020']  = (-999999,2,4,6,9,13,14)
    field_information['GGDM 3.0']['TransportationWaterCrv']['EnumeratedIndexValues']['COS']['BI006']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['TransportationWaterCrv']['EnumeratedIndexValues']['COS']['BI030']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['TransportationWaterCrv']['EnumeratedIndexValues']['COS']['BI045']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['TransportationWaterCrv']['CWT'] = ('Boolean',('BH020'))
    field_information['GGDM 3.0']['TransportationWaterCrv']['DEV'] = ('Integer',('BH020'))
    field_information['GGDM 3.0']['TransportationWaterCrv']['DOXY'] = ('Real',('BH020'))
    field_information['GGDM 3.0']['TransportationWaterCrv']['DZP'] = ('Real',('BH020','BI006','BI030'))
    field_information['GGDM 3.0']['TransportationWaterCrv']['F_CODE'] = ('CONSTRAINED_STRING',('AQ070','BH020','BI006','BI030','BI045'))
    field_information['GGDM 3.0']['TransportationWaterCrv']['FCL'] = ('Real',('AQ070'))
    field_information['GGDM 3.0']['TransportationWaterCrv']['FER'] = ('Enumeration',('AQ070'))
    field_information['GGDM 3.0']['TransportationWaterCrv']['EnumeratedIndexValues']['FER'] = {}
    field_information['GGDM 3.0']['TransportationWaterCrv']['EnumeratedIndexValues']['FER']['AQ070']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['TransportationWaterCrv']['FRZ'] = ('Boolean',('BH020'))
    field_information['GGDM 3.0']['TransportationWaterCrv']['FUFI'] = ('StructuredText',('AQ070','BH020','BI006','BI030','BI045'))
    field_information['GGDM 3.0']['TransportationWaterCrv']['FURL'] = ('StructuredText',('AQ070','BH020','BI006','BI030','BI045'))
    field_information['GGDM 3.0']['TransportationWaterCrv']['GDBV'] = ('Enumeration',('AQ070','BH020','BI006','BI030','BI045'))
    field_information['GGDM 3.0']['TransportationWaterCrv']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['TransportationWaterCrv']['EnumeratedIndexValues']['GDBV']['AQ070']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['TransportationWaterCrv']['EnumeratedIndexValues']['GDBV']['BH020']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['TransportationWaterCrv']['EnumeratedIndexValues']['GDBV']['BI006']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['TransportationWaterCrv']['EnumeratedIndexValues']['GDBV']['BI030']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['TransportationWaterCrv']['EnumeratedIndexValues']['GDBV']['BI045']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['TransportationWaterCrv']['HDP'] = ('Real',('BH020','BI030','BI045'))
    field_information['GGDM 3.0']['TransportationWaterCrv']['HEI'] = ('Real',('BI045'))
    field_information['GGDM 3.0']['TransportationWaterCrv']['HGT'] = ('Real',('BH020','BI006','BI030','BI045'))
    field_information['GGDM 3.0']['TransportationWaterCrv']['LEA'] = ('Real',('BH020'))
    field_information['GGDM 3.0']['TransportationWaterCrv']['LMC'] = ('Boolean',('AQ070','BH020','BI006','BI030','BI045'))
    field_information['GGDM 3.0']['TransportationWaterCrv']['LNU'] = ('Real',('BI006','BI030'))
    field_information['GGDM 3.0']['TransportationWaterCrv']['LOC'] = ('Enumeration',('BH020'))
    field_information['GGDM 3.0']['TransportationWaterCrv']['EnumeratedIndexValues']['LOC'] = {}
    field_information['GGDM 3.0']['TransportationWaterCrv']['EnumeratedIndexValues']['LOC']['BH020']  = (-999999,40,44)
    field_information['GGDM 3.0']['TransportationWaterCrv']['LZN'] = ('Real',('AQ070','BH020','BI006','BI030','BI045'))
    field_information['GGDM 3.0']['TransportationWaterCrv']['MCC'] = ('Enumeration',('BI006','BI030','BI045'))
    field_information['GGDM 3.0']['TransportationWaterCrv']['EnumeratedIndexValues']['MCC'] = {}
    field_information['GGDM 3.0']['TransportationWaterCrv']['EnumeratedIndexValues']['MCC']['BI006']  = (-999999,77,83,107,117,150,999)
    field_information['GGDM 3.0']['TransportationWaterCrv']['EnumeratedIndexValues']['MCC']['BI030']  = (-999999,9,21,62,77,83,104,107,108,117,150,999)
    field_information['GGDM 3.0']['TransportationWaterCrv']['EnumeratedIndexValues']['MCC']['BI045']  = (-999999,21,51,64,77,83,107,117,150,999)
    field_information['GGDM 3.0']['TransportationWaterCrv']['MCC2'] = ('Enumeration',('BI006','BI030','BI045'))
    field_information['GGDM 3.0']['TransportationWaterCrv']['EnumeratedIndexValues']['MCC2'] = {}
    field_information['GGDM 3.0']['TransportationWaterCrv']['EnumeratedIndexValues']['MCC2']['BI006']  = (-999999,77,83,107,117,150,999)
    field_information['GGDM 3.0']['TransportationWaterCrv']['EnumeratedIndexValues']['MCC2']['BI030']  = (-999999,9,21,62,77,83,104,107,108,117,150,999)
    field_information['GGDM 3.0']['TransportationWaterCrv']['EnumeratedIndexValues']['MCC2']['BI045']  = (-999999,21,51,64,77,83,107,117,150,999)
    field_information['GGDM 3.0']['TransportationWaterCrv']['MCC3'] = ('Enumeration',('BI006','BI030','BI045'))
    field_information['GGDM 3.0']['TransportationWaterCrv']['EnumeratedIndexValues']['MCC3'] = {}
    field_information['GGDM 3.0']['TransportationWaterCrv']['EnumeratedIndexValues']['MCC3']['BI006']  = (-999999,77,83,107,117,150,999)
    field_information['GGDM 3.0']['TransportationWaterCrv']['EnumeratedIndexValues']['MCC3']['BI030']  = (-999999,9,21,62,77,83,104,107,108,117,150,999)
    field_information['GGDM 3.0']['TransportationWaterCrv']['EnumeratedIndexValues']['MCC3']['BI045']  = (-999999,21,51,64,77,83,107,117,150,999)
    field_information['GGDM 3.0']['TransportationWaterCrv']['MCX'] = ('Boolean',('AQ070'))
    field_information['GGDM 3.0']['TransportationWaterCrv']['MWD'] = ('Real',('BH020','BI006','BI030'))
    field_information['GGDM 3.0']['TransportationWaterCrv']['NVS'] = ('Enumeration',('BH020'))
    field_information['GGDM 3.0']['TransportationWaterCrv']['EnumeratedIndexValues']['NVS'] = {}
    field_information['GGDM 3.0']['TransportationWaterCrv']['EnumeratedIndexValues']['NVS']['BH020']  = (-999999,1,2,3,4,5,999)
    field_information['GGDM 3.0']['TransportationWaterCrv']['OPT'] = ('Enumeration',('AQ070'))
    field_information['GGDM 3.0']['TransportationWaterCrv']['EnumeratedIndexValues']['OPT'] = {}
    field_information['GGDM 3.0']['TransportationWaterCrv']['EnumeratedIndexValues']['OPT']['AQ070']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['TransportationWaterCrv']['OTH'] = ('StructuredText',('AQ070','BH020','BI006','BI030','BI045'))
    field_information['GGDM 3.0']['TransportationWaterCrv']['PCF'] = ('Enumeration',('BH020','BI006','BI030','BI045'))
    field_information['GGDM 3.0']['TransportationWaterCrv']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['TransportationWaterCrv']['EnumeratedIndexValues']['PCF']['BH020']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['TransportationWaterCrv']['EnumeratedIndexValues']['PCF']['BI006']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['TransportationWaterCrv']['EnumeratedIndexValues']['PCF']['BI030']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['TransportationWaterCrv']['EnumeratedIndexValues']['PCF']['BI045']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['TransportationWaterCrv']['PSN'] = ('Real',('AQ070'))
    field_information['GGDM 3.0']['TransportationWaterCrv']['PWA'] = ('Real',('BH020'))
    field_information['GGDM 3.0']['TransportationWaterCrv']['RIN_ROI'] = ('Enumeration',('AQ070'))
    field_information['GGDM 3.0']['TransportationWaterCrv']['EnumeratedIndexValues']['RIN_ROI'] = {}
    field_information['GGDM 3.0']['TransportationWaterCrv']['EnumeratedIndexValues']['RIN_ROI']['AQ070']  = (-999999,1,2,3,4,5,999)
    field_information['GGDM 3.0']['TransportationWaterCrv']['RIN_ROI2'] = ('Enumeration',('AQ070'))
    field_information['GGDM 3.0']['TransportationWaterCrv']['EnumeratedIndexValues']['RIN_ROI2'] = {}
    field_information['GGDM 3.0']['TransportationWaterCrv']['EnumeratedIndexValues']['RIN_ROI2']['AQ070']  = (-999999,1,2,3,4,5,999)
    field_information['GGDM 3.0']['TransportationWaterCrv']['RIN_ROI3'] = ('Enumeration',('AQ070'))
    field_information['GGDM 3.0']['TransportationWaterCrv']['EnumeratedIndexValues']['RIN_ROI3'] = {}
    field_information['GGDM 3.0']['TransportationWaterCrv']['EnumeratedIndexValues']['RIN_ROI3']['AQ070']  = (-999999,1,2,3,4,5,999)
    field_information['GGDM 3.0']['TransportationWaterCrv']['RIN_RTN'] = ('String',('AQ070'))
    field_information['GGDM 3.0']['TransportationWaterCrv']['RIN_RTN2'] = ('String',('AQ070'))
    field_information['GGDM 3.0']['TransportationWaterCrv']['RIN_RTN3'] = ('String',('AQ070'))
    field_information['GGDM 3.0']['TransportationWaterCrv']['RLE'] = ('Enumeration',('BH020'))
    field_information['GGDM 3.0']['TransportationWaterCrv']['EnumeratedIndexValues']['RLE'] = {}
    field_information['GGDM 3.0']['TransportationWaterCrv']['EnumeratedIndexValues']['RLE']['BH020']  = (-999999,1,2,3,998)
    field_information['GGDM 3.0']['TransportationWaterCrv']['SBB'] = ('Boolean',('BH020'))
    field_information['GGDM 3.0']['TransportationWaterCrv']['SPD'] = ('Real',('AQ070'))
    field_information['GGDM 3.0']['TransportationWaterCrv']['SPM'] = ('Real',('AQ070'))
    field_information['GGDM 3.0']['TransportationWaterCrv']['THI'] = ('Real',('BI045'))
    field_information['GGDM 3.0']['TransportationWaterCrv']['TID'] = ('Boolean',('BH020'))
    field_information['GGDM 3.0']['TransportationWaterCrv']['TRS'] = ('Enumeration',('AQ070'))
    field_information['GGDM 3.0']['TransportationWaterCrv']['EnumeratedIndexValues']['TRS'] = {}
    field_information['GGDM 3.0']['TransportationWaterCrv']['EnumeratedIndexValues']['TRS']['AQ070']  = (-999999,9,12,13,999)
    field_information['GGDM 3.0']['TransportationWaterCrv']['TRS2'] = ('Enumeration',('AQ070'))
    field_information['GGDM 3.0']['TransportationWaterCrv']['EnumeratedIndexValues']['TRS2'] = {}
    field_information['GGDM 3.0']['TransportationWaterCrv']['EnumeratedIndexValues']['TRS2']['AQ070']  = (-999999,9,12,13,999)
    field_information['GGDM 3.0']['TransportationWaterCrv']['TRS3'] = ('Enumeration',('AQ070'))
    field_information['GGDM 3.0']['TransportationWaterCrv']['EnumeratedIndexValues']['TRS3'] = {}
    field_information['GGDM 3.0']['TransportationWaterCrv']['EnumeratedIndexValues']['TRS3']['AQ070']  = (-999999,9,12,13,999)
    field_information['GGDM 3.0']['TransportationWaterCrv']['UFI'] = ('StructuredText',('AQ070','BH020','BI006','BI030','BI045'))
    field_information['GGDM 3.0']['TransportationWaterCrv']['VOI'] = ('StructuredText',('BI006'))
    field_information['GGDM 3.0']['TransportationWaterCrv']['WD3'] = ('Real',('BH020'))
    field_information['GGDM 3.0']['TransportationWaterCrv']['WDAC'] = ('Enumeration',('BH020'))
    field_information['GGDM 3.0']['TransportationWaterCrv']['EnumeratedIndexValues']['WDAC'] = {}
    field_information['GGDM 3.0']['TransportationWaterCrv']['EnumeratedIndexValues']['WDAC']['BH020']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['TransportationWaterCrv']['WDAL'] = ('real',('BH020'))
    field_information['GGDM 3.0']['TransportationWaterCrv']['WDAU'] = ('real',('BH020'))
    field_information['GGDM 3.0']['TransportationWaterCrv']['WDH'] = ('Real',('BH020'))
    field_information['GGDM 3.0']['TransportationWaterCrv']['WDL'] = ('Real',('BH020'))
    field_information['GGDM 3.0']['TransportationWaterCrv']['WDU'] = ('Real',('BI006','BI030'))
    field_information['GGDM 3.0']['TransportationWaterCrv']['WID'] = ('Real',('BH020','BI006','BI030'))
    field_information['GGDM 3.0']['TransportationWaterCrv']['WVA'] = ('Real',('BH020'))
    field_information['GGDM 3.0']['TransportationWaterCrv']['WVH'] = ('Real',('BH020'))
    field_information['GGDM 3.0']['TransportationWaterCrv']['WVL'] = ('Real',('BH020'))
    field_information['GGDM 3.0']['TransportationWaterCrv']['ZI001_SDV'] = ('StructuredText',('AQ070','BH020','BI006','BI030','BI045'))
    field_information['GGDM 3.0']['TransportationWaterCrv']['ZI001_SRT'] = ('Enumeration',('AQ070','BH020','BI006','BI030','BI045'))
    field_information['GGDM 3.0']['TransportationWaterCrv']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['TransportationWaterCrv']['EnumeratedIndexValues']['ZI001_SRT']['AQ070']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['TransportationWaterCrv']['EnumeratedIndexValues']['ZI001_SRT']['BH020']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['TransportationWaterCrv']['EnumeratedIndexValues']['ZI001_SRT']['BI006']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['TransportationWaterCrv']['EnumeratedIndexValues']['ZI001_SRT']['BI030']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['TransportationWaterCrv']['EnumeratedIndexValues']['ZI001_SRT']['BI045']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['TransportationWaterCrv']['ZI002_UFI'] = ('StructuredText',('AQ070','BH020','BI006','BI030','BI045'))
    field_information['GGDM 3.0']['TransportationWaterCrv']['ZI004_RCG'] = ('Enumeration',('AQ070','BH020','BI006','BI030','BI045'))
    field_information['GGDM 3.0']['TransportationWaterCrv']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['TransportationWaterCrv']['EnumeratedIndexValues']['ZI004_RCG']['AQ070']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['TransportationWaterCrv']['EnumeratedIndexValues']['ZI004_RCG']['BH020']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['TransportationWaterCrv']['EnumeratedIndexValues']['ZI004_RCG']['BI006']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['TransportationWaterCrv']['EnumeratedIndexValues']['ZI004_RCG']['BI030']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['TransportationWaterCrv']['EnumeratedIndexValues']['ZI004_RCG']['BI045']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['TransportationWaterCrv']['ZI005_FNA'] = ('String',('AQ070','BH020','BI006','BI030'))
    field_information['GGDM 3.0']['TransportationWaterCrv']['ZI005_FNA2'] = ('String',('BH020'))
    field_information['GGDM 3.0']['TransportationWaterCrv']['ZI005_FNA3'] = ('String',('BH020'))
    field_information['GGDM 3.0']['TransportationWaterCrv']['ZI005_GNT'] = ('Enumeration',('AQ070','BH020','BI006','BI030'))
    field_information['GGDM 3.0']['TransportationWaterCrv']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['TransportationWaterCrv']['EnumeratedIndexValues']['ZI005_GNT']['AQ070']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['TransportationWaterCrv']['EnumeratedIndexValues']['ZI005_GNT']['BH020']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['TransportationWaterCrv']['EnumeratedIndexValues']['ZI005_GNT']['BI006']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['TransportationWaterCrv']['EnumeratedIndexValues']['ZI005_GNT']['BI030']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['TransportationWaterCrv']['ZI005_GNT2'] = ('Enumeration',('BH020'))
    field_information['GGDM 3.0']['TransportationWaterCrv']['EnumeratedIndexValues']['ZI005_GNT2'] = {}
    field_information['GGDM 3.0']['TransportationWaterCrv']['EnumeratedIndexValues']['ZI005_GNT2']['BH020']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['TransportationWaterCrv']['ZI005_GNT3'] = ('Enumeration',('BH020'))
    field_information['GGDM 3.0']['TransportationWaterCrv']['EnumeratedIndexValues']['ZI005_GNT3'] = {}
    field_information['GGDM 3.0']['TransportationWaterCrv']['EnumeratedIndexValues']['ZI005_GNT3']['BH020']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['TransportationWaterCrv']['ZI005_NFN'] = ('String',('AQ070','BH020','BI006','BI030'))
    field_information['GGDM 3.0']['TransportationWaterCrv']['ZI005_NFN2'] = ('String',('BH020'))
    field_information['GGDM 3.0']['TransportationWaterCrv']['ZI005_NFN3'] = ('String',('BH020'))
    field_information['GGDM 3.0']['TransportationWaterCrv']['ZI006_MEM'] = ('String',('AQ070','BH020','BI006','BI030','BI045'))
    field_information['GGDM 3.0']['TransportationWaterCrv']['ZI020_GE4'] = ('CodeList',('AQ070','BH020','BI006','BI030','BI045'))
    field_information['GGDM 3.0']['TransportationWaterCrv']['ZI024_ASE'] = ('Real',('BH020'))
    field_information['GGDM 3.0']['TransportationWaterCrv']['ZI024_AWO'] = ('Real',('BH020'))
    field_information['GGDM 3.0']['TransportationWaterCrv']['ZI024_AWOI'] = ('Real',('BH020'))
    field_information['GGDM 3.0']['TransportationWaterCrv']['ZI024_AWOX'] = ('Real',('BH020'))
    field_information['GGDM 3.0']['TransportationWaterCrv']['ZI024_CFR'] = ('Real',('BH020'))
    field_information['GGDM 3.0']['TransportationWaterCrv']['ZI024_CLO'] = ('Real',('BH020'))
    field_information['GGDM 3.0']['TransportationWaterCrv']['ZI024_CYN'] = ('Real',('BH020'))
    field_information['GGDM 3.0']['TransportationWaterCrv']['ZI024_FMR'] = ('Real',('BH020'))
    field_information['GGDM 3.0']['TransportationWaterCrv']['ZI024_FRR'] = ('Real',('BH020'))
    field_information['GGDM 3.0']['TransportationWaterCrv']['ZI024_HAR'] = ('Real',('BH020'))
    field_information['GGDM 3.0']['TransportationWaterCrv']['ZI024_HYP'] = ('Enumeration',('BH020'))
    field_information['GGDM 3.0']['TransportationWaterCrv']['EnumeratedIndexValues']['ZI024_HYP'] = {}
    field_information['GGDM 3.0']['TransportationWaterCrv']['EnumeratedIndexValues']['ZI024_HYP']['BH020']  = (-999999,1,2,4)
    field_information['GGDM 3.0']['TransportationWaterCrv']['ZI024_MGN'] = ('Real',('BH020'))
    field_information['GGDM 3.0']['TransportationWaterCrv']['ZI024_PHW'] = ('Real',('BH020'))
    field_information['GGDM 3.0']['TransportationWaterCrv']['ZI024_SCC'] = ('Enumeration',('BH020'))
    field_information['GGDM 3.0']['TransportationWaterCrv']['EnumeratedIndexValues']['ZI024_SCC'] = {}
    field_information['GGDM 3.0']['TransportationWaterCrv']['EnumeratedIndexValues']['ZI024_SCC']['BH020']  = (-999999,1,4,10,11,12,13,14,998,999)
    field_information['GGDM 3.0']['TransportationWaterCrv']['ZI024_SQN'] = ('Enumeration',('BH020'))
    field_information['GGDM 3.0']['TransportationWaterCrv']['EnumeratedIndexValues']['ZI024_SQN'] = {}
    field_information['GGDM 3.0']['TransportationWaterCrv']['EnumeratedIndexValues']['ZI024_SQN']['BH020']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['TransportationWaterCrv']['ZI024_SUL'] = ('Real',('BH020'))
    field_information['GGDM 3.0']['TransportationWaterCrv']['ZI024_TDS'] = ('Real',('BH020'))
    field_information['GGDM 3.0']['TransportationWaterCrv']['ZI024_TEP'] = ('Real',('BH020'))
    field_information['GGDM 3.0']['TransportationWaterCrv']['ZI024_TUR'] = ('Real',('BH020'))
    field_information['GGDM 3.0']['TransportationWaterCrv']['ZI024_WAC'] = ('Real',('BH020'))
    field_information['GGDM 3.0']['TransportationWaterCrv']['ZI024_WPAC'] = ('Enumeration',('BH020'))
    field_information['GGDM 3.0']['TransportationWaterCrv']['EnumeratedIndexValues']['ZI024_WPAC'] = {}
    field_information['GGDM 3.0']['TransportationWaterCrv']['EnumeratedIndexValues']['ZI024_WPAC']['BH020']  = (-999999,100,101,102,103,104,105,106,107)
    field_information['GGDM 3.0']['TransportationWaterCrv']['ZI024_WSG'] = ('Enumeration',('BH020'))
    field_information['GGDM 3.0']['TransportationWaterCrv']['EnumeratedIndexValues']['ZI024_WSG'] = {}
    field_information['GGDM 3.0']['TransportationWaterCrv']['EnumeratedIndexValues']['ZI024_WSG']['BH020']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['TransportationWaterCrv']['ZI024_WTNO'] = ('Real',('BH020'))
    field_information['GGDM 3.0']['TransportationWaterCrv']['ZI024_WUR'] = ('Enumeration',('BH020'))
    field_information['GGDM 3.0']['TransportationWaterCrv']['EnumeratedIndexValues']['ZI024_WUR'] = {}
    field_information['GGDM 3.0']['TransportationWaterCrv']['EnumeratedIndexValues']['ZI024_WUR']['BH020']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['TransportationWaterCrv']['ZI024_WUR2'] = ('Enumeration',('BH020'))
    field_information['GGDM 3.0']['TransportationWaterCrv']['EnumeratedIndexValues']['ZI024_WUR2'] = {}
    field_information['GGDM 3.0']['TransportationWaterCrv']['EnumeratedIndexValues']['ZI024_WUR2']['BH020']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['TransportationWaterCrv']['ZI024_WUR3'] = ('Enumeration',('BH020'))
    field_information['GGDM 3.0']['TransportationWaterCrv']['EnumeratedIndexValues']['ZI024_WUR3'] = {}
    field_information['GGDM 3.0']['TransportationWaterCrv']['EnumeratedIndexValues']['ZI024_WUR3']['BH020']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['TransportationWaterCrv']['ZI024_WUR4'] = ('Enumeration',('BH020'))
    field_information['GGDM 3.0']['TransportationWaterCrv']['EnumeratedIndexValues']['ZI024_WUR4'] = {}
    field_information['GGDM 3.0']['TransportationWaterCrv']['EnumeratedIndexValues']['ZI024_WUR4']['BH020']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['TransportationWaterCrv']['ZI024_YWQ'] = ('Enumeration',('BH020'))
    field_information['GGDM 3.0']['TransportationWaterCrv']['EnumeratedIndexValues']['ZI024_YWQ'] = {}
    field_information['GGDM 3.0']['TransportationWaterCrv']['EnumeratedIndexValues']['ZI024_YWQ']['BH020']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['TransportationWaterCrv']['ZI026_CTUC'] = ('Enumeration',('AQ070','BH020','BI006','BI030','BI045'))
    field_information['GGDM 3.0']['TransportationWaterCrv']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['TransportationWaterCrv']['EnumeratedIndexValues']['ZI026_CTUC']['AQ070']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['TransportationWaterCrv']['EnumeratedIndexValues']['ZI026_CTUC']['BH020']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['TransportationWaterCrv']['EnumeratedIndexValues']['ZI026_CTUC']['BI006']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['TransportationWaterCrv']['EnumeratedIndexValues']['ZI026_CTUC']['BI030']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['TransportationWaterCrv']['EnumeratedIndexValues']['ZI026_CTUC']['BI045']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['TransportationWaterCrv']['ZI026_CTUL'] = ('integer',('AQ070','BH020','BI006','BI030','BI045'))
    field_information['GGDM 3.0']['TransportationWaterCrv']['ZI026_CTUU'] = ('integer',('AQ070','BH020','BI006','BI030','BI045'))
    field_information['GGDM 3.0']['TransportationWaterCrv']['ZI031S_URI'] = ('StructuredText',('AQ070','BH020','BI006','BI030','BI045'))
    field_information['GGDM 3.0']['TransportationWaterCrv']['ZI039S_UFI'] = ('StructuredText',('AQ070','BH020','BI006','BI030','BI045'))
    field_information['GGDM 3.0']['TransportationWaterCrv']['ZSAX_RS0'] = ('CodeList',('AQ070','BH020','BI006','BI030','BI045'))
    field_information['GGDM 3.0']['TransportationWaterCrv']['ZSAX_RX0'] = ('StructuredText',('AQ070','BH020','BI006','BI030','BI045'))
    field_information['GGDM 3.0']['TransportationWaterCrv']['ZSAX_RX3'] = ('StructuredText',('AQ070','BH020','BI006','BI030','BI045'))
    field_information['GGDM 3.0']['TransportationWaterCrv']['ZSAX_RX4'] = ('StructuredText',('AQ070','BH020','BI006','BI030','BI045'))
    field_information['GGDM 3.0']['TransportationWaterCrv']['ZVH'] = ('Real',('BH020','BI006','BI030','BI045'))
    field_information['GGDM 3.0']['TransportationWaterPnt']['ADR'] = ('String',('AQ080'))
    field_information['GGDM 3.0']['TransportationWaterPnt']['AOO'] = ('Real',('AQ080','AQ111','BI006','BI030','BI045'))
    field_information['GGDM 3.0']['TransportationWaterPnt']['ARA'] = ('Real',('AQ080','BI006','BI030'))
    field_information['GGDM 3.0']['TransportationWaterPnt']['ATB'] = ('Boolean',('AQ080'))
    field_information['GGDM 3.0']['TransportationWaterPnt']['AWP'] = ('Boolean',('AQ080','BI006'))
    field_information['GGDM 3.0']['TransportationWaterPnt']['BEN'] = ('StructuredText',('AQ080','AQ111','BI006','BI030','BI045'))
    field_information['GGDM 3.0']['TransportationWaterPnt']['BGT'] = ('Enumeration',('BI045'))
    field_information['GGDM 3.0']['TransportationWaterPnt']['EnumeratedIndexValues']['BGT'] = {}
    field_information['GGDM 3.0']['TransportationWaterPnt']['EnumeratedIndexValues']['BGT']['BI045']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['TransportationWaterPnt']['CAA'] = ('Enumeration',('AQ080','AQ111','BI006','BI030'))
    field_information['GGDM 3.0']['TransportationWaterPnt']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['TransportationWaterPnt']['EnumeratedIndexValues']['CAA']['AQ080']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['TransportationWaterPnt']['EnumeratedIndexValues']['CAA']['AQ111']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['TransportationWaterPnt']['EnumeratedIndexValues']['CAA']['BI006']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['TransportationWaterPnt']['EnumeratedIndexValues']['CAA']['BI030']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['TransportationWaterPnt']['CNCP'] = ('StructuredText',('AQ080','AQ111','BI006','BI030','BI045'))
    field_information['GGDM 3.0']['TransportationWaterPnt']['COS'] = ('Enumeration',('AQ080','AQ111','BI006','BI030','BI045'))
    field_information['GGDM 3.0']['TransportationWaterPnt']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['TransportationWaterPnt']['EnumeratedIndexValues']['COS']['AQ080']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['TransportationWaterPnt']['EnumeratedIndexValues']['COS']['AQ111']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['TransportationWaterPnt']['EnumeratedIndexValues']['COS']['BI006']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['TransportationWaterPnt']['EnumeratedIndexValues']['COS']['BI030']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['TransportationWaterPnt']['EnumeratedIndexValues']['COS']['BI045']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['TransportationWaterPnt']['DZP'] = ('Real',('BI006','BI030'))
    field_information['GGDM 3.0']['TransportationWaterPnt']['F_CODE'] = ('CONSTRAINED_STRING',('AQ080','AQ111','BI006','BI030','BI045'))
    field_information['GGDM 3.0']['TransportationWaterPnt']['FFN'] = ('Enumeration',('AQ080'))
    field_information['GGDM 3.0']['TransportationWaterPnt']['EnumeratedIndexValues']['FFN'] = {}
    field_information['GGDM 3.0']['TransportationWaterPnt']['EnumeratedIndexValues']['FFN']['AQ080']  = (-999999,382,482,483,484,490,494,495,505,507,537,538,539,540,847,970,999)
    field_information['GGDM 3.0']['TransportationWaterPnt']['FFN2'] = ('Enumeration',('AQ080'))
    field_information['GGDM 3.0']['TransportationWaterPnt']['EnumeratedIndexValues']['FFN2'] = {}
    field_information['GGDM 3.0']['TransportationWaterPnt']['EnumeratedIndexValues']['FFN2']['AQ080']  = (-999999,382,482,483,484,490,494,495,505,507,537,538,539,540,847,970,999)
    field_information['GGDM 3.0']['TransportationWaterPnt']['FFN3'] = ('Enumeration',('AQ080'))
    field_information['GGDM 3.0']['TransportationWaterPnt']['EnumeratedIndexValues']['FFN3'] = {}
    field_information['GGDM 3.0']['TransportationWaterPnt']['EnumeratedIndexValues']['FFN3']['AQ080']  = (-999999,382,482,483,484,490,494,495,505,507,537,538,539,540,847,970,999)
    field_information['GGDM 3.0']['TransportationWaterPnt']['FUFI'] = ('StructuredText',('AQ080','AQ111','BI006','BI030','BI045'))
    field_information['GGDM 3.0']['TransportationWaterPnt']['FURL'] = ('StructuredText',('AQ080','AQ111','BI006','BI030','BI045'))
    field_information['GGDM 3.0']['TransportationWaterPnt']['GDBV'] = ('Enumeration',('AQ080','AQ111','BI006','BI030','BI045'))
    field_information['GGDM 3.0']['TransportationWaterPnt']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['TransportationWaterPnt']['EnumeratedIndexValues']['GDBV']['AQ080']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['TransportationWaterPnt']['EnumeratedIndexValues']['GDBV']['AQ111']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['TransportationWaterPnt']['EnumeratedIndexValues']['GDBV']['BI006']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['TransportationWaterPnt']['EnumeratedIndexValues']['GDBV']['BI030']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['TransportationWaterPnt']['EnumeratedIndexValues']['GDBV']['BI045']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['TransportationWaterPnt']['HDP'] = ('Real',('BI030','BI045'))
    field_information['GGDM 3.0']['TransportationWaterPnt']['HEI'] = ('Real',('BI045'))
    field_information['GGDM 3.0']['TransportationWaterPnt']['HGT'] = ('Real',('AQ080','AQ111','BI006','BI030','BI045'))
    field_information['GGDM 3.0']['TransportationWaterPnt']['HST'] = ('Enumeration',('AQ080'))
    field_information['GGDM 3.0']['TransportationWaterPnt']['EnumeratedIndexValues']['HST'] = {}
    field_information['GGDM 3.0']['TransportationWaterPnt']['EnumeratedIndexValues']['HST']['AQ080']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['TransportationWaterPnt']['HST2'] = ('Enumeration',('AQ080'))
    field_information['GGDM 3.0']['TransportationWaterPnt']['EnumeratedIndexValues']['HST2'] = {}
    field_information['GGDM 3.0']['TransportationWaterPnt']['EnumeratedIndexValues']['HST2']['AQ080']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['TransportationWaterPnt']['HST3'] = ('Enumeration',('AQ080'))
    field_information['GGDM 3.0']['TransportationWaterPnt']['EnumeratedIndexValues']['HST3'] = {}
    field_information['GGDM 3.0']['TransportationWaterPnt']['EnumeratedIndexValues']['HST3']['AQ080']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['TransportationWaterPnt']['LMC'] = ('Boolean',('AQ080','BI006','BI030','BI045'))
    field_information['GGDM 3.0']['TransportationWaterPnt']['LNU'] = ('Real',('BI006','BI030'))
    field_information['GGDM 3.0']['TransportationWaterPnt']['LZN'] = ('Real',('AQ080','AQ111','BI006','BI030','BI045'))
    field_information['GGDM 3.0']['TransportationWaterPnt']['MCC'] = ('Enumeration',('BI006','BI030','BI045'))
    field_information['GGDM 3.0']['TransportationWaterPnt']['EnumeratedIndexValues']['MCC'] = {}
    field_information['GGDM 3.0']['TransportationWaterPnt']['EnumeratedIndexValues']['MCC']['BI006']  = (-999999,77,83,107,117,150,999)
    field_information['GGDM 3.0']['TransportationWaterPnt']['EnumeratedIndexValues']['MCC']['BI030']  = (-999999,9,21,62,77,83,104,107,108,117,150,999)
    field_information['GGDM 3.0']['TransportationWaterPnt']['EnumeratedIndexValues']['MCC']['BI045']  = (-999999,21,51,64,77,83,107,117,150,999)
    field_information['GGDM 3.0']['TransportationWaterPnt']['MCC2'] = ('Enumeration',('BI006','BI030','BI045'))
    field_information['GGDM 3.0']['TransportationWaterPnt']['EnumeratedIndexValues']['MCC2'] = {}
    field_information['GGDM 3.0']['TransportationWaterPnt']['EnumeratedIndexValues']['MCC2']['BI006']  = (-999999,77,83,107,117,150,999)
    field_information['GGDM 3.0']['TransportationWaterPnt']['EnumeratedIndexValues']['MCC2']['BI030']  = (-999999,9,21,62,77,83,104,107,108,117,150,999)
    field_information['GGDM 3.0']['TransportationWaterPnt']['EnumeratedIndexValues']['MCC2']['BI045']  = (-999999,21,51,64,77,83,107,117,150,999)
    field_information['GGDM 3.0']['TransportationWaterPnt']['MCC3'] = ('Enumeration',('BI006','BI030','BI045'))
    field_information['GGDM 3.0']['TransportationWaterPnt']['EnumeratedIndexValues']['MCC3'] = {}
    field_information['GGDM 3.0']['TransportationWaterPnt']['EnumeratedIndexValues']['MCC3']['BI006']  = (-999999,77,83,107,117,150,999)
    field_information['GGDM 3.0']['TransportationWaterPnt']['EnumeratedIndexValues']['MCC3']['BI030']  = (-999999,9,21,62,77,83,104,107,108,117,150,999)
    field_information['GGDM 3.0']['TransportationWaterPnt']['EnumeratedIndexValues']['MCC3']['BI045']  = (-999999,21,51,64,77,83,107,117,150,999)
    field_information['GGDM 3.0']['TransportationWaterPnt']['MUB'] = ('Boolean',('AQ080'))
    field_information['GGDM 3.0']['TransportationWaterPnt']['MWD'] = ('Real',('BI006','BI030'))
    field_information['GGDM 3.0']['TransportationWaterPnt']['OTH'] = ('StructuredText',('AQ080','AQ111','BI006','BI030','BI045'))
    field_information['GGDM 3.0']['TransportationWaterPnt']['PCF'] = ('Enumeration',('AQ080','AQ111','BI006','BI030','BI045'))
    field_information['GGDM 3.0']['TransportationWaterPnt']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['TransportationWaterPnt']['EnumeratedIndexValues']['PCF']['AQ080']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['TransportationWaterPnt']['EnumeratedIndexValues']['PCF']['AQ111']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['TransportationWaterPnt']['EnumeratedIndexValues']['PCF']['BI006']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['TransportationWaterPnt']['EnumeratedIndexValues']['PCF']['BI030']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['TransportationWaterPnt']['EnumeratedIndexValues']['PCF']['BI045']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['TransportationWaterPnt']['SSR'] = ('Enumeration',('AQ080'))
    field_information['GGDM 3.0']['TransportationWaterPnt']['EnumeratedIndexValues']['SSR'] = {}
    field_information['GGDM 3.0']['TransportationWaterPnt']['EnumeratedIndexValues']['SSR']['AQ080']  = (-999999,6,7,38,40,41,42,47,50,55,64,999)
    field_information['GGDM 3.0']['TransportationWaterPnt']['SSR2'] = ('Enumeration',('AQ080'))
    field_information['GGDM 3.0']['TransportationWaterPnt']['EnumeratedIndexValues']['SSR2'] = {}
    field_information['GGDM 3.0']['TransportationWaterPnt']['EnumeratedIndexValues']['SSR2']['AQ080']  = (-999999,6,7,38,40,41,42,47,50,55,64,999)
    field_information['GGDM 3.0']['TransportationWaterPnt']['SSR3'] = ('Enumeration',('AQ080'))
    field_information['GGDM 3.0']['TransportationWaterPnt']['EnumeratedIndexValues']['SSR3'] = {}
    field_information['GGDM 3.0']['TransportationWaterPnt']['EnumeratedIndexValues']['SSR3']['AQ080']  = (-999999,6,7,38,40,41,42,47,50,55,64,999)
    field_information['GGDM 3.0']['TransportationWaterPnt']['THI'] = ('Real',('BI045'))
    field_information['GGDM 3.0']['TransportationWaterPnt']['TRS'] = ('Enumeration',('AQ080'))
    field_information['GGDM 3.0']['TransportationWaterPnt']['EnumeratedIndexValues']['TRS'] = {}
    field_information['GGDM 3.0']['TransportationWaterPnt']['EnumeratedIndexValues']['TRS']['AQ080']  = (-999999,2,5,7,8,9,12,13,17,20,999)
    field_information['GGDM 3.0']['TransportationWaterPnt']['TRS2'] = ('Enumeration',('AQ080'))
    field_information['GGDM 3.0']['TransportationWaterPnt']['EnumeratedIndexValues']['TRS2'] = {}
    field_information['GGDM 3.0']['TransportationWaterPnt']['EnumeratedIndexValues']['TRS2']['AQ080']  = (-999999,2,5,7,8,9,12,13,17,20,999)
    field_information['GGDM 3.0']['TransportationWaterPnt']['TRS3'] = ('Enumeration',('AQ080'))
    field_information['GGDM 3.0']['TransportationWaterPnt']['EnumeratedIndexValues']['TRS3'] = {}
    field_information['GGDM 3.0']['TransportationWaterPnt']['EnumeratedIndexValues']['TRS3']['AQ080']  = (-999999,2,5,7,8,9,12,13,17,20,999)
    field_information['GGDM 3.0']['TransportationWaterPnt']['UFI'] = ('StructuredText',('AQ080','AQ111','BI006','BI030','BI045'))
    field_information['GGDM 3.0']['TransportationWaterPnt']['VOI'] = ('StructuredText',('AQ080','BI006'))
    field_information['GGDM 3.0']['TransportationWaterPnt']['WDU'] = ('Real',('BI006','BI030'))
    field_information['GGDM 3.0']['TransportationWaterPnt']['WID'] = ('Real',('AQ080','AQ111','BI006','BI030'))
    field_information['GGDM 3.0']['TransportationWaterPnt']['ZI001_SDV'] = ('StructuredText',('AQ080','AQ111','BI006','BI030','BI045'))
    field_information['GGDM 3.0']['TransportationWaterPnt']['ZI001_SRT'] = ('Enumeration',('AQ080','AQ111','BI006','BI030','BI045'))
    field_information['GGDM 3.0']['TransportationWaterPnt']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['TransportationWaterPnt']['EnumeratedIndexValues']['ZI001_SRT']['AQ080']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['TransportationWaterPnt']['EnumeratedIndexValues']['ZI001_SRT']['AQ111']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['TransportationWaterPnt']['EnumeratedIndexValues']['ZI001_SRT']['BI006']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['TransportationWaterPnt']['EnumeratedIndexValues']['ZI001_SRT']['BI030']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['TransportationWaterPnt']['EnumeratedIndexValues']['ZI001_SRT']['BI045']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['TransportationWaterPnt']['ZI002_UFI'] = ('StructuredText',('AQ080','AQ111','BI006','BI030','BI045'))
    field_information['GGDM 3.0']['TransportationWaterPnt']['ZI004_RCG'] = ('Enumeration',('AQ080','AQ111','BI006','BI030','BI045'))
    field_information['GGDM 3.0']['TransportationWaterPnt']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['TransportationWaterPnt']['EnumeratedIndexValues']['ZI004_RCG']['AQ080']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['TransportationWaterPnt']['EnumeratedIndexValues']['ZI004_RCG']['AQ111']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['TransportationWaterPnt']['EnumeratedIndexValues']['ZI004_RCG']['BI006']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['TransportationWaterPnt']['EnumeratedIndexValues']['ZI004_RCG']['BI030']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['TransportationWaterPnt']['EnumeratedIndexValues']['ZI004_RCG']['BI045']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['TransportationWaterPnt']['ZI005_FNA'] = ('String',('AQ080','AQ111','BI006','BI030'))
    field_information['GGDM 3.0']['TransportationWaterPnt']['ZI005_GNT'] = ('Enumeration',('AQ080','AQ111','BI006','BI030'))
    field_information['GGDM 3.0']['TransportationWaterPnt']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['TransportationWaterPnt']['EnumeratedIndexValues']['ZI005_GNT']['AQ080']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['TransportationWaterPnt']['EnumeratedIndexValues']['ZI005_GNT']['AQ111']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['TransportationWaterPnt']['EnumeratedIndexValues']['ZI005_GNT']['BI006']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['TransportationWaterPnt']['EnumeratedIndexValues']['ZI005_GNT']['BI030']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['TransportationWaterPnt']['ZI005_NFN'] = ('String',('AQ080','AQ111','BI006','BI030'))
    field_information['GGDM 3.0']['TransportationWaterPnt']['ZI006_MEM'] = ('String',('AQ080','AQ111','BI006','BI030','BI045'))
    field_information['GGDM 3.0']['TransportationWaterPnt']['ZI020_GE4'] = ('CodeList',('AQ080','AQ111','BI006','BI030','BI045'))
    field_information['GGDM 3.0']['TransportationWaterPnt']['ZI026_CTUC'] = ('Enumeration',('AQ080','AQ111','BI006','BI030','BI045'))
    field_information['GGDM 3.0']['TransportationWaterPnt']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['TransportationWaterPnt']['EnumeratedIndexValues']['ZI026_CTUC']['AQ080']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['TransportationWaterPnt']['EnumeratedIndexValues']['ZI026_CTUC']['AQ111']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['TransportationWaterPnt']['EnumeratedIndexValues']['ZI026_CTUC']['BI006']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['TransportationWaterPnt']['EnumeratedIndexValues']['ZI026_CTUC']['BI030']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['TransportationWaterPnt']['EnumeratedIndexValues']['ZI026_CTUC']['BI045']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['TransportationWaterPnt']['ZI026_CTUL'] = ('integer',('AQ080','AQ111','BI006','BI030','BI045'))
    field_information['GGDM 3.0']['TransportationWaterPnt']['ZI026_CTUU'] = ('integer',('AQ080','AQ111','BI006','BI030','BI045'))
    field_information['GGDM 3.0']['TransportationWaterPnt']['ZI031S_URI'] = ('StructuredText',('AQ080','AQ111','BI006','BI030','BI045'))
    field_information['GGDM 3.0']['TransportationWaterPnt']['ZI039S_UFI'] = ('StructuredText',('AQ080','AQ111','BI006','BI030','BI045'))
    field_information['GGDM 3.0']['TransportationWaterPnt']['ZSAX_RS0'] = ('CodeList',('AQ080','AQ111','BI006','BI030','BI045'))
    field_information['GGDM 3.0']['TransportationWaterPnt']['ZSAX_RX0'] = ('StructuredText',('AQ080','AQ111','BI006','BI030','BI045'))
    field_information['GGDM 3.0']['TransportationWaterPnt']['ZSAX_RX3'] = ('StructuredText',('AQ080','AQ111','BI006','BI030','BI045'))
    field_information['GGDM 3.0']['TransportationWaterPnt']['ZSAX_RX4'] = ('StructuredText',('AQ080','AQ111','BI006','BI030','BI045'))
    field_information['GGDM 3.0']['TransportationWaterPnt']['ZVH'] = ('Real',('AQ080','BI006','BI030','BI045'))
    field_information['GGDM 3.0']['TransportationWaterPntExt']['AOO'] = ('Real',('AQ070'))
    field_information['GGDM 3.0']['TransportationWaterPntExt']['BEN'] = ('StructuredText',('AQ070'))
    field_information['GGDM 3.0']['TransportationWaterPntExt']['CAA'] = ('Enumeration',('AQ070'))
    field_information['GGDM 3.0']['TransportationWaterPntExt']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['TransportationWaterPntExt']['EnumeratedIndexValues']['CAA']['AQ070']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['TransportationWaterPntExt']['CNCP'] = ('StructuredText',('AQ070'))
    field_information['GGDM 3.0']['TransportationWaterPntExt']['COS'] = ('Enumeration',('AQ070'))
    field_information['GGDM 3.0']['TransportationWaterPntExt']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['TransportationWaterPntExt']['EnumeratedIndexValues']['COS']['AQ070']  = (-999999,2,4,6,9,13,14)
    field_information['GGDM 3.0']['TransportationWaterPntExt']['F_CODE'] = ('CONSTRAINED_STRING',('AQ070'))
    field_information['GGDM 3.0']['TransportationWaterPntExt']['FCL'] = ('Real',('AQ070'))
    field_information['GGDM 3.0']['TransportationWaterPntExt']['FER'] = ('Enumeration',('AQ070'))
    field_information['GGDM 3.0']['TransportationWaterPntExt']['EnumeratedIndexValues']['FER'] = {}
    field_information['GGDM 3.0']['TransportationWaterPntExt']['EnumeratedIndexValues']['FER']['AQ070']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['TransportationWaterPntExt']['FUFI'] = ('StructuredText',('AQ070'))
    field_information['GGDM 3.0']['TransportationWaterPntExt']['FURL'] = ('StructuredText',('AQ070'))
    field_information['GGDM 3.0']['TransportationWaterPntExt']['GDBV'] = ('Enumeration',('AQ070'))
    field_information['GGDM 3.0']['TransportationWaterPntExt']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['TransportationWaterPntExt']['EnumeratedIndexValues']['GDBV']['AQ070']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['TransportationWaterPntExt']['LMC'] = ('Boolean',('AQ070'))
    field_information['GGDM 3.0']['TransportationWaterPntExt']['LZN'] = ('Real',('AQ070'))
    field_information['GGDM 3.0']['TransportationWaterPntExt']['MCX'] = ('Boolean',('AQ070'))
    field_information['GGDM 3.0']['TransportationWaterPntExt']['OPT'] = ('Enumeration',('AQ070'))
    field_information['GGDM 3.0']['TransportationWaterPntExt']['EnumeratedIndexValues']['OPT'] = {}
    field_information['GGDM 3.0']['TransportationWaterPntExt']['EnumeratedIndexValues']['OPT']['AQ070']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['TransportationWaterPntExt']['OTH'] = ('StructuredText',('AQ070'))
    field_information['GGDM 3.0']['TransportationWaterPntExt']['PSN'] = ('Real',('AQ070'))
    field_information['GGDM 3.0']['TransportationWaterPntExt']['RIN_ROI'] = ('Enumeration',('AQ070'))
    field_information['GGDM 3.0']['TransportationWaterPntExt']['EnumeratedIndexValues']['RIN_ROI'] = {}
    field_information['GGDM 3.0']['TransportationWaterPntExt']['EnumeratedIndexValues']['RIN_ROI']['AQ070']  = (-999999,1,2,3,4,5,999)
    field_information['GGDM 3.0']['TransportationWaterPntExt']['RIN_ROI2'] = ('Enumeration',('AQ070'))
    field_information['GGDM 3.0']['TransportationWaterPntExt']['EnumeratedIndexValues']['RIN_ROI2'] = {}
    field_information['GGDM 3.0']['TransportationWaterPntExt']['EnumeratedIndexValues']['RIN_ROI2']['AQ070']  = (-999999,1,2,3,4,5,999)
    field_information['GGDM 3.0']['TransportationWaterPntExt']['RIN_ROI3'] = ('Enumeration',('AQ070'))
    field_information['GGDM 3.0']['TransportationWaterPntExt']['EnumeratedIndexValues']['RIN_ROI3'] = {}
    field_information['GGDM 3.0']['TransportationWaterPntExt']['EnumeratedIndexValues']['RIN_ROI3']['AQ070']  = (-999999,1,2,3,4,5,999)
    field_information['GGDM 3.0']['TransportationWaterPntExt']['RIN_RTN'] = ('String',('AQ070'))
    field_information['GGDM 3.0']['TransportationWaterPntExt']['RIN_RTN2'] = ('String',('AQ070'))
    field_information['GGDM 3.0']['TransportationWaterPntExt']['RIN_RTN3'] = ('String',('AQ070'))
    field_information['GGDM 3.0']['TransportationWaterPntExt']['SPD'] = ('Real',('AQ070'))
    field_information['GGDM 3.0']['TransportationWaterPntExt']['SPM'] = ('Real',('AQ070'))
    field_information['GGDM 3.0']['TransportationWaterPntExt']['TRS'] = ('Enumeration',('AQ070'))
    field_information['GGDM 3.0']['TransportationWaterPntExt']['EnumeratedIndexValues']['TRS'] = {}
    field_information['GGDM 3.0']['TransportationWaterPntExt']['EnumeratedIndexValues']['TRS']['AQ070']  = (-999999,9,12,13,999)
    field_information['GGDM 3.0']['TransportationWaterPntExt']['TRS2'] = ('Enumeration',('AQ070'))
    field_information['GGDM 3.0']['TransportationWaterPntExt']['EnumeratedIndexValues']['TRS2'] = {}
    field_information['GGDM 3.0']['TransportationWaterPntExt']['EnumeratedIndexValues']['TRS2']['AQ070']  = (-999999,9,12,13,999)
    field_information['GGDM 3.0']['TransportationWaterPntExt']['TRS3'] = ('Enumeration',('AQ070'))
    field_information['GGDM 3.0']['TransportationWaterPntExt']['EnumeratedIndexValues']['TRS3'] = {}
    field_information['GGDM 3.0']['TransportationWaterPntExt']['EnumeratedIndexValues']['TRS3']['AQ070']  = (-999999,9,12,13,999)
    field_information['GGDM 3.0']['TransportationWaterPntExt']['UFI'] = ('StructuredText',('AQ070'))
    field_information['GGDM 3.0']['TransportationWaterPntExt']['ZI001_SDV'] = ('StructuredText',('AQ070'))
    field_information['GGDM 3.0']['TransportationWaterPntExt']['ZI001_SRT'] = ('Enumeration',('AQ070'))
    field_information['GGDM 3.0']['TransportationWaterPntExt']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['TransportationWaterPntExt']['EnumeratedIndexValues']['ZI001_SRT']['AQ070']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['TransportationWaterPntExt']['ZI002_UFI'] = ('StructuredText',('AQ070'))
    field_information['GGDM 3.0']['TransportationWaterPntExt']['ZI004_RCG'] = ('Enumeration',('AQ070'))
    field_information['GGDM 3.0']['TransportationWaterPntExt']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['TransportationWaterPntExt']['EnumeratedIndexValues']['ZI004_RCG']['AQ070']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['TransportationWaterPntExt']['ZI005_FNA'] = ('String',('AQ070'))
    field_information['GGDM 3.0']['TransportationWaterPntExt']['ZI005_GNT'] = ('Enumeration',('AQ070'))
    field_information['GGDM 3.0']['TransportationWaterPntExt']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['TransportationWaterPntExt']['EnumeratedIndexValues']['ZI005_GNT']['AQ070']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['TransportationWaterPntExt']['ZI005_NFN'] = ('String',('AQ070'))
    field_information['GGDM 3.0']['TransportationWaterPntExt']['ZI006_MEM'] = ('String',('AQ070'))
    field_information['GGDM 3.0']['TransportationWaterPntExt']['ZI020_GE4'] = ('CodeList',('AQ070'))
    field_information['GGDM 3.0']['TransportationWaterPntExt']['ZI026_CTUC'] = ('Enumeration',('AQ070'))
    field_information['GGDM 3.0']['TransportationWaterPntExt']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['TransportationWaterPntExt']['EnumeratedIndexValues']['ZI026_CTUC']['AQ070']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['TransportationWaterPntExt']['ZI026_CTUL'] = ('integer',('AQ070'))
    field_information['GGDM 3.0']['TransportationWaterPntExt']['ZI026_CTUU'] = ('integer',('AQ070'))
    field_information['GGDM 3.0']['TransportationWaterPntExt']['ZI031S_URI'] = ('StructuredText',('AQ070'))
    field_information['GGDM 3.0']['TransportationWaterPntExt']['ZI039S_UFI'] = ('StructuredText',('AQ070'))
    field_information['GGDM 3.0']['TransportationWaterPntExt']['ZSAX_RS0'] = ('CodeList',('AQ070'))
    field_information['GGDM 3.0']['TransportationWaterPntExt']['ZSAX_RX0'] = ('StructuredText',('AQ070'))
    field_information['GGDM 3.0']['TransportationWaterPntExt']['ZSAX_RX3'] = ('StructuredText',('AQ070'))
    field_information['GGDM 3.0']['TransportationWaterPntExt']['ZSAX_RX4'] = ('StructuredText',('AQ070'))
    field_information['GGDM 3.0']['TransportationWaterSrf']['ADR'] = ('String',('AQ080'))
    field_information['GGDM 3.0']['TransportationWaterSrf']['AOO'] = ('Real',('AQ080','BI006','BI030'))
    field_information['GGDM 3.0']['TransportationWaterSrf']['ARA'] = ('Real',('AQ080','BH020','BI006','BI030'))
    field_information['GGDM 3.0']['TransportationWaterSrf']['ATB'] = ('Boolean',('AQ080'))
    field_information['GGDM 3.0']['TransportationWaterSrf']['AWP'] = ('Boolean',('AQ080','BI006'))
    field_information['GGDM 3.0']['TransportationWaterSrf']['BBMCA'] = ('Enumeration',('BH020'))
    field_information['GGDM 3.0']['TransportationWaterSrf']['EnumeratedIndexValues']['BBMCA'] = {}
    field_information['GGDM 3.0']['TransportationWaterSrf']['EnumeratedIndexValues']['BBMCA']['BH020']  = (-999999,1,2,3,4,5,6,7,8,9,11,14,15,16,17,18,999)
    field_information['GGDM 3.0']['TransportationWaterSrf']['BBMCA2'] = ('Enumeration',('BH020'))
    field_information['GGDM 3.0']['TransportationWaterSrf']['EnumeratedIndexValues']['BBMCA2'] = {}
    field_information['GGDM 3.0']['TransportationWaterSrf']['EnumeratedIndexValues']['BBMCA2']['BH020']  = (-999999,1,2,3,4,5,6,7,8,9,11,14,15,16,17,18,999)
    field_information['GGDM 3.0']['TransportationWaterSrf']['BBMCA3'] = ('Enumeration',('BH020'))
    field_information['GGDM 3.0']['TransportationWaterSrf']['EnumeratedIndexValues']['BBMCA3'] = {}
    field_information['GGDM 3.0']['TransportationWaterSrf']['EnumeratedIndexValues']['BBMCA3']['BH020']  = (-999999,1,2,3,4,5,6,7,8,9,11,14,15,16,17,18,999)
    field_information['GGDM 3.0']['TransportationWaterSrf']['BBMCB'] = ('Enumeration',('BH020'))
    field_information['GGDM 3.0']['TransportationWaterSrf']['EnumeratedIndexValues']['BBMCB'] = {}
    field_information['GGDM 3.0']['TransportationWaterSrf']['EnumeratedIndexValues']['BBMCB']['BH020']  = (-999999,1,2,3,4,5,6,7,8,9,11,14,15,16,17,18,999)
    field_information['GGDM 3.0']['TransportationWaterSrf']['BBMCB2'] = ('Enumeration',('BH020'))
    field_information['GGDM 3.0']['TransportationWaterSrf']['EnumeratedIndexValues']['BBMCB2'] = {}
    field_information['GGDM 3.0']['TransportationWaterSrf']['EnumeratedIndexValues']['BBMCB2']['BH020']  = (-999999,1,2,3,4,5,6,7,8,9,11,14,15,16,17,18,999)
    field_information['GGDM 3.0']['TransportationWaterSrf']['BBMCB3'] = ('Enumeration',('BH020'))
    field_information['GGDM 3.0']['TransportationWaterSrf']['EnumeratedIndexValues']['BBMCB3'] = {}
    field_information['GGDM 3.0']['TransportationWaterSrf']['EnumeratedIndexValues']['BBMCB3']['BH020']  = (-999999,1,2,3,4,5,6,7,8,9,11,14,15,16,17,18,999)
    field_information['GGDM 3.0']['TransportationWaterSrf']['BEN'] = ('StructuredText',('AQ080','BH020','BI006','BI030'))
    field_information['GGDM 3.0']['TransportationWaterSrf']['BH141_AWBA'] = ('Real',('BH020'))
    field_information['GGDM 3.0']['TransportationWaterSrf']['BH141_AWBB'] = ('Real',('BH020'))
    field_information['GGDM 3.0']['TransportationWaterSrf']['BH141_IBOA'] = ('Enumeration',('BH020'))
    field_information['GGDM 3.0']['TransportationWaterSrf']['EnumeratedIndexValues']['BH141_IBOA'] = {}
    field_information['GGDM 3.0']['TransportationWaterSrf']['EnumeratedIndexValues']['BH141_IBOA']['BH020']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['TransportationWaterSrf']['BH141_IBOB'] = ('Enumeration',('BH020'))
    field_information['GGDM 3.0']['TransportationWaterSrf']['EnumeratedIndexValues']['BH141_IBOB'] = {}
    field_information['GGDM 3.0']['TransportationWaterSrf']['EnumeratedIndexValues']['BH141_IBOB']['BH020']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['TransportationWaterSrf']['BH141_SHDA'] = ('Boolean',('BH020'))
    field_information['GGDM 3.0']['TransportationWaterSrf']['BH141_SHDB'] = ('Boolean',('BH020'))
    field_information['GGDM 3.0']['TransportationWaterSrf']['BH141_SLTA'] = ('Enumeration',('BH020'))
    field_information['GGDM 3.0']['TransportationWaterSrf']['EnumeratedIndexValues']['BH141_SLTA'] = {}
    field_information['GGDM 3.0']['TransportationWaterSrf']['EnumeratedIndexValues']['BH141_SLTA']['BH020']  = (-999999,6,8,10,11,12,13,14,16,17,18,999)
    field_information['GGDM 3.0']['TransportationWaterSrf']['BH141_SLTB'] = ('Enumeration',('BH020'))
    field_information['GGDM 3.0']['TransportationWaterSrf']['EnumeratedIndexValues']['BH141_SLTB'] = {}
    field_information['GGDM 3.0']['TransportationWaterSrf']['EnumeratedIndexValues']['BH141_SLTB']['BH020']  = (-999999,6,8,10,11,12,13,14,17,18,999)
    field_information['GGDM 3.0']['TransportationWaterSrf']['BH141_WBHA'] = ('Real',('BH020'))
    field_information['GGDM 3.0']['TransportationWaterSrf']['BH141_WBHB'] = ('Real',('BH020'))
    field_information['GGDM 3.0']['TransportationWaterSrf']['BMC'] = ('Enumeration',('BH020'))
    field_information['GGDM 3.0']['TransportationWaterSrf']['EnumeratedIndexValues']['BMC'] = {}
    field_information['GGDM 3.0']['TransportationWaterSrf']['EnumeratedIndexValues']['BMC']['BH020']  = (-999999,1,2,3,4,5,6,7,8,9,14,15,16,17,18,999)
    field_information['GGDM 3.0']['TransportationWaterSrf']['BMC2'] = ('Enumeration',('BH020'))
    field_information['GGDM 3.0']['TransportationWaterSrf']['EnumeratedIndexValues']['BMC2'] = {}
    field_information['GGDM 3.0']['TransportationWaterSrf']['EnumeratedIndexValues']['BMC2']['BH020']  = (-999999,1,2,3,4,5,6,7,8,9,14,15,16,17,18,999)
    field_information['GGDM 3.0']['TransportationWaterSrf']['BMC3'] = ('Enumeration',('BH020'))
    field_information['GGDM 3.0']['TransportationWaterSrf']['EnumeratedIndexValues']['BMC3'] = {}
    field_information['GGDM 3.0']['TransportationWaterSrf']['EnumeratedIndexValues']['BMC3']['BH020']  = (-999999,1,2,3,4,5,6,7,8,9,14,15,16,17,18,999)
    field_information['GGDM 3.0']['TransportationWaterSrf']['BPWHAC'] = ('Enumeration',('BH020'))
    field_information['GGDM 3.0']['TransportationWaterSrf']['EnumeratedIndexValues']['BPWHAC'] = {}
    field_information['GGDM 3.0']['TransportationWaterSrf']['EnumeratedIndexValues']['BPWHAC']['BH020']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['TransportationWaterSrf']['BPWHAL'] = ('real',('BH020'))
    field_information['GGDM 3.0']['TransportationWaterSrf']['BPWHAU'] = ('real',('BH020'))
    field_information['GGDM 3.0']['TransportationWaterSrf']['BPWHBC'] = ('Enumeration',('BH020'))
    field_information['GGDM 3.0']['TransportationWaterSrf']['EnumeratedIndexValues']['BPWHBC'] = {}
    field_information['GGDM 3.0']['TransportationWaterSrf']['EnumeratedIndexValues']['BPWHBC']['BH020']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['TransportationWaterSrf']['BPWHBL'] = ('real',('BH020'))
    field_information['GGDM 3.0']['TransportationWaterSrf']['BPWHBU'] = ('real',('BH020'))
    field_information['GGDM 3.0']['TransportationWaterSrf']['BPWSAC'] = ('Enumeration',('BH020'))
    field_information['GGDM 3.0']['TransportationWaterSrf']['EnumeratedIndexValues']['BPWSAC'] = {}
    field_information['GGDM 3.0']['TransportationWaterSrf']['EnumeratedIndexValues']['BPWSAC']['BH020']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['TransportationWaterSrf']['BPWSAL'] = ('real',('BH020'))
    field_information['GGDM 3.0']['TransportationWaterSrf']['BPWSAU'] = ('real',('BH020'))
    field_information['GGDM 3.0']['TransportationWaterSrf']['BPWSBC'] = ('Enumeration',('BH020'))
    field_information['GGDM 3.0']['TransportationWaterSrf']['EnumeratedIndexValues']['BPWSBC'] = {}
    field_information['GGDM 3.0']['TransportationWaterSrf']['EnumeratedIndexValues']['BPWSBC']['BH020']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['TransportationWaterSrf']['BPWSBL'] = ('real',('BH020'))
    field_information['GGDM 3.0']['TransportationWaterSrf']['BPWSBU'] = ('real',('BH020'))
    field_information['GGDM 3.0']['TransportationWaterSrf']['BWVCAC'] = ('Enumeration',('BH020'))
    field_information['GGDM 3.0']['TransportationWaterSrf']['EnumeratedIndexValues']['BWVCAC'] = {}
    field_information['GGDM 3.0']['TransportationWaterSrf']['EnumeratedIndexValues']['BWVCAC']['BH020']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['TransportationWaterSrf']['BWVCAL'] = ('real',('BH020'))
    field_information['GGDM 3.0']['TransportationWaterSrf']['BWVCAU'] = ('real',('BH020'))
    field_information['GGDM 3.0']['TransportationWaterSrf']['BWVCBC'] = ('Enumeration',('BH020'))
    field_information['GGDM 3.0']['TransportationWaterSrf']['EnumeratedIndexValues']['BWVCBC'] = {}
    field_information['GGDM 3.0']['TransportationWaterSrf']['EnumeratedIndexValues']['BWVCBC']['BH020']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['TransportationWaterSrf']['BWVCBL'] = ('real',('BH020'))
    field_information['GGDM 3.0']['TransportationWaterSrf']['BWVCBU'] = ('real',('BH020'))
    field_information['GGDM 3.0']['TransportationWaterSrf']['CAA'] = ('Enumeration',('AQ080','BH020','BI006','BI030'))
    field_information['GGDM 3.0']['TransportationWaterSrf']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['TransportationWaterSrf']['EnumeratedIndexValues']['CAA']['AQ080']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['TransportationWaterSrf']['EnumeratedIndexValues']['CAA']['BH020']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['TransportationWaterSrf']['EnumeratedIndexValues']['CAA']['BI006']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['TransportationWaterSrf']['EnumeratedIndexValues']['CAA']['BI030']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['TransportationWaterSrf']['CDA'] = ('Boolean',('BH020'))
    field_information['GGDM 3.0']['TransportationWaterSrf']['CDL'] = ('Real',('BH020'))
    field_information['GGDM 3.0']['TransportationWaterSrf']['CNCP'] = ('StructuredText',('AQ080','BH020','BI006','BI030'))
    field_information['GGDM 3.0']['TransportationWaterSrf']['COS'] = ('Enumeration',('AQ080','BH020','BI006','BI030'))
    field_information['GGDM 3.0']['TransportationWaterSrf']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['TransportationWaterSrf']['EnumeratedIndexValues']['COS']['AQ080']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['TransportationWaterSrf']['EnumeratedIndexValues']['COS']['BH020']  = (-999999,2,4,6,9,13,14)
    field_information['GGDM 3.0']['TransportationWaterSrf']['EnumeratedIndexValues']['COS']['BI006']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['TransportationWaterSrf']['EnumeratedIndexValues']['COS']['BI030']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['TransportationWaterSrf']['CWT'] = ('Boolean',('BH020'))
    field_information['GGDM 3.0']['TransportationWaterSrf']['DEV'] = ('Integer',('BH020'))
    field_information['GGDM 3.0']['TransportationWaterSrf']['DOXY'] = ('Real',('BH020'))
    field_information['GGDM 3.0']['TransportationWaterSrf']['DZP'] = ('Real',('BH020','BI006','BI030'))
    field_information['GGDM 3.0']['TransportationWaterSrf']['F_CODE'] = ('CONSTRAINED_STRING',('AQ080','BH020','BI006','BI030'))
    field_information['GGDM 3.0']['TransportationWaterSrf']['FFN'] = ('Enumeration',('AQ080'))
    field_information['GGDM 3.0']['TransportationWaterSrf']['EnumeratedIndexValues']['FFN'] = {}
    field_information['GGDM 3.0']['TransportationWaterSrf']['EnumeratedIndexValues']['FFN']['AQ080']  = (-999999,382,482,483,484,490,494,495,505,507,537,538,539,540,847,970,999)
    field_information['GGDM 3.0']['TransportationWaterSrf']['FFN2'] = ('Enumeration',('AQ080'))
    field_information['GGDM 3.0']['TransportationWaterSrf']['EnumeratedIndexValues']['FFN2'] = {}
    field_information['GGDM 3.0']['TransportationWaterSrf']['EnumeratedIndexValues']['FFN2']['AQ080']  = (-999999,382,482,483,484,490,494,495,505,507,537,538,539,540,847,970,999)
    field_information['GGDM 3.0']['TransportationWaterSrf']['FFN3'] = ('Enumeration',('AQ080'))
    field_information['GGDM 3.0']['TransportationWaterSrf']['EnumeratedIndexValues']['FFN3'] = {}
    field_information['GGDM 3.0']['TransportationWaterSrf']['EnumeratedIndexValues']['FFN3']['AQ080']  = (-999999,382,482,483,484,490,494,495,505,507,537,538,539,540,847,970,999)
    field_information['GGDM 3.0']['TransportationWaterSrf']['FRZ'] = ('Boolean',('BH020'))
    field_information['GGDM 3.0']['TransportationWaterSrf']['FUFI'] = ('StructuredText',('AQ080','BH020','BI006','BI030'))
    field_information['GGDM 3.0']['TransportationWaterSrf']['FURL'] = ('StructuredText',('AQ080','BH020','BI006','BI030'))
    field_information['GGDM 3.0']['TransportationWaterSrf']['GDBV'] = ('Enumeration',('AQ080','BH020','BI006','BI030'))
    field_information['GGDM 3.0']['TransportationWaterSrf']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['TransportationWaterSrf']['EnumeratedIndexValues']['GDBV']['AQ080']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['TransportationWaterSrf']['EnumeratedIndexValues']['GDBV']['BH020']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['TransportationWaterSrf']['EnumeratedIndexValues']['GDBV']['BI006']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['TransportationWaterSrf']['EnumeratedIndexValues']['GDBV']['BI030']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['TransportationWaterSrf']['HDP'] = ('Real',('BH020','BI030'))
    field_information['GGDM 3.0']['TransportationWaterSrf']['HGT'] = ('Real',('AQ080','BH020','BI006','BI030'))
    field_information['GGDM 3.0']['TransportationWaterSrf']['HST'] = ('Enumeration',('AQ080'))
    field_information['GGDM 3.0']['TransportationWaterSrf']['EnumeratedIndexValues']['HST'] = {}
    field_information['GGDM 3.0']['TransportationWaterSrf']['EnumeratedIndexValues']['HST']['AQ080']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['TransportationWaterSrf']['HST2'] = ('Enumeration',('AQ080'))
    field_information['GGDM 3.0']['TransportationWaterSrf']['EnumeratedIndexValues']['HST2'] = {}
    field_information['GGDM 3.0']['TransportationWaterSrf']['EnumeratedIndexValues']['HST2']['AQ080']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['TransportationWaterSrf']['HST3'] = ('Enumeration',('AQ080'))
    field_information['GGDM 3.0']['TransportationWaterSrf']['EnumeratedIndexValues']['HST3'] = {}
    field_information['GGDM 3.0']['TransportationWaterSrf']['EnumeratedIndexValues']['HST3']['AQ080']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['TransportationWaterSrf']['LEA'] = ('Real',('BH020'))
    field_information['GGDM 3.0']['TransportationWaterSrf']['LMC'] = ('Boolean',('AQ080','BH020','BI006','BI030'))
    field_information['GGDM 3.0']['TransportationWaterSrf']['LNU'] = ('Real',('BI006','BI030'))
    field_information['GGDM 3.0']['TransportationWaterSrf']['LOC'] = ('Enumeration',('BH020'))
    field_information['GGDM 3.0']['TransportationWaterSrf']['EnumeratedIndexValues']['LOC'] = {}
    field_information['GGDM 3.0']['TransportationWaterSrf']['EnumeratedIndexValues']['LOC']['BH020']  = (-999999,40,44)
    field_information['GGDM 3.0']['TransportationWaterSrf']['LZN'] = ('Real',('AQ080','BH020','BI006','BI030'))
    field_information['GGDM 3.0']['TransportationWaterSrf']['MCC'] = ('Enumeration',('BI006','BI030'))
    field_information['GGDM 3.0']['TransportationWaterSrf']['EnumeratedIndexValues']['MCC'] = {}
    field_information['GGDM 3.0']['TransportationWaterSrf']['EnumeratedIndexValues']['MCC']['BI006']  = (-999999,77,83,107,117,150,999)
    field_information['GGDM 3.0']['TransportationWaterSrf']['EnumeratedIndexValues']['MCC']['BI030']  = (-999999,9,21,62,77,83,104,107,108,117,150,999)
    field_information['GGDM 3.0']['TransportationWaterSrf']['MCC2'] = ('Enumeration',('BI006','BI030'))
    field_information['GGDM 3.0']['TransportationWaterSrf']['EnumeratedIndexValues']['MCC2'] = {}
    field_information['GGDM 3.0']['TransportationWaterSrf']['EnumeratedIndexValues']['MCC2']['BI006']  = (-999999,77,83,107,117,150,999)
    field_information['GGDM 3.0']['TransportationWaterSrf']['EnumeratedIndexValues']['MCC2']['BI030']  = (-999999,9,21,62,77,83,104,107,108,117,150,999)
    field_information['GGDM 3.0']['TransportationWaterSrf']['MCC3'] = ('Enumeration',('BI006','BI030'))
    field_information['GGDM 3.0']['TransportationWaterSrf']['EnumeratedIndexValues']['MCC3'] = {}
    field_information['GGDM 3.0']['TransportationWaterSrf']['EnumeratedIndexValues']['MCC3']['BI006']  = (-999999,77,83,107,117,150,999)
    field_information['GGDM 3.0']['TransportationWaterSrf']['EnumeratedIndexValues']['MCC3']['BI030']  = (-999999,9,21,62,77,83,104,107,108,117,150,999)
    field_information['GGDM 3.0']['TransportationWaterSrf']['MUB'] = ('Boolean',('AQ080'))
    field_information['GGDM 3.0']['TransportationWaterSrf']['MWD'] = ('Real',('BH020','BI006','BI030'))
    field_information['GGDM 3.0']['TransportationWaterSrf']['NVS'] = ('Enumeration',('BH020'))
    field_information['GGDM 3.0']['TransportationWaterSrf']['EnumeratedIndexValues']['NVS'] = {}
    field_information['GGDM 3.0']['TransportationWaterSrf']['EnumeratedIndexValues']['NVS']['BH020']  = (-999999,1,2,3,4,5,999)
    field_information['GGDM 3.0']['TransportationWaterSrf']['OTH'] = ('StructuredText',('AQ080','BH020','BI006','BI030'))
    field_information['GGDM 3.0']['TransportationWaterSrf']['PCF'] = ('Enumeration',('AQ080','BH020','BI006','BI030'))
    field_information['GGDM 3.0']['TransportationWaterSrf']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['TransportationWaterSrf']['EnumeratedIndexValues']['PCF']['AQ080']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['TransportationWaterSrf']['EnumeratedIndexValues']['PCF']['BH020']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['TransportationWaterSrf']['EnumeratedIndexValues']['PCF']['BI006']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['TransportationWaterSrf']['EnumeratedIndexValues']['PCF']['BI030']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['TransportationWaterSrf']['PWA'] = ('Real',('BH020'))
    field_information['GGDM 3.0']['TransportationWaterSrf']['RLE'] = ('Enumeration',('BH020'))
    field_information['GGDM 3.0']['TransportationWaterSrf']['EnumeratedIndexValues']['RLE'] = {}
    field_information['GGDM 3.0']['TransportationWaterSrf']['EnumeratedIndexValues']['RLE']['BH020']  = (-999999,1,2,3,998)
    field_information['GGDM 3.0']['TransportationWaterSrf']['SBB'] = ('Boolean',('BH020'))
    field_information['GGDM 3.0']['TransportationWaterSrf']['SSR'] = ('Enumeration',('AQ080'))
    field_information['GGDM 3.0']['TransportationWaterSrf']['EnumeratedIndexValues']['SSR'] = {}
    field_information['GGDM 3.0']['TransportationWaterSrf']['EnumeratedIndexValues']['SSR']['AQ080']  = (-999999,6,7,38,40,41,42,47,50,55,64,999)
    field_information['GGDM 3.0']['TransportationWaterSrf']['SSR2'] = ('Enumeration',('AQ080'))
    field_information['GGDM 3.0']['TransportationWaterSrf']['EnumeratedIndexValues']['SSR2'] = {}
    field_information['GGDM 3.0']['TransportationWaterSrf']['EnumeratedIndexValues']['SSR2']['AQ080']  = (-999999,6,7,38,40,41,42,47,50,55,64,999)
    field_information['GGDM 3.0']['TransportationWaterSrf']['SSR3'] = ('Enumeration',('AQ080'))
    field_information['GGDM 3.0']['TransportationWaterSrf']['EnumeratedIndexValues']['SSR3'] = {}
    field_information['GGDM 3.0']['TransportationWaterSrf']['EnumeratedIndexValues']['SSR3']['AQ080']  = (-999999,6,7,38,40,41,42,47,50,55,64,999)
    field_information['GGDM 3.0']['TransportationWaterSrf']['TID'] = ('Boolean',('BH020'))
    field_information['GGDM 3.0']['TransportationWaterSrf']['TRS'] = ('Enumeration',('AQ080'))
    field_information['GGDM 3.0']['TransportationWaterSrf']['EnumeratedIndexValues']['TRS'] = {}
    field_information['GGDM 3.0']['TransportationWaterSrf']['EnumeratedIndexValues']['TRS']['AQ080']  = (-999999,2,5,7,8,9,12,13,17,20,999)
    field_information['GGDM 3.0']['TransportationWaterSrf']['TRS2'] = ('Enumeration',('AQ080'))
    field_information['GGDM 3.0']['TransportationWaterSrf']['EnumeratedIndexValues']['TRS2'] = {}
    field_information['GGDM 3.0']['TransportationWaterSrf']['EnumeratedIndexValues']['TRS2']['AQ080']  = (-999999,2,5,7,8,9,12,13,17,20,999)
    field_information['GGDM 3.0']['TransportationWaterSrf']['TRS3'] = ('Enumeration',('AQ080'))
    field_information['GGDM 3.0']['TransportationWaterSrf']['EnumeratedIndexValues']['TRS3'] = {}
    field_information['GGDM 3.0']['TransportationWaterSrf']['EnumeratedIndexValues']['TRS3']['AQ080']  = (-999999,2,5,7,8,9,12,13,17,20,999)
    field_information['GGDM 3.0']['TransportationWaterSrf']['UFI'] = ('StructuredText',('AQ080','BH020','BI006','BI030'))
    field_information['GGDM 3.0']['TransportationWaterSrf']['VOI'] = ('StructuredText',('AQ080','BI006'))
    field_information['GGDM 3.0']['TransportationWaterSrf']['WD3'] = ('Real',('BH020'))
    field_information['GGDM 3.0']['TransportationWaterSrf']['WDAC'] = ('Enumeration',('BH020'))
    field_information['GGDM 3.0']['TransportationWaterSrf']['EnumeratedIndexValues']['WDAC'] = {}
    field_information['GGDM 3.0']['TransportationWaterSrf']['EnumeratedIndexValues']['WDAC']['BH020']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['TransportationWaterSrf']['WDAL'] = ('real',('BH020'))
    field_information['GGDM 3.0']['TransportationWaterSrf']['WDAU'] = ('real',('BH020'))
    field_information['GGDM 3.0']['TransportationWaterSrf']['WDH'] = ('Real',('BH020'))
    field_information['GGDM 3.0']['TransportationWaterSrf']['WDL'] = ('Real',('BH020'))
    field_information['GGDM 3.0']['TransportationWaterSrf']['WDU'] = ('Real',('BI006','BI030'))
    field_information['GGDM 3.0']['TransportationWaterSrf']['WID'] = ('Real',('AQ080','BH020','BI006','BI030'))
    field_information['GGDM 3.0']['TransportationWaterSrf']['WVA'] = ('Real',('BH020'))
    field_information['GGDM 3.0']['TransportationWaterSrf']['WVH'] = ('Real',('BH020'))
    field_information['GGDM 3.0']['TransportationWaterSrf']['WVL'] = ('Real',('BH020'))
    field_information['GGDM 3.0']['TransportationWaterSrf']['ZI001_SDV'] = ('StructuredText',('AQ080','BH020','BI006','BI030'))
    field_information['GGDM 3.0']['TransportationWaterSrf']['ZI001_SRT'] = ('Enumeration',('AQ080','BH020','BI006','BI030'))
    field_information['GGDM 3.0']['TransportationWaterSrf']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['TransportationWaterSrf']['EnumeratedIndexValues']['ZI001_SRT']['AQ080']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['TransportationWaterSrf']['EnumeratedIndexValues']['ZI001_SRT']['BH020']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['TransportationWaterSrf']['EnumeratedIndexValues']['ZI001_SRT']['BI006']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['TransportationWaterSrf']['EnumeratedIndexValues']['ZI001_SRT']['BI030']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['TransportationWaterSrf']['ZI002_UFI'] = ('StructuredText',('AQ080','BH020','BI006','BI030'))
    field_information['GGDM 3.0']['TransportationWaterSrf']['ZI004_RCG'] = ('Enumeration',('AQ080','BH020','BI006','BI030'))
    field_information['GGDM 3.0']['TransportationWaterSrf']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['TransportationWaterSrf']['EnumeratedIndexValues']['ZI004_RCG']['AQ080']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['TransportationWaterSrf']['EnumeratedIndexValues']['ZI004_RCG']['BH020']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['TransportationWaterSrf']['EnumeratedIndexValues']['ZI004_RCG']['BI006']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['TransportationWaterSrf']['EnumeratedIndexValues']['ZI004_RCG']['BI030']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['TransportationWaterSrf']['ZI005_FNA'] = ('String',('AQ080','BH020','BI006','BI030'))
    field_information['GGDM 3.0']['TransportationWaterSrf']['ZI005_FNA2'] = ('String',('BH020'))
    field_information['GGDM 3.0']['TransportationWaterSrf']['ZI005_FNA3'] = ('String',('BH020'))
    field_information['GGDM 3.0']['TransportationWaterSrf']['ZI005_GNT'] = ('Enumeration',('AQ080','BH020','BI006','BI030'))
    field_information['GGDM 3.0']['TransportationWaterSrf']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['TransportationWaterSrf']['EnumeratedIndexValues']['ZI005_GNT']['AQ080']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['TransportationWaterSrf']['EnumeratedIndexValues']['ZI005_GNT']['BH020']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['TransportationWaterSrf']['EnumeratedIndexValues']['ZI005_GNT']['BI006']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['TransportationWaterSrf']['EnumeratedIndexValues']['ZI005_GNT']['BI030']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['TransportationWaterSrf']['ZI005_GNT2'] = ('Enumeration',('BH020'))
    field_information['GGDM 3.0']['TransportationWaterSrf']['EnumeratedIndexValues']['ZI005_GNT2'] = {}
    field_information['GGDM 3.0']['TransportationWaterSrf']['EnumeratedIndexValues']['ZI005_GNT2']['BH020']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['TransportationWaterSrf']['ZI005_GNT3'] = ('Enumeration',('BH020'))
    field_information['GGDM 3.0']['TransportationWaterSrf']['EnumeratedIndexValues']['ZI005_GNT3'] = {}
    field_information['GGDM 3.0']['TransportationWaterSrf']['EnumeratedIndexValues']['ZI005_GNT3']['BH020']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['TransportationWaterSrf']['ZI005_NFN'] = ('String',('AQ080','BH020','BI006','BI030'))
    field_information['GGDM 3.0']['TransportationWaterSrf']['ZI005_NFN2'] = ('String',('BH020'))
    field_information['GGDM 3.0']['TransportationWaterSrf']['ZI005_NFN3'] = ('String',('BH020'))
    field_information['GGDM 3.0']['TransportationWaterSrf']['ZI006_MEM'] = ('String',('AQ080','BH020','BI006','BI030'))
    field_information['GGDM 3.0']['TransportationWaterSrf']['ZI020_GE4'] = ('CodeList',('AQ080','BH020','BI006','BI030'))
    field_information['GGDM 3.0']['TransportationWaterSrf']['ZI024_ASE'] = ('Real',('BH020'))
    field_information['GGDM 3.0']['TransportationWaterSrf']['ZI024_AWO'] = ('Real',('BH020'))
    field_information['GGDM 3.0']['TransportationWaterSrf']['ZI024_AWOI'] = ('Real',('BH020'))
    field_information['GGDM 3.0']['TransportationWaterSrf']['ZI024_AWOX'] = ('Real',('BH020'))
    field_information['GGDM 3.0']['TransportationWaterSrf']['ZI024_CFR'] = ('Real',('BH020'))
    field_information['GGDM 3.0']['TransportationWaterSrf']['ZI024_CLO'] = ('Real',('BH020'))
    field_information['GGDM 3.0']['TransportationWaterSrf']['ZI024_CYN'] = ('Real',('BH020'))
    field_information['GGDM 3.0']['TransportationWaterSrf']['ZI024_FMR'] = ('Real',('BH020'))
    field_information['GGDM 3.0']['TransportationWaterSrf']['ZI024_FRR'] = ('Real',('BH020'))
    field_information['GGDM 3.0']['TransportationWaterSrf']['ZI024_HAR'] = ('Real',('BH020'))
    field_information['GGDM 3.0']['TransportationWaterSrf']['ZI024_HYP'] = ('Enumeration',('BH020'))
    field_information['GGDM 3.0']['TransportationWaterSrf']['EnumeratedIndexValues']['ZI024_HYP'] = {}
    field_information['GGDM 3.0']['TransportationWaterSrf']['EnumeratedIndexValues']['ZI024_HYP']['BH020']  = (-999999,1,2,4)
    field_information['GGDM 3.0']['TransportationWaterSrf']['ZI024_MGN'] = ('Real',('BH020'))
    field_information['GGDM 3.0']['TransportationWaterSrf']['ZI024_PHW'] = ('Real',('BH020'))
    field_information['GGDM 3.0']['TransportationWaterSrf']['ZI024_SCC'] = ('Enumeration',('BH020'))
    field_information['GGDM 3.0']['TransportationWaterSrf']['EnumeratedIndexValues']['ZI024_SCC'] = {}
    field_information['GGDM 3.0']['TransportationWaterSrf']['EnumeratedIndexValues']['ZI024_SCC']['BH020']  = (-999999,1,4,10,11,12,13,14,998,999)
    field_information['GGDM 3.0']['TransportationWaterSrf']['ZI024_SQN'] = ('Enumeration',('BH020'))
    field_information['GGDM 3.0']['TransportationWaterSrf']['EnumeratedIndexValues']['ZI024_SQN'] = {}
    field_information['GGDM 3.0']['TransportationWaterSrf']['EnumeratedIndexValues']['ZI024_SQN']['BH020']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['TransportationWaterSrf']['ZI024_SUL'] = ('Real',('BH020'))
    field_information['GGDM 3.0']['TransportationWaterSrf']['ZI024_TDS'] = ('Real',('BH020'))
    field_information['GGDM 3.0']['TransportationWaterSrf']['ZI024_TEP'] = ('Real',('BH020'))
    field_information['GGDM 3.0']['TransportationWaterSrf']['ZI024_TUR'] = ('Real',('BH020'))
    field_information['GGDM 3.0']['TransportationWaterSrf']['ZI024_WAC'] = ('Real',('BH020'))
    field_information['GGDM 3.0']['TransportationWaterSrf']['ZI024_WPAC'] = ('Enumeration',('BH020'))
    field_information['GGDM 3.0']['TransportationWaterSrf']['EnumeratedIndexValues']['ZI024_WPAC'] = {}
    field_information['GGDM 3.0']['TransportationWaterSrf']['EnumeratedIndexValues']['ZI024_WPAC']['BH020']  = (-999999,100,101,102,103,104,105,106,107)
    field_information['GGDM 3.0']['TransportationWaterSrf']['ZI024_WSG'] = ('Enumeration',('BH020'))
    field_information['GGDM 3.0']['TransportationWaterSrf']['EnumeratedIndexValues']['ZI024_WSG'] = {}
    field_information['GGDM 3.0']['TransportationWaterSrf']['EnumeratedIndexValues']['ZI024_WSG']['BH020']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['TransportationWaterSrf']['ZI024_WTNO'] = ('Real',('BH020'))
    field_information['GGDM 3.0']['TransportationWaterSrf']['ZI024_WUR'] = ('Enumeration',('BH020'))
    field_information['GGDM 3.0']['TransportationWaterSrf']['EnumeratedIndexValues']['ZI024_WUR'] = {}
    field_information['GGDM 3.0']['TransportationWaterSrf']['EnumeratedIndexValues']['ZI024_WUR']['BH020']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['TransportationWaterSrf']['ZI024_WUR2'] = ('Enumeration',('BH020'))
    field_information['GGDM 3.0']['TransportationWaterSrf']['EnumeratedIndexValues']['ZI024_WUR2'] = {}
    field_information['GGDM 3.0']['TransportationWaterSrf']['EnumeratedIndexValues']['ZI024_WUR2']['BH020']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['TransportationWaterSrf']['ZI024_WUR3'] = ('Enumeration',('BH020'))
    field_information['GGDM 3.0']['TransportationWaterSrf']['EnumeratedIndexValues']['ZI024_WUR3'] = {}
    field_information['GGDM 3.0']['TransportationWaterSrf']['EnumeratedIndexValues']['ZI024_WUR3']['BH020']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['TransportationWaterSrf']['ZI024_WUR4'] = ('Enumeration',('BH020'))
    field_information['GGDM 3.0']['TransportationWaterSrf']['EnumeratedIndexValues']['ZI024_WUR4'] = {}
    field_information['GGDM 3.0']['TransportationWaterSrf']['EnumeratedIndexValues']['ZI024_WUR4']['BH020']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['TransportationWaterSrf']['ZI024_YWQ'] = ('Enumeration',('BH020'))
    field_information['GGDM 3.0']['TransportationWaterSrf']['EnumeratedIndexValues']['ZI024_YWQ'] = {}
    field_information['GGDM 3.0']['TransportationWaterSrf']['EnumeratedIndexValues']['ZI024_YWQ']['BH020']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['TransportationWaterSrf']['ZI026_CTUC'] = ('Enumeration',('AQ080','BH020','BI006','BI030'))
    field_information['GGDM 3.0']['TransportationWaterSrf']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['TransportationWaterSrf']['EnumeratedIndexValues']['ZI026_CTUC']['AQ080']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['TransportationWaterSrf']['EnumeratedIndexValues']['ZI026_CTUC']['BH020']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['TransportationWaterSrf']['EnumeratedIndexValues']['ZI026_CTUC']['BI006']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['TransportationWaterSrf']['EnumeratedIndexValues']['ZI026_CTUC']['BI030']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['TransportationWaterSrf']['ZI026_CTUL'] = ('integer',('AQ080','BH020','BI006','BI030'))
    field_information['GGDM 3.0']['TransportationWaterSrf']['ZI026_CTUU'] = ('integer',('AQ080','BH020','BI006','BI030'))
    field_information['GGDM 3.0']['TransportationWaterSrf']['ZI031S_URI'] = ('StructuredText',('AQ080','BH020','BI006','BI030'))
    field_information['GGDM 3.0']['TransportationWaterSrf']['ZI039S_UFI'] = ('StructuredText',('AQ080','BH020','BI006','BI030'))
    field_information['GGDM 3.0']['TransportationWaterSrf']['ZSAX_RS0'] = ('CodeList',('AQ080','BH020','BI006','BI030'))
    field_information['GGDM 3.0']['TransportationWaterSrf']['ZSAX_RX0'] = ('StructuredText',('AQ080','BH020','BI006','BI030'))
    field_information['GGDM 3.0']['TransportationWaterSrf']['ZSAX_RX3'] = ('StructuredText',('AQ080','BH020','BI006','BI030'))
    field_information['GGDM 3.0']['TransportationWaterSrf']['ZSAX_RX4'] = ('StructuredText',('AQ080','BH020','BI006','BI030'))
    field_information['GGDM 3.0']['TransportationWaterSrf']['ZVH'] = ('Real',('AQ080','BH020','BI006','BI030'))
    field_information['GGDM 3.0']['UtilityInfrastructureAONExt']['ARA'] = ('Real',('NU116'))
    field_information['GGDM 3.0']['UtilityInfrastructureAONExt']['BEN'] = ('StructuredText',('NU113','NU116'))
    field_information['GGDM 3.0']['UtilityInfrastructureAONExt']['CAA'] = ('Enumeration',('NU113','NU116'))
    field_information['GGDM 3.0']['UtilityInfrastructureAONExt']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['UtilityInfrastructureAONExt']['EnumeratedIndexValues']['CAA']['NU113']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['UtilityInfrastructureAONExt']['EnumeratedIndexValues']['CAA']['NU116']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['UtilityInfrastructureAONExt']['CNCP'] = ('StructuredText',('NU113','NU116'))
    field_information['GGDM 3.0']['UtilityInfrastructureAONExt']['COS'] = ('Enumeration',('NU113','NU116'))
    field_information['GGDM 3.0']['UtilityInfrastructureAONExt']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['UtilityInfrastructureAONExt']['EnumeratedIndexValues']['COS']['NU113']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['UtilityInfrastructureAONExt']['EnumeratedIndexValues']['COS']['NU116']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['UtilityInfrastructureAONExt']['CWT'] = ('Boolean',('NU113'))
    field_information['GGDM 3.0']['UtilityInfrastructureAONExt']['DEV'] = ('Integer',('NU113'))
    field_information['GGDM 3.0']['UtilityInfrastructureAONExt']['DIM'] = ('Real',('NU113'))
    field_information['GGDM 3.0']['UtilityInfrastructureAONExt']['DMF'] = ('Integer',('NU113','NU116'))
    field_information['GGDM 3.0']['UtilityInfrastructureAONExt']['DZP'] = ('Real',('NU113','NU116'))
    field_information['GGDM 3.0']['UtilityInfrastructureAONExt']['F_CODE'] = ('CONSTRAINED_STRING',('NU113','NU116'))
    field_information['GGDM 3.0']['UtilityInfrastructureAONExt']['FFN'] = ('Enumeration',('NU116'))
    field_information['GGDM 3.0']['UtilityInfrastructureAONExt']['EnumeratedIndexValues']['FFN'] = {}
    field_information['GGDM 3.0']['UtilityInfrastructureAONExt']['EnumeratedIndexValues']['FFN']['NU116']  = (-999999,50,60,192,350,360,361,362,363,370,500,505,999)
    field_information['GGDM 3.0']['UtilityInfrastructureAONExt']['FFN2'] = ('Enumeration',('NU116'))
    field_information['GGDM 3.0']['UtilityInfrastructureAONExt']['EnumeratedIndexValues']['FFN2'] = {}
    field_information['GGDM 3.0']['UtilityInfrastructureAONExt']['EnumeratedIndexValues']['FFN2']['NU116']  = (-999999,50,60,192,350,360,361,362,363,370,500,505,999)
    field_information['GGDM 3.0']['UtilityInfrastructureAONExt']['FFN3'] = ('Enumeration',('NU116'))
    field_information['GGDM 3.0']['UtilityInfrastructureAONExt']['EnumeratedIndexValues']['FFN3'] = {}
    field_information['GGDM 3.0']['UtilityInfrastructureAONExt']['EnumeratedIndexValues']['FFN3']['NU116']  = (-999999,50,60,192,350,360,361,362,363,370,500,505,999)
    field_information['GGDM 3.0']['UtilityInfrastructureAONExt']['FLO'] = ('Boolean',('NU113'))
    field_information['GGDM 3.0']['UtilityInfrastructureAONExt']['FUFI'] = ('StructuredText',('NU113','NU116'))
    field_information['GGDM 3.0']['UtilityInfrastructureAONExt']['FURL'] = ('StructuredText',('NU113','NU116'))
    field_information['GGDM 3.0']['UtilityInfrastructureAONExt']['GDBV'] = ('Enumeration',('NU113','NU116'))
    field_information['GGDM 3.0']['UtilityInfrastructureAONExt']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['UtilityInfrastructureAONExt']['EnumeratedIndexValues']['GDBV']['NU113']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['UtilityInfrastructureAONExt']['EnumeratedIndexValues']['GDBV']['NU116']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['UtilityInfrastructureAONExt']['HGT'] = ('Real',('NU113','NU116'))
    field_information['GGDM 3.0']['UtilityInfrastructureAONExt']['LEA'] = ('Real',('NU113'))
    field_information['GGDM 3.0']['UtilityInfrastructureAONExt']['LMC'] = ('Boolean',('NU113','NU116'))
    field_information['GGDM 3.0']['UtilityInfrastructureAONExt']['LOC'] = ('Enumeration',('NU113'))
    field_information['GGDM 3.0']['UtilityInfrastructureAONExt']['EnumeratedIndexValues']['LOC'] = {}
    field_information['GGDM 3.0']['UtilityInfrastructureAONExt']['EnumeratedIndexValues']['LOC']['NU113']  = (-999999,17,23,40,44,45,46)
    field_information['GGDM 3.0']['UtilityInfrastructureAONExt']['LUN'] = ('Boolean',('NU116'))
    field_information['GGDM 3.0']['UtilityInfrastructureAONExt']['LZN'] = ('Real',('NU113','NU116'))
    field_information['GGDM 3.0']['UtilityInfrastructureAONExt']['MCC'] = ('Enumeration',('NU113'))
    field_information['GGDM 3.0']['UtilityInfrastructureAONExt']['EnumeratedIndexValues']['MCC'] = {}
    field_information['GGDM 3.0']['UtilityInfrastructureAONExt']['EnumeratedIndexValues']['MCC']['NU113']  = (-999999,2,21,23,51,54,62,64,74,77,83,107,117,999)
    field_information['GGDM 3.0']['UtilityInfrastructureAONExt']['MCC2'] = ('Enumeration',('NU113'))
    field_information['GGDM 3.0']['UtilityInfrastructureAONExt']['EnumeratedIndexValues']['MCC2'] = {}
    field_information['GGDM 3.0']['UtilityInfrastructureAONExt']['EnumeratedIndexValues']['MCC2']['NU113']  = (-999999,2,21,23,51,54,62,64,74,77,83,107,117,999)
    field_information['GGDM 3.0']['UtilityInfrastructureAONExt']['MCC3'] = ('Enumeration',('NU113'))
    field_information['GGDM 3.0']['UtilityInfrastructureAONExt']['EnumeratedIndexValues']['MCC3'] = {}
    field_information['GGDM 3.0']['UtilityInfrastructureAONExt']['EnumeratedIndexValues']['MCC3']['NU113']  = (-999999,2,21,23,51,54,62,64,74,77,83,107,117,999)
    field_information['GGDM 3.0']['UtilityInfrastructureAONExt']['NPL'] = ('Integer',('NU113'))
    field_information['GGDM 3.0']['UtilityInfrastructureAONExt']['OTH'] = ('StructuredText',('NU113','NU116'))
    field_information['GGDM 3.0']['UtilityInfrastructureAONExt']['OWO'] = ('Boolean',('NU113'))
    field_information['GGDM 3.0']['UtilityInfrastructureAONExt']['PCF'] = ('Enumeration',('NU113','NU116'))
    field_information['GGDM 3.0']['UtilityInfrastructureAONExt']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['UtilityInfrastructureAONExt']['EnumeratedIndexValues']['PCF']['NU113']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['UtilityInfrastructureAONExt']['EnumeratedIndexValues']['PCF']['NU116']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['UtilityInfrastructureAONExt']['PLT'] = ('Enumeration',('NU113'))
    field_information['GGDM 3.0']['UtilityInfrastructureAONExt']['EnumeratedIndexValues']['PLT'] = {}
    field_information['GGDM 3.0']['UtilityInfrastructureAONExt']['EnumeratedIndexValues']['PLT']['NU113']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['UtilityInfrastructureAONExt']['PLT2'] = ('Enumeration',('NU113'))
    field_information['GGDM 3.0']['UtilityInfrastructureAONExt']['EnumeratedIndexValues']['PLT2'] = {}
    field_information['GGDM 3.0']['UtilityInfrastructureAONExt']['EnumeratedIndexValues']['PLT2']['NU113']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['UtilityInfrastructureAONExt']['PLT3'] = ('Enumeration',('NU113'))
    field_information['GGDM 3.0']['UtilityInfrastructureAONExt']['EnumeratedIndexValues']['PLT3'] = {}
    field_information['GGDM 3.0']['UtilityInfrastructureAONExt']['EnumeratedIndexValues']['PLT3']['NU113']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['UtilityInfrastructureAONExt']['PMPR'] = ('Boolean',('NU113'))
    field_information['GGDM 3.0']['UtilityInfrastructureAONExt']['PPO'] = ('Enumeration',('NU113','NU116'))
    field_information['GGDM 3.0']['UtilityInfrastructureAONExt']['EnumeratedIndexValues']['PPO'] = {}
    field_information['GGDM 3.0']['UtilityInfrastructureAONExt']['EnumeratedIndexValues']['PPO']['NU113']  = (-999999,16,45,46,49,61,62,70,83,101,122,123,146,999)
    field_information['GGDM 3.0']['UtilityInfrastructureAONExt']['EnumeratedIndexValues']['PPO']['NU116']  = (-999999,16,45,46,83,101,122,999)
    field_information['GGDM 3.0']['UtilityInfrastructureAONExt']['PPO2'] = ('Enumeration',('NU113','NU116'))
    field_information['GGDM 3.0']['UtilityInfrastructureAONExt']['EnumeratedIndexValues']['PPO2'] = {}
    field_information['GGDM 3.0']['UtilityInfrastructureAONExt']['EnumeratedIndexValues']['PPO2']['NU113']  = (-999999,16,45,46,49,61,62,70,83,101,122,123,146,999)
    field_information['GGDM 3.0']['UtilityInfrastructureAONExt']['EnumeratedIndexValues']['PPO2']['NU116']  = (-999999,16,45,46,83,101,122,999)
    field_information['GGDM 3.0']['UtilityInfrastructureAONExt']['PPO3'] = ('Enumeration',('NU113','NU116'))
    field_information['GGDM 3.0']['UtilityInfrastructureAONExt']['EnumeratedIndexValues']['PPO3'] = {}
    field_information['GGDM 3.0']['UtilityInfrastructureAONExt']['EnumeratedIndexValues']['PPO3']['NU113']  = (-999999,16,45,46,49,61,62,70,83,101,122,123,146,999)
    field_information['GGDM 3.0']['UtilityInfrastructureAONExt']['EnumeratedIndexValues']['PPO3']['NU116']  = (-999999,16,45,46,83,101,122,999)
    field_information['GGDM 3.0']['UtilityInfrastructureAONExt']['RLE'] = ('Enumeration',('NU113'))
    field_information['GGDM 3.0']['UtilityInfrastructureAONExt']['EnumeratedIndexValues']['RLE'] = {}
    field_information['GGDM 3.0']['UtilityInfrastructureAONExt']['EnumeratedIndexValues']['RLE']['NU113']  = (-999999,1,2,3)
    field_information['GGDM 3.0']['UtilityInfrastructureAONExt']['RTA'] = ('Enumeration',('NU113'))
    field_information['GGDM 3.0']['UtilityInfrastructureAONExt']['EnumeratedIndexValues']['RTA'] = {}
    field_information['GGDM 3.0']['UtilityInfrastructureAONExt']['EnumeratedIndexValues']['RTA']['NU113']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['UtilityInfrastructureAONExt']['SBB'] = ('Boolean',('NU113'))
    field_information['GGDM 3.0']['UtilityInfrastructureAONExt']['SPT'] = ('Boolean',('NU113'))
    field_information['GGDM 3.0']['UtilityInfrastructureAONExt']['UFI'] = ('StructuredText',('NU113','NU116'))
    field_information['GGDM 3.0']['UtilityInfrastructureAONExt']['VCM'] = ('Enumeration',('NU116'))
    field_information['GGDM 3.0']['UtilityInfrastructureAONExt']['EnumeratedIndexValues']['VCM'] = {}
    field_information['GGDM 3.0']['UtilityInfrastructureAONExt']['EnumeratedIndexValues']['VCM']['NU116']  = (-999999,2,3,4,7,8,9,12,13,15,16,18,999)
    field_information['GGDM 3.0']['UtilityInfrastructureAONExt']['VCM2'] = ('Enumeration',('NU116'))
    field_information['GGDM 3.0']['UtilityInfrastructureAONExt']['EnumeratedIndexValues']['VCM2'] = {}
    field_information['GGDM 3.0']['UtilityInfrastructureAONExt']['EnumeratedIndexValues']['VCM2']['NU116']  = (-999999,2,3,4,7,8,9,12,13,15,16,18,999)
    field_information['GGDM 3.0']['UtilityInfrastructureAONExt']['VCM3'] = ('Enumeration',('NU116'))
    field_information['GGDM 3.0']['UtilityInfrastructureAONExt']['EnumeratedIndexValues']['VCM3'] = {}
    field_information['GGDM 3.0']['UtilityInfrastructureAONExt']['EnumeratedIndexValues']['VCM3']['NU116']  = (-999999,2,3,4,7,8,9,12,13,15,16,18,999)
    field_information['GGDM 3.0']['UtilityInfrastructureAONExt']['WDAC'] = ('Enumeration',('NU116'))
    field_information['GGDM 3.0']['UtilityInfrastructureAONExt']['EnumeratedIndexValues']['WDAC'] = {}
    field_information['GGDM 3.0']['UtilityInfrastructureAONExt']['EnumeratedIndexValues']['WDAC']['NU116']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['UtilityInfrastructureAONExt']['WDAL'] = ('real',('NU116'))
    field_information['GGDM 3.0']['UtilityInfrastructureAONExt']['WDAU'] = ('real',('NU116'))
    field_information['GGDM 3.0']['UtilityInfrastructureAONExt']['WDH'] = ('Real',('NU116'))
    field_information['GGDM 3.0']['UtilityInfrastructureAONExt']['WDL'] = ('Real',('NU116'))
    field_information['GGDM 3.0']['UtilityInfrastructureAONExt']['WID'] = ('Real',('NU116'))
    field_information['GGDM 3.0']['UtilityInfrastructureAONExt']['WVA'] = ('Real',('NU113'))
    field_information['GGDM 3.0']['UtilityInfrastructureAONExt']['ZI001_SDV'] = ('StructuredText',('NU113','NU116'))
    field_information['GGDM 3.0']['UtilityInfrastructureAONExt']['ZI001_SRT'] = ('Enumeration',('NU113','NU116'))
    field_information['GGDM 3.0']['UtilityInfrastructureAONExt']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['UtilityInfrastructureAONExt']['EnumeratedIndexValues']['ZI001_SRT']['NU113']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['UtilityInfrastructureAONExt']['EnumeratedIndexValues']['ZI001_SRT']['NU116']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['UtilityInfrastructureAONExt']['ZI002_UFI'] = ('StructuredText',('NU113','NU116'))
    field_information['GGDM 3.0']['UtilityInfrastructureAONExt']['ZI004_RCG'] = ('Enumeration',('NU113','NU116'))
    field_information['GGDM 3.0']['UtilityInfrastructureAONExt']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['UtilityInfrastructureAONExt']['EnumeratedIndexValues']['ZI004_RCG']['NU113']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['UtilityInfrastructureAONExt']['EnumeratedIndexValues']['ZI004_RCG']['NU116']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['UtilityInfrastructureAONExt']['ZI005_FNA'] = ('String',('NU113','NU116'))
    field_information['GGDM 3.0']['UtilityInfrastructureAONExt']['ZI005_FNA2'] = ('String',('NU113','NU116'))
    field_information['GGDM 3.0']['UtilityInfrastructureAONExt']['ZI005_FNA3'] = ('String',('NU113'))
    field_information['GGDM 3.0']['UtilityInfrastructureAONExt']['ZI005_GNT'] = ('Enumeration',('NU113','NU116'))
    field_information['GGDM 3.0']['UtilityInfrastructureAONExt']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['UtilityInfrastructureAONExt']['EnumeratedIndexValues']['ZI005_GNT']['NU113']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['UtilityInfrastructureAONExt']['EnumeratedIndexValues']['ZI005_GNT']['NU116']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['UtilityInfrastructureAONExt']['ZI005_GNT2'] = ('Enumeration',('NU113','NU116'))
    field_information['GGDM 3.0']['UtilityInfrastructureAONExt']['EnumeratedIndexValues']['ZI005_GNT2'] = {}
    field_information['GGDM 3.0']['UtilityInfrastructureAONExt']['EnumeratedIndexValues']['ZI005_GNT2']['NU113']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['UtilityInfrastructureAONExt']['EnumeratedIndexValues']['ZI005_GNT2']['NU116']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['UtilityInfrastructureAONExt']['ZI005_GNT3'] = ('Enumeration',('NU113'))
    field_information['GGDM 3.0']['UtilityInfrastructureAONExt']['EnumeratedIndexValues']['ZI005_GNT3'] = {}
    field_information['GGDM 3.0']['UtilityInfrastructureAONExt']['EnumeratedIndexValues']['ZI005_GNT3']['NU113']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['UtilityInfrastructureAONExt']['ZI005_NFN'] = ('String',('NU113','NU116'))
    field_information['GGDM 3.0']['UtilityInfrastructureAONExt']['ZI005_NFN2'] = ('String',('NU113','NU116'))
    field_information['GGDM 3.0']['UtilityInfrastructureAONExt']['ZI005_NFN3'] = ('String',('NU113'))
    field_information['GGDM 3.0']['UtilityInfrastructureAONExt']['ZI006_MEM'] = ('String',('NU113','NU116'))
    field_information['GGDM 3.0']['UtilityInfrastructureAONExt']['ZI020_GE4'] = ('CodeList',('NU113','NU116'))
    field_information['GGDM 3.0']['UtilityInfrastructureAONExt']['ZI024_ASE'] = ('Real',('NU113','NU116'))
    field_information['GGDM 3.0']['UtilityInfrastructureAONExt']['ZI024_AWO'] = ('Real',('NU113','NU116'))
    field_information['GGDM 3.0']['UtilityInfrastructureAONExt']['ZI024_AWOI'] = ('Real',('NU113','NU116'))
    field_information['GGDM 3.0']['UtilityInfrastructureAONExt']['ZI024_AWOX'] = ('Real',('NU113','NU116'))
    field_information['GGDM 3.0']['UtilityInfrastructureAONExt']['ZI024_CFR'] = ('Real',('NU113','NU116'))
    field_information['GGDM 3.0']['UtilityInfrastructureAONExt']['ZI024_CLO'] = ('Real',('NU113','NU116'))
    field_information['GGDM 3.0']['UtilityInfrastructureAONExt']['ZI024_CYN'] = ('Real',('NU113','NU116'))
    field_information['GGDM 3.0']['UtilityInfrastructureAONExt']['ZI024_DRL'] = ('Enumeration',('NU116'))
    field_information['GGDM 3.0']['UtilityInfrastructureAONExt']['EnumeratedIndexValues']['ZI024_DRL'] = {}
    field_information['GGDM 3.0']['UtilityInfrastructureAONExt']['EnumeratedIndexValues']['ZI024_DRL']['NU116']  = (-999999,17,40,44,45,50,999)
    field_information['GGDM 3.0']['UtilityInfrastructureAONExt']['ZI024_DVPT'] = ('Enumeration',('NU116'))
    field_information['GGDM 3.0']['UtilityInfrastructureAONExt']['EnumeratedIndexValues']['ZI024_DVPT'] = {}
    field_information['GGDM 3.0']['UtilityInfrastructureAONExt']['EnumeratedIndexValues']['ZI024_DVPT']['NU116']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['UtilityInfrastructureAONExt']['ZI024_FMR'] = ('Real',('NU113','NU116'))
    field_information['GGDM 3.0']['UtilityInfrastructureAONExt']['ZI024_FRR'] = ('Real',('NU113','NU116'))
    field_information['GGDM 3.0']['UtilityInfrastructureAONExt']['ZI024_HAR'] = ('Real',('NU113','NU116'))
    field_information['GGDM 3.0']['UtilityInfrastructureAONExt']['ZI024_MGN'] = ('Real',('NU113','NU116'))
    field_information['GGDM 3.0']['UtilityInfrastructureAONExt']['ZI024_PHW'] = ('Real',('NU113','NU116'))
    field_information['GGDM 3.0']['UtilityInfrastructureAONExt']['ZI024_PMP'] = ('Enumeration',('NU116'))
    field_information['GGDM 3.0']['UtilityInfrastructureAONExt']['EnumeratedIndexValues']['ZI024_PMP'] = {}
    field_information['GGDM 3.0']['UtilityInfrastructureAONExt']['EnumeratedIndexValues']['ZI024_PMP']['NU116']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['GGDM 3.0']['UtilityInfrastructureAONExt']['ZI024_SCC'] = ('Enumeration',('NU113','NU116'))
    field_information['GGDM 3.0']['UtilityInfrastructureAONExt']['EnumeratedIndexValues']['ZI024_SCC'] = {}
    field_information['GGDM 3.0']['UtilityInfrastructureAONExt']['EnumeratedIndexValues']['ZI024_SCC']['NU113']  = (-999999,1,4,10,11,12,13,14,998,999)
    field_information['GGDM 3.0']['UtilityInfrastructureAONExt']['EnumeratedIndexValues']['ZI024_SCC']['NU116']  = (-999999,1,4,10,11,12,13,14,998,999)
    field_information['GGDM 3.0']['UtilityInfrastructureAONExt']['ZI024_SUL'] = ('Real',('NU113','NU116'))
    field_information['GGDM 3.0']['UtilityInfrastructureAONExt']['ZI024_TDS'] = ('Real',('NU113','NU116'))
    field_information['GGDM 3.0']['UtilityInfrastructureAONExt']['ZI024_TEP'] = ('Real',('NU113','NU116'))
    field_information['GGDM 3.0']['UtilityInfrastructureAONExt']['ZI024_TUR'] = ('Real',('NU113','NU116'))
    field_information['GGDM 3.0']['UtilityInfrastructureAONExt']['ZI024_WAC'] = ('Real',('NU113','NU116'))
    field_information['GGDM 3.0']['UtilityInfrastructureAONExt']['ZI024_WTNO'] = ('Real',('NU113','NU116'))
    field_information['GGDM 3.0']['UtilityInfrastructureAONExt']['ZI024_WUR'] = ('Enumeration',('NU113','NU116'))
    field_information['GGDM 3.0']['UtilityInfrastructureAONExt']['EnumeratedIndexValues']['ZI024_WUR'] = {}
    field_information['GGDM 3.0']['UtilityInfrastructureAONExt']['EnumeratedIndexValues']['ZI024_WUR']['NU113']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['UtilityInfrastructureAONExt']['EnumeratedIndexValues']['ZI024_WUR']['NU116']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['UtilityInfrastructureAONExt']['ZI024_WUR2'] = ('Enumeration',('NU113','NU116'))
    field_information['GGDM 3.0']['UtilityInfrastructureAONExt']['EnumeratedIndexValues']['ZI024_WUR2'] = {}
    field_information['GGDM 3.0']['UtilityInfrastructureAONExt']['EnumeratedIndexValues']['ZI024_WUR2']['NU113']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['UtilityInfrastructureAONExt']['EnumeratedIndexValues']['ZI024_WUR2']['NU116']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['UtilityInfrastructureAONExt']['ZI024_WUR3'] = ('Enumeration',('NU113','NU116'))
    field_information['GGDM 3.0']['UtilityInfrastructureAONExt']['EnumeratedIndexValues']['ZI024_WUR3'] = {}
    field_information['GGDM 3.0']['UtilityInfrastructureAONExt']['EnumeratedIndexValues']['ZI024_WUR3']['NU113']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['UtilityInfrastructureAONExt']['EnumeratedIndexValues']['ZI024_WUR3']['NU116']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['UtilityInfrastructureAONExt']['ZI024_WUR4'] = ('Enumeration',('NU113','NU116'))
    field_information['GGDM 3.0']['UtilityInfrastructureAONExt']['EnumeratedIndexValues']['ZI024_WUR4'] = {}
    field_information['GGDM 3.0']['UtilityInfrastructureAONExt']['EnumeratedIndexValues']['ZI024_WUR4']['NU113']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['UtilityInfrastructureAONExt']['EnumeratedIndexValues']['ZI024_WUR4']['NU116']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['UtilityInfrastructureAONExt']['ZI024_YWQ'] = ('Enumeration',('NU113','NU116'))
    field_information['GGDM 3.0']['UtilityInfrastructureAONExt']['EnumeratedIndexValues']['ZI024_YWQ'] = {}
    field_information['GGDM 3.0']['UtilityInfrastructureAONExt']['EnumeratedIndexValues']['ZI024_YWQ']['NU113']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['UtilityInfrastructureAONExt']['EnumeratedIndexValues']['ZI024_YWQ']['NU116']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['UtilityInfrastructureAONExt']['ZI025_HDP'] = ('Real',('NU113'))
    field_information['GGDM 3.0']['UtilityInfrastructureAONExt']['ZI026_CTUC'] = ('Enumeration',('NU113','NU116'))
    field_information['GGDM 3.0']['UtilityInfrastructureAONExt']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['UtilityInfrastructureAONExt']['EnumeratedIndexValues']['ZI026_CTUC']['NU113']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['UtilityInfrastructureAONExt']['EnumeratedIndexValues']['ZI026_CTUC']['NU116']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['UtilityInfrastructureAONExt']['ZI026_CTUL'] = ('integer',('NU113','NU116'))
    field_information['GGDM 3.0']['UtilityInfrastructureAONExt']['ZI026_CTUU'] = ('integer',('NU113','NU116'))
    field_information['GGDM 3.0']['UtilityInfrastructureAONExt']['ZI031S_URI'] = ('StructuredText',('NU113','NU116'))
    field_information['GGDM 3.0']['UtilityInfrastructureAONExt']['ZI039S_UFI'] = ('StructuredText',('NU113','NU116'))
    field_information['GGDM 3.0']['UtilityInfrastructureAONExt']['ZSAX_RS0'] = ('CodeList',('NU113','NU116'))
    field_information['GGDM 3.0']['UtilityInfrastructureAONExt']['ZSAX_RX0'] = ('StructuredText',('NU113','NU116'))
    field_information['GGDM 3.0']['UtilityInfrastructureAONExt']['ZSAX_RX3'] = ('StructuredText',('NU113','NU116'))
    field_information['GGDM 3.0']['UtilityInfrastructureAONExt']['ZSAX_RX4'] = ('StructuredText',('NU113','NU116'))
    field_information['GGDM 3.0']['UtilityInfrastructureAONExt']['ZVH'] = ('Real',('NU113','NU116'))
    field_information['GGDM 3.0']['UtilityInfrastructureCrv']['AWP'] = ('Boolean',('AT005'))
    field_information['GGDM 3.0']['UtilityInfrastructureCrv']['BEN'] = ('StructuredText',('AQ113','AT005'))
    field_information['GGDM 3.0']['UtilityInfrastructureCrv']['CAA'] = ('Enumeration',('AQ113','AT005'))
    field_information['GGDM 3.0']['UtilityInfrastructureCrv']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['UtilityInfrastructureCrv']['EnumeratedIndexValues']['CAA']['AQ113']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['UtilityInfrastructureCrv']['EnumeratedIndexValues']['CAA']['AT005']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['UtilityInfrastructureCrv']['CAB'] = ('Enumeration',('AT005'))
    field_information['GGDM 3.0']['UtilityInfrastructureCrv']['EnumeratedIndexValues']['CAB'] = {}
    field_information['GGDM 3.0']['UtilityInfrastructureCrv']['EnumeratedIndexValues']['CAB']['AT005']  = (-999999,2,3,4,6,7,8,9,10,11,12,13,14,15,19,999)
    field_information['GGDM 3.0']['UtilityInfrastructureCrv']['CAB2'] = ('Enumeration',('AT005'))
    field_information['GGDM 3.0']['UtilityInfrastructureCrv']['EnumeratedIndexValues']['CAB2'] = {}
    field_information['GGDM 3.0']['UtilityInfrastructureCrv']['EnumeratedIndexValues']['CAB2']['AT005']  = (-999999,2,3,4,6,7,8,9,10,11,12,13,14,15,19,999)
    field_information['GGDM 3.0']['UtilityInfrastructureCrv']['CAB3'] = ('Enumeration',('AT005'))
    field_information['GGDM 3.0']['UtilityInfrastructureCrv']['EnumeratedIndexValues']['CAB3'] = {}
    field_information['GGDM 3.0']['UtilityInfrastructureCrv']['EnumeratedIndexValues']['CAB3']['AT005']  = (-999999,2,3,4,6,7,8,9,10,11,12,13,14,15,19,999)
    field_information['GGDM 3.0']['UtilityInfrastructureCrv']['CNCP'] = ('StructuredText',('AQ113','AT005'))
    field_information['GGDM 3.0']['UtilityInfrastructureCrv']['COS'] = ('Enumeration',('AQ113','AT005'))
    field_information['GGDM 3.0']['UtilityInfrastructureCrv']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['UtilityInfrastructureCrv']['EnumeratedIndexValues']['COS']['AQ113']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['UtilityInfrastructureCrv']['EnumeratedIndexValues']['COS']['AT005']  = (-999999,2,4,6,9,13,14)
    field_information['GGDM 3.0']['UtilityInfrastructureCrv']['CST'] = ('Boolean',('AT005'))
    field_information['GGDM 3.0']['UtilityInfrastructureCrv']['CWT'] = ('Boolean',('AQ113'))
    field_information['GGDM 3.0']['UtilityInfrastructureCrv']['DEV'] = ('Integer',('AQ113'))
    field_information['GGDM 3.0']['UtilityInfrastructureCrv']['DIM'] = ('Real',('AQ113'))
    field_information['GGDM 3.0']['UtilityInfrastructureCrv']['DZP'] = ('Real',('AQ113','AT005'))
    field_information['GGDM 3.0']['UtilityInfrastructureCrv']['F_CODE'] = ('CONSTRAINED_STRING',('AQ113','AT005'))
    field_information['GGDM 3.0']['UtilityInfrastructureCrv']['FLO'] = ('Boolean',('AQ113','AT005'))
    field_information['GGDM 3.0']['UtilityInfrastructureCrv']['FUFI'] = ('StructuredText',('AQ113','AT005'))
    field_information['GGDM 3.0']['UtilityInfrastructureCrv']['FURL'] = ('StructuredText',('AQ113','AT005'))
    field_information['GGDM 3.0']['UtilityInfrastructureCrv']['GDBV'] = ('Enumeration',('AQ113','AT005'))
    field_information['GGDM 3.0']['UtilityInfrastructureCrv']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['UtilityInfrastructureCrv']['EnumeratedIndexValues']['GDBV']['AQ113']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['UtilityInfrastructureCrv']['EnumeratedIndexValues']['GDBV']['AT005']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['UtilityInfrastructureCrv']['HGT'] = ('Real',('AQ113','AT005'))
    field_information['GGDM 3.0']['UtilityInfrastructureCrv']['KVA'] = ('Real',('AT005'))
    field_information['GGDM 3.0']['UtilityInfrastructureCrv']['LEA'] = ('Real',('AQ113','AT005'))
    field_information['GGDM 3.0']['UtilityInfrastructureCrv']['LMC'] = ('Boolean',('AQ113','AT005'))
    field_information['GGDM 3.0']['UtilityInfrastructureCrv']['LOC'] = ('Enumeration',('AQ113','AT005'))
    field_information['GGDM 3.0']['UtilityInfrastructureCrv']['EnumeratedIndexValues']['LOC'] = {}
    field_information['GGDM 3.0']['UtilityInfrastructureCrv']['EnumeratedIndexValues']['LOC']['AQ113']  = (-999999,17,23,40,44,45,46)
    field_information['GGDM 3.0']['UtilityInfrastructureCrv']['EnumeratedIndexValues']['LOC']['AT005']  = (-999999,17,23,40,44,45,46,47)
    field_information['GGDM 3.0']['UtilityInfrastructureCrv']['LZN'] = ('Real',('AQ113','AT005'))
    field_information['GGDM 3.0']['UtilityInfrastructureCrv']['MCC'] = ('Enumeration',('AQ113'))
    field_information['GGDM 3.0']['UtilityInfrastructureCrv']['EnumeratedIndexValues']['MCC'] = {}
    field_information['GGDM 3.0']['UtilityInfrastructureCrv']['EnumeratedIndexValues']['MCC']['AQ113']  = (-999999,2,21,23,51,54,62,64,74,77,83,107,117,999)
    field_information['GGDM 3.0']['UtilityInfrastructureCrv']['MCC2'] = ('Enumeration',('AQ113'))
    field_information['GGDM 3.0']['UtilityInfrastructureCrv']['EnumeratedIndexValues']['MCC2'] = {}
    field_information['GGDM 3.0']['UtilityInfrastructureCrv']['EnumeratedIndexValues']['MCC2']['AQ113']  = (-999999,2,21,23,51,54,62,64,74,77,83,107,117,999)
    field_information['GGDM 3.0']['UtilityInfrastructureCrv']['MCC3'] = ('Enumeration',('AQ113'))
    field_information['GGDM 3.0']['UtilityInfrastructureCrv']['EnumeratedIndexValues']['MCC3'] = {}
    field_information['GGDM 3.0']['UtilityInfrastructureCrv']['EnumeratedIndexValues']['MCC3']['AQ113']  = (-999999,2,21,23,51,54,62,64,74,77,83,107,117,999)
    field_information['GGDM 3.0']['UtilityInfrastructureCrv']['NPL'] = ('Integer',('AQ113','AT005'))
    field_information['GGDM 3.0']['UtilityInfrastructureCrv']['OHC'] = ('Real',('AT005'))
    field_information['GGDM 3.0']['UtilityInfrastructureCrv']['OTH'] = ('StructuredText',('AQ113','AT005'))
    field_information['GGDM 3.0']['UtilityInfrastructureCrv']['OWO'] = ('Boolean',('AQ113','AT005'))
    field_information['GGDM 3.0']['UtilityInfrastructureCrv']['PCF'] = ('Enumeration',('AQ113','AT005'))
    field_information['GGDM 3.0']['UtilityInfrastructureCrv']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['UtilityInfrastructureCrv']['EnumeratedIndexValues']['PCF']['AQ113']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['UtilityInfrastructureCrv']['EnumeratedIndexValues']['PCF']['AT005']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['UtilityInfrastructureCrv']['PFH'] = ('Real',('AT005'))
    field_information['GGDM 3.0']['UtilityInfrastructureCrv']['PLT'] = ('Enumeration',('AQ113'))
    field_information['GGDM 3.0']['UtilityInfrastructureCrv']['EnumeratedIndexValues']['PLT'] = {}
    field_information['GGDM 3.0']['UtilityInfrastructureCrv']['EnumeratedIndexValues']['PLT']['AQ113']  = (-999999,1,2,3,4,5,7,999)
    field_information['GGDM 3.0']['UtilityInfrastructureCrv']['PLT2'] = ('Enumeration',('AQ113'))
    field_information['GGDM 3.0']['UtilityInfrastructureCrv']['EnumeratedIndexValues']['PLT2'] = {}
    field_information['GGDM 3.0']['UtilityInfrastructureCrv']['EnumeratedIndexValues']['PLT2']['AQ113']  = (-999999,1,2,3,4,5,7,999)
    field_information['GGDM 3.0']['UtilityInfrastructureCrv']['PLT3'] = ('Enumeration',('AQ113'))
    field_information['GGDM 3.0']['UtilityInfrastructureCrv']['EnumeratedIndexValues']['PLT3'] = {}
    field_information['GGDM 3.0']['UtilityInfrastructureCrv']['EnumeratedIndexValues']['PLT3']['AQ113']  = (-999999,1,2,3,4,5,7,999)
    field_information['GGDM 3.0']['UtilityInfrastructureCrv']['PMPR'] = ('Boolean',('AQ113'))
    field_information['GGDM 3.0']['UtilityInfrastructureCrv']['PPO'] = ('Enumeration',('AQ113'))
    field_information['GGDM 3.0']['UtilityInfrastructureCrv']['EnumeratedIndexValues']['PPO'] = {}
    field_information['GGDM 3.0']['UtilityInfrastructureCrv']['EnumeratedIndexValues']['PPO']['AQ113']  = (-999999,16,45,46,49,61,62,70,83,101,122,123,146,999)
    field_information['GGDM 3.0']['UtilityInfrastructureCrv']['PPO2'] = ('Enumeration',('AQ113'))
    field_information['GGDM 3.0']['UtilityInfrastructureCrv']['EnumeratedIndexValues']['PPO2'] = {}
    field_information['GGDM 3.0']['UtilityInfrastructureCrv']['EnumeratedIndexValues']['PPO2']['AQ113']  = (-999999,16,45,46,49,61,62,70,83,101,122,123,146,999)
    field_information['GGDM 3.0']['UtilityInfrastructureCrv']['PPO3'] = ('Enumeration',('AQ113'))
    field_information['GGDM 3.0']['UtilityInfrastructureCrv']['EnumeratedIndexValues']['PPO3'] = {}
    field_information['GGDM 3.0']['UtilityInfrastructureCrv']['EnumeratedIndexValues']['PPO3']['AQ113']  = (-999999,16,45,46,49,61,62,70,83,101,122,123,146,999)
    field_information['GGDM 3.0']['UtilityInfrastructureCrv']['RLE'] = ('Enumeration',('AQ113'))
    field_information['GGDM 3.0']['UtilityInfrastructureCrv']['EnumeratedIndexValues']['RLE'] = {}
    field_information['GGDM 3.0']['UtilityInfrastructureCrv']['EnumeratedIndexValues']['RLE']['AQ113']  = (-999999,1,2,3)
    field_information['GGDM 3.0']['UtilityInfrastructureCrv']['RTA'] = ('Enumeration',('AQ113'))
    field_information['GGDM 3.0']['UtilityInfrastructureCrv']['EnumeratedIndexValues']['RTA'] = {}
    field_information['GGDM 3.0']['UtilityInfrastructureCrv']['EnumeratedIndexValues']['RTA']['AQ113']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['UtilityInfrastructureCrv']['SBB'] = ('Boolean',('AQ113'))
    field_information['GGDM 3.0']['UtilityInfrastructureCrv']['SPT'] = ('Boolean',('AQ113'))
    field_information['GGDM 3.0']['UtilityInfrastructureCrv']['TST'] = ('Enumeration',('AT005'))
    field_information['GGDM 3.0']['UtilityInfrastructureCrv']['EnumeratedIndexValues']['TST'] = {}
    field_information['GGDM 3.0']['UtilityInfrastructureCrv']['EnumeratedIndexValues']['TST']['AT005']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['UtilityInfrastructureCrv']['UFI'] = ('StructuredText',('AQ113','AT005'))
    field_information['GGDM 3.0']['UtilityInfrastructureCrv']['VCO'] = ('Real',('AQ113','AT005'))
    field_information['GGDM 3.0']['UtilityInfrastructureCrv']['VOI'] = ('StructuredText',('AT005'))
    field_information['GGDM 3.0']['UtilityInfrastructureCrv']['WVA'] = ('Real',('AQ113'))
    field_information['GGDM 3.0']['UtilityInfrastructureCrv']['ZI001_SDV'] = ('StructuredText',('AQ113','AT005'))
    field_information['GGDM 3.0']['UtilityInfrastructureCrv']['ZI001_SRT'] = ('Enumeration',('AQ113','AT005'))
    field_information['GGDM 3.0']['UtilityInfrastructureCrv']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['UtilityInfrastructureCrv']['EnumeratedIndexValues']['ZI001_SRT']['AQ113']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['UtilityInfrastructureCrv']['EnumeratedIndexValues']['ZI001_SRT']['AT005']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['UtilityInfrastructureCrv']['ZI002_UFI'] = ('StructuredText',('AQ113','AT005'))
    field_information['GGDM 3.0']['UtilityInfrastructureCrv']['ZI004_RCG'] = ('Enumeration',('AQ113','AT005'))
    field_information['GGDM 3.0']['UtilityInfrastructureCrv']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['UtilityInfrastructureCrv']['EnumeratedIndexValues']['ZI004_RCG']['AQ113']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['UtilityInfrastructureCrv']['EnumeratedIndexValues']['ZI004_RCG']['AT005']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['UtilityInfrastructureCrv']['ZI005_FNA'] = ('String',('AQ113','AT005'))
    field_information['GGDM 3.0']['UtilityInfrastructureCrv']['ZI005_FNA2'] = ('String',('AQ113'))
    field_information['GGDM 3.0']['UtilityInfrastructureCrv']['ZI005_FNA3'] = ('String',('AQ113'))
    field_information['GGDM 3.0']['UtilityInfrastructureCrv']['ZI005_GNT'] = ('Enumeration',('AQ113','AT005'))
    field_information['GGDM 3.0']['UtilityInfrastructureCrv']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['UtilityInfrastructureCrv']['EnumeratedIndexValues']['ZI005_GNT']['AQ113']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['UtilityInfrastructureCrv']['EnumeratedIndexValues']['ZI005_GNT']['AT005']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['UtilityInfrastructureCrv']['ZI005_GNT2'] = ('Enumeration',('AQ113'))
    field_information['GGDM 3.0']['UtilityInfrastructureCrv']['EnumeratedIndexValues']['ZI005_GNT2'] = {}
    field_information['GGDM 3.0']['UtilityInfrastructureCrv']['EnumeratedIndexValues']['ZI005_GNT2']['AQ113']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['UtilityInfrastructureCrv']['ZI005_GNT3'] = ('Enumeration',('AQ113'))
    field_information['GGDM 3.0']['UtilityInfrastructureCrv']['EnumeratedIndexValues']['ZI005_GNT3'] = {}
    field_information['GGDM 3.0']['UtilityInfrastructureCrv']['EnumeratedIndexValues']['ZI005_GNT3']['AQ113']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['UtilityInfrastructureCrv']['ZI005_NFN'] = ('String',('AQ113','AT005'))
    field_information['GGDM 3.0']['UtilityInfrastructureCrv']['ZI005_NFN2'] = ('String',('AQ113'))
    field_information['GGDM 3.0']['UtilityInfrastructureCrv']['ZI005_NFN3'] = ('String',('AQ113'))
    field_information['GGDM 3.0']['UtilityInfrastructureCrv']['ZI006_MEM'] = ('String',('AQ113','AT005'))
    field_information['GGDM 3.0']['UtilityInfrastructureCrv']['ZI020_GE4'] = ('CodeList',('AQ113','AT005'))
    field_information['GGDM 3.0']['UtilityInfrastructureCrv']['ZI024_ASE'] = ('Real',('AQ113'))
    field_information['GGDM 3.0']['UtilityInfrastructureCrv']['ZI024_AWO'] = ('Real',('AQ113'))
    field_information['GGDM 3.0']['UtilityInfrastructureCrv']['ZI024_AWOI'] = ('Real',('AQ113'))
    field_information['GGDM 3.0']['UtilityInfrastructureCrv']['ZI024_AWOX'] = ('Real',('AQ113'))
    field_information['GGDM 3.0']['UtilityInfrastructureCrv']['ZI024_CFR'] = ('Real',('AQ113'))
    field_information['GGDM 3.0']['UtilityInfrastructureCrv']['ZI024_CLO'] = ('Real',('AQ113'))
    field_information['GGDM 3.0']['UtilityInfrastructureCrv']['ZI024_CYN'] = ('Real',('AQ113'))
    field_information['GGDM 3.0']['UtilityInfrastructureCrv']['ZI024_FMR'] = ('Real',('AQ113'))
    field_information['GGDM 3.0']['UtilityInfrastructureCrv']['ZI024_FRR'] = ('Real',('AQ113'))
    field_information['GGDM 3.0']['UtilityInfrastructureCrv']['ZI024_HAR'] = ('Real',('AQ113'))
    field_information['GGDM 3.0']['UtilityInfrastructureCrv']['ZI024_MGN'] = ('Real',('AQ113'))
    field_information['GGDM 3.0']['UtilityInfrastructureCrv']['ZI024_PHW'] = ('Real',('AQ113'))
    field_information['GGDM 3.0']['UtilityInfrastructureCrv']['ZI024_SCC'] = ('Enumeration',('AQ113'))
    field_information['GGDM 3.0']['UtilityInfrastructureCrv']['EnumeratedIndexValues']['ZI024_SCC'] = {}
    field_information['GGDM 3.0']['UtilityInfrastructureCrv']['EnumeratedIndexValues']['ZI024_SCC']['AQ113']  = (-999999,1,4,10,11,12,13,14,998,999)
    field_information['GGDM 3.0']['UtilityInfrastructureCrv']['ZI024_SUL'] = ('Real',('AQ113'))
    field_information['GGDM 3.0']['UtilityInfrastructureCrv']['ZI024_TDS'] = ('Real',('AQ113'))
    field_information['GGDM 3.0']['UtilityInfrastructureCrv']['ZI024_TEP'] = ('Real',('AQ113'))
    field_information['GGDM 3.0']['UtilityInfrastructureCrv']['ZI024_TUR'] = ('Real',('AQ113'))
    field_information['GGDM 3.0']['UtilityInfrastructureCrv']['ZI024_WAC'] = ('Real',('AQ113'))
    field_information['GGDM 3.0']['UtilityInfrastructureCrv']['ZI024_WTNO'] = ('Real',('AQ113'))
    field_information['GGDM 3.0']['UtilityInfrastructureCrv']['ZI024_WUR'] = ('Enumeration',('AQ113'))
    field_information['GGDM 3.0']['UtilityInfrastructureCrv']['EnumeratedIndexValues']['ZI024_WUR'] = {}
    field_information['GGDM 3.0']['UtilityInfrastructureCrv']['EnumeratedIndexValues']['ZI024_WUR']['AQ113']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['UtilityInfrastructureCrv']['ZI024_WUR2'] = ('Enumeration',('AQ113'))
    field_information['GGDM 3.0']['UtilityInfrastructureCrv']['EnumeratedIndexValues']['ZI024_WUR2'] = {}
    field_information['GGDM 3.0']['UtilityInfrastructureCrv']['EnumeratedIndexValues']['ZI024_WUR2']['AQ113']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['UtilityInfrastructureCrv']['ZI024_WUR3'] = ('Enumeration',('AQ113'))
    field_information['GGDM 3.0']['UtilityInfrastructureCrv']['EnumeratedIndexValues']['ZI024_WUR3'] = {}
    field_information['GGDM 3.0']['UtilityInfrastructureCrv']['EnumeratedIndexValues']['ZI024_WUR3']['AQ113']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['UtilityInfrastructureCrv']['ZI024_WUR4'] = ('Enumeration',('AQ113'))
    field_information['GGDM 3.0']['UtilityInfrastructureCrv']['EnumeratedIndexValues']['ZI024_WUR4'] = {}
    field_information['GGDM 3.0']['UtilityInfrastructureCrv']['EnumeratedIndexValues']['ZI024_WUR4']['AQ113']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['UtilityInfrastructureCrv']['ZI024_YWQ'] = ('Enumeration',('AQ113'))
    field_information['GGDM 3.0']['UtilityInfrastructureCrv']['EnumeratedIndexValues']['ZI024_YWQ'] = {}
    field_information['GGDM 3.0']['UtilityInfrastructureCrv']['EnumeratedIndexValues']['ZI024_YWQ']['AQ113']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['UtilityInfrastructureCrv']['ZI025_HDP'] = ('Real',('AQ113','AT005'))
    field_information['GGDM 3.0']['UtilityInfrastructureCrv']['ZI025_WLE'] = ('Enumeration',('AT005'))
    field_information['GGDM 3.0']['UtilityInfrastructureCrv']['EnumeratedIndexValues']['ZI025_WLE'] = {}
    field_information['GGDM 3.0']['UtilityInfrastructureCrv']['EnumeratedIndexValues']['ZI025_WLE']['AT005']  = (-999999,1,2,3,4,5,9,999)
    field_information['GGDM 3.0']['UtilityInfrastructureCrv']['ZI026_CTUC'] = ('Enumeration',('AQ113','AT005'))
    field_information['GGDM 3.0']['UtilityInfrastructureCrv']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['UtilityInfrastructureCrv']['EnumeratedIndexValues']['ZI026_CTUC']['AQ113']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['UtilityInfrastructureCrv']['EnumeratedIndexValues']['ZI026_CTUC']['AT005']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['UtilityInfrastructureCrv']['ZI026_CTUL'] = ('integer',('AQ113','AT005'))
    field_information['GGDM 3.0']['UtilityInfrastructureCrv']['ZI026_CTUU'] = ('integer',('AQ113','AT005'))
    field_information['GGDM 3.0']['UtilityInfrastructureCrv']['ZI031S_URI'] = ('StructuredText',('AQ113','AT005'))
    field_information['GGDM 3.0']['UtilityInfrastructureCrv']['ZI039S_UFI'] = ('StructuredText',('AQ113','AT005'))
    field_information['GGDM 3.0']['UtilityInfrastructureCrv']['ZSAX_RS0'] = ('CodeList',('AQ113','AT005'))
    field_information['GGDM 3.0']['UtilityInfrastructureCrv']['ZSAX_RX0'] = ('StructuredText',('AQ113','AT005'))
    field_information['GGDM 3.0']['UtilityInfrastructureCrv']['ZSAX_RX3'] = ('StructuredText',('AQ113','AT005'))
    field_information['GGDM 3.0']['UtilityInfrastructureCrv']['ZSAX_RX4'] = ('StructuredText',('AQ113','AT005'))
    field_information['GGDM 3.0']['UtilityInfrastructureCrv']['ZVH'] = ('Real',('AQ113','AT005'))
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['ADR'] = ('String',('AC507','AD010','AD025','AD030','AD050','AD055','AD060','AQ116','AT012','BH220'))
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['ADUR'] = ('Real',('BH220'))
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['ANFL'] = ('Real',('BH220'))
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['AOO'] = ('Real',('AC507','AD010','AD020','AD025','AD030','AD041','AD050','AD055','AD060','AF010','AF030','AJ051','AQ116','AT010','AT011','AT012','AT042','BH220'))
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['ARA'] = ('Real',('AB021','AC507','AD010','AD020','AD025','AD030','AD041','AD050','AD055','AD060','AF030','AJ051','AQ114','AQ115','AQ116','AT012','AT042','BH220'))
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['AT005_CAB'] = ('Enumeration',('AT042'))
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['AT005_CAB'] = {}
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['AT005_CAB']['AT042']  = (-999999,2,3,4,6,7,8,9,10,11,12,13,14,15,19,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['AT005_CAB2'] = ('Enumeration',('AT042'))
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['AT005_CAB2'] = {}
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['AT005_CAB2']['AT042']  = (-999999,2,3,4,6,7,8,9,10,11,12,13,14,15,19,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['AT005_CAB3'] = ('Enumeration',('AT042'))
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['AT005_CAB3'] = {}
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['AT005_CAB3']['AT042']  = (-999999,2,3,4,6,7,8,9,10,11,12,13,14,15,19,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['AWP'] = ('Boolean',('AD041','AF010','AF030','AJ051','AT011','AT042'))
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['BEN'] = ('StructuredText',('AB021','AC507','AD010','AD020','AD025','AD030','AD041','AD050','AD055','AD060','AF010','AF030','AJ051','AL017','AQ114','AQ115','AQ116','AT010','AT011','AT012','AT042','BH220'))
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['CAA'] = ('Enumeration',('AC507','AD010','AD025','AD030','AD041','AD050','AD055','AD060','AF010','AF030','AJ051','AL017','AQ116','AT010','AT011','AT012','AT042','BH220'))
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['CAA']['AC507']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['CAA']['AD010']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['CAA']['AD025']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['CAA']['AD030']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['CAA']['AD041']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['CAA']['AD050']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['CAA']['AD055']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['CAA']['AD060']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['CAA']['AF010']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['CAA']['AF030']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['CAA']['AJ051']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['CAA']['AL017']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['CAA']['AQ116']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['CAA']['AT010']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['CAA']['AT011']  = (-999999,3,5,7,17,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['CAA']['AT012']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['CAA']['AT042']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['CAA']['BH220']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['CNCP'] = ('StructuredText',('AB021','AC507','AD010','AD020','AD025','AD030','AD041','AD050','AD055','AD060','AF010','AF030','AJ051','AL017','AQ114','AQ116','AT010','AT011','AT012','BH220'))
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['COS'] = ('Enumeration',('AB021','AC507','AD010','AD020','AD025','AD030','AD041','AD050','AD055','AD060','AF010','AF030','AJ051','AL017','AQ114','AQ116','AT010','AT011','AT012','BH220'))
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['COS']['AB021']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['COS']['AC507']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['COS']['AD010']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['COS']['AD020']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['COS']['AD025']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['COS']['AD030']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['COS']['AD041']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['COS']['AD050']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['COS']['AD055']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['COS']['AD060']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['COS']['AF010']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['COS']['AF030']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['COS']['AJ051']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['COS']['AL017']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['COS']['AQ114']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['COS']['AQ116']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['COS']['AT010']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['COS']['AT011']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['COS']['AT012']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['COS']['BH220']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['DCAP'] = ('Real',('AC507','BH220'))
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['DIM'] = ('Real',('AF010'))
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['DINF'] = ('Enumeration',('AC507','BH220'))
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['DINF'] = {}
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['DINF']['AC507']  = (-999999,1,2,3,4,5,6,7,8,998,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['DINF']['BH220']  = (-999999,1,2,3,4,5,6,7,8,998,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['DZP'] = ('Real',('AD041','AQ116'))
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EPW'] = ('Real',('AD010'))
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['F_CODE'] = ('CONSTRAINED_STRING',('AB021','AC507','AD010','AD020','AD025','AD030','AD041','AD050','AD055','AD060','AF010','AF030','AJ051','AL017','AQ114','AQ115','AQ116','AT010','AT011','AT012','AT042','BH220'))
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['FFN'] = ('Enumeration',('AD050','AD055','AQ116','AT012'))
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['FFN'] = {}
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['FFN']['AD050']  = (-999999,99,440,563,811,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['FFN']['AD055']  = (-999999,99,440,563,811,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['FFN']['AQ116']  = (-999999,50,60,192,350,360,361,362,363,370,500,505,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['FFN']['AT012']  = (-999999,486,601,604,610,614,615,620,625,720,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['FFN2'] = ('Enumeration',('AD050','AD055','AQ116','AT012'))
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['FFN2'] = {}
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['FFN2']['AD050']  = (-999999,99,440,563,811,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['FFN2']['AD055']  = (-999999,99,440,563,811,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['FFN2']['AQ116']  = (-999999,50,60,192,350,360,361,362,363,370,500,505,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['FFN2']['AT012']  = (-999999,486,601,604,610,614,615,620,625,720,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['FFN3'] = ('Enumeration',('AD050','AD055','AQ116','AT012'))
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['FFN3'] = {}
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['FFN3']['AD050']  = (-999999,99,440,563,811,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['FFN3']['AD055']  = (-999999,99,440,563,811,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['FFN3']['AQ116']  = (-999999,50,60,192,350,360,361,362,363,370,500,505,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['FFN3']['AT012']  = (-999999,486,601,604,610,614,615,620,625,720,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['FUFI'] = ('StructuredText',('AB021','AC507','AD010','AD020','AD025','AD030','AD041','AD050','AD055','AD060','AF010','AF030','AJ051','AL017','AQ114','AQ115','AQ116','AT010','AT011','AT012','AT042','BH220'))
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['FURL'] = ('StructuredText',('AB021','AC507','AD010','AD020','AD025','AD030','AD041','AD050','AD055','AD060','AF010','AF030','AJ051','AL017','AQ114','AQ115','AQ116','AT010','AT011','AT012','AT042','BH220'))
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['GDBV'] = ('Enumeration',('AB021','AC507','AD010','AD020','AD025','AD030','AD041','AD050','AD055','AD060','AF010','AF030','AJ051','AL017','AQ114','AQ115','AQ116','AT010','AT011','AT012','AT042','BH220'))
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['GDBV']['AB021']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['GDBV']['AC507']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['GDBV']['AD010']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['GDBV']['AD020']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['GDBV']['AD025']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['GDBV']['AD030']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['GDBV']['AD041']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['GDBV']['AD050']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['GDBV']['AD055']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['GDBV']['AD060']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['GDBV']['AF010']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['GDBV']['AF030']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['GDBV']['AJ051']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['GDBV']['AL017']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['GDBV']['AQ114']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['GDBV']['AQ115']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['GDBV']['AQ116']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['GDBV']['AT010']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['GDBV']['AT011']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['GDBV']['AT012']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['GDBV']['AT042']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['GDBV']['BH220']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['GRD'] = ('Boolean',('AC507','BH220'))
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['GUG'] = ('Boolean',('AJ051'))
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['HEI'] = ('Real',('AF010','AT010','AT011'))
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['HGT'] = ('Real',('AC507','AD010','AD020','AD025','AD030','AD041','AD050','AD055','AD060','AF010','AF030','AJ051','AL017','AQ116','AT010','AT011','AT012','AT042','BH220'))
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['LEA'] = ('Real',('AD041'))
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['LMC'] = ('Boolean',('AB021','AC507','AD010','AD020','AD025','AD030','AD041','AD050','AD055','AD060','AF010','AF030','AJ051','AL017','AQ116','AT010','AT011','AT012','AT042','BH220'))
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['LUN'] = ('Boolean',('AQ116'))
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['LZN'] = ('Real',('AB021','AC507','AD010','AD020','AD025','AD030','AD041','AD050','AD055','AD060','AF030','AJ051','AL017','AQ114','AQ115','AQ116','AT010','AT012','AT042','BH220'))
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['MCC'] = ('Enumeration',('AQ114','AQ115','AT010'))
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['MCC'] = {}
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['MCC']['AQ114']  = (-999999,21,51,62,64,107,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['MCC']['AQ115']  = (-999999,2,51,64,107,117,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['MCC']['AT010']  = (-999999,64,152,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['MCC2'] = ('Enumeration',('AQ114','AQ115','AT010'))
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['MCC2'] = {}
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['MCC2']['AQ114']  = (-999999,21,51,62,64,107,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['MCC2']['AQ115']  = (-999999,2,51,64,107,117,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['MCC2']['AT010']  = (-999999,64,152,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['MCC3'] = ('Enumeration',('AQ114','AQ115','AT010'))
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['MCC3'] = {}
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['MCC3']['AQ114']  = (-999999,21,51,62,64,107,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['MCC3']['AQ115']  = (-999999,2,51,64,107,117,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['MCC3']['AT010']  = (-999999,64,152,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['OTH'] = ('StructuredText',('AB021','AC507','AD010','AD020','AD025','AD030','AD041','AD050','AD055','AD060','AF010','AF030','AJ051','AL017','AQ114','AQ115','AQ116','AT010','AT011','AT012','AT042','BH220'))
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['PCF'] = ('Enumeration',('AB021','AC507','AD010','AD020','AD025','AD030','AD041','AD050','AD055','AD060','AF010','AF030','AJ051','AL017','AQ114','AQ116','AT010','AT011','AT012','AT042','BH220'))
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['PCF']['AB021']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['PCF']['AC507']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['PCF']['AD010']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['PCF']['AD020']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['PCF']['AD025']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['PCF']['AD030']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['PCF']['AD041']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['PCF']['AD050']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['PCF']['AD055']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['PCF']['AD060']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['PCF']['AF010']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['PCF']['AF030']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['PCF']['AJ051']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['PCF']['AL017']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['PCF']['AQ114']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['PCF']['AQ116']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['PCF']['AT010']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['PCF']['AT011']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['PCF']['AT012']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['PCF']['AT042']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['PCF']['BH220']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['POS'] = ('Enumeration',('AD010'))
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['POS'] = {}
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['POS']['AD010']  = (-999999,1,2,3,4,5,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['POS2'] = ('Enumeration',('AD010'))
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['POS2'] = {}
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['POS2']['AD010']  = (-999999,1,2,3,4,5,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['POS3'] = ('Enumeration',('AD010'))
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['POS3'] = {}
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['POS3']['AD010']  = (-999999,1,2,3,4,5,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['PPO'] = ('Enumeration',('AC507','AD020','AD025','AQ116'))
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['PPO'] = {}
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['PPO']['AC507']  = (-999999,16,45,46,61,62,83,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['PPO']['AD020']  = (-999999,37,146,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['PPO']['AD025']  = (-999999,37,146,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['PPO']['AQ116']  = (-999999,16,45,46,83,101,122,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['PPO2'] = ('Enumeration',('AC507','AD020','AD025','AQ116'))
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['PPO2'] = {}
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['PPO2']['AC507']  = (-999999,16,45,46,61,62,83,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['PPO2']['AD020']  = (-999999,37,146,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['PPO2']['AD025']  = (-999999,37,146,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['PPO2']['AQ116']  = (-999999,16,45,46,83,101,122,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['PPO3'] = ('Enumeration',('AC507','AD020','AD025','AQ116'))
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['PPO3'] = {}
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['PPO3']['AC507']  = (-999999,16,45,46,61,62,83,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['PPO3']['AD020']  = (-999999,37,146,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['PPO3']['AD025']  = (-999999,37,146,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['PPO3']['AQ116']  = (-999999,16,45,46,83,101,122,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['RAC'] = ('Enumeration',('AT011'))
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['RAC'] = {}
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['RAC']['AT011']  = (-999999,1,2,3,4,5,6,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['SBT'] = ('Enumeration',('AD030'))
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['SBT'] = {}
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['SBT']['AD030']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['SBT2'] = ('Enumeration',('AD030'))
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['SBT2'] = {}
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['SBT2']['AD030']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['SBT3'] = ('Enumeration',('AD030'))
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['SBT3'] = {}
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['SBT3']['AD030']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['SPT'] = ('Boolean',('AT011'))
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['SRL'] = ('Enumeration',('AJ051'))
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['SRL'] = {}
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['SRL']['AJ051']  = (-999999,1,2,3)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['SSR'] = ('Enumeration',('AD041'))
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['SSR'] = {}
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['SSR']['AD041']  = (-999999,6,38,40,41,42,47,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['SSR2'] = ('Enumeration',('AD041'))
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['SSR2'] = {}
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['SSR2']['AD041']  = (-999999,6,38,40,41,42,47,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['SSR3'] = ('Enumeration',('AD041'))
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['SSR3'] = {}
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['SSR3']['AD041']  = (-999999,6,38,40,41,42,47,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['TOS'] = ('Enumeration',('AJ051'))
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['TOS'] = {}
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['TOS']['AJ051']  = (-999999,6,11,12,13,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['UFI'] = ('StructuredText',('AB021','AC507','AD010','AD020','AD025','AD030','AD041','AD050','AD055','AD060','AF010','AF030','AJ051','AL017','AQ114','AQ115','AQ116','AT010','AT011','AT012','AT042','BH220'))
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['UTY'] = ('Enumeration',('AQ115'))
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['UTY'] = {}
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['UTY']['AQ115']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['UTY2'] = ('Enumeration',('AQ115'))
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['UTY2'] = {}
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['UTY2']['AQ115']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['UTY3'] = ('Enumeration',('AQ115'))
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['UTY3'] = {}
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['UTY3']['AQ115']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['VCM'] = ('Enumeration',('AC507','AD010','AD025','AD030','AD041','AD050','AF010','AF030','AJ051','AQ116'))
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['VCM'] = {}
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['VCM']['AC507']  = (-999999,3,4,7,8,9,12,13,15,16,18,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['VCM']['AD010']  = (-999999,3,4,7,8,9,12,13,15,16,18,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['VCM']['AD025']  = (-999999,2,3,5,7,9,15,18,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['VCM']['AD030']  = (-999999,2,3,4,8,9,12,13,15,16,18,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['VCM']['AD041']  = (-999999,4,12,13,15,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['VCM']['AD050']  = (-999999,3,4,8,9,12,13,15,16,18,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['VCM']['AF010']  = (-999999,3,4,7,8,9,12,13,15,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['VCM']['AF030']  = (-999999,2,3,4,7,8,9,15,16,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['VCM']['AJ051']  = (-999999,2,4,5,7,9,15,18,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['VCM']['AQ116']  = (-999999,2,3,4,7,8,9,12,13,15,16,18,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['VCM2'] = ('Enumeration',('AC507','AD010','AD025','AD030','AD041','AD050','AF010','AF030','AJ051','AQ116'))
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['VCM2'] = {}
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['VCM2']['AC507']  = (-999999,3,4,7,8,9,12,13,15,16,18,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['VCM2']['AD010']  = (-999999,3,4,7,8,9,12,13,15,16,18,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['VCM2']['AD025']  = (-999999,2,3,5,7,9,15,18,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['VCM2']['AD030']  = (-999999,2,3,4,8,9,12,13,15,16,18,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['VCM2']['AD041']  = (-999999,4,12,13,15,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['VCM2']['AD050']  = (-999999,3,4,8,9,12,13,15,16,18,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['VCM2']['AF010']  = (-999999,3,4,7,8,9,12,13,15,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['VCM2']['AF030']  = (-999999,2,3,4,7,8,9,15,16,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['VCM2']['AJ051']  = (-999999,2,4,5,7,9,15,18,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['VCM2']['AQ116']  = (-999999,2,3,4,7,8,9,12,13,15,16,18,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['VCM3'] = ('Enumeration',('AC507','AD010','AD025','AD030','AD041','AD050','AF010','AF030','AJ051','AQ116'))
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['VCM3'] = {}
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['VCM3']['AC507']  = (-999999,3,4,7,8,9,12,13,15,16,18,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['VCM3']['AD010']  = (-999999,3,4,7,8,9,12,13,15,16,18,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['VCM3']['AD025']  = (-999999,2,3,5,7,9,15,18,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['VCM3']['AD030']  = (-999999,2,3,4,8,9,12,13,15,16,18,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['VCM3']['AD041']  = (-999999,4,12,13,15,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['VCM3']['AD050']  = (-999999,3,4,8,9,12,13,15,16,18,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['VCM3']['AF010']  = (-999999,3,4,7,8,9,12,13,15,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['VCM3']['AF030']  = (-999999,2,3,4,7,8,9,15,16,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['VCM3']['AJ051']  = (-999999,2,4,5,7,9,15,18,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['VCM3']['AQ116']  = (-999999,2,3,4,7,8,9,12,13,15,16,18,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['VOI'] = ('StructuredText',('AD041','AF010','AF030','AJ051','AT011','AT042'))
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['WDAC'] = ('Enumeration',('AQ116'))
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['WDAC'] = {}
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['WDAC']['AQ116']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['WDAL'] = ('real',('AQ116'))
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['WDAU'] = ('real',('AQ116'))
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['WDH'] = ('Real',('AQ116'))
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['WDL'] = ('Real',('AQ116'))
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['WDST'] = ('Enumeration',('AC507','BH220'))
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['WDST'] = {}
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['WDST']['AC507']  = (-999999,1,2,3,4,5,6,7,8,998,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['WDST']['BH220']  = (-999999,1,2,3,4,5,6,7,8,998,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['WID'] = ('Real',('AB021','AC507','AD010','AD020','AD025','AD030','AD041','AD050','AD055','AD060','AF030','AJ051','AQ114','AQ115','AQ116','AT010','AT012','AT042','BH220'))
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['WLSS'] = ('Real',('BH220'))
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['ZI001_SDV'] = ('StructuredText',('AB021','AC507','AD010','AD020','AD025','AD030','AD041','AD050','AD055','AD060','AF010','AF030','AJ051','AL017','AQ114','AQ115','AQ116','AT010','AT011','AT012','AT042','BH220'))
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['ZI001_SRT'] = ('Enumeration',('AB021','AC507','AD010','AD020','AD025','AD030','AD041','AD050','AD055','AD060','AF010','AF030','AJ051','AL017','AQ114','AQ115','AQ116','AT010','AT011','AT012','AT042','BH220'))
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['ZI001_SRT']['AB021']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['ZI001_SRT']['AC507']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['ZI001_SRT']['AD010']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['ZI001_SRT']['AD020']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['ZI001_SRT']['AD025']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['ZI001_SRT']['AD030']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['ZI001_SRT']['AD041']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['ZI001_SRT']['AD050']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['ZI001_SRT']['AD055']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['ZI001_SRT']['AD060']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['ZI001_SRT']['AF010']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['ZI001_SRT']['AF030']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['ZI001_SRT']['AJ051']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['ZI001_SRT']['AL017']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['ZI001_SRT']['AQ114']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['ZI001_SRT']['AQ115']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['ZI001_SRT']['AQ116']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['ZI001_SRT']['AT010']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['ZI001_SRT']['AT011']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['ZI001_SRT']['AT012']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['ZI001_SRT']['AT042']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['ZI001_SRT']['BH220']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['ZI002_UFI'] = ('StructuredText',('AB021','AC507','AD010','AD020','AD025','AD030','AD041','AD050','AD055','AD060','AF010','AF030','AJ051','AL017','AQ114','AQ115','AQ116','AT010','AT011','AT012','AT042','BH220'))
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['ZI004_RCG'] = ('Enumeration',('AB021','AC507','AD010','AD020','AD025','AD030','AD041','AD050','AD055','AD060','AF010','AF030','AJ051','AL017','AQ114','AQ115','AQ116','AT010','AT011','AT012','AT042','BH220'))
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['ZI004_RCG']['AB021']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['ZI004_RCG']['AC507']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['ZI004_RCG']['AD010']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['ZI004_RCG']['AD020']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['ZI004_RCG']['AD025']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['ZI004_RCG']['AD030']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['ZI004_RCG']['AD041']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['ZI004_RCG']['AD050']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['ZI004_RCG']['AD055']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['ZI004_RCG']['AD060']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['ZI004_RCG']['AF010']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['ZI004_RCG']['AF030']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['ZI004_RCG']['AJ051']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['ZI004_RCG']['AL017']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['ZI004_RCG']['AQ114']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['ZI004_RCG']['AQ115']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['ZI004_RCG']['AQ116']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['ZI004_RCG']['AT010']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['ZI004_RCG']['AT011']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['ZI004_RCG']['AT012']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['ZI004_RCG']['AT042']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['ZI004_RCG']['BH220']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['ZI005_FNA'] = ('String',('AB021','AC507','AD010','AD020','AD025','AD030','AD041','AD050','AD055','AD060','AF010','AF030','AJ051','AL017','AQ114','AQ115','AQ116','AT010','AT011','AT012','AT042','BH220'))
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['ZI005_FNA2'] = ('String',('AC507','AQ116','BH220'))
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['ZI005_FNA3'] = ('String',('AC507'))
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['ZI005_GNT'] = ('Enumeration',('AB021','AC507','AD010','AD020','AD025','AD030','AD041','AD050','AD055','AD060','AF010','AF030','AJ051','AL017','AQ114','AQ115','AQ116','AT010','AT011','AT012','AT042','BH220'))
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['ZI005_GNT']['AB021']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['ZI005_GNT']['AC507']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['ZI005_GNT']['AD010']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['ZI005_GNT']['AD020']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['ZI005_GNT']['AD025']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['ZI005_GNT']['AD030']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['ZI005_GNT']['AD041']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['ZI005_GNT']['AD050']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['ZI005_GNT']['AD055']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['ZI005_GNT']['AD060']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['ZI005_GNT']['AF010']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['ZI005_GNT']['AF030']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['ZI005_GNT']['AJ051']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['ZI005_GNT']['AL017']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['ZI005_GNT']['AQ114']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['ZI005_GNT']['AQ115']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['ZI005_GNT']['AQ116']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['ZI005_GNT']['AT010']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['ZI005_GNT']['AT011']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['ZI005_GNT']['AT012']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['ZI005_GNT']['AT042']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['ZI005_GNT']['BH220']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['ZI005_GNT2'] = ('Enumeration',('AC507','AQ116','BH220'))
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['ZI005_GNT2'] = {}
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['ZI005_GNT2']['AC507']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['ZI005_GNT2']['AQ116']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['ZI005_GNT2']['BH220']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['ZI005_GNT3'] = ('Enumeration',('AC507'))
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['ZI005_GNT3'] = {}
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['ZI005_GNT3']['AC507']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['ZI005_NFN'] = ('String',('AB021','AC507','AD010','AD020','AD025','AD030','AD041','AD050','AD055','AD060','AF010','AF030','AJ051','AL017','AQ114','AQ115','AQ116','AT010','AT011','AT012','AT042','BH220'))
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['ZI005_NFN2'] = ('String',('AC507','AQ116','BH220'))
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['ZI005_NFN3'] = ('String',('AC507'))
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['ZI006_MEM'] = ('String',('AB021','AC507','AD010','AD020','AD025','AD030','AD041','AD050','AD055','AD060','AF010','AF030','AJ051','AL017','AQ114','AQ115','AQ116','AT010','AT011','AT012','AT042','BH220'))
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['ZI014_PBY'] = ('Enumeration',('AC507'))
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['ZI014_PBY'] = {}
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['ZI014_PBY']['AC507']  = (-999999,1,2,6,7,8,12,15,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['ZI014_PBY2'] = ('Enumeration',('AC507'))
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['ZI014_PBY2'] = {}
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['ZI014_PBY2']['AC507']  = (-999999,1,2,6,7,8,12,15,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['ZI014_PBY3'] = ('Enumeration',('AC507'))
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['ZI014_PBY3'] = {}
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['ZI014_PBY3']['AC507']  = (-999999,1,2,6,7,8,12,15,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['ZI018_WIT'] = ('Enumeration',('AT011'))
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['ZI018_WIT'] = {}
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['ZI018_WIT']['AT011']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['ZI020_GE4'] = ('CodeList',('AB021','AC507','AD010','AD020','AD025','AD030','AD041','AD050','AD055','AD060','AF010','AF030','AJ051','AL017','AQ114','AQ115','AQ116','AT010','AT011','AT012','AT042','BH220'))
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['ZI024_ASE'] = ('Real',('AC507','AL017','AQ116','BH220'))
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['ZI024_AWO'] = ('Real',('AC507','AQ116','BH220'))
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['ZI024_AWOI'] = ('Real',('AC507','AQ116','BH220'))
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['ZI024_AWOX'] = ('Real',('AC507','AQ116','BH220'))
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['ZI024_CFR'] = ('Real',('AC507','AL017','AQ116','BH220'))
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['ZI024_CLO'] = ('Real',('AC507','AL017','AQ116','BH220'))
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['ZI024_CYN'] = ('Real',('AC507','AL017','AQ116','BH220'))
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['ZI024_DRL'] = ('Enumeration',('AC507','AQ116','BH220'))
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['ZI024_DRL'] = {}
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['ZI024_DRL']['AC507']  = (-999999,17,40,44,45,50,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['ZI024_DRL']['AQ116']  = (-999999,17,40,44,45,50,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['ZI024_DRL']['BH220']  = (-999999,17,40,44,45,50,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['ZI024_DVPT'] = ('Enumeration',('AC507','AQ116','BH220'))
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['ZI024_DVPT'] = {}
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['ZI024_DVPT']['AC507']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['ZI024_DVPT']['AQ116']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['ZI024_DVPT']['BH220']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['ZI024_FMR'] = ('Real',('AC507','AL017','AQ116','BH220'))
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['ZI024_FRR'] = ('Real',('AC507','AL017','AQ116','BH220'))
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['ZI024_HAR'] = ('Real',('AC507','AL017','AQ116','BH220'))
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['ZI024_MGN'] = ('Real',('AC507','AL017','AQ116','BH220'))
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['ZI024_PHW'] = ('Real',('AC507','AL017','AQ116','BH220'))
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['ZI024_PMP'] = ('Enumeration',('AC507','AQ116','BH220'))
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['ZI024_PMP'] = {}
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['ZI024_PMP']['AC507']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['ZI024_PMP']['AQ116']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['ZI024_PMP']['BH220']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['ZI024_PUR'] = ('Enumeration',('AC507','BH220'))
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['ZI024_PUR'] = {}
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['ZI024_PUR']['AC507']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['ZI024_PUR']['BH220']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['ZI024_PUR2'] = ('Enumeration',('AC507','BH220'))
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['ZI024_PUR2'] = {}
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['ZI024_PUR2']['AC507']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['ZI024_PUR2']['BH220']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['ZI024_PUR3'] = ('Enumeration',('AC507','BH220'))
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['ZI024_PUR3'] = {}
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['ZI024_PUR3']['AC507']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['ZI024_PUR3']['BH220']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['ZI024_PUR4'] = ('Enumeration',('AC507','BH220'))
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['ZI024_PUR4'] = {}
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['ZI024_PUR4']['AC507']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['ZI024_PUR4']['BH220']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['ZI024_PUR5'] = ('Enumeration',('AC507','BH220'))
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['ZI024_PUR5'] = {}
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['ZI024_PUR5']['AC507']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['ZI024_PUR5']['BH220']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['ZI024_SCC'] = ('Enumeration',('AC507','AL017','AQ116','BH220'))
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['ZI024_SCC'] = {}
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['ZI024_SCC']['AC507']  = (-999999,1,4,10,11,12,13,14,998,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['ZI024_SCC']['AL017']  = (-999999,1,4,10,11,12,13,14,998,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['ZI024_SCC']['AQ116']  = (-999999,1,4,10,11,12,13,14,998,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['ZI024_SCC']['BH220']  = (-999999,1,4,10,11,12,13,14,998,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['ZI024_SUL'] = ('Real',('AC507','AL017','AQ116','BH220'))
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['ZI024_TDS'] = ('Real',('AC507','AL017','AQ116','BH220'))
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['ZI024_TEP'] = ('Real',('AC507','AL017','AQ116','BH220'))
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['ZI024_TUR'] = ('Real',('AC507','AL017','AQ116','BH220'))
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['ZI024_WAC'] = ('Real',('AC507','AL017','AQ116','BH220'))
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['ZI024_WTNO'] = ('Real',('AC507','AL017','AQ116','BH220'))
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['ZI024_WUR'] = ('Enumeration',('AC507','AL017','AQ116','BH220'))
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['ZI024_WUR'] = {}
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['ZI024_WUR']['AC507']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['ZI024_WUR']['AL017']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['ZI024_WUR']['AQ116']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['ZI024_WUR']['BH220']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['ZI024_WUR2'] = ('Enumeration',('AC507','AQ116','BH220'))
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['ZI024_WUR2'] = {}
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['ZI024_WUR2']['AC507']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['ZI024_WUR2']['AQ116']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['ZI024_WUR2']['BH220']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['ZI024_WUR3'] = ('Enumeration',('AC507','AQ116','BH220'))
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['ZI024_WUR3'] = {}
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['ZI024_WUR3']['AC507']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['ZI024_WUR3']['AQ116']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['ZI024_WUR3']['BH220']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['ZI024_WUR4'] = ('Enumeration',('AC507','AQ116','BH220'))
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['ZI024_WUR4'] = {}
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['ZI024_WUR4']['AC507']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['ZI024_WUR4']['AQ116']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['ZI024_WUR4']['BH220']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['ZI024_YWQ'] = ('Enumeration',('AL017','AQ116','BH220'))
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['ZI024_YWQ'] = {}
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['ZI024_YWQ']['AL017']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['ZI024_YWQ']['AQ116']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['ZI024_YWQ']['BH220']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['ZI026_CTUC'] = ('Enumeration',('AB021','AC507','AD010','AD020','AD025','AD030','AD041','AD050','AD055','AD060','AF010','AF030','AJ051','AL017','AQ114','AQ115','AQ116','AT010','AT011','AT012','AT042','BH220'))
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['ZI026_CTUC']['AB021']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['ZI026_CTUC']['AC507']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['ZI026_CTUC']['AD010']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['ZI026_CTUC']['AD020']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['ZI026_CTUC']['AD025']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['ZI026_CTUC']['AD030']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['ZI026_CTUC']['AD041']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['ZI026_CTUC']['AD050']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['ZI026_CTUC']['AD055']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['ZI026_CTUC']['AD060']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['ZI026_CTUC']['AF010']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['ZI026_CTUC']['AF030']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['ZI026_CTUC']['AJ051']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['ZI026_CTUC']['AL017']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['ZI026_CTUC']['AQ114']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['ZI026_CTUC']['AQ115']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['ZI026_CTUC']['AQ116']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['ZI026_CTUC']['AT010']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['ZI026_CTUC']['AT011']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['ZI026_CTUC']['AT012']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['ZI026_CTUC']['AT042']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['ZI026_CTUC']['BH220']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['ZI026_CTUL'] = ('integer',('AB021','AC507','AD010','AD020','AD025','AD030','AD041','AD050','AD055','AD060','AF010','AF030','AJ051','AL017','AQ114','AQ115','AQ116','AT010','AT011','AT012','AT042','BH220'))
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['ZI026_CTUU'] = ('integer',('AB021','AC507','AD010','AD020','AD025','AD030','AD041','AD050','AD055','AD060','AF010','AF030','AJ051','AL017','AQ114','AQ115','AQ116','AT010','AT011','AT012','AT042','BH220'))
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['ZI031S_URI'] = ('StructuredText',('AB021','AC507','AD010','AD020','AD025','AD030','AD041','AD050','AD055','AD060','AF010','AF030','AJ051','AL017','AQ114','AQ115','AQ116','AT010','AT011','AT012','AT042','BH220'))
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['ZI032_GUG'] = ('Boolean',('AT042'))
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['ZI032_PYC'] = ('Enumeration',('AT042'))
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['ZI032_PYC'] = {}
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['ZI032_PYC']['AT042']  = (-999999,1,2,3,4,5,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['ZI032_PYM'] = ('Enumeration',('AT042'))
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['ZI032_PYM'] = {}
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['ZI032_PYM']['AT042']  = (-999999,1,3,4,5,7,8,9,10,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['ZI032_TOS'] = ('Enumeration',('AT042'))
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['ZI032_TOS'] = {}
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['ZI032_TOS']['AT042']  = (-999999,6,8,11,12,13,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['ZI039S_UFI'] = ('StructuredText',('AB021','AC507','AD010','AD020','AD025','AD030','AD041','AD050','AD055','AD060','AF010','AF030','AJ051','AL017','AQ114','AQ115','AQ116','AT010','AT011','AT012','AT042','BH220'))
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['ZSAX_RS0'] = ('CodeList',('AB021','AC507','AD010','AD020','AD025','AD030','AD041','AD050','AD055','AD060','AF010','AF030','AJ051','AL017','AQ114','AQ115','AQ116','AT010','AT011','AT012','AT042','BH220'))
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['ZSAX_RX0'] = ('StructuredText',('AB021','AC507','AD010','AD020','AD025','AD030','AD041','AD050','AD055','AD060','AF010','AF030','AJ051','AL017','AQ114','AQ115','AQ116','AT010','AT011','AT012','AT042','BH220'))
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['ZSAX_RX3'] = ('StructuredText',('AB021','AC507','AD010','AD020','AD025','AD030','AD041','AD050','AD055','AD060','AF010','AF030','AJ051','AL017','AQ114','AQ115','AQ116','AT010','AT011','AT012','AT042','BH220'))
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['ZSAX_RX4'] = ('StructuredText',('AB021','AC507','AD010','AD020','AD025','AD030','AD041','AD050','AD055','AD060','AF010','AF030','AJ051','AL017','AQ114','AQ115','AQ116','AT010','AT011','AT012','AT042','BH220'))
    field_information['GGDM 3.0']['UtilityInfrastructurePnt']['ZVH'] = ('Real',('AC507','AD010','AD020','AD025','AD030','AD041','AD050','AD055','AD060','AF010','AF030','AJ051','AL017','AQ116','AT010','AT011','AT012','AT042','BH220'))
    field_information['GGDM 3.0']['UtilityInfrastructurePntExt']['BEN'] = ('StructuredText',('STDPP','T0181'))
    field_information['GGDM 3.0']['UtilityInfrastructurePntExt']['CAA'] = ('Enumeration',('STDPP','T0181'))
    field_information['GGDM 3.0']['UtilityInfrastructurePntExt']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['UtilityInfrastructurePntExt']['EnumeratedIndexValues']['CAA']['STDPP']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePntExt']['EnumeratedIndexValues']['CAA']['T0181']  = (-999999,3,5,7,11,13,16,17,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePntExt']['CNCP'] = ('StructuredText',('STDPP','T0181'))
    field_information['GGDM 3.0']['UtilityInfrastructurePntExt']['COS'] = ('Enumeration',('STDPP','T0181'))
    field_information['GGDM 3.0']['UtilityInfrastructurePntExt']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['UtilityInfrastructurePntExt']['EnumeratedIndexValues']['COS']['STDPP']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['UtilityInfrastructurePntExt']['EnumeratedIndexValues']['COS']['T0181']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['UtilityInfrastructurePntExt']['DZP'] = ('Real',('T0181'))
    field_information['GGDM 3.0']['UtilityInfrastructurePntExt']['F_CODE'] = ('CONSTRAINED_STRING',('STDPP','T0181'))
    field_information['GGDM 3.0']['UtilityInfrastructurePntExt']['FUFI'] = ('StructuredText',('STDPP','T0181'))
    field_information['GGDM 3.0']['UtilityInfrastructurePntExt']['FURL'] = ('StructuredText',('STDPP','T0181'))
    field_information['GGDM 3.0']['UtilityInfrastructurePntExt']['GDBV'] = ('Enumeration',('STDPP','T0181'))
    field_information['GGDM 3.0']['UtilityInfrastructurePntExt']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['UtilityInfrastructurePntExt']['EnumeratedIndexValues']['GDBV']['STDPP']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePntExt']['EnumeratedIndexValues']['GDBV']['T0181']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePntExt']['HGT'] = ('Real',('STDPP','T0181'))
    field_information['GGDM 3.0']['UtilityInfrastructurePntExt']['HSCD'] = ('Real',('STDPP'))
    field_information['GGDM 3.0']['UtilityInfrastructurePntExt']['LMC'] = ('Boolean',('STDPP'))
    field_information['GGDM 3.0']['UtilityInfrastructurePntExt']['LUN'] = ('Boolean',('T0181'))
    field_information['GGDM 3.0']['UtilityInfrastructurePntExt']['LZN'] = ('Real',('STDPP'))
    field_information['GGDM 3.0']['UtilityInfrastructurePntExt']['OTH'] = ('StructuredText',('STDPP','T0181'))
    field_information['GGDM 3.0']['UtilityInfrastructurePntExt']['PCF'] = ('Enumeration',('STDPP','T0181'))
    field_information['GGDM 3.0']['UtilityInfrastructurePntExt']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['UtilityInfrastructurePntExt']['EnumeratedIndexValues']['PCF']['STDPP']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['UtilityInfrastructurePntExt']['EnumeratedIndexValues']['PCF']['T0181']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['UtilityInfrastructurePntExt']['SPT'] = ('Boolean',('T0181'))
    field_information['GGDM 3.0']['UtilityInfrastructurePntExt']['UFI'] = ('StructuredText',('STDPP','T0181'))
    field_information['GGDM 3.0']['UtilityInfrastructurePntExt']['ZI001_SDV'] = ('StructuredText',('STDPP','T0181'))
    field_information['GGDM 3.0']['UtilityInfrastructurePntExt']['ZI001_SRT'] = ('Enumeration',('STDPP','T0181'))
    field_information['GGDM 3.0']['UtilityInfrastructurePntExt']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['UtilityInfrastructurePntExt']['EnumeratedIndexValues']['ZI001_SRT']['STDPP']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePntExt']['EnumeratedIndexValues']['ZI001_SRT']['T0181']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePntExt']['ZI002_UFI'] = ('StructuredText',('STDPP','T0181'))
    field_information['GGDM 3.0']['UtilityInfrastructurePntExt']['ZI004_RCG'] = ('Enumeration',('STDPP','T0181'))
    field_information['GGDM 3.0']['UtilityInfrastructurePntExt']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['UtilityInfrastructurePntExt']['EnumeratedIndexValues']['ZI004_RCG']['STDPP']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePntExt']['EnumeratedIndexValues']['ZI004_RCG']['T0181']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePntExt']['ZI005_FNA'] = ('String',('STDPP'))
    field_information['GGDM 3.0']['UtilityInfrastructurePntExt']['ZI005_GNT'] = ('Enumeration',('STDPP'))
    field_information['GGDM 3.0']['UtilityInfrastructurePntExt']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['UtilityInfrastructurePntExt']['EnumeratedIndexValues']['ZI005_GNT']['STDPP']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePntExt']['ZI005_NFN'] = ('String',('STDPP'))
    field_information['GGDM 3.0']['UtilityInfrastructurePntExt']['ZI006_MEM'] = ('String',('STDPP','T0181'))
    field_information['GGDM 3.0']['UtilityInfrastructurePntExt']['ZI020_GE4'] = ('CodeList',('STDPP','T0181'))
    field_information['GGDM 3.0']['UtilityInfrastructurePntExt']['ZI024_ASE'] = ('Real',('STDPP'))
    field_information['GGDM 3.0']['UtilityInfrastructurePntExt']['ZI024_CFR'] = ('Real',('STDPP'))
    field_information['GGDM 3.0']['UtilityInfrastructurePntExt']['ZI024_CLO'] = ('Real',('STDPP'))
    field_information['GGDM 3.0']['UtilityInfrastructurePntExt']['ZI024_CYN'] = ('Real',('STDPP'))
    field_information['GGDM 3.0']['UtilityInfrastructurePntExt']['ZI024_DRL'] = ('Enumeration',('T0181'))
    field_information['GGDM 3.0']['UtilityInfrastructurePntExt']['EnumeratedIndexValues']['ZI024_DRL'] = {}
    field_information['GGDM 3.0']['UtilityInfrastructurePntExt']['EnumeratedIndexValues']['ZI024_DRL']['T0181']  = (-999999,17,40,44,45,50,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePntExt']['ZI024_DVPT'] = ('Enumeration',('T0181'))
    field_information['GGDM 3.0']['UtilityInfrastructurePntExt']['EnumeratedIndexValues']['ZI024_DVPT'] = {}
    field_information['GGDM 3.0']['UtilityInfrastructurePntExt']['EnumeratedIndexValues']['ZI024_DVPT']['T0181']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePntExt']['ZI024_FMR'] = ('Real',('STDPP'))
    field_information['GGDM 3.0']['UtilityInfrastructurePntExt']['ZI024_FRR'] = ('Real',('STDPP'))
    field_information['GGDM 3.0']['UtilityInfrastructurePntExt']['ZI024_HAR'] = ('Real',('STDPP'))
    field_information['GGDM 3.0']['UtilityInfrastructurePntExt']['ZI024_MGN'] = ('Real',('STDPP'))
    field_information['GGDM 3.0']['UtilityInfrastructurePntExt']['ZI024_PHW'] = ('Real',('STDPP'))
    field_information['GGDM 3.0']['UtilityInfrastructurePntExt']['ZI024_PMP'] = ('Enumeration',('T0181'))
    field_information['GGDM 3.0']['UtilityInfrastructurePntExt']['EnumeratedIndexValues']['ZI024_PMP'] = {}
    field_information['GGDM 3.0']['UtilityInfrastructurePntExt']['EnumeratedIndexValues']['ZI024_PMP']['T0181']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePntExt']['ZI024_SCC'] = ('Enumeration',('STDPP'))
    field_information['GGDM 3.0']['UtilityInfrastructurePntExt']['EnumeratedIndexValues']['ZI024_SCC'] = {}
    field_information['GGDM 3.0']['UtilityInfrastructurePntExt']['EnumeratedIndexValues']['ZI024_SCC']['STDPP']  = (-999999,1,4,10,11,12,13,14,998,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePntExt']['ZI024_SUL'] = ('Real',('STDPP'))
    field_information['GGDM 3.0']['UtilityInfrastructurePntExt']['ZI024_TDS'] = ('Real',('STDPP'))
    field_information['GGDM 3.0']['UtilityInfrastructurePntExt']['ZI024_TEP'] = ('Real',('STDPP'))
    field_information['GGDM 3.0']['UtilityInfrastructurePntExt']['ZI024_TUR'] = ('Real',('STDPP'))
    field_information['GGDM 3.0']['UtilityInfrastructurePntExt']['ZI024_WAC'] = ('Real',('STDPP'))
    field_information['GGDM 3.0']['UtilityInfrastructurePntExt']['ZI024_WTNO'] = ('Real',('STDPP'))
    field_information['GGDM 3.0']['UtilityInfrastructurePntExt']['ZI024_WUR'] = ('Enumeration',('STDPP'))
    field_information['GGDM 3.0']['UtilityInfrastructurePntExt']['EnumeratedIndexValues']['ZI024_WUR'] = {}
    field_information['GGDM 3.0']['UtilityInfrastructurePntExt']['EnumeratedIndexValues']['ZI024_WUR']['STDPP']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePntExt']['ZI024_YWQ'] = ('Enumeration',('STDPP'))
    field_information['GGDM 3.0']['UtilityInfrastructurePntExt']['EnumeratedIndexValues']['ZI024_YWQ'] = {}
    field_information['GGDM 3.0']['UtilityInfrastructurePntExt']['EnumeratedIndexValues']['ZI024_YWQ']['STDPP']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['UtilityInfrastructurePntExt']['ZI026_CTUC'] = ('Enumeration',('STDPP','T0181'))
    field_information['GGDM 3.0']['UtilityInfrastructurePntExt']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['UtilityInfrastructurePntExt']['EnumeratedIndexValues']['ZI026_CTUC']['STDPP']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['UtilityInfrastructurePntExt']['EnumeratedIndexValues']['ZI026_CTUC']['T0181']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['UtilityInfrastructurePntExt']['ZI026_CTUL'] = ('integer',('STDPP','T0181'))
    field_information['GGDM 3.0']['UtilityInfrastructurePntExt']['ZI026_CTUU'] = ('integer',('STDPP','T0181'))
    field_information['GGDM 3.0']['UtilityInfrastructurePntExt']['ZI031S_URI'] = ('StructuredText',('STDPP','T0181'))
    field_information['GGDM 3.0']['UtilityInfrastructurePntExt']['ZI039S_UFI'] = ('StructuredText',('STDPP','T0181'))
    field_information['GGDM 3.0']['UtilityInfrastructurePntExt']['ZSAX_RS0'] = ('CodeList',('STDPP','T0181'))
    field_information['GGDM 3.0']['UtilityInfrastructurePntExt']['ZSAX_RX0'] = ('StructuredText',('STDPP','T0181'))
    field_information['GGDM 3.0']['UtilityInfrastructurePntExt']['ZSAX_RX3'] = ('StructuredText',('STDPP','T0181'))
    field_information['GGDM 3.0']['UtilityInfrastructurePntExt']['ZSAX_RX4'] = ('StructuredText',('STDPP','T0181'))
    field_information['GGDM 3.0']['UtilityInfrastructurePntExt']['ZVH'] = ('Real',('STDPP'))
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['ADR'] = ('String',('AC507','AD010','AD025','AD030','AD050','AD055','AD060','AQ116','AT012','BH220'))
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['ADUR'] = ('Real',('BH220'))
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['ANFL'] = ('Real',('BH220'))
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['AOO'] = ('Real',('AC507','AD010','AD020','AD025','AD030','AD041','AD050','AD055','AD060','AF030','AQ116','AT012','BH220'))
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['ARA'] = ('Real',('AC507','AD010','AD020','AD025','AD030','AD041','AD050','AD055','AD060','AF030','AQ116','AT012','BH220'))
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['AWP'] = ('Boolean',('AD041','AF030'))
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['BEN'] = ('StructuredText',('AC507','AD010','AD020','AD025','AD030','AD041','AD050','AD055','AD060','AF030','AQ116','AT012','BH220'))
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['CAA'] = ('Enumeration',('AC507','AD010','AD025','AD030','AD041','AD050','AD055','AD060','AF030','AQ116','AT012','BH220'))
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['CAA']['AC507']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['CAA']['AD010']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['CAA']['AD025']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['CAA']['AD030']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['CAA']['AD041']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['CAA']['AD050']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['CAA']['AD055']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['CAA']['AD060']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['CAA']['AF030']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['CAA']['AQ116']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['CAA']['AT012']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['CAA']['BH220']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['CNCP'] = ('StructuredText',('AC507','AD010','AD020','AD025','AD030','AD041','AD050','AD055','AD060','AF030','AQ116','AT012','BH220'))
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['COS'] = ('Enumeration',('AC507','AD010','AD020','AD025','AD030','AD041','AD050','AD055','AD060','AF030','AQ116','AT012','BH220'))
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['COS']['AC507']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['COS']['AD010']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['COS']['AD020']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['COS']['AD025']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['COS']['AD030']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['COS']['AD041']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['COS']['AD050']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['COS']['AD055']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['COS']['AD060']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['COS']['AF030']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['COS']['AQ116']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['COS']['AT012']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['COS']['BH220']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['DCAP'] = ('Real',('AC507','BH220'))
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['DINF'] = ('Enumeration',('AC507','BH220'))
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['DINF'] = {}
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['DINF']['AC507']  = (-999999,1,2,3,4,5,6,7,8,998,999)
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['DINF']['BH220']  = (-999999,1,2,3,4,5,6,7,8,998,999)
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['DZP'] = ('Real',('AD041','AQ116'))
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EPW'] = ('Real',('AD010'))
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['F_CODE'] = ('CONSTRAINED_STRING',('AC507','AD010','AD020','AD025','AD030','AD041','AD050','AD055','AD060','AF030','AQ116','AT012','BH220'))
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['FFN'] = ('Enumeration',('AD050','AD055','AQ116','AT012'))
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['FFN'] = {}
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['FFN']['AD050']  = (-999999,99,440,563,811,999)
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['FFN']['AD055']  = (-999999,99,440,563,811,999)
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['FFN']['AQ116']  = (-999999,50,60,192,350,360,361,362,363,370,500,505,999)
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['FFN']['AT012']  = (-999999,486,601,604,610,614,615,620,625,720,999)
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['FFN2'] = ('Enumeration',('AD050','AD055','AQ116','AT012'))
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['FFN2'] = {}
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['FFN2']['AD050']  = (-999999,99,440,563,811,999)
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['FFN2']['AD055']  = (-999999,99,440,563,811,999)
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['FFN2']['AQ116']  = (-999999,50,60,192,350,360,361,362,363,370,500,505,999)
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['FFN2']['AT012']  = (-999999,486,601,604,610,614,615,620,625,720,999)
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['FFN3'] = ('Enumeration',('AD050','AD055','AQ116','AT012'))
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['FFN3'] = {}
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['FFN3']['AD050']  = (-999999,99,440,563,811,999)
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['FFN3']['AD055']  = (-999999,99,440,563,811,999)
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['FFN3']['AQ116']  = (-999999,50,60,192,350,360,361,362,363,370,500,505,999)
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['FFN3']['AT012']  = (-999999,486,601,604,610,614,615,620,625,720,999)
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['FUFI'] = ('StructuredText',('AC507','AD010','AD020','AD025','AD030','AD041','AD050','AD055','AD060','AF030','AQ116','AT012','BH220'))
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['FURL'] = ('StructuredText',('AC507','AD010','AD020','AD025','AD030','AD041','AD050','AD055','AD060','AF030','AQ116','AT012','BH220'))
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['GDBV'] = ('Enumeration',('AC507','AD010','AD020','AD025','AD030','AD041','AD050','AD055','AD060','AF030','AQ116','AT012','BH220'))
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['GDBV']['AC507']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['GDBV']['AD010']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['GDBV']['AD020']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['GDBV']['AD025']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['GDBV']['AD030']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['GDBV']['AD041']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['GDBV']['AD050']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['GDBV']['AD055']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['GDBV']['AD060']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['GDBV']['AF030']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['GDBV']['AQ116']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['GDBV']['AT012']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['GDBV']['BH220']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['GRD'] = ('Boolean',('AC507','BH220'))
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['HGT'] = ('Real',('AC507','AD010','AD020','AD025','AD030','AD041','AD050','AD055','AD060','AF030','AQ116','AT012','BH220'))
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['LEA'] = ('Real',('AD041'))
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['LMC'] = ('Boolean',('AC507','AD010','AD020','AD025','AD030','AD041','AD050','AD055','AD060','AF030','AQ116','AT012','BH220'))
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['LUN'] = ('Boolean',('AQ116'))
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['LZN'] = ('Real',('AC507','AD010','AD020','AD025','AD030','AD041','AD050','AD055','AD060','AF030','AQ116','AT012','BH220'))
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['OTH'] = ('StructuredText',('AC507','AD010','AD020','AD025','AD030','AD041','AD050','AD055','AD060','AF030','AQ116','AT012','BH220'))
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['PCF'] = ('Enumeration',('AC507','AD010','AD020','AD025','AD030','AD041','AD050','AD055','AD060','AF030','AQ116','AT012','BH220'))
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['PCF']['AC507']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['PCF']['AD010']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['PCF']['AD020']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['PCF']['AD025']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['PCF']['AD030']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['PCF']['AD041']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['PCF']['AD050']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['PCF']['AD055']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['PCF']['AD060']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['PCF']['AF030']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['PCF']['AQ116']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['PCF']['AT012']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['PCF']['BH220']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['POS'] = ('Enumeration',('AD010'))
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['POS'] = {}
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['POS']['AD010']  = (-999999,1,2,3,4,5,999)
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['POS2'] = ('Enumeration',('AD010'))
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['POS2'] = {}
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['POS2']['AD010']  = (-999999,1,2,3,4,5,999)
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['POS3'] = ('Enumeration',('AD010'))
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['POS3'] = {}
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['POS3']['AD010']  = (-999999,1,2,3,4,5,999)
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['PPO'] = ('Enumeration',('AC507','AD020','AD025','AQ116'))
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['PPO'] = {}
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['PPO']['AC507']  = (-999999,16,45,46,61,62,83,999)
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['PPO']['AD020']  = (-999999,37,146,999)
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['PPO']['AD025']  = (-999999,37,146,999)
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['PPO']['AQ116']  = (-999999,16,45,46,83,101,122,999)
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['PPO2'] = ('Enumeration',('AC507','AD020','AD025','AQ116'))
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['PPO2'] = {}
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['PPO2']['AC507']  = (-999999,16,45,46,61,62,83,999)
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['PPO2']['AD020']  = (-999999,37,146,999)
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['PPO2']['AD025']  = (-999999,37,146,999)
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['PPO2']['AQ116']  = (-999999,16,45,46,83,101,122,999)
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['PPO3'] = ('Enumeration',('AC507','AD020','AD025','AQ116'))
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['PPO3'] = {}
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['PPO3']['AC507']  = (-999999,16,45,46,61,62,83,999)
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['PPO3']['AD020']  = (-999999,37,146,999)
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['PPO3']['AD025']  = (-999999,37,146,999)
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['PPO3']['AQ116']  = (-999999,16,45,46,83,101,122,999)
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['SBT'] = ('Enumeration',('AD030'))
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['SBT'] = {}
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['SBT']['AD030']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['SBT2'] = ('Enumeration',('AD030'))
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['SBT2'] = {}
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['SBT2']['AD030']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['SBT3'] = ('Enumeration',('AD030'))
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['SBT3'] = {}
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['SBT3']['AD030']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['SSR'] = ('Enumeration',('AD041'))
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['SSR'] = {}
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['SSR']['AD041']  = (-999999,6,38,40,41,42,47,999)
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['SSR2'] = ('Enumeration',('AD041'))
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['SSR2'] = {}
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['SSR2']['AD041']  = (-999999,6,38,40,41,42,47,999)
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['SSR3'] = ('Enumeration',('AD041'))
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['SSR3'] = {}
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['SSR3']['AD041']  = (-999999,6,38,40,41,42,47,999)
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['UFI'] = ('StructuredText',('AC507','AD010','AD020','AD025','AD030','AD041','AD050','AD055','AD060','AF030','AQ116','AT012','BH220'))
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['VCM'] = ('Enumeration',('AC507','AD010','AD025','AD030','AD041','AD050','AF030','AQ116'))
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['VCM'] = {}
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['VCM']['AC507']  = (-999999,3,4,7,8,9,12,13,15,16,18,999)
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['VCM']['AD010']  = (-999999,3,4,7,8,9,12,13,15,16,18,999)
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['VCM']['AD025']  = (-999999,2,3,5,7,9,15,18,999)
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['VCM']['AD030']  = (-999999,2,3,4,8,9,12,13,15,16,18,999)
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['VCM']['AD041']  = (-999999,4,12,13,15,999)
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['VCM']['AD050']  = (-999999,3,4,8,9,12,13,15,16,18,999)
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['VCM']['AF030']  = (-999999,2,3,4,7,8,9,15,16,999)
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['VCM']['AQ116']  = (-999999,2,3,4,7,8,9,12,13,15,16,18,999)
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['VCM2'] = ('Enumeration',('AC507','AD010','AD025','AD030','AD041','AD050','AF030','AQ116'))
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['VCM2'] = {}
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['VCM2']['AC507']  = (-999999,3,4,7,8,9,12,13,15,16,18,999)
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['VCM2']['AD010']  = (-999999,3,4,7,8,9,12,13,15,16,18,999)
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['VCM2']['AD025']  = (-999999,2,3,5,7,9,15,18,999)
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['VCM2']['AD030']  = (-999999,2,3,4,8,9,12,13,15,16,18,999)
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['VCM2']['AD041']  = (-999999,4,12,13,15,999)
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['VCM2']['AD050']  = (-999999,3,4,8,9,12,13,15,16,18,999)
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['VCM2']['AF030']  = (-999999,2,3,4,7,8,9,15,16,999)
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['VCM2']['AQ116']  = (-999999,2,3,4,7,8,9,12,13,15,16,18,999)
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['VCM3'] = ('Enumeration',('AC507','AD010','AD025','AD030','AD041','AD050','AF030','AQ116'))
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['VCM3'] = {}
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['VCM3']['AC507']  = (-999999,3,4,7,8,9,12,13,15,16,18,999)
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['VCM3']['AD010']  = (-999999,3,4,7,8,9,12,13,15,16,18,999)
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['VCM3']['AD025']  = (-999999,2,3,5,7,9,15,18,999)
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['VCM3']['AD030']  = (-999999,2,3,4,8,9,12,13,15,16,18,999)
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['VCM3']['AD041']  = (-999999,4,12,13,15,999)
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['VCM3']['AD050']  = (-999999,3,4,8,9,12,13,15,16,18,999)
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['VCM3']['AF030']  = (-999999,2,3,4,7,8,9,15,16,999)
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['VCM3']['AQ116']  = (-999999,2,3,4,7,8,9,12,13,15,16,18,999)
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['VOI'] = ('StructuredText',('AD041','AF030'))
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['WDAC'] = ('Enumeration',('AQ116'))
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['WDAC'] = {}
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['WDAC']['AQ116']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['WDAL'] = ('real',('AQ116'))
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['WDAU'] = ('real',('AQ116'))
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['WDH'] = ('Real',('AQ116'))
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['WDL'] = ('Real',('AQ116'))
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['WDST'] = ('Enumeration',('AC507','BH220'))
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['WDST'] = {}
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['WDST']['AC507']  = (-999999,1,2,3,4,5,6,7,8,998,999)
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['WDST']['BH220']  = (-999999,1,2,3,4,5,6,7,8,998,999)
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['WID'] = ('Real',('AC507','AD010','AD020','AD025','AD030','AD041','AD050','AD055','AD060','AF030','AQ116','AT012','BH220'))
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['WLSS'] = ('Real',('BH220'))
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['ZI001_SDV'] = ('StructuredText',('AC507','AD010','AD020','AD025','AD030','AD041','AD050','AD055','AD060','AF030','AQ116','AT012','BH220'))
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['ZI001_SRT'] = ('Enumeration',('AC507','AD010','AD020','AD025','AD030','AD041','AD050','AD055','AD060','AF030','AQ116','AT012','BH220'))
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['ZI001_SRT']['AC507']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['ZI001_SRT']['AD010']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['ZI001_SRT']['AD020']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['ZI001_SRT']['AD025']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['ZI001_SRT']['AD030']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['ZI001_SRT']['AD041']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['ZI001_SRT']['AD050']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['ZI001_SRT']['AD055']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['ZI001_SRT']['AD060']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['ZI001_SRT']['AF030']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['ZI001_SRT']['AQ116']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['ZI001_SRT']['AT012']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['ZI001_SRT']['BH220']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['ZI002_UFI'] = ('StructuredText',('AC507','AD010','AD020','AD025','AD030','AD041','AD050','AD055','AD060','AF030','AQ116','AT012','BH220'))
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['ZI004_RCG'] = ('Enumeration',('AC507','AD010','AD020','AD025','AD030','AD041','AD050','AD055','AD060','AF030','AQ116','AT012','BH220'))
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['ZI004_RCG']['AC507']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['ZI004_RCG']['AD010']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['ZI004_RCG']['AD020']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['ZI004_RCG']['AD025']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['ZI004_RCG']['AD030']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['ZI004_RCG']['AD041']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['ZI004_RCG']['AD050']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['ZI004_RCG']['AD055']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['ZI004_RCG']['AD060']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['ZI004_RCG']['AF030']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['ZI004_RCG']['AQ116']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['ZI004_RCG']['AT012']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['ZI004_RCG']['BH220']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['ZI005_FNA'] = ('String',('AC507','AD010','AD020','AD025','AD030','AD041','AD050','AD055','AD060','AF030','AQ116','AT012','BH220'))
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['ZI005_FNA2'] = ('String',('AC507','AQ116','BH220'))
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['ZI005_FNA3'] = ('String',('AC507'))
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['ZI005_GNT'] = ('Enumeration',('AC507','AD010','AD020','AD025','AD030','AD041','AD050','AD055','AD060','AF030','AQ116','AT012','BH220'))
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['ZI005_GNT']['AC507']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['ZI005_GNT']['AD010']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['ZI005_GNT']['AD020']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['ZI005_GNT']['AD025']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['ZI005_GNT']['AD030']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['ZI005_GNT']['AD041']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['ZI005_GNT']['AD050']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['ZI005_GNT']['AD055']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['ZI005_GNT']['AD060']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['ZI005_GNT']['AF030']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['ZI005_GNT']['AQ116']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['ZI005_GNT']['AT012']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['ZI005_GNT']['BH220']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['ZI005_GNT2'] = ('Enumeration',('AC507','AQ116','BH220'))
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['ZI005_GNT2'] = {}
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['ZI005_GNT2']['AC507']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['ZI005_GNT2']['AQ116']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['ZI005_GNT2']['BH220']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['ZI005_GNT3'] = ('Enumeration',('AC507'))
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['ZI005_GNT3'] = {}
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['ZI005_GNT3']['AC507']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['ZI005_NFN'] = ('String',('AC507','AD010','AD020','AD025','AD030','AD041','AD050','AD055','AD060','AF030','AQ116','AT012','BH220'))
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['ZI005_NFN2'] = ('String',('AC507','AQ116','BH220'))
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['ZI005_NFN3'] = ('String',('AC507'))
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['ZI006_MEM'] = ('String',('AC507','AD010','AD020','AD025','AD030','AD041','AD050','AD055','AD060','AF030','AQ116','AT012','BH220'))
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['ZI014_PBY'] = ('Enumeration',('AC507'))
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['ZI014_PBY'] = {}
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['ZI014_PBY']['AC507']  = (-999999,1,2,6,7,8,12,15,999)
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['ZI014_PBY2'] = ('Enumeration',('AC507'))
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['ZI014_PBY2'] = {}
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['ZI014_PBY2']['AC507']  = (-999999,1,2,6,7,8,12,15,999)
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['ZI014_PBY3'] = ('Enumeration',('AC507'))
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['ZI014_PBY3'] = {}
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['ZI014_PBY3']['AC507']  = (-999999,1,2,6,7,8,12,15,999)
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['ZI020_GE4'] = ('CodeList',('AC507','AD010','AD020','AD025','AD030','AD041','AD050','AD055','AD060','AF030','AQ116','AT012','BH220'))
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['ZI024_ASE'] = ('Real',('AC507','AQ116','BH220'))
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['ZI024_AWO'] = ('Real',('AC507','AQ116','BH220'))
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['ZI024_AWOI'] = ('Real',('AC507','AQ116','BH220'))
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['ZI024_AWOX'] = ('Real',('AC507','AQ116','BH220'))
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['ZI024_CFR'] = ('Real',('AC507','AQ116','BH220'))
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['ZI024_CLO'] = ('Real',('AC507','AQ116','BH220'))
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['ZI024_CYN'] = ('Real',('AC507','AQ116','BH220'))
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['ZI024_DRL'] = ('Enumeration',('AC507','AQ116','BH220'))
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['ZI024_DRL'] = {}
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['ZI024_DRL']['AC507']  = (-999999,17,40,44,45,50,999)
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['ZI024_DRL']['AQ116']  = (-999999,17,40,44,45,50,999)
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['ZI024_DRL']['BH220']  = (-999999,17,40,44,45,50,999)
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['ZI024_DVPT'] = ('Enumeration',('AC507','AQ116','BH220'))
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['ZI024_DVPT'] = {}
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['ZI024_DVPT']['AC507']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['ZI024_DVPT']['AQ116']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['ZI024_DVPT']['BH220']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['ZI024_FMR'] = ('Real',('AC507','AQ116','BH220'))
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['ZI024_FRR'] = ('Real',('AC507','AQ116','BH220'))
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['ZI024_HAR'] = ('Real',('AC507','AQ116','BH220'))
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['ZI024_MGN'] = ('Real',('AC507','AQ116','BH220'))
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['ZI024_PHW'] = ('Real',('AC507','AQ116','BH220'))
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['ZI024_PMP'] = ('Enumeration',('AC507','AQ116','BH220'))
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['ZI024_PMP'] = {}
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['ZI024_PMP']['AC507']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['ZI024_PMP']['AQ116']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['ZI024_PMP']['BH220']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['ZI024_PUR'] = ('Enumeration',('AC507','BH220'))
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['ZI024_PUR'] = {}
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['ZI024_PUR']['AC507']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['ZI024_PUR']['BH220']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['ZI024_PUR2'] = ('Enumeration',('AC507','BH220'))
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['ZI024_PUR2'] = {}
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['ZI024_PUR2']['AC507']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['ZI024_PUR2']['BH220']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['ZI024_PUR3'] = ('Enumeration',('AC507','BH220'))
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['ZI024_PUR3'] = {}
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['ZI024_PUR3']['AC507']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['ZI024_PUR3']['BH220']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['ZI024_PUR4'] = ('Enumeration',('AC507','BH220'))
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['ZI024_PUR4'] = {}
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['ZI024_PUR4']['AC507']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['ZI024_PUR4']['BH220']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['ZI024_PUR5'] = ('Enumeration',('AC507','BH220'))
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['ZI024_PUR5'] = {}
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['ZI024_PUR5']['AC507']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['ZI024_PUR5']['BH220']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['ZI024_SCC'] = ('Enumeration',('AC507','AQ116','BH220'))
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['ZI024_SCC'] = {}
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['ZI024_SCC']['AC507']  = (-999999,1,4,10,11,12,13,14,998,999)
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['ZI024_SCC']['AQ116']  = (-999999,1,4,10,11,12,13,14,998,999)
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['ZI024_SCC']['BH220']  = (-999999,1,4,10,11,12,13,14,998,999)
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['ZI024_SUL'] = ('Real',('AC507','AQ116','BH220'))
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['ZI024_TDS'] = ('Real',('AC507','AQ116','BH220'))
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['ZI024_TEP'] = ('Real',('AC507','AQ116','BH220'))
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['ZI024_TUR'] = ('Real',('AC507','AQ116','BH220'))
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['ZI024_WAC'] = ('Real',('AC507','AQ116','BH220'))
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['ZI024_WTNO'] = ('Real',('AC507','AQ116','BH220'))
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['ZI024_WUR'] = ('Enumeration',('AC507','AQ116','BH220'))
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['ZI024_WUR'] = {}
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['ZI024_WUR']['AC507']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['ZI024_WUR']['AQ116']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['ZI024_WUR']['BH220']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['ZI024_WUR2'] = ('Enumeration',('AC507','AQ116','BH220'))
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['ZI024_WUR2'] = {}
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['ZI024_WUR2']['AC507']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['ZI024_WUR2']['AQ116']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['ZI024_WUR2']['BH220']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['ZI024_WUR3'] = ('Enumeration',('AC507','AQ116','BH220'))
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['ZI024_WUR3'] = {}
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['ZI024_WUR3']['AC507']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['ZI024_WUR3']['AQ116']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['ZI024_WUR3']['BH220']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['ZI024_WUR4'] = ('Enumeration',('AC507','AQ116','BH220'))
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['ZI024_WUR4'] = {}
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['ZI024_WUR4']['AC507']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['ZI024_WUR4']['AQ116']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['ZI024_WUR4']['BH220']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['ZI024_YWQ'] = ('Enumeration',('AQ116','BH220'))
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['ZI024_YWQ'] = {}
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['ZI024_YWQ']['AQ116']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['ZI024_YWQ']['BH220']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['ZI026_CTUC'] = ('Enumeration',('AC507','AD010','AD020','AD025','AD030','AD041','AD050','AD055','AD060','AF030','AQ116','AT012','BH220'))
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['ZI026_CTUC']['AC507']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['ZI026_CTUC']['AD010']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['ZI026_CTUC']['AD020']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['ZI026_CTUC']['AD025']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['ZI026_CTUC']['AD030']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['ZI026_CTUC']['AD041']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['ZI026_CTUC']['AD050']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['ZI026_CTUC']['AD055']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['ZI026_CTUC']['AD060']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['ZI026_CTUC']['AF030']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['ZI026_CTUC']['AQ116']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['ZI026_CTUC']['AT012']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['ZI026_CTUC']['BH220']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['ZI026_CTUL'] = ('integer',('AC507','AD010','AD020','AD025','AD030','AD041','AD050','AD055','AD060','AF030','AQ116','AT012','BH220'))
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['ZI026_CTUU'] = ('integer',('AC507','AD010','AD020','AD025','AD030','AD041','AD050','AD055','AD060','AF030','AQ116','AT012','BH220'))
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['ZI031S_URI'] = ('StructuredText',('AC507','AD010','AD020','AD025','AD030','AD041','AD050','AD055','AD060','AF030','AQ116','AT012','BH220'))
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['ZI039S_UFI'] = ('StructuredText',('AC507','AD010','AD020','AD025','AD030','AD041','AD050','AD055','AD060','AF030','AQ116','AT012','BH220'))
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['ZSAX_RS0'] = ('CodeList',('AC507','AD010','AD020','AD025','AD030','AD041','AD050','AD055','AD060','AF030','AQ116','AT012','BH220'))
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['ZSAX_RX0'] = ('StructuredText',('AC507','AD010','AD020','AD025','AD030','AD041','AD050','AD055','AD060','AF030','AQ116','AT012','BH220'))
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['ZSAX_RX3'] = ('StructuredText',('AC507','AD010','AD020','AD025','AD030','AD041','AD050','AD055','AD060','AF030','AQ116','AT012','BH220'))
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['ZSAX_RX4'] = ('StructuredText',('AC507','AD010','AD020','AD025','AD030','AD041','AD050','AD055','AD060','AF030','AQ116','AT012','BH220'))
    field_information['GGDM 3.0']['UtilityInfrastructureSrf']['ZVH'] = ('Real',('AC507','AD010','AD020','AD025','AD030','AD041','AD050','AD055','AD060','AF030','AQ116','AT012','BH220'))
    field_information['GGDM 3.0']['VegetationCrv']['AOO'] = ('Real',('EC015'))
    field_information['GGDM 3.0']['VegetationCrv']['ARA'] = ('Real',('EA020','EC015','EC040'))
    field_information['GGDM 3.0']['VegetationCrv']['BEN'] = ('StructuredText',('EA020','EC015','EC040'))
    field_information['GGDM 3.0']['VegetationCrv']['DMBC'] = ('Enumeration',('EC015'))
    field_information['GGDM 3.0']['VegetationCrv']['EnumeratedIndexValues']['DMBC'] = {}
    field_information['GGDM 3.0']['VegetationCrv']['EnumeratedIndexValues']['DMBC']['EC015']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['VegetationCrv']['DMBL'] = ('real',('EC015'))
    field_information['GGDM 3.0']['VegetationCrv']['DMBU'] = ('real',('EC015'))
    field_information['GGDM 3.0']['VegetationCrv']['DMT'] = ('Real',('EC015'))
    field_information['GGDM 3.0']['VegetationCrv']['F_CODE'] = ('CONSTRAINED_STRING',('EA020','EC015','EC040'))
    field_information['GGDM 3.0']['VegetationCrv']['FUFI'] = ('StructuredText',('EA020','EC015','EC040'))
    field_information['GGDM 3.0']['VegetationCrv']['FURL'] = ('StructuredText',('EA020','EC015','EC040'))
    field_information['GGDM 3.0']['VegetationCrv']['GDBV'] = ('Enumeration',('EA020','EC015','EC040'))
    field_information['GGDM 3.0']['VegetationCrv']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['VegetationCrv']['EnumeratedIndexValues']['GDBV']['EA020']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['VegetationCrv']['EnumeratedIndexValues']['GDBV']['EC015']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['VegetationCrv']['EnumeratedIndexValues']['GDBV']['EC040']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['VegetationCrv']['HGT'] = ('Real',('EA020','EC015'))
    field_information['GGDM 3.0']['VegetationCrv']['LMC'] = ('Boolean',('EA020','EC015'))
    field_information['GGDM 3.0']['VegetationCrv']['LZN'] = ('Real',('EA020','EC015','EC040'))
    field_information['GGDM 3.0']['VegetationCrv']['OTH'] = ('StructuredText',('EA020','EC015','EC040'))
    field_information['GGDM 3.0']['VegetationCrv']['PVH'] = ('Real',('EA020','EC015'))
    field_information['GGDM 3.0']['VegetationCrv']['SBC'] = ('Boolean',('EC015'))
    field_information['GGDM 3.0']['VegetationCrv']['SDSC'] = ('Enumeration',('EC015'))
    field_information['GGDM 3.0']['VegetationCrv']['EnumeratedIndexValues']['SDSC'] = {}
    field_information['GGDM 3.0']['VegetationCrv']['EnumeratedIndexValues']['SDSC']['EC015']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['VegetationCrv']['SDSL'] = ('real',('EC015'))
    field_information['GGDM 3.0']['VegetationCrv']['SDSU'] = ('real',('EC015'))
    field_information['GGDM 3.0']['VegetationCrv']['TRE'] = ('Enumeration',('EC015'))
    field_information['GGDM 3.0']['VegetationCrv']['EnumeratedIndexValues']['TRE'] = {}
    field_information['GGDM 3.0']['VegetationCrv']['EnumeratedIndexValues']['TRE']['EC015']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['VegetationCrv']['TSCC'] = ('Enumeration',('EC015'))
    field_information['GGDM 3.0']['VegetationCrv']['EnumeratedIndexValues']['TSCC'] = {}
    field_information['GGDM 3.0']['VegetationCrv']['EnumeratedIndexValues']['TSCC']['EC015']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['VegetationCrv']['TSCL'] = ('real',('EC015'))
    field_information['GGDM 3.0']['VegetationCrv']['TSCU'] = ('real',('EC015'))
    field_information['GGDM 3.0']['VegetationCrv']['UFI'] = ('StructuredText',('EA020','EC015','EC040'))
    field_information['GGDM 3.0']['VegetationCrv']['VSP'] = ('Enumeration',('EC015'))
    field_information['GGDM 3.0']['VegetationCrv']['EnumeratedIndexValues']['VSP'] = {}
    field_information['GGDM 3.0']['VegetationCrv']['EnumeratedIndexValues']['VSP']['EC015']  = (-999999,8,25,999)
    field_information['GGDM 3.0']['VegetationCrv']['VSP2'] = ('Enumeration',('EC015'))
    field_information['GGDM 3.0']['VegetationCrv']['EnumeratedIndexValues']['VSP2'] = {}
    field_information['GGDM 3.0']['VegetationCrv']['EnumeratedIndexValues']['VSP2']['EC015']  = (-999999,8,25,999)
    field_information['GGDM 3.0']['VegetationCrv']['VSP3'] = ('Enumeration',('EC015'))
    field_information['GGDM 3.0']['VegetationCrv']['EnumeratedIndexValues']['VSP3'] = {}
    field_information['GGDM 3.0']['VegetationCrv']['EnumeratedIndexValues']['VSP3']['EC015']  = (-999999,8,25,999)
    field_information['GGDM 3.0']['VegetationCrv']['VTI'] = ('Real',('EA020','EC015','EC040'))
    field_information['GGDM 3.0']['VegetationCrv']['WID'] = ('Real',('EA020','EC015','EC040'))
    field_information['GGDM 3.0']['VegetationCrv']['ZI001_SDV'] = ('StructuredText',('EA020','EC015','EC040'))
    field_information['GGDM 3.0']['VegetationCrv']['ZI001_SRT'] = ('Enumeration',('EA020','EC015','EC040'))
    field_information['GGDM 3.0']['VegetationCrv']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['VegetationCrv']['EnumeratedIndexValues']['ZI001_SRT']['EA020']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['VegetationCrv']['EnumeratedIndexValues']['ZI001_SRT']['EC015']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['VegetationCrv']['EnumeratedIndexValues']['ZI001_SRT']['EC040']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['VegetationCrv']['ZI002_UFI'] = ('StructuredText',('EA020','EC015','EC040'))
    field_information['GGDM 3.0']['VegetationCrv']['ZI004_RCG'] = ('Enumeration',('EA020','EC015','EC040'))
    field_information['GGDM 3.0']['VegetationCrv']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['VegetationCrv']['EnumeratedIndexValues']['ZI004_RCG']['EA020']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['VegetationCrv']['EnumeratedIndexValues']['ZI004_RCG']['EC015']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['VegetationCrv']['EnumeratedIndexValues']['ZI004_RCG']['EC040']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['VegetationCrv']['ZI005_FNA'] = ('String',('EC015','EC040'))
    field_information['GGDM 3.0']['VegetationCrv']['ZI005_GNT'] = ('Enumeration',('EC015','EC040'))
    field_information['GGDM 3.0']['VegetationCrv']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['VegetationCrv']['EnumeratedIndexValues']['ZI005_GNT']['EC015']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['VegetationCrv']['EnumeratedIndexValues']['ZI005_GNT']['EC040']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['VegetationCrv']['ZI005_NFN'] = ('String',('EC015','EC040'))
    field_information['GGDM 3.0']['VegetationCrv']['ZI006_MEM'] = ('String',('EA020','EC015','EC040'))
    field_information['GGDM 3.0']['VegetationCrv']['ZI020_GE4'] = ('CodeList',('EA020','EC015','EC040'))
    field_information['GGDM 3.0']['VegetationCrv']['ZI026_CTUC'] = ('Enumeration',('EA020','EC015','EC040'))
    field_information['GGDM 3.0']['VegetationCrv']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['VegetationCrv']['EnumeratedIndexValues']['ZI026_CTUC']['EA020']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['VegetationCrv']['EnumeratedIndexValues']['ZI026_CTUC']['EC015']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['VegetationCrv']['EnumeratedIndexValues']['ZI026_CTUC']['EC040']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['VegetationCrv']['ZI026_CTUL'] = ('integer',('EA020','EC015','EC040'))
    field_information['GGDM 3.0']['VegetationCrv']['ZI026_CTUU'] = ('integer',('EA020','EC015','EC040'))
    field_information['GGDM 3.0']['VegetationCrv']['ZI031S_URI'] = ('StructuredText',('EA020','EC015','EC040'))
    field_information['GGDM 3.0']['VegetationCrv']['ZI039S_UFI'] = ('StructuredText',('EA020','EC015','EC040'))
    field_information['GGDM 3.0']['VegetationCrv']['ZSAX_RS0'] = ('CodeList',('EA020','EC015','EC040'))
    field_information['GGDM 3.0']['VegetationCrv']['ZSAX_RX0'] = ('StructuredText',('EA020','EC015','EC040'))
    field_information['GGDM 3.0']['VegetationCrv']['ZSAX_RX3'] = ('StructuredText',('EA020','EC015','EC040'))
    field_information['GGDM 3.0']['VegetationCrv']['ZSAX_RX4'] = ('StructuredText',('EA020','EC015','EC040'))
    field_information['GGDM 3.0']['VegetationCrv']['ZVH'] = ('Real',('EC015'))
    field_information['GGDM 3.0']['VegetationPnt']['BEN'] = ('StructuredText',('EC005'))
    field_information['GGDM 3.0']['VegetationPnt']['F_CODE'] = ('CONSTRAINED_STRING',('EC005'))
    field_information['GGDM 3.0']['VegetationPnt']['FUFI'] = ('StructuredText',('EC005'))
    field_information['GGDM 3.0']['VegetationPnt']['FURL'] = ('StructuredText',('EC005'))
    field_information['GGDM 3.0']['VegetationPnt']['GDBV'] = ('Enumeration',('EC005'))
    field_information['GGDM 3.0']['VegetationPnt']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['VegetationPnt']['EnumeratedIndexValues']['GDBV']['EC005']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['GGDM 3.0']['VegetationPnt']['HGT'] = ('Real',('EC005'))
    field_information['GGDM 3.0']['VegetationPnt']['LMC'] = ('Boolean',('EC005'))
    field_information['GGDM 3.0']['VegetationPnt']['OTH'] = ('StructuredText',('EC005'))
    field_information['GGDM 3.0']['VegetationPnt']['SDSC'] = ('Enumeration',('EC005'))
    field_information['GGDM 3.0']['VegetationPnt']['EnumeratedIndexValues']['SDSC'] = {}
    field_information['GGDM 3.0']['VegetationPnt']['EnumeratedIndexValues']['SDSC']['EC005']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['VegetationPnt']['SDSL'] = ('real',('EC005'))
    field_information['GGDM 3.0']['VegetationPnt']['SDSU'] = ('real',('EC005'))
    field_information['GGDM 3.0']['VegetationPnt']['TRE'] = ('Enumeration',('EC005'))
    field_information['GGDM 3.0']['VegetationPnt']['EnumeratedIndexValues']['TRE'] = {}
    field_information['GGDM 3.0']['VegetationPnt']['EnumeratedIndexValues']['TRE']['EC005']  = (-999999,1,2,999)
    field_information['GGDM 3.0']['VegetationPnt']['UFI'] = ('StructuredText',('EC005'))
    field_information['GGDM 3.0']['VegetationPnt']['VSP'] = ('Enumeration',('EC005'))
    field_information['GGDM 3.0']['VegetationPnt']['EnumeratedIndexValues']['VSP'] = {}
    field_information['GGDM 3.0']['VegetationPnt']['EnumeratedIndexValues']['VSP']['EC005']  = (-999999,8,19,22,25,999)
    field_information['GGDM 3.0']['VegetationPnt']['ZI001_SDV'] = ('StructuredText',('EC005'))
    field_information['GGDM 3.0']['VegetationPnt']['ZI001_SRT'] = ('Enumeration',('EC005'))
    field_information['GGDM 3.0']['VegetationPnt']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['VegetationPnt']['EnumeratedIndexValues']['ZI001_SRT']['EC005']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['VegetationPnt']['ZI002_UFI'] = ('StructuredText',('EC005'))
    field_information['GGDM 3.0']['VegetationPnt']['ZI004_RCG'] = ('Enumeration',('EC005'))
    field_information['GGDM 3.0']['VegetationPnt']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['VegetationPnt']['EnumeratedIndexValues']['ZI004_RCG']['EC005']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['VegetationPnt']['ZI005_FNA'] = ('String',('EC005'))
    field_information['GGDM 3.0']['VegetationPnt']['ZI005_GNT'] = ('Enumeration',('EC005'))
    field_information['GGDM 3.0']['VegetationPnt']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['VegetationPnt']['EnumeratedIndexValues']['ZI005_GNT']['EC005']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['VegetationPnt']['ZI005_NFN'] = ('String',('EC005'))
    field_information['GGDM 3.0']['VegetationPnt']['ZI006_MEM'] = ('String',('EC005'))
    field_information['GGDM 3.0']['VegetationPnt']['ZI020_GE4'] = ('CodeList',('EC005'))
    field_information['GGDM 3.0']['VegetationPnt']['ZI026_CTUC'] = ('Enumeration',('EC005'))
    field_information['GGDM 3.0']['VegetationPnt']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['VegetationPnt']['EnumeratedIndexValues']['ZI026_CTUC']['EC005']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['VegetationPnt']['ZI026_CTUL'] = ('integer',('EC005'))
    field_information['GGDM 3.0']['VegetationPnt']['ZI026_CTUU'] = ('integer',('EC005'))
    field_information['GGDM 3.0']['VegetationPnt']['ZI031S_URI'] = ('StructuredText',('EC005'))
    field_information['GGDM 3.0']['VegetationPnt']['ZI039S_UFI'] = ('StructuredText',('EC005'))
    field_information['GGDM 3.0']['VegetationPnt']['ZSAX_RS0'] = ('CodeList',('EC005'))
    field_information['GGDM 3.0']['VegetationPnt']['ZSAX_RX0'] = ('StructuredText',('EC005'))
    field_information['GGDM 3.0']['VegetationPnt']['ZSAX_RX3'] = ('StructuredText',('EC005'))
    field_information['GGDM 3.0']['VegetationPnt']['ZSAX_RX4'] = ('StructuredText',('EC005'))
    field_information['GGDM 3.0']['VegetationPnt']['ZVH'] = ('Real',('EC005'))
    field_information['GGDM 3.0']['VegetationPntExt']['ARA'] = ('Real',('EC050'))
    field_information['GGDM 3.0']['VegetationPntExt']['BEN'] = ('StructuredText',('EC050'))
    field_information['GGDM 3.0']['VegetationPntExt']['COA'] = ('Enumeration',('EC050'))
    field_information['GGDM 3.0']['VegetationPntExt']['EnumeratedIndexValues']['COA'] = {}
    field_information['GGDM 3.0']['VegetationPntExt']['EnumeratedIndexValues']['COA']['EC050']  = (-999999,2,4)
    field_information['GGDM 3.0']['VegetationPntExt']['COC'] = ('Enumeration',('EC050'))
    field_information['GGDM 3.0']['VegetationPntExt']['EnumeratedIndexValues']['COC'] = {}
    field_information['GGDM 3.0']['VegetationPntExt']['EnumeratedIndexValues']['COC']['EC050']  = (-999999,1,2,3,4)
    field_information['GGDM 3.0']['VegetationPntExt']['COG'] = ('Enumeration',('EC050'))
    field_information['GGDM 3.0']['VegetationPntExt']['EnumeratedIndexValues']['COG'] = {}
    field_information['GGDM 3.0']['VegetationPntExt']['EnumeratedIndexValues']['COG']['EC050']  = (-999999,2,4)
    field_information['GGDM 3.0']['VegetationPntExt']['DMBC'] = ('Enumeration',('EC050'))
    field_information['GGDM 3.0']['VegetationPntExt']['EnumeratedIndexValues']['DMBC'] = {}
    field_information['GGDM 3.0']['VegetationPntExt']['EnumeratedIndexValues']['DMBC']['EC050']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['VegetationPntExt']['DMBL'] = ('real',('EC050'))
    field_information['GGDM 3.0']['VegetationPntExt']['DMBU'] = ('real',('EC050'))
    field_information['GGDM 3.0']['VegetationPntExt']['DMT'] = ('Real',('EC050'))
    field_information['GGDM 3.0']['VegetationPntExt']['F_CODE'] = ('CONSTRAINED_STRING',('EC050'))
    field_information['GGDM 3.0']['VegetationPntExt']['FEO'] = ('Real',('EC050'))
    field_information['GGDM 3.0']['VegetationPntExt']['FUFI'] = ('StructuredText',('EC050'))
    field_information['GGDM 3.0']['VegetationPntExt']['FURL'] = ('StructuredText',('EC050'))
    field_information['GGDM 3.0']['VegetationPntExt']['GDBV'] = ('Enumeration',('EC050'))
    field_information['GGDM 3.0']['VegetationPntExt']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['VegetationPntExt']['EnumeratedIndexValues']['GDBV']['EC050']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['VegetationPntExt']['HGT'] = ('Real',('EC050'))
    field_information['GGDM 3.0']['VegetationPntExt']['LMC'] = ('Boolean',('EC050'))
    field_information['GGDM 3.0']['VegetationPntExt']['LZN'] = ('Real',('EC050'))
    field_information['GGDM 3.0']['VegetationPntExt']['OTH'] = ('StructuredText',('EC050'))
    field_information['GGDM 3.0']['VegetationPntExt']['PVH'] = ('Real',('EC050'))
    field_information['GGDM 3.0']['VegetationPntExt']['SBC'] = ('Boolean',('EC050'))
    field_information['GGDM 3.0']['VegetationPntExt']['SDSC'] = ('Enumeration',('EC050'))
    field_information['GGDM 3.0']['VegetationPntExt']['EnumeratedIndexValues']['SDSC'] = {}
    field_information['GGDM 3.0']['VegetationPntExt']['EnumeratedIndexValues']['SDSC']['EC050']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['VegetationPntExt']['SDSL'] = ('real',('EC050'))
    field_information['GGDM 3.0']['VegetationPntExt']['SDSU'] = ('real',('EC050'))
    field_information['GGDM 3.0']['VegetationPntExt']['STR'] = ('Real',('EC050'))
    field_information['GGDM 3.0']['VegetationPntExt']['TRE'] = ('Enumeration',('EC050'))
    field_information['GGDM 3.0']['VegetationPntExt']['EnumeratedIndexValues']['TRE'] = {}
    field_information['GGDM 3.0']['VegetationPntExt']['EnumeratedIndexValues']['TRE']['EC050']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['VegetationPntExt']['TSCC'] = ('Enumeration',('EC050'))
    field_information['GGDM 3.0']['VegetationPntExt']['EnumeratedIndexValues']['TSCC'] = {}
    field_information['GGDM 3.0']['VegetationPntExt']['EnumeratedIndexValues']['TSCC']['EC050']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['VegetationPntExt']['TSCL'] = ('real',('EC050'))
    field_information['GGDM 3.0']['VegetationPntExt']['TSCU'] = ('real',('EC050'))
    field_information['GGDM 3.0']['VegetationPntExt']['UFI'] = ('StructuredText',('EC050'))
    field_information['GGDM 3.0']['VegetationPntExt']['VSP'] = ('Enumeration',('EC050'))
    field_information['GGDM 3.0']['VegetationPntExt']['EnumeratedIndexValues']['VSP'] = {}
    field_information['GGDM 3.0']['VegetationPntExt']['EnumeratedIndexValues']['VSP']['EC050']  = (-999999,8,19,22,25,999)
    field_information['GGDM 3.0']['VegetationPntExt']['VSP2'] = ('Enumeration',('EC050'))
    field_information['GGDM 3.0']['VegetationPntExt']['EnumeratedIndexValues']['VSP2'] = {}
    field_information['GGDM 3.0']['VegetationPntExt']['EnumeratedIndexValues']['VSP2']['EC050']  = (-999999,8,19,22,25,999)
    field_information['GGDM 3.0']['VegetationPntExt']['VSP3'] = ('Enumeration',('EC050'))
    field_information['GGDM 3.0']['VegetationPntExt']['EnumeratedIndexValues']['VSP3'] = {}
    field_information['GGDM 3.0']['VegetationPntExt']['EnumeratedIndexValues']['VSP3']['EC050']  = (-999999,8,19,22,25,999)
    field_information['GGDM 3.0']['VegetationPntExt']['VTI'] = ('Real',('EC050'))
    field_information['GGDM 3.0']['VegetationPntExt']['WCL'] = ('Real',('EC050'))
    field_information['GGDM 3.0']['VegetationPntExt']['WID'] = ('Real',('EC050'))
    field_information['GGDM 3.0']['VegetationPntExt']['ZI001_SDV'] = ('StructuredText',('EC050'))
    field_information['GGDM 3.0']['VegetationPntExt']['ZI001_SRT'] = ('Enumeration',('EC050'))
    field_information['GGDM 3.0']['VegetationPntExt']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['VegetationPntExt']['EnumeratedIndexValues']['ZI001_SRT']['EC050']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['VegetationPntExt']['ZI002_UFI'] = ('StructuredText',('EC050'))
    field_information['GGDM 3.0']['VegetationPntExt']['ZI004_RCG'] = ('Enumeration',('EC050'))
    field_information['GGDM 3.0']['VegetationPntExt']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['VegetationPntExt']['EnumeratedIndexValues']['ZI004_RCG']['EC050']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['VegetationPntExt']['ZI005_FNA'] = ('String',('EC050'))
    field_information['GGDM 3.0']['VegetationPntExt']['ZI005_GNT'] = ('Enumeration',('EC050'))
    field_information['GGDM 3.0']['VegetationPntExt']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['VegetationPntExt']['EnumeratedIndexValues']['ZI005_GNT']['EC050']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['VegetationPntExt']['ZI005_NFN'] = ('String',('EC050'))
    field_information['GGDM 3.0']['VegetationPntExt']['ZI006_MEM'] = ('String',('EC050'))
    field_information['GGDM 3.0']['VegetationPntExt']['ZI020_GE4'] = ('CodeList',('EC050'))
    field_information['GGDM 3.0']['VegetationPntExt']['ZI026_CTUC'] = ('Enumeration',('EC050'))
    field_information['GGDM 3.0']['VegetationPntExt']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['VegetationPntExt']['EnumeratedIndexValues']['ZI026_CTUC']['EC050']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['VegetationPntExt']['ZI026_CTUL'] = ('integer',('EC050'))
    field_information['GGDM 3.0']['VegetationPntExt']['ZI026_CTUU'] = ('integer',('EC050'))
    field_information['GGDM 3.0']['VegetationPntExt']['ZI031S_URI'] = ('StructuredText',('EC050'))
    field_information['GGDM 3.0']['VegetationPntExt']['ZI039S_UFI'] = ('StructuredText',('EC050'))
    field_information['GGDM 3.0']['VegetationPntExt']['ZSAX_RS0'] = ('CodeList',('EC050'))
    field_information['GGDM 3.0']['VegetationPntExt']['ZSAX_RX0'] = ('StructuredText',('EC050'))
    field_information['GGDM 3.0']['VegetationPntExt']['ZSAX_RX3'] = ('StructuredText',('EC050'))
    field_information['GGDM 3.0']['VegetationPntExt']['ZSAX_RX4'] = ('StructuredText',('EC050'))
    field_information['GGDM 3.0']['VegetationPntExt']['ZVH'] = ('Real',('EC050'))
    field_information['GGDM 3.0']['VegetationSrf']['AOO'] = ('Real',('EB070','EC015'))
    field_information['GGDM 3.0']['VegetationSrf']['ARA'] = ('Real',('BH015','BH077','BJ110','EB010','EB020','EB070','EC015','EC040','EC060','ED010','ED020','EE010'))
    field_information['GGDM 3.0']['VegetationSrf']['BEN'] = ('StructuredText',('BH015','BH077','BJ110','EB010','EB020','EB070','EC015','EC040','EC060','ED010','ED020','EE010'))
    field_information['GGDM 3.0']['VegetationSrf']['BMC'] = ('Enumeration',('BH015','ED010','ED020'))
    field_information['GGDM 3.0']['VegetationSrf']['EnumeratedIndexValues']['BMC'] = {}
    field_information['GGDM 3.0']['VegetationSrf']['EnumeratedIndexValues']['BMC']['BH015']  = (-999999,1,2,3,4,5,6,8,9,14,18,999)
    field_information['GGDM 3.0']['VegetationSrf']['EnumeratedIndexValues']['BMC']['ED010']  = (-999999,1,2,3,4,5,6,8,9,14,18,999)
    field_information['GGDM 3.0']['VegetationSrf']['EnumeratedIndexValues']['BMC']['ED020']  = (-999999,1,2,3,4,5,6,8,9,14,18,999)
    field_information['GGDM 3.0']['VegetationSrf']['BMC2'] = ('Enumeration',('BH015','ED010','ED020'))
    field_information['GGDM 3.0']['VegetationSrf']['EnumeratedIndexValues']['BMC2'] = {}
    field_information['GGDM 3.0']['VegetationSrf']['EnumeratedIndexValues']['BMC2']['BH015']  = (-999999,1,2,3,4,5,6,8,9,14,18,999)
    field_information['GGDM 3.0']['VegetationSrf']['EnumeratedIndexValues']['BMC2']['ED010']  = (-999999,1,2,3,4,5,6,8,9,14,18,999)
    field_information['GGDM 3.0']['VegetationSrf']['EnumeratedIndexValues']['BMC2']['ED020']  = (-999999,1,2,3,4,5,6,8,9,14,18,999)
    field_information['GGDM 3.0']['VegetationSrf']['BMC3'] = ('Enumeration',('BH015','ED010','ED020'))
    field_information['GGDM 3.0']['VegetationSrf']['EnumeratedIndexValues']['BMC3'] = {}
    field_information['GGDM 3.0']['VegetationSrf']['EnumeratedIndexValues']['BMC3']['BH015']  = (-999999,1,2,3,4,5,6,8,9,14,18,999)
    field_information['GGDM 3.0']['VegetationSrf']['EnumeratedIndexValues']['BMC3']['ED010']  = (-999999,1,2,3,4,5,6,8,9,14,18,999)
    field_information['GGDM 3.0']['VegetationSrf']['EnumeratedIndexValues']['BMC3']['ED020']  = (-999999,1,2,3,4,5,6,8,9,14,18,999)
    field_information['GGDM 3.0']['VegetationSrf']['BOC'] = ('Enumeration',('BH015'))
    field_information['GGDM 3.0']['VegetationSrf']['EnumeratedIndexValues']['BOC'] = {}
    field_information['GGDM 3.0']['VegetationSrf']['EnumeratedIndexValues']['BOC']['BH015']  = (-999999,1,2,3,4,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,999)
    field_information['GGDM 3.0']['VegetationSrf']['CAA'] = ('Enumeration',('BH015','ED010','ED020'))
    field_information['GGDM 3.0']['VegetationSrf']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['VegetationSrf']['EnumeratedIndexValues']['CAA']['BH015']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['VegetationSrf']['EnumeratedIndexValues']['CAA']['ED010']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['VegetationSrf']['EnumeratedIndexValues']['CAA']['ED020']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['VegetationSrf']['DMBC'] = ('Enumeration',('EB020','EC015','ED010','ED020'))
    field_information['GGDM 3.0']['VegetationSrf']['EnumeratedIndexValues']['DMBC'] = {}
    field_information['GGDM 3.0']['VegetationSrf']['EnumeratedIndexValues']['DMBC']['EB020']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['VegetationSrf']['EnumeratedIndexValues']['DMBC']['EC015']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['VegetationSrf']['EnumeratedIndexValues']['DMBC']['ED010']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['VegetationSrf']['EnumeratedIndexValues']['DMBC']['ED020']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['VegetationSrf']['DMBL'] = ('real',('EB020','EC015','ED010','ED020'))
    field_information['GGDM 3.0']['VegetationSrf']['DMBU'] = ('real',('EB020','EC015','ED010','ED020'))
    field_information['GGDM 3.0']['VegetationSrf']['DMT'] = ('Real',('EC015','ED020'))
    field_information['GGDM 3.0']['VegetationSrf']['DZP'] = ('Real',('BH015','ED010','ED020'))
    field_information['GGDM 3.0']['VegetationSrf']['F_CODE'] = ('CONSTRAINED_STRING',('BH015','BH077','BJ110','EB010','EB020','EB070','EC015','EC040','EC060','ED010','ED020','EE010'))
    field_information['GGDM 3.0']['VegetationSrf']['FFN'] = ('Enumeration',('EB010'))
    field_information['GGDM 3.0']['VegetationSrf']['EnumeratedIndexValues']['FFN'] = {}
    field_information['GGDM 3.0']['VegetationSrf']['EnumeratedIndexValues']['FFN']['EB010']  = (-999999,14,907,921,999)
    field_information['GGDM 3.0']['VegetationSrf']['FFN2'] = ('Enumeration',('EB010'))
    field_information['GGDM 3.0']['VegetationSrf']['EnumeratedIndexValues']['FFN2'] = {}
    field_information['GGDM 3.0']['VegetationSrf']['EnumeratedIndexValues']['FFN2']['EB010']  = (-999999,14,907,921,999)
    field_information['GGDM 3.0']['VegetationSrf']['FFN3'] = ('Enumeration',('EB010'))
    field_information['GGDM 3.0']['VegetationSrf']['EnumeratedIndexValues']['FFN3'] = {}
    field_information['GGDM 3.0']['VegetationSrf']['EnumeratedIndexValues']['FFN3']['EB010']  = (-999999,14,907,921,999)
    field_information['GGDM 3.0']['VegetationSrf']['FUFI'] = ('StructuredText',('BH015','BH077','BJ110','EB010','EB020','EB070','EC015','EC040','EC060','ED010','ED020','EE010'))
    field_information['GGDM 3.0']['VegetationSrf']['FURL'] = ('StructuredText',('BH015','BH077','BJ110','EB010','EB020','EB070','EC015','EC040','EC060','ED010','ED020','EE010'))
    field_information['GGDM 3.0']['VegetationSrf']['GDBV'] = ('Enumeration',('BH015','BH077','BJ110','EB010','EB020','EB070','EC015','EC040','EC060','ED010','ED020','EE010'))
    field_information['GGDM 3.0']['VegetationSrf']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['VegetationSrf']['EnumeratedIndexValues']['GDBV']['BH015']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['VegetationSrf']['EnumeratedIndexValues']['GDBV']['BH077']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['VegetationSrf']['EnumeratedIndexValues']['GDBV']['BJ110']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['VegetationSrf']['EnumeratedIndexValues']['GDBV']['EB010']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['VegetationSrf']['EnumeratedIndexValues']['GDBV']['EB020']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['VegetationSrf']['EnumeratedIndexValues']['GDBV']['EB070']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['VegetationSrf']['EnumeratedIndexValues']['GDBV']['EC015']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['VegetationSrf']['EnumeratedIndexValues']['GDBV']['EC040']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['VegetationSrf']['EnumeratedIndexValues']['GDBV']['EC060']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['VegetationSrf']['EnumeratedIndexValues']['GDBV']['ED010']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['VegetationSrf']['EnumeratedIndexValues']['GDBV']['ED020']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['VegetationSrf']['EnumeratedIndexValues']['GDBV']['EE010']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['VegetationSrf']['HDP'] = ('Real',('ED020'))
    field_information['GGDM 3.0']['VegetationSrf']['HGT'] = ('Real',('EB020','EB070','EC015','ED020'))
    field_information['GGDM 3.0']['VegetationSrf']['LMC'] = ('Boolean',('EB070','EC015'))
    field_information['GGDM 3.0']['VegetationSrf']['LZN'] = ('Real',('BH015','BH077','BJ110','EB010','EB020','EB070','EC015','EC040','EC060','ED010','ED020','EE010'))
    field_information['GGDM 3.0']['VegetationSrf']['OTH'] = ('StructuredText',('BH015','BH077','BJ110','EB010','EB020','EB070','EC015','EC040','EC060','ED010','ED020','EE010'))
    field_information['GGDM 3.0']['VegetationSrf']['PVH'] = ('Real',('EB020','EB070','EC015','ED020'))
    field_information['GGDM 3.0']['VegetationSrf']['SBC'] = ('Boolean',('EC015'))
    field_information['GGDM 3.0']['VegetationSrf']['SDSC'] = ('Enumeration',('EC015','ED020'))
    field_information['GGDM 3.0']['VegetationSrf']['EnumeratedIndexValues']['SDSC'] = {}
    field_information['GGDM 3.0']['VegetationSrf']['EnumeratedIndexValues']['SDSC']['EC015']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['VegetationSrf']['EnumeratedIndexValues']['SDSC']['ED020']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['VegetationSrf']['SDSL'] = ('real',('EC015','ED020'))
    field_information['GGDM 3.0']['VegetationSrf']['SDSU'] = ('real',('EC015','ED020'))
    field_information['GGDM 3.0']['VegetationSrf']['SNDC'] = ('Enumeration',('BJ110'))
    field_information['GGDM 3.0']['VegetationSrf']['EnumeratedIndexValues']['SNDC'] = {}
    field_information['GGDM 3.0']['VegetationSrf']['EnumeratedIndexValues']['SNDC']['BJ110']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['VegetationSrf']['SNDL'] = ('real',('BJ110'))
    field_information['GGDM 3.0']['VegetationSrf']['SNDU'] = ('real',('BJ110'))
    field_information['GGDM 3.0']['VegetationSrf']['TID'] = ('Boolean',('ED010','ED020'))
    field_information['GGDM 3.0']['VegetationSrf']['TRE'] = ('Enumeration',('EB070','EC015','ED020'))
    field_information['GGDM 3.0']['VegetationSrf']['EnumeratedIndexValues']['TRE'] = {}
    field_information['GGDM 3.0']['VegetationSrf']['EnumeratedIndexValues']['TRE']['EB070']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['VegetationSrf']['EnumeratedIndexValues']['TRE']['EC015']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['VegetationSrf']['EnumeratedIndexValues']['TRE']['ED020']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['VegetationSrf']['TSCC'] = ('Enumeration',('EC015','ED020'))
    field_information['GGDM 3.0']['VegetationSrf']['EnumeratedIndexValues']['TSCC'] = {}
    field_information['GGDM 3.0']['VegetationSrf']['EnumeratedIndexValues']['TSCC']['EC015']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['VegetationSrf']['EnumeratedIndexValues']['TSCC']['ED020']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['VegetationSrf']['TSCL'] = ('real',('EC015','ED020'))
    field_information['GGDM 3.0']['VegetationSrf']['TSCU'] = ('real',('EC015','ED020'))
    field_information['GGDM 3.0']['VegetationSrf']['TWS'] = ('Boolean',('EB010','EC060'))
    field_information['GGDM 3.0']['VegetationSrf']['UFI'] = ('StructuredText',('BH015','BH077','BJ110','EB010','EB020','EB070','EC015','EC040','EC060','ED010','ED020','EE010'))
    field_information['GGDM 3.0']['VegetationSrf']['VEG'] = ('Enumeration',('EB010'))
    field_information['GGDM 3.0']['VegetationSrf']['EnumeratedIndexValues']['VEG'] = {}
    field_information['GGDM 3.0']['VegetationSrf']['EnumeratedIndexValues']['VEG']['EB010']  = (-999999,8,10,999)
    field_information['GGDM 3.0']['VegetationSrf']['VSP'] = ('Enumeration',('EC015','ED020'))
    field_information['GGDM 3.0']['VegetationSrf']['EnumeratedIndexValues']['VSP'] = {}
    field_information['GGDM 3.0']['VegetationSrf']['EnumeratedIndexValues']['VSP']['EC015']  = (-999999,8,25,999)
    field_information['GGDM 3.0']['VegetationSrf']['EnumeratedIndexValues']['VSP']['ED020']  = (-999999,19,22,64,999)
    field_information['GGDM 3.0']['VegetationSrf']['VSP2'] = ('Enumeration',('EC015','ED020'))
    field_information['GGDM 3.0']['VegetationSrf']['EnumeratedIndexValues']['VSP2'] = {}
    field_information['GGDM 3.0']['VegetationSrf']['EnumeratedIndexValues']['VSP2']['EC015']  = (-999999,8,25,999)
    field_information['GGDM 3.0']['VegetationSrf']['EnumeratedIndexValues']['VSP2']['ED020']  = (-999999,19,22,64,999)
    field_information['GGDM 3.0']['VegetationSrf']['VSP3'] = ('Enumeration',('EC015','ED020'))
    field_information['GGDM 3.0']['VegetationSrf']['EnumeratedIndexValues']['VSP3'] = {}
    field_information['GGDM 3.0']['VegetationSrf']['EnumeratedIndexValues']['VSP3']['EC015']  = (-999999,8,25,999)
    field_information['GGDM 3.0']['VegetationSrf']['EnumeratedIndexValues']['VSP3']['ED020']  = (-999999,19,22,64,999)
    field_information['GGDM 3.0']['VegetationSrf']['VTI'] = ('Real',('BH015','BH077','BJ110','EB010','EB020','EC015','EC040','EE010'))
    field_information['GGDM 3.0']['VegetationSrf']['WDAC'] = ('Enumeration',('ED010','ED020'))
    field_information['GGDM 3.0']['VegetationSrf']['EnumeratedIndexValues']['WDAC'] = {}
    field_information['GGDM 3.0']['VegetationSrf']['EnumeratedIndexValues']['WDAC']['ED010']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['VegetationSrf']['EnumeratedIndexValues']['WDAC']['ED020']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['VegetationSrf']['WDAL'] = ('real',('ED010','ED020'))
    field_information['GGDM 3.0']['VegetationSrf']['WDAU'] = ('real',('ED010','ED020'))
    field_information['GGDM 3.0']['VegetationSrf']['WID'] = ('Real',('BH015','BH077','BJ110','EB010','EB020','EB070','EC015','EC040','EC060','ED010','ED020','EE010'))
    field_information['GGDM 3.0']['VegetationSrf']['ZI001_SDV'] = ('StructuredText',('BH015','BH077','BJ110','EB010','EB020','EB070','EC015','EC040','EC060','ED010','ED020','EE010'))
    field_information['GGDM 3.0']['VegetationSrf']['ZI001_SRT'] = ('Enumeration',('BH015','BH077','BJ110','EB010','EB020','EB070','EC015','EC040','EC060','ED010','ED020','EE010'))
    field_information['GGDM 3.0']['VegetationSrf']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['VegetationSrf']['EnumeratedIndexValues']['ZI001_SRT']['BH015']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['VegetationSrf']['EnumeratedIndexValues']['ZI001_SRT']['BH077']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['VegetationSrf']['EnumeratedIndexValues']['ZI001_SRT']['BJ110']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['VegetationSrf']['EnumeratedIndexValues']['ZI001_SRT']['EB010']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['VegetationSrf']['EnumeratedIndexValues']['ZI001_SRT']['EB020']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['VegetationSrf']['EnumeratedIndexValues']['ZI001_SRT']['EB070']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['VegetationSrf']['EnumeratedIndexValues']['ZI001_SRT']['EC015']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['VegetationSrf']['EnumeratedIndexValues']['ZI001_SRT']['EC040']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['VegetationSrf']['EnumeratedIndexValues']['ZI001_SRT']['EC060']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['VegetationSrf']['EnumeratedIndexValues']['ZI001_SRT']['ED010']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['VegetationSrf']['EnumeratedIndexValues']['ZI001_SRT']['ED020']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['VegetationSrf']['EnumeratedIndexValues']['ZI001_SRT']['EE010']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['VegetationSrf']['ZI002_UFI'] = ('StructuredText',('BH015','BH077','BJ110','EB010','EB020','EB070','EC015','EC040','EC060','ED010','ED020','EE010'))
    field_information['GGDM 3.0']['VegetationSrf']['ZI004_RCG'] = ('Enumeration',('BH015','BH077','BJ110','EB010','EB020','EB070','EC015','EC040','EC060','ED010','ED020','EE010'))
    field_information['GGDM 3.0']['VegetationSrf']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['VegetationSrf']['EnumeratedIndexValues']['ZI004_RCG']['BH015']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['VegetationSrf']['EnumeratedIndexValues']['ZI004_RCG']['BH077']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['VegetationSrf']['EnumeratedIndexValues']['ZI004_RCG']['BJ110']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['VegetationSrf']['EnumeratedIndexValues']['ZI004_RCG']['EB010']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['VegetationSrf']['EnumeratedIndexValues']['ZI004_RCG']['EB020']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['VegetationSrf']['EnumeratedIndexValues']['ZI004_RCG']['EB070']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['VegetationSrf']['EnumeratedIndexValues']['ZI004_RCG']['EC015']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['VegetationSrf']['EnumeratedIndexValues']['ZI004_RCG']['EC040']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['VegetationSrf']['EnumeratedIndexValues']['ZI004_RCG']['EC060']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['VegetationSrf']['EnumeratedIndexValues']['ZI004_RCG']['ED010']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['VegetationSrf']['EnumeratedIndexValues']['ZI004_RCG']['ED020']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['VegetationSrf']['EnumeratedIndexValues']['ZI004_RCG']['EE010']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['VegetationSrf']['ZI005_FNA'] = ('String',('BH015','BJ110','EB010','EB020','EC015','EC040','EC060','ED010','ED020','EE010'))
    field_information['GGDM 3.0']['VegetationSrf']['ZI005_GNT'] = ('Enumeration',('BH015','BJ110','EB010','EB020','EC015','EC040','EC060','ED010','ED020','EE010'))
    field_information['GGDM 3.0']['VegetationSrf']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['VegetationSrf']['EnumeratedIndexValues']['ZI005_GNT']['BH015']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['VegetationSrf']['EnumeratedIndexValues']['ZI005_GNT']['BJ110']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['VegetationSrf']['EnumeratedIndexValues']['ZI005_GNT']['EB010']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['VegetationSrf']['EnumeratedIndexValues']['ZI005_GNT']['EB020']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['VegetationSrf']['EnumeratedIndexValues']['ZI005_GNT']['EC015']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['VegetationSrf']['EnumeratedIndexValues']['ZI005_GNT']['EC040']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['VegetationSrf']['EnumeratedIndexValues']['ZI005_GNT']['EC060']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['VegetationSrf']['EnumeratedIndexValues']['ZI005_GNT']['ED010']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['VegetationSrf']['EnumeratedIndexValues']['ZI005_GNT']['ED020']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['VegetationSrf']['EnumeratedIndexValues']['ZI005_GNT']['EE010']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['VegetationSrf']['ZI005_NFN'] = ('String',('BH015','BJ110','EB010','EB020','EC015','EC040','EC060','ED010','ED020','EE010'))
    field_information['GGDM 3.0']['VegetationSrf']['ZI006_MEM'] = ('String',('BH015','BH077','BJ110','EB010','EB020','EB070','EC015','EC040','EC060','ED010','ED020','EE010'))
    field_information['GGDM 3.0']['VegetationSrf']['ZI020_GE4'] = ('CodeList',('BH015','BH077','BJ110','EB010','EB020','EB070','EC015','EC040','EC060','ED010','ED020','EE010'))
    field_information['GGDM 3.0']['VegetationSrf']['ZI024_ASE'] = ('Real',('BH015','ED010','ED020'))
    field_information['GGDM 3.0']['VegetationSrf']['ZI024_CFR'] = ('Real',('BH015','ED010','ED020'))
    field_information['GGDM 3.0']['VegetationSrf']['ZI024_CLO'] = ('Real',('BH015','ED010','ED020'))
    field_information['GGDM 3.0']['VegetationSrf']['ZI024_CYN'] = ('Real',('BH015','ED010','ED020'))
    field_information['GGDM 3.0']['VegetationSrf']['ZI024_FMR'] = ('Real',('BH015','ED010','ED020'))
    field_information['GGDM 3.0']['VegetationSrf']['ZI024_FRR'] = ('Real',('BH015','ED010','ED020'))
    field_information['GGDM 3.0']['VegetationSrf']['ZI024_HAR'] = ('Real',('BH015','ED010','ED020'))
    field_information['GGDM 3.0']['VegetationSrf']['ZI024_HYP'] = ('Enumeration',('ED010','ED020'))
    field_information['GGDM 3.0']['VegetationSrf']['EnumeratedIndexValues']['ZI024_HYP'] = {}
    field_information['GGDM 3.0']['VegetationSrf']['EnumeratedIndexValues']['ZI024_HYP']['ED010']  = (-999999,1,2,4)
    field_information['GGDM 3.0']['VegetationSrf']['EnumeratedIndexValues']['ZI024_HYP']['ED020']  = (-999999,1,2,4)
    field_information['GGDM 3.0']['VegetationSrf']['ZI024_MGN'] = ('Real',('BH015','ED010','ED020'))
    field_information['GGDM 3.0']['VegetationSrf']['ZI024_PHW'] = ('Real',('BH015','ED010','ED020'))
    field_information['GGDM 3.0']['VegetationSrf']['ZI024_SCC'] = ('Enumeration',('BH015','ED010','ED020'))
    field_information['GGDM 3.0']['VegetationSrf']['EnumeratedIndexValues']['ZI024_SCC'] = {}
    field_information['GGDM 3.0']['VegetationSrf']['EnumeratedIndexValues']['ZI024_SCC']['BH015']  = (-999999,1,4,10,11,12,13,14,998,999)
    field_information['GGDM 3.0']['VegetationSrf']['EnumeratedIndexValues']['ZI024_SCC']['ED010']  = (-999999,1,4,10,11,12,13,14,998,999)
    field_information['GGDM 3.0']['VegetationSrf']['EnumeratedIndexValues']['ZI024_SCC']['ED020']  = (-999999,1,4,10,11,12,13,14,998,999)
    field_information['GGDM 3.0']['VegetationSrf']['ZI024_SUL'] = ('Real',('BH015','ED010','ED020'))
    field_information['GGDM 3.0']['VegetationSrf']['ZI024_TDS'] = ('Real',('BH015','ED010','ED020'))
    field_information['GGDM 3.0']['VegetationSrf']['ZI024_TEP'] = ('Real',('BH015','ED010','ED020'))
    field_information['GGDM 3.0']['VegetationSrf']['ZI024_TUR'] = ('Real',('BH015','ED010','ED020'))
    field_information['GGDM 3.0']['VegetationSrf']['ZI024_WAC'] = ('Real',('BH015','ED010','ED020'))
    field_information['GGDM 3.0']['VegetationSrf']['ZI024_WTNO'] = ('Real',('BH015','ED010','ED020'))
    field_information['GGDM 3.0']['VegetationSrf']['ZI024_WUR'] = ('Enumeration',('BH015','ED010','ED020'))
    field_information['GGDM 3.0']['VegetationSrf']['EnumeratedIndexValues']['ZI024_WUR'] = {}
    field_information['GGDM 3.0']['VegetationSrf']['EnumeratedIndexValues']['ZI024_WUR']['BH015']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['VegetationSrf']['EnumeratedIndexValues']['ZI024_WUR']['ED010']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['VegetationSrf']['EnumeratedIndexValues']['ZI024_WUR']['ED020']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['VegetationSrf']['ZI024_YWQ'] = ('Enumeration',('BH015','ED010','ED020'))
    field_information['GGDM 3.0']['VegetationSrf']['EnumeratedIndexValues']['ZI024_YWQ'] = {}
    field_information['GGDM 3.0']['VegetationSrf']['EnumeratedIndexValues']['ZI024_YWQ']['BH015']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['VegetationSrf']['EnumeratedIndexValues']['ZI024_YWQ']['ED010']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['VegetationSrf']['EnumeratedIndexValues']['ZI024_YWQ']['ED020']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['VegetationSrf']['ZI026_CTUC'] = ('Enumeration',('BH015','BH077','BJ110','EB010','EB020','EB070','EC015','EC040','EC060','ED010','ED020','EE010'))
    field_information['GGDM 3.0']['VegetationSrf']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['VegetationSrf']['EnumeratedIndexValues']['ZI026_CTUC']['BH015']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['VegetationSrf']['EnumeratedIndexValues']['ZI026_CTUC']['BH077']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['VegetationSrf']['EnumeratedIndexValues']['ZI026_CTUC']['BJ110']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['VegetationSrf']['EnumeratedIndexValues']['ZI026_CTUC']['EB010']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['VegetationSrf']['EnumeratedIndexValues']['ZI026_CTUC']['EB020']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['VegetationSrf']['EnumeratedIndexValues']['ZI026_CTUC']['EB070']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['VegetationSrf']['EnumeratedIndexValues']['ZI026_CTUC']['EC015']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['VegetationSrf']['EnumeratedIndexValues']['ZI026_CTUC']['EC040']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['VegetationSrf']['EnumeratedIndexValues']['ZI026_CTUC']['EC060']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['VegetationSrf']['EnumeratedIndexValues']['ZI026_CTUC']['ED010']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['VegetationSrf']['EnumeratedIndexValues']['ZI026_CTUC']['ED020']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['VegetationSrf']['EnumeratedIndexValues']['ZI026_CTUC']['EE010']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['VegetationSrf']['ZI026_CTUL'] = ('integer',('BH015','BH077','BJ110','EB010','EB020','EB070','EC015','EC040','EC060','ED010','ED020','EE010'))
    field_information['GGDM 3.0']['VegetationSrf']['ZI026_CTUU'] = ('integer',('BH015','BH077','BJ110','EB010','EB020','EB070','EC015','EC040','EC060','ED010','ED020','EE010'))
    field_information['GGDM 3.0']['VegetationSrf']['ZI031S_URI'] = ('StructuredText',('BH015','BH077','BJ110','EB010','EB020','EB070','EC015','EC040','EC060','ED010','ED020','EE010'))
    field_information['GGDM 3.0']['VegetationSrf']['ZI039S_UFI'] = ('StructuredText',('BH015','BH077','BJ110','EB010','EB020','EB070','EC015','EC040','EC060','ED010','ED020','EE010'))
    field_information['GGDM 3.0']['VegetationSrf']['ZSAX_RS0'] = ('CodeList',('BH015','BH077','BJ110','EB010','EB020','EB070','EC015','EC040','EC060','ED010','ED020','EE010'))
    field_information['GGDM 3.0']['VegetationSrf']['ZSAX_RX0'] = ('StructuredText',('BH015','BH077','BJ110','EB010','EB020','EB070','EC015','EC040','EC060','ED010','ED020','EE010'))
    field_information['GGDM 3.0']['VegetationSrf']['ZSAX_RX3'] = ('StructuredText',('BH015','BH077','BJ110','EB010','EB020','EB070','EC015','EC040','EC060','ED010','ED020','EE010'))
    field_information['GGDM 3.0']['VegetationSrf']['ZSAX_RX4'] = ('StructuredText',('BH015','BH077','BJ110','EB010','EB020','EB070','EC015','EC040','EC060','ED010','ED020','EE010'))
    field_information['GGDM 3.0']['VegetationSrf']['ZVH'] = ('Real',('EB070','EC015'))
    field_information['GGDM 3.0']['VegetationSrfExt']['ARA'] = ('Real',('EC050'))
    field_information['GGDM 3.0']['VegetationSrfExt']['BEN'] = ('StructuredText',('EC050'))
    field_information['GGDM 3.0']['VegetationSrfExt']['COA'] = ('Enumeration',('EC050'))
    field_information['GGDM 3.0']['VegetationSrfExt']['EnumeratedIndexValues']['COA'] = {}
    field_information['GGDM 3.0']['VegetationSrfExt']['EnumeratedIndexValues']['COA']['EC050']  = (-999999,2,4)
    field_information['GGDM 3.0']['VegetationSrfExt']['COC'] = ('Enumeration',('EC050'))
    field_information['GGDM 3.0']['VegetationSrfExt']['EnumeratedIndexValues']['COC'] = {}
    field_information['GGDM 3.0']['VegetationSrfExt']['EnumeratedIndexValues']['COC']['EC050']  = (-999999,1,2,3,4)
    field_information['GGDM 3.0']['VegetationSrfExt']['COG'] = ('Enumeration',('EC050'))
    field_information['GGDM 3.0']['VegetationSrfExt']['EnumeratedIndexValues']['COG'] = {}
    field_information['GGDM 3.0']['VegetationSrfExt']['EnumeratedIndexValues']['COG']['EC050']  = (-999999,2,4)
    field_information['GGDM 3.0']['VegetationSrfExt']['DMBC'] = ('Enumeration',('EC050'))
    field_information['GGDM 3.0']['VegetationSrfExt']['EnumeratedIndexValues']['DMBC'] = {}
    field_information['GGDM 3.0']['VegetationSrfExt']['EnumeratedIndexValues']['DMBC']['EC050']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['VegetationSrfExt']['DMBL'] = ('real',('EC050'))
    field_information['GGDM 3.0']['VegetationSrfExt']['DMBU'] = ('real',('EC050'))
    field_information['GGDM 3.0']['VegetationSrfExt']['DMT'] = ('Real',('EC050'))
    field_information['GGDM 3.0']['VegetationSrfExt']['F_CODE'] = ('CONSTRAINED_STRING',('EC050'))
    field_information['GGDM 3.0']['VegetationSrfExt']['FEO'] = ('Real',('EC050'))
    field_information['GGDM 3.0']['VegetationSrfExt']['FUFI'] = ('StructuredText',('EC050'))
    field_information['GGDM 3.0']['VegetationSrfExt']['FURL'] = ('StructuredText',('EC050'))
    field_information['GGDM 3.0']['VegetationSrfExt']['GDBV'] = ('Enumeration',('EC050'))
    field_information['GGDM 3.0']['VegetationSrfExt']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['VegetationSrfExt']['EnumeratedIndexValues']['GDBV']['EC050']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['VegetationSrfExt']['HGT'] = ('Real',('EC050'))
    field_information['GGDM 3.0']['VegetationSrfExt']['LMC'] = ('Boolean',('EC050'))
    field_information['GGDM 3.0']['VegetationSrfExt']['LZN'] = ('Real',('EC050'))
    field_information['GGDM 3.0']['VegetationSrfExt']['OTH'] = ('StructuredText',('EC050'))
    field_information['GGDM 3.0']['VegetationSrfExt']['PVH'] = ('Real',('EC050'))
    field_information['GGDM 3.0']['VegetationSrfExt']['SBC'] = ('Boolean',('EC050'))
    field_information['GGDM 3.0']['VegetationSrfExt']['SDSC'] = ('Enumeration',('EC050'))
    field_information['GGDM 3.0']['VegetationSrfExt']['EnumeratedIndexValues']['SDSC'] = {}
    field_information['GGDM 3.0']['VegetationSrfExt']['EnumeratedIndexValues']['SDSC']['EC050']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['VegetationSrfExt']['SDSL'] = ('real',('EC050'))
    field_information['GGDM 3.0']['VegetationSrfExt']['SDSU'] = ('real',('EC050'))
    field_information['GGDM 3.0']['VegetationSrfExt']['STR'] = ('Real',('EC050'))
    field_information['GGDM 3.0']['VegetationSrfExt']['TRE'] = ('Enumeration',('EC050'))
    field_information['GGDM 3.0']['VegetationSrfExt']['EnumeratedIndexValues']['TRE'] = {}
    field_information['GGDM 3.0']['VegetationSrfExt']['EnumeratedIndexValues']['TRE']['EC050']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['VegetationSrfExt']['TSCC'] = ('Enumeration',('EC050'))
    field_information['GGDM 3.0']['VegetationSrfExt']['EnumeratedIndexValues']['TSCC'] = {}
    field_information['GGDM 3.0']['VegetationSrfExt']['EnumeratedIndexValues']['TSCC']['EC050']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['VegetationSrfExt']['TSCL'] = ('real',('EC050'))
    field_information['GGDM 3.0']['VegetationSrfExt']['TSCU'] = ('real',('EC050'))
    field_information['GGDM 3.0']['VegetationSrfExt']['UFI'] = ('StructuredText',('EC050'))
    field_information['GGDM 3.0']['VegetationSrfExt']['VSP'] = ('Enumeration',('EC050'))
    field_information['GGDM 3.0']['VegetationSrfExt']['EnumeratedIndexValues']['VSP'] = {}
    field_information['GGDM 3.0']['VegetationSrfExt']['EnumeratedIndexValues']['VSP']['EC050']  = (-999999,8,19,22,25,999)
    field_information['GGDM 3.0']['VegetationSrfExt']['VSP2'] = ('Enumeration',('EC050'))
    field_information['GGDM 3.0']['VegetationSrfExt']['EnumeratedIndexValues']['VSP2'] = {}
    field_information['GGDM 3.0']['VegetationSrfExt']['EnumeratedIndexValues']['VSP2']['EC050']  = (-999999,8,19,22,25,999)
    field_information['GGDM 3.0']['VegetationSrfExt']['VSP3'] = ('Enumeration',('EC050'))
    field_information['GGDM 3.0']['VegetationSrfExt']['EnumeratedIndexValues']['VSP3'] = {}
    field_information['GGDM 3.0']['VegetationSrfExt']['EnumeratedIndexValues']['VSP3']['EC050']  = (-999999,8,19,22,25,999)
    field_information['GGDM 3.0']['VegetationSrfExt']['VTI'] = ('Real',('EC050'))
    field_information['GGDM 3.0']['VegetationSrfExt']['WCL'] = ('Real',('EC050'))
    field_information['GGDM 3.0']['VegetationSrfExt']['WID'] = ('Real',('EC050'))
    field_information['GGDM 3.0']['VegetationSrfExt']['ZI001_SDV'] = ('StructuredText',('EC050'))
    field_information['GGDM 3.0']['VegetationSrfExt']['ZI001_SRT'] = ('Enumeration',('EC050'))
    field_information['GGDM 3.0']['VegetationSrfExt']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['VegetationSrfExt']['EnumeratedIndexValues']['ZI001_SRT']['EC050']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['VegetationSrfExt']['ZI002_UFI'] = ('StructuredText',('EC050'))
    field_information['GGDM 3.0']['VegetationSrfExt']['ZI004_RCG'] = ('Enumeration',('EC050'))
    field_information['GGDM 3.0']['VegetationSrfExt']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['VegetationSrfExt']['EnumeratedIndexValues']['ZI004_RCG']['EC050']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 998,999)
    field_information['GGDM 3.0']['VegetationSrfExt']['ZI005_FNA'] = ('String',('EC050'))
    field_information['GGDM 3.0']['VegetationSrfExt']['ZI005_GNT'] = ('Enumeration',('EC050'))
    field_information['GGDM 3.0']['VegetationSrfExt']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['VegetationSrfExt']['EnumeratedIndexValues']['ZI005_GNT']['EC050']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['VegetationSrfExt']['ZI005_NFN'] = ('String',('EC050'))
    field_information['GGDM 3.0']['VegetationSrfExt']['ZI006_MEM'] = ('String',('EC050'))
    field_information['GGDM 3.0']['VegetationSrfExt']['ZI020_GE4'] = ('CodeList',('EC050'))
    field_information['GGDM 3.0']['VegetationSrfExt']['ZI026_CTUC'] = ('Enumeration',('EC050'))
    field_information['GGDM 3.0']['VegetationSrfExt']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['VegetationSrfExt']['EnumeratedIndexValues']['ZI026_CTUC']['EC050']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['VegetationSrfExt']['ZI026_CTUL'] = ('integer',('EC050'))
    field_information['GGDM 3.0']['VegetationSrfExt']['ZI026_CTUU'] = ('integer',('EC050'))
    field_information['GGDM 3.0']['VegetationSrfExt']['ZI031S_URI'] = ('StructuredText',('EC050'))
    field_information['GGDM 3.0']['VegetationSrfExt']['ZI039S_UFI'] = ('StructuredText',('EC050'))
    field_information['GGDM 3.0']['VegetationSrfExt']['ZSAX_RS0'] = ('CodeList',('EC050'))
    field_information['GGDM 3.0']['VegetationSrfExt']['ZSAX_RX0'] = ('StructuredText',('EC050'))
    field_information['GGDM 3.0']['VegetationSrfExt']['ZSAX_RX3'] = ('StructuredText',('EC050'))
    field_information['GGDM 3.0']['VegetationSrfExt']['ZSAX_RX4'] = ('StructuredText',('EC050'))
    field_information['GGDM 3.0']['VegetationSrfExt']['ZVH'] = ('Real',('EC050'))


    field_information['GGDM 3.0']['SummaryDomainValues'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['ACH'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['ADI'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['ADR'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['ADUR'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['AHA'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['AMA'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['ANFL'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['AOO'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['APT'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['APT2'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['APT3'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['APU'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['APU2'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['APU3'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['APY'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['AQF'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['AQN'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['AQO'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['AQO2'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['AQO3'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['AQP'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['AQP2'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['AQP3'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['AQTC'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['AQTL'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['AQTU'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['ARA'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['ART'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['ASO'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['ASU'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['ASU2'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['ASU3'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['ASY'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['AT005_CAB'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['AT005_CAB2'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['AT005_CAB3'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['ATB'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['ATC'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['AVA'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['AWP'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['AXS'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['AYRC'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['AYRL'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['AYRU'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['AZC'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['BA000_VDC'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['BA000_VDR'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['BAC'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['BAT'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['BBMCA'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['BBMCA2'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['BBMCA3'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['BBMCB'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['BBMCB2'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['BBMCB3'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['BC010_REF'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['BC010_TZP'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['BC034_BRF'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['BC034_BRF2'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['BC034_MRT'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['BC034_MRT2'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['BC034_MRT3'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['BC040_CAA'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['BC040_COL'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['BC040_EOL'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['BC040_LCN'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['BC040_LVN'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['BC040_MLR'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['BC040_PER'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['BC040_ZVH'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['BC101_SST'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['BCC'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['BDS'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['BEL'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['BEN'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['BER'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['BET'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['BGT'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['BH010_CAA'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['BH141_AWBA'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['BH141_AWBB'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['BH141_IBOA'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['BH141_IBOB'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['BH141_SHDA'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['BH141_SHDB'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['BH141_SLTA'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['BH141_SLTB'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['BH141_WBHA'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['BH141_WBHB'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['BMC'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['BMC2'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['BMC3'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['BNF'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['BOC'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['BOT'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['BPWHAC'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['BPWHAL'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['BPWHAU'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['BPWHBC'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['BPWHBL'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['BPWHBU'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['BPWSAC'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['BPWSAL'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['BPWSAU'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['BPWSBC'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['BPWSBL'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['BPWSBU'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['BRF'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['BRF2'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['BRG'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['BRN'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['BRR'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['BRS'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['BSC'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['BSC2'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['BSC3'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['BSM'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['BST'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['BSU'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['BUS'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['BUT'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['BWVCAC'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['BWVCAL'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['BWVCAU'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['BWVCBC'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['BWVCBL'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['BWVCBU'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['C35'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['C36'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['C37'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['C38'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['C39'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['C40'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['C41'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['C42'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['C43'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['C44'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['C45'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['C46'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['CAA'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['CAB'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['CAB2'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['CAB3'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['CAM'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['CAT'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['CBP'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['CCG'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['CCN'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['CCR'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['CCT'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['CDA'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['CDI'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['CDL'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['CDM'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['CDR'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['CDY'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['CET'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['CFT'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['CHA'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['CID'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['CIW'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['CMS'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['CNCP'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['CNF'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['COA'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['COC'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['COG'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['COL'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['CON'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['COS'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['CPA'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['CPS'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['CPT'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['CRA'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['CRM'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['CRN'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['CRS'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['CRV'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['CRX'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['CSC'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['CSC2'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['CSC3'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['CSI'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['CSO'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['CSS'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['CST'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['CSY'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['CTC'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['CTL'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['CUL'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['CUR'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['CVT'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['CVT2'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['CVT3'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['CWT'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['D35'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['D36'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['D37'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['D38'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['D39'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['D40'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['D41'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['D42'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['D43'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['D44'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['D45'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['D46'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['DAN'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['DCAP'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['DEV'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['DF1'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['DF2'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['DF3'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['DF4'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['DFT'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['DFU'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['DFU2'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['DFU3'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['DGC'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['DIA'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['DIM'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['DINF'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['DIR'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['DIT'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['DKC'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['DKC2'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['DKC3'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['DKS'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['DMBC'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['DMBL'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['DMBU'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['DMC'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['DMD'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['DMF'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['DMT'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['DNE'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['DOF'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['DOXY'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['DPAC'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['DPAL'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['DPAU'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['DPG'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['DPG2'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['DPG3'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['DQS'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['DRP'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['DSD'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['DSP'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['DTN'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['DWL'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['DZC'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['DZP'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['EET'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['EOL'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['EPW'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['EQS'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['ESC'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['ETS'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['ETY'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['ETZ'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['EVA'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['EXP'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['F_CODE'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['FA003_BAL'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['FAC'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['FCL'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['FCO'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['FCS'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['FDI'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['FEF'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['FEO'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['FER'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['FHC'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['FHC2'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['FHC3'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['FIC'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['FLO'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['FLT'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['FPT'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['FRT'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['FRT2'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['FRT3'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['FRZ'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['FSC'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['FTI'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['FUFI'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['FURL'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['FZR'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['GA032_NSX'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['GB001_AID'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['GB052_RIDH'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['GB052_RIDL'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['GB052_TRHH'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['GB052_TRHL'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['GDBV'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['GEC'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['GFT'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['GFY'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['GOT'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['GRD'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['GSGCHC'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['GSGCHL'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['GSGCHU'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['GSGCLC'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['GSGCLL'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['GSGCLU'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['GTC'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['GUG'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['GWS'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['GWTR'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['HAF'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['HBH'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['HCA'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['HDH'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['HDP'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['HEI'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['HGS'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['HGT'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['HHD'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['HQC'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['HSC'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['HSCD'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['HSE'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['HSS'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['HST'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['HST2'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['HST3'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['HTP'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['HVA'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['HYCD'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['IAA'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['IAS'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['IKO'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['INU'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['IWT'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['KVA'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['LAF'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['LASZ'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['LC1'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['LC2'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['LC3'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['LC4'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['LCA'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['LCN'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['LDC'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['LEA'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['LFC'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['LFC2'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['LFC3'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['LMC'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['LND'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['LNU'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['LOC'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['LOG'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['LOR'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['LSA'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['LSI'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['LSP'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['LST'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['LTN'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['LUN'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['LVN'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['LZN'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['MAG'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['MAN'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['MAS'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_MCC1'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_MCC2'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_PSC1'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_PSC2'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_SCO1'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_SCO2'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['MCA'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['MCC'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['MCC2'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['MCC3'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['MCX'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['MCY'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['MCY2'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['MCY3'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['MDE'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['MEL'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['MEM'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['MES'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['MFB'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['MFE'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['MFY'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['MGL'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['MGL2'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['MGL3'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['MKSZ'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['MLO'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['MLOP'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['MLR'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['MLUS'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['MNR'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['MNR2'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['MNR3'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['MNS'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['MRP'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['MRR'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['MRR2'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['MRR3'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['MRT'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['MST'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['MST2'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['MST3'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['MUB'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['MWD'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['MWG'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['MZN'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['NA8'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['NAO'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['NDX'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['NDX2'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['NDX3'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['NFP'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['NFP2'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['NFP3'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['NLT'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['NMC'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['NMC2'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['NMC3'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['NOA'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['NOA2'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['NOA3'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['NOR'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['NOS'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['NPL'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['NSC'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['NVS'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['OCS'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['OHC'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['ONE'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['OOC'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['OPT'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['ORC'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['ORS'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['ORS2'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['ORS3'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['OTH'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['OWO'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['PBY'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['PBY2'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['PBY3'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['PCF'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['PEC'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['PER'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['PFD'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['PFH'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['PFHC'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['PFHL'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['PFHU'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['PLC'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['PLT'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['PLT2'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['PLT3'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['PMPR'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['POS'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['POS2'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['POS3'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['PPL'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['PPO'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['PPO2'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['PPO3'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['PRM'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['PRVR'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['PRW'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['PRW2'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['PRW3'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['PSE'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['PSN'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['PTG'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['PUD'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['PVH'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['PWA'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['PWAC'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['PWAL'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['PWAU'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['PWC'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['PWR'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['PYC'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['PYM'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['RAC'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['RAD'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['RAS'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['RAY'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['RCG'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['REF'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['REW'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['RFD'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['RIN_ROI'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['RIN_ROI2'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['RIN_ROI3'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['RIN_RTN'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['RIN_RTN2'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['RIN_RTN3'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['RIP'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['RIT'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['RKF'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['RLE'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['RMWC'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['RMWL'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['RMWU'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['ROR'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['RPC'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['RRC'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['RRC2'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['RRC3'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['RS6'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['RSA'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['RSI'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['RTA'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['RTL'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['RTN'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['RTN2'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['RTN3'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['RTT'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['RTY'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['RWC'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['RX0'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['RX1'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['RX2'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['RX3'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['RX4'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['RX5'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['RX6'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['RX7'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['RY1'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['RY2'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['SAD'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['SAX_RS1'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['SAX_RS2'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['SAX_RS4'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['SAX_RS5'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['SAX_RS6'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['SAX_RS8'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['SAX_RS9'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['SAX_RX1'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['SAX_RX2'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['SAX_RX5'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['SAX_RX6'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['SAX_RX7'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['SAX_RX9'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['SAX_RY0'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['SAX_RY1'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['SAX_RY2'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['SBB'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['SBC'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['SBT'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['SBT2'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['SBT3'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['SCOG'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['SCVN'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['SDCC'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['SDCL'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['SDCU'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['SDI'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['SDO'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['SDQ'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['SDSC'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['SDSL'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['SDSU'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['SDT'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['SEP'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['SERP'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['SGCC'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['SGCL'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['SGCU'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['SHC'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['SHD'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['SHO'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['SHT'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['SIC'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['SLR'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['SLT'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['SNDC'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['SNDL'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['SNDU'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['SPD'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['SPM'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['SPT'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['SRD'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['SRE'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['SRL'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['SSC'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['SSE'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['SSG'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['SSR'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['SSR2'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['SSR3'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['STA'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['STA2'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['STA3'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['STAF'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['STL'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['STL2'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['STL3'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['STNB'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['STP'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['STR'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['SUY'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['SWC'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['SWCP'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['SWT'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['SWW'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['TAN'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['TCS'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['TEL'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['THI'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['THR'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['TID'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['TOS'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['TRA'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['TRE'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['TRP'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['TRS'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['TRS2'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['TRS3'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['TSCC'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['TSCL'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['TSCU'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['TSM'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['TSM2'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['TSM3'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['TSP'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['TSSM'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['TSSM2'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['TSSM3'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['TST'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['TSTE'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['TTC'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['TTC2'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['TTC3'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['TTY'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['TWS'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['TXP'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['TZP'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['UBC'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['UFI'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['UMA'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['URI'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['UTY'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['UTY2'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['UTY3'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['VAVC'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['VAVL'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['VAVU'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['VCA'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['VCA2'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['VCA3'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['VCM'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['VCM2'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['VCM3'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['VCO'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['VCS'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['VCS_VCD'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['VCS_VCR'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['VCT'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['VCT2'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['VCT3'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['VDT'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['VEC'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['VEG'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['VET'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['VGT'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['VIS'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['VIS2'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['VIS3'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['VLM'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['VOA'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['VOI'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['VSP'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['VSP2'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['VSP3'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['VTI'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['WAD'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['WBD'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['WCAC'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['WCC'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['WCL'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['WD1'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['WD2'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['WD3'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['WDAC'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['WDAL'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['WDAU'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['WDH'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['WDL'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['WDST'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['WDU'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['WEQ'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['WEQ2'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['WEQ3'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['WFT'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['WHCO'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['WID'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['WLE'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['WLO'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['WLSS'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['WMT'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['WOC'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['WODR'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['WPC'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['WPC2'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['WPC3'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['WPI'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['WPST'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['WRCC'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['WRCL'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['WRCU'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['WRT'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['WSRC'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['WST'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['WT2'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['WTBB'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['WTCA'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['WTCL'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['WTFE'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['WTI'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['WTKK'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['WTMN'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['WTNA'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['WTNO'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['WTPO'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['WTSI'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['WTST'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['WTT'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['WTYP'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['WVA'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['WVH'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['WVL'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['WWM'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['WWM2'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['WWM3'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['WWRC'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['WWRL'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['WWRU'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['YSU'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['YWQ'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHBH_DCR'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHBH_DKC'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHBH_DKC2'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHBH_DKC3'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHBH_SVC'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHBH_TEC'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHBH_TEC2'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHBH_TEC3'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHBH_VDC'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHBH_VDR'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHDP_DCR'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHDP_DKC'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHDP_DKC2'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHDP_DKC3'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHDP_SVC'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHDP_TEC'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHDP_TEC2'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHDP_TEC3'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHDP_VDC'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHDP_VDR'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI001_SDP'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI001_SDV'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI001_SPS'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI001_VSC'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI001_VSD'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI001_VSN'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI002_UFI'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI004_PRE'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI005_FNA'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI005_FNA2'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI005_FNA3'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI005_FNAA'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI005_FNAB'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI005_GNR'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI005_GNR2'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI005_GNR3'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI005_GNT2'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI005_GNT3'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI005_GNTA'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI005_GNTB'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI005_NFN'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI005_NFN2'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI005_NFN3'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI005_NFNA'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI005_NFNB'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI006_MEM'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI012_DCR'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI012_DKC'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI012_DKC2'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI012_DKC3'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI012_SVC'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI012_TEC'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI012_TEC2'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI012_TEC3'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI012_VDC'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI012_VDR'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI013_CSP'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI013_CSP2'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI013_CSP3'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI013_FFP'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI013_FFP2'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI013_FFP3'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI013_FMM'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI013_FMM2'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI013_FMM3'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI013_IRG'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI013_PIG'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PBY'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PBY2'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PBY3'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PPO'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PPO2'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PPO3'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PRW'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PRW2'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PRW3'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI015_GCUC'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI015_GCUL'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI015_GCUU'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI016_ROC'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI016_WD1'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI016_WTC'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI017_GAW'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI017_RGC'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI017_RIR'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI017_RRA'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI017_TRT'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI018_BRF'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI018_WIT'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI019_ASP'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI019_ASP2'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI019_ASP3'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI019_ASU'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI019_ASU2'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI019_ASU3'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI019_ASX'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI019_SFS'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI020_FI2A'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI020_FI2B'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI020_GE4'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI020_GE42'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI020_GE43'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI020_GE44'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI020_GE4A'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI020_GE4B'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI020_IC4'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI024_ASE'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI024_AWO'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI024_AWOI'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI024_AWOX'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI024_CFR'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI024_CLO'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI024_CYN'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI024_DRL'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI024_DVPT'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI024_FMR'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI024_FRR'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI024_HAR'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI024_HYP'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI024_MGN'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI024_PHW'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI024_PMP'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI024_PUR'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI024_PUR2'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI024_PUR3'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI024_PUR4'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI024_PUR5'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI024_RTP'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI024_SCC'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI024_SQN'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI024_SUL'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI024_TDS'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI024_TEP'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI024_TUR'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI024_WAC'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI024_WPAC'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI024_WSG'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI024_WTBB'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI024_WTCA'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI024_WTFE'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI024_WTKK'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI024_WTMN'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI024_WTNA'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI024_WTNO'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI024_WTPO'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI024_WTSI'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI024_WUR'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI024_WUR2'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI024_WUR3'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI024_WUR4'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI024_YWQ'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI025_HDP'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI025_MAN'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI025_UHS'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI025_WLE'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI026_CTUL'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI026_CTUU'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI026_SUR'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI031S_URI'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI032_GUG'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI032_PYC'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI032_PYM'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI032_TOS'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI037_REL'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI037_RFA'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI039S_UFI'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI071_CTX'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI071_FFN'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI071_FFN2'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI071_FFN3'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI071_UAO'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI103_MVD'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['ZSAX_RS0'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['ZSAX_RX0'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['ZSAX_RX3'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['ZSAX_RX4'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['ZVA'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['ZVH'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['ZVH_AVA'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['ZVH_VDT'] = {}
    field_information['GGDM 3.0']['SummaryDomainValues']['ACH'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['ACH'][1] = u'Unrestricted Anchorage'
    field_information['GGDM 3.0']['SummaryDomainValues']['ACH'][2] = u'Deep Water Anchorage'
    field_information['GGDM 3.0']['SummaryDomainValues']['ACH'][3] = u'Tanker Anchorage'
    field_information['GGDM 3.0']['SummaryDomainValues']['ACH'][4] = u'Explosives Anchorage'
    field_information['GGDM 3.0']['SummaryDomainValues']['ACH'][5] = u'Quarantine Anchorage'
    field_information['GGDM 3.0']['SummaryDomainValues']['ACH'][6] = u'Seaplane Anchorage'
    field_information['GGDM 3.0']['SummaryDomainValues']['ACH'][7] = u'Small Craft Anchorage'
    field_information['GGDM 3.0']['SummaryDomainValues']['ACH'][8] = u'Small Craft Mooring Area'
    field_information['GGDM 3.0']['SummaryDomainValues']['ACH'][9] = u'Anchorage for up to 24 hours'
    field_information['GGDM 3.0']['SummaryDomainValues']['ACH'][10] = u'Time Limited'
    field_information['GGDM 3.0']['SummaryDomainValues']['ACH'][11] = u'Reserved Anchorage'
    field_information['GGDM 3.0']['SummaryDomainValues']['ACH'][12] = u'Naval Reserve Anchorage'
    field_information['GGDM 3.0']['SummaryDomainValues']['ACH'][13] = u'Anchorage Berth'
    field_information['GGDM 3.0']['SummaryDomainValues']['ACH'][14] = u'Waiting Anchorage'
    field_information['GGDM 3.0']['SummaryDomainValues']['ACH'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['ADI'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['ADI'][1] = u'International or Supranational'
    field_information['GGDM 3.0']['SummaryDomainValues']['ADI'][2] = u'National'
    field_information['GGDM 3.0']['SummaryDomainValues']['ADI'][3] = u'Subnational'
    field_information['GGDM 3.0']['SummaryDomainValues']['ADI'][4] = u'Local'
    field_information['GGDM 3.0']['SummaryDomainValues']['ADI'][6] = u'Municipal'
    field_information['GGDM 3.0']['SummaryDomainValues']['ADI'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['AMA'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['AMA'][1] = u'Artificial Mountain'
    field_information['GGDM 3.0']['SummaryDomainValues']['AMA'][2] = u'Ferris Wheel'
    field_information['GGDM 3.0']['SummaryDomainValues']['AMA'][3] = u'Roller-coaster'
    field_information['GGDM 3.0']['SummaryDomainValues']['AMA'][4] = u'Spherical'
    field_information['GGDM 3.0']['SummaryDomainValues']['AMA'][5] = u'Water Attraction'
    field_information['GGDM 3.0']['SummaryDomainValues']['AMA'][6] = u'Vertical Ride'
    field_information['GGDM 3.0']['SummaryDomainValues']['AMA'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['APT'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['APT'][1] = u'Major Airfield'
    field_information['GGDM 3.0']['SummaryDomainValues']['APT'][2] = u'Minor Airfield'
    field_information['GGDM 3.0']['SummaryDomainValues']['APT'][3] = u'General Aviation Aircraft Operating Only'
    field_information['GGDM 3.0']['SummaryDomainValues']['APT'][5] = u'Glider Site'
    field_information['GGDM 3.0']['SummaryDomainValues']['APT'][6] = u'Ultralight Site'
    field_information['GGDM 3.0']['SummaryDomainValues']['APT'][7] = u'Hang Glider Site'
    field_information['GGDM 3.0']['SummaryDomainValues']['APT'][8] = u'Winch Launched Hang Glider Site'
    field_information['GGDM 3.0']['SummaryDomainValues']['APT'][12] = u'Emergency'
    field_information['GGDM 3.0']['SummaryDomainValues']['APT'][13] = u'Parascending Site'
    field_information['GGDM 3.0']['SummaryDomainValues']['APT'][16] = u'Search and Rescue Airfield'
    field_information['GGDM 3.0']['SummaryDomainValues']['APT'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['APT2'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['APT2'][1] = u'Major Airfield'
    field_information['GGDM 3.0']['SummaryDomainValues']['APT2'][2] = u'Minor Airfield'
    field_information['GGDM 3.0']['SummaryDomainValues']['APT2'][3] = u'General Aviation Aircraft Operating Only'
    field_information['GGDM 3.0']['SummaryDomainValues']['APT2'][5] = u'Glider Site'
    field_information['GGDM 3.0']['SummaryDomainValues']['APT2'][6] = u'Ultralight Site'
    field_information['GGDM 3.0']['SummaryDomainValues']['APT2'][7] = u'Hang Glider Site'
    field_information['GGDM 3.0']['SummaryDomainValues']['APT2'][8] = u'Winch Launched Hang Glider Site'
    field_information['GGDM 3.0']['SummaryDomainValues']['APT2'][12] = u'Emergency'
    field_information['GGDM 3.0']['SummaryDomainValues']['APT2'][13] = u'Parascending Site'
    field_information['GGDM 3.0']['SummaryDomainValues']['APT2'][16] = u'Search and Rescue Airfield'
    field_information['GGDM 3.0']['SummaryDomainValues']['APT2'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['APT3'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['APT3'][1] = u'Major Airfield'
    field_information['GGDM 3.0']['SummaryDomainValues']['APT3'][2] = u'Minor Airfield'
    field_information['GGDM 3.0']['SummaryDomainValues']['APT3'][3] = u'General Aviation Aircraft Operating Only'
    field_information['GGDM 3.0']['SummaryDomainValues']['APT3'][5] = u'Glider Site'
    field_information['GGDM 3.0']['SummaryDomainValues']['APT3'][6] = u'Ultralight Site'
    field_information['GGDM 3.0']['SummaryDomainValues']['APT3'][7] = u'Hang Glider Site'
    field_information['GGDM 3.0']['SummaryDomainValues']['APT3'][8] = u'Winch Launched Hang Glider Site'
    field_information['GGDM 3.0']['SummaryDomainValues']['APT3'][12] = u'Emergency'
    field_information['GGDM 3.0']['SummaryDomainValues']['APT3'][13] = u'Parascending Site'
    field_information['GGDM 3.0']['SummaryDomainValues']['APT3'][16] = u'Search and Rescue Airfield'
    field_information['GGDM 3.0']['SummaryDomainValues']['APT3'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['APU'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['APU'][1] = u'Parking'
    field_information['GGDM 3.0']['SummaryDomainValues']['APU'][2] = u'Loading and/or Unloading'
    field_information['GGDM 3.0']['SummaryDomainValues']['APU'][3] = u'Fuelling'
    field_information['GGDM 3.0']['SummaryDomainValues']['APU'][4] = u'Transient'
    field_information['GGDM 3.0']['SummaryDomainValues']['APU'][5] = u'Compass Rose'
    field_information['GGDM 3.0']['SummaryDomainValues']['APU'][6] = u'Engine Run Up'
    field_information['GGDM 3.0']['SummaryDomainValues']['APU'][7] = u'Maintenance'
    field_information['GGDM 3.0']['SummaryDomainValues']['APU'][8] = u'Alert'
    field_information['GGDM 3.0']['SummaryDomainValues']['APU'][9] = u'Firing-In'
    field_information['GGDM 3.0']['SummaryDomainValues']['APU'][10] = u'Hot Refuelling'
    field_information['GGDM 3.0']['SummaryDomainValues']['APU'][11] = u'Weapon Loading'
    field_information['GGDM 3.0']['SummaryDomainValues']['APU'][12] = u'De-icing and/or Anti-icing'
    field_information['GGDM 3.0']['SummaryDomainValues']['APU'][13] = u'INS Alignment'
    field_information['GGDM 3.0']['SummaryDomainValues']['APU'][14] = u'Decontamination'
    field_information['GGDM 3.0']['SummaryDomainValues']['APU'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['APU2'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['APU2'][1] = u'Parking'
    field_information['GGDM 3.0']['SummaryDomainValues']['APU2'][2] = u'Loading and/or Unloading'
    field_information['GGDM 3.0']['SummaryDomainValues']['APU2'][3] = u'Fuelling'
    field_information['GGDM 3.0']['SummaryDomainValues']['APU2'][4] = u'Transient'
    field_information['GGDM 3.0']['SummaryDomainValues']['APU2'][5] = u'Compass Rose'
    field_information['GGDM 3.0']['SummaryDomainValues']['APU2'][6] = u'Engine Run Up'
    field_information['GGDM 3.0']['SummaryDomainValues']['APU2'][7] = u'Maintenance'
    field_information['GGDM 3.0']['SummaryDomainValues']['APU2'][8] = u'Alert'
    field_information['GGDM 3.0']['SummaryDomainValues']['APU2'][9] = u'Firing-In'
    field_information['GGDM 3.0']['SummaryDomainValues']['APU2'][10] = u'Hot Refuelling'
    field_information['GGDM 3.0']['SummaryDomainValues']['APU2'][11] = u'Weapon Loading'
    field_information['GGDM 3.0']['SummaryDomainValues']['APU2'][12] = u'De-icing and/or Anti-icing'
    field_information['GGDM 3.0']['SummaryDomainValues']['APU2'][13] = u'INS Alignment'
    field_information['GGDM 3.0']['SummaryDomainValues']['APU2'][14] = u'Decontamination'
    field_information['GGDM 3.0']['SummaryDomainValues']['APU2'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['APU3'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['APU3'][1] = u'Parking'
    field_information['GGDM 3.0']['SummaryDomainValues']['APU3'][2] = u'Loading and/or Unloading'
    field_information['GGDM 3.0']['SummaryDomainValues']['APU3'][3] = u'Fuelling'
    field_information['GGDM 3.0']['SummaryDomainValues']['APU3'][4] = u'Transient'
    field_information['GGDM 3.0']['SummaryDomainValues']['APU3'][5] = u'Compass Rose'
    field_information['GGDM 3.0']['SummaryDomainValues']['APU3'][6] = u'Engine Run Up'
    field_information['GGDM 3.0']['SummaryDomainValues']['APU3'][7] = u'Maintenance'
    field_information['GGDM 3.0']['SummaryDomainValues']['APU3'][8] = u'Alert'
    field_information['GGDM 3.0']['SummaryDomainValues']['APU3'][9] = u'Firing-In'
    field_information['GGDM 3.0']['SummaryDomainValues']['APU3'][10] = u'Hot Refuelling'
    field_information['GGDM 3.0']['SummaryDomainValues']['APU3'][11] = u'Weapon Loading'
    field_information['GGDM 3.0']['SummaryDomainValues']['APU3'][12] = u'De-icing and/or Anti-icing'
    field_information['GGDM 3.0']['SummaryDomainValues']['APU3'][13] = u'INS Alignment'
    field_information['GGDM 3.0']['SummaryDomainValues']['APU3'][14] = u'Decontamination'
    field_information['GGDM 3.0']['SummaryDomainValues']['APU3'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['APY'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['APY'][1] = u'Passenger'
    field_information['GGDM 3.0']['SummaryDomainValues']['APY'][2] = u'Cargo'
    field_information['GGDM 3.0']['SummaryDomainValues']['APY'][3] = u'Remote Parking'
    field_information['GGDM 3.0']['SummaryDomainValues']['APY'][4] = u'Services and/or Hangar'
    field_information['GGDM 3.0']['SummaryDomainValues']['APY'][5] = u'General Aviation'
    field_information['GGDM 3.0']['SummaryDomainValues']['APY'][6] = u'Military'
    field_information['GGDM 3.0']['SummaryDomainValues']['APY'][7] = u'Dispersal'
    field_information['GGDM 3.0']['SummaryDomainValues']['APY'][8] = u'Holding'
    field_information['GGDM 3.0']['SummaryDomainValues']['APY'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['AQF'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['AQF'][1] = u'Marine Culture'
    field_information['GGDM 3.0']['SummaryDomainValues']['AQF'][2] = u'Sea Ranch'
    field_information['GGDM 3.0']['SummaryDomainValues']['AQF'][3] = u'Shrimp Farm'
    field_information['GGDM 3.0']['SummaryDomainValues']['AQF'][4] = u'Kelp Farm'
    field_information['GGDM 3.0']['SummaryDomainValues']['AQF'][8] = u'Pearl Culture Farm'
    field_information['GGDM 3.0']['SummaryDomainValues']['AQO'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['AQO'][1] = u'Basalt'
    field_information['GGDM 3.0']['SummaryDomainValues']['AQO'][2] = u'Boulders'
    field_information['GGDM 3.0']['SummaryDomainValues']['AQO'][3] = u'Clay'
    field_information['GGDM 3.0']['SummaryDomainValues']['AQO'][4] = u'Conglomerate'
    field_information['GGDM 3.0']['SummaryDomainValues']['AQO'][5] = u'Dolomite'
    field_information['GGDM 3.0']['SummaryDomainValues']['AQO'][6] = u'Granite'
    field_information['GGDM 3.0']['SummaryDomainValues']['AQO'][7] = u'Gravel'
    field_information['GGDM 3.0']['SummaryDomainValues']['AQO'][8] = u'Igneous Rock'
    field_information['GGDM 3.0']['SummaryDomainValues']['AQO'][9] = u'Karst'
    field_information['GGDM 3.0']['SummaryDomainValues']['AQO'][10] = u'Limestone'
    field_information['GGDM 3.0']['SummaryDomainValues']['AQO'][11] = u'Marl'
    field_information['GGDM 3.0']['SummaryDomainValues']['AQO'][12] = u'Metamorphic Rock'
    field_information['GGDM 3.0']['SummaryDomainValues']['AQO'][13] = u'Mud'
    field_information['GGDM 3.0']['SummaryDomainValues']['AQO'][14] = u'Sand'
    field_information['GGDM 3.0']['SummaryDomainValues']['AQO'][15] = u'Schist'
    field_information['GGDM 3.0']['SummaryDomainValues']['AQO'][16] = u'Unconsolidated'
    field_information['GGDM 3.0']['SummaryDomainValues']['AQO'][17] = u'Semi-consolidated and Consolidated Volcanic Ash'
    field_information['GGDM 3.0']['SummaryDomainValues']['AQO'][18] = u'Volcanic Rock'
    field_information['GGDM 3.0']['SummaryDomainValues']['AQO'][19] = u'Sandstone'
    field_information['GGDM 3.0']['SummaryDomainValues']['AQO'][20] = u'Shale'
    field_information['GGDM 3.0']['SummaryDomainValues']['AQO'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['AQO2'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['AQO2'][1] = u'Basalt'
    field_information['GGDM 3.0']['SummaryDomainValues']['AQO2'][2] = u'Boulders'
    field_information['GGDM 3.0']['SummaryDomainValues']['AQO2'][3] = u'Clay'
    field_information['GGDM 3.0']['SummaryDomainValues']['AQO2'][4] = u'Conglomerate'
    field_information['GGDM 3.0']['SummaryDomainValues']['AQO2'][5] = u'Dolomite'
    field_information['GGDM 3.0']['SummaryDomainValues']['AQO2'][6] = u'Granite'
    field_information['GGDM 3.0']['SummaryDomainValues']['AQO2'][7] = u'Gravel'
    field_information['GGDM 3.0']['SummaryDomainValues']['AQO2'][8] = u'Igneous Rock'
    field_information['GGDM 3.0']['SummaryDomainValues']['AQO2'][9] = u'Karst'
    field_information['GGDM 3.0']['SummaryDomainValues']['AQO2'][10] = u'Limestone'
    field_information['GGDM 3.0']['SummaryDomainValues']['AQO2'][11] = u'Marl'
    field_information['GGDM 3.0']['SummaryDomainValues']['AQO2'][12] = u'Metamorphic Rock'
    field_information['GGDM 3.0']['SummaryDomainValues']['AQO2'][13] = u'Mud'
    field_information['GGDM 3.0']['SummaryDomainValues']['AQO2'][14] = u'Sand'
    field_information['GGDM 3.0']['SummaryDomainValues']['AQO2'][15] = u'Schist'
    field_information['GGDM 3.0']['SummaryDomainValues']['AQO2'][16] = u'Unconsolidated'
    field_information['GGDM 3.0']['SummaryDomainValues']['AQO2'][17] = u'Semi-consolidated and Consolidated Volcanic Ash'
    field_information['GGDM 3.0']['SummaryDomainValues']['AQO2'][18] = u'Volcanic Rock'
    field_information['GGDM 3.0']['SummaryDomainValues']['AQO2'][19] = u'Sandstone'
    field_information['GGDM 3.0']['SummaryDomainValues']['AQO2'][20] = u'Shale'
    field_information['GGDM 3.0']['SummaryDomainValues']['AQO2'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['AQO3'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['AQO3'][1] = u'Basalt'
    field_information['GGDM 3.0']['SummaryDomainValues']['AQO3'][2] = u'Boulders'
    field_information['GGDM 3.0']['SummaryDomainValues']['AQO3'][3] = u'Clay'
    field_information['GGDM 3.0']['SummaryDomainValues']['AQO3'][4] = u'Conglomerate'
    field_information['GGDM 3.0']['SummaryDomainValues']['AQO3'][5] = u'Dolomite'
    field_information['GGDM 3.0']['SummaryDomainValues']['AQO3'][6] = u'Granite'
    field_information['GGDM 3.0']['SummaryDomainValues']['AQO3'][7] = u'Gravel'
    field_information['GGDM 3.0']['SummaryDomainValues']['AQO3'][8] = u'Igneous Rock'
    field_information['GGDM 3.0']['SummaryDomainValues']['AQO3'][9] = u'Karst'
    field_information['GGDM 3.0']['SummaryDomainValues']['AQO3'][10] = u'Limestone'
    field_information['GGDM 3.0']['SummaryDomainValues']['AQO3'][11] = u'Marl'
    field_information['GGDM 3.0']['SummaryDomainValues']['AQO3'][12] = u'Metamorphic Rock'
    field_information['GGDM 3.0']['SummaryDomainValues']['AQO3'][13] = u'Mud'
    field_information['GGDM 3.0']['SummaryDomainValues']['AQO3'][14] = u'Sand'
    field_information['GGDM 3.0']['SummaryDomainValues']['AQO3'][15] = u'Schist'
    field_information['GGDM 3.0']['SummaryDomainValues']['AQO3'][16] = u'Unconsolidated'
    field_information['GGDM 3.0']['SummaryDomainValues']['AQO3'][17] = u'Semi-consolidated and Consolidated Volcanic Ash'
    field_information['GGDM 3.0']['SummaryDomainValues']['AQO3'][18] = u'Volcanic Rock'
    field_information['GGDM 3.0']['SummaryDomainValues']['AQO3'][19] = u'Sandstone'
    field_information['GGDM 3.0']['SummaryDomainValues']['AQO3'][20] = u'Shale'
    field_information['GGDM 3.0']['SummaryDomainValues']['AQO3'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['AQP'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['AQP'][1] = u'Basalt'
    field_information['GGDM 3.0']['SummaryDomainValues']['AQP'][2] = u'Boulders'
    field_information['GGDM 3.0']['SummaryDomainValues']['AQP'][3] = u'Clay'
    field_information['GGDM 3.0']['SummaryDomainValues']['AQP'][4] = u'Conglomerate'
    field_information['GGDM 3.0']['SummaryDomainValues']['AQP'][5] = u'Dolomite'
    field_information['GGDM 3.0']['SummaryDomainValues']['AQP'][6] = u'Granite'
    field_information['GGDM 3.0']['SummaryDomainValues']['AQP'][7] = u'Gravel'
    field_information['GGDM 3.0']['SummaryDomainValues']['AQP'][8] = u'Igneous Rock'
    field_information['GGDM 3.0']['SummaryDomainValues']['AQP'][9] = u'Karst'
    field_information['GGDM 3.0']['SummaryDomainValues']['AQP'][10] = u'Limestone'
    field_information['GGDM 3.0']['SummaryDomainValues']['AQP'][11] = u'Marl'
    field_information['GGDM 3.0']['SummaryDomainValues']['AQP'][12] = u'Metamorphic Rock'
    field_information['GGDM 3.0']['SummaryDomainValues']['AQP'][13] = u'Mud'
    field_information['GGDM 3.0']['SummaryDomainValues']['AQP'][14] = u'Sand'
    field_information['GGDM 3.0']['SummaryDomainValues']['AQP'][15] = u'Schist'
    field_information['GGDM 3.0']['SummaryDomainValues']['AQP'][16] = u'Unconsolidated'
    field_information['GGDM 3.0']['SummaryDomainValues']['AQP'][17] = u'Semi-consolidated and Consolidated Volcanic Ash'
    field_information['GGDM 3.0']['SummaryDomainValues']['AQP'][18] = u'Volcanic Rock'
    field_information['GGDM 3.0']['SummaryDomainValues']['AQP'][19] = u'Sandstone'
    field_information['GGDM 3.0']['SummaryDomainValues']['AQP'][20] = u'Shale'
    field_information['GGDM 3.0']['SummaryDomainValues']['AQP'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['AQP2'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['AQP2'][1] = u'Basalt'
    field_information['GGDM 3.0']['SummaryDomainValues']['AQP2'][2] = u'Boulders'
    field_information['GGDM 3.0']['SummaryDomainValues']['AQP2'][3] = u'Clay'
    field_information['GGDM 3.0']['SummaryDomainValues']['AQP2'][4] = u'Conglomerate'
    field_information['GGDM 3.0']['SummaryDomainValues']['AQP2'][5] = u'Dolomite'
    field_information['GGDM 3.0']['SummaryDomainValues']['AQP2'][6] = u'Granite'
    field_information['GGDM 3.0']['SummaryDomainValues']['AQP2'][7] = u'Gravel'
    field_information['GGDM 3.0']['SummaryDomainValues']['AQP2'][8] = u'Igneous Rock'
    field_information['GGDM 3.0']['SummaryDomainValues']['AQP2'][9] = u'Karst'
    field_information['GGDM 3.0']['SummaryDomainValues']['AQP2'][10] = u'Limestone'
    field_information['GGDM 3.0']['SummaryDomainValues']['AQP2'][11] = u'Marl'
    field_information['GGDM 3.0']['SummaryDomainValues']['AQP2'][12] = u'Metamorphic Rock'
    field_information['GGDM 3.0']['SummaryDomainValues']['AQP2'][13] = u'Mud'
    field_information['GGDM 3.0']['SummaryDomainValues']['AQP2'][14] = u'Sand'
    field_information['GGDM 3.0']['SummaryDomainValues']['AQP2'][15] = u'Schist'
    field_information['GGDM 3.0']['SummaryDomainValues']['AQP2'][16] = u'Unconsolidated'
    field_information['GGDM 3.0']['SummaryDomainValues']['AQP2'][17] = u'Semi-consolidated and Consolidated Volcanic Ash'
    field_information['GGDM 3.0']['SummaryDomainValues']['AQP2'][18] = u'Volcanic Rock'
    field_information['GGDM 3.0']['SummaryDomainValues']['AQP2'][19] = u'Sandstone'
    field_information['GGDM 3.0']['SummaryDomainValues']['AQP2'][20] = u'Shale'
    field_information['GGDM 3.0']['SummaryDomainValues']['AQP2'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['AQP3'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['AQP3'][1] = u'Basalt'
    field_information['GGDM 3.0']['SummaryDomainValues']['AQP3'][2] = u'Boulders'
    field_information['GGDM 3.0']['SummaryDomainValues']['AQP3'][3] = u'Clay'
    field_information['GGDM 3.0']['SummaryDomainValues']['AQP3'][4] = u'Conglomerate'
    field_information['GGDM 3.0']['SummaryDomainValues']['AQP3'][5] = u'Dolomite'
    field_information['GGDM 3.0']['SummaryDomainValues']['AQP3'][6] = u'Granite'
    field_information['GGDM 3.0']['SummaryDomainValues']['AQP3'][7] = u'Gravel'
    field_information['GGDM 3.0']['SummaryDomainValues']['AQP3'][8] = u'Igneous Rock'
    field_information['GGDM 3.0']['SummaryDomainValues']['AQP3'][9] = u'Karst'
    field_information['GGDM 3.0']['SummaryDomainValues']['AQP3'][10] = u'Limestone'
    field_information['GGDM 3.0']['SummaryDomainValues']['AQP3'][11] = u'Marl'
    field_information['GGDM 3.0']['SummaryDomainValues']['AQP3'][12] = u'Metamorphic Rock'
    field_information['GGDM 3.0']['SummaryDomainValues']['AQP3'][13] = u'Mud'
    field_information['GGDM 3.0']['SummaryDomainValues']['AQP3'][14] = u'Sand'
    field_information['GGDM 3.0']['SummaryDomainValues']['AQP3'][15] = u'Schist'
    field_information['GGDM 3.0']['SummaryDomainValues']['AQP3'][16] = u'Unconsolidated'
    field_information['GGDM 3.0']['SummaryDomainValues']['AQP3'][17] = u'Semi-consolidated and Consolidated Volcanic Ash'
    field_information['GGDM 3.0']['SummaryDomainValues']['AQP3'][18] = u'Volcanic Rock'
    field_information['GGDM 3.0']['SummaryDomainValues']['AQP3'][19] = u'Sandstone'
    field_information['GGDM 3.0']['SummaryDomainValues']['AQP3'][20] = u'Shale'
    field_information['GGDM 3.0']['SummaryDomainValues']['AQP3'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['AQTC'][2] = u'Open Interval'
    field_information['GGDM 3.0']['SummaryDomainValues']['AQTC'][3] = u'Greater-than-or-equal to Less-than Interval'
    field_information['GGDM 3.0']['SummaryDomainValues']['AQTC'][4] = u'Greater-than to Less-than-or-equal Interval'
    field_information['GGDM 3.0']['SummaryDomainValues']['AQTC'][5] = u'Closed Interval'
    field_information['GGDM 3.0']['SummaryDomainValues']['AQTC'][6] = u'Greater-than Semi-interval'
    field_information['GGDM 3.0']['SummaryDomainValues']['AQTC'][7] = u'Greater-than or Equal Semi-interval'
    field_information['GGDM 3.0']['SummaryDomainValues']['AQTC'][8] = u'Less-than Semi-interval'
    field_information['GGDM 3.0']['SummaryDomainValues']['AQTC'][9] = u'Less-than or Equal Semi-interval'
    field_information['GGDM 3.0']['SummaryDomainValues']['ART'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['ART'][1] = u'Low'
    field_information['GGDM 3.0']['SummaryDomainValues']['ART'][2] = u'High'
    field_information['GGDM 3.0']['SummaryDomainValues']['ART'][3] = u'Both'
    field_information['GGDM 3.0']['SummaryDomainValues']['ASO'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['ASO'][1] = u'Operational'
    field_information['GGDM 3.0']['SummaryDomainValues']['ASO'][2] = u'Unserviceable'
    field_information['GGDM 3.0']['SummaryDomainValues']['ASO'][3] = u'On-Test'
    field_information['GGDM 3.0']['SummaryDomainValues']['ASO'][4] = u'Interrupt'
    field_information['GGDM 3.0']['SummaryDomainValues']['ASO'][6] = u'Conditional'
    field_information['GGDM 3.0']['SummaryDomainValues']['ASO'][7] = u'False Indication Definite'
    field_information['GGDM 3.0']['SummaryDomainValues']['ASO'][8] = u'False Indication Possible'
    field_information['GGDM 3.0']['SummaryDomainValues']['ASO'][10] = u'Displaced'
    field_information['GGDM 3.0']['SummaryDomainValues']['ASO'][11] = u'In Construction'
    field_information['GGDM 3.0']['SummaryDomainValues']['ASO'][12] = u'Withdrawn'
    field_information['GGDM 3.0']['SummaryDomainValues']['ASO'][13] = u'Intermittent'
    field_information['GGDM 3.0']['SummaryDomainValues']['ASO'][14] = u'Irregular'
    field_information['GGDM 3.0']['SummaryDomainValues']['ASO'][15] = u'NAVAID DME Out-of-service'
    field_information['GGDM 3.0']['SummaryDomainValues']['ASO'][16] = u'NAVAID Frequency Out-of-service'
    field_information['GGDM 3.0']['SummaryDomainValues']['ASO'][17] = u'NAVAID Partial Service'
    field_information['GGDM 3.0']['SummaryDomainValues']['ASU'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['ASU'][1] = u'Asphalt'
    field_information['GGDM 3.0']['SummaryDomainValues']['ASU'][2] = u'Bituminous Mix'
    field_information['GGDM 3.0']['SummaryDomainValues']['ASU'][3] = u'Brick'
    field_information['GGDM 3.0']['SummaryDomainValues']['ASU'][4] = u'Clay'
    field_information['GGDM 3.0']['SummaryDomainValues']['ASU'][5] = u'Concrete'
    field_information['GGDM 3.0']['SummaryDomainValues']['ASU'][6] = u'Coral'
    field_information['GGDM 3.0']['SummaryDomainValues']['ASU'][7] = u'Earthen'
    field_information['GGDM 3.0']['SummaryDomainValues']['ASU'][8] = u'Gravel'
    field_information['GGDM 3.0']['SummaryDomainValues']['ASU'][9] = u'Ice'
    field_information['GGDM 3.0']['SummaryDomainValues']['ASU'][10] = u'Landing Mat'
    field_information['GGDM 3.0']['SummaryDomainValues']['ASU'][11] = u'Laterite'
    field_information['GGDM 3.0']['SummaryDomainValues']['ASU'][12] = u'Macadam'
    field_information['GGDM 3.0']['SummaryDomainValues']['ASU'][13] = u'Membrane'
    field_information['GGDM 3.0']['SummaryDomainValues']['ASU'][14] = u'Non-bituminous Mix'
    field_information['GGDM 3.0']['SummaryDomainValues']['ASU'][15] = u'Pierced Steel Planking'
    field_information['GGDM 3.0']['SummaryDomainValues']['ASU'][16] = u'Sand'
    field_information['GGDM 3.0']['SummaryDomainValues']['ASU'][17] = u'Snow'
    field_information['GGDM 3.0']['SummaryDomainValues']['ASU'][18] = u'Stone'
    field_information['GGDM 3.0']['SummaryDomainValues']['ASU'][20] = u'Wood'
    field_information['GGDM 3.0']['SummaryDomainValues']['ASU'][21] = u'Asphalt Over Concrete'
    field_information['GGDM 3.0']['SummaryDomainValues']['ASU'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['ASU2'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['ASU2'][1] = u'Asphalt'
    field_information['GGDM 3.0']['SummaryDomainValues']['ASU2'][2] = u'Bituminous Mix'
    field_information['GGDM 3.0']['SummaryDomainValues']['ASU2'][3] = u'Brick'
    field_information['GGDM 3.0']['SummaryDomainValues']['ASU2'][4] = u'Clay'
    field_information['GGDM 3.0']['SummaryDomainValues']['ASU2'][5] = u'Concrete'
    field_information['GGDM 3.0']['SummaryDomainValues']['ASU2'][6] = u'Coral'
    field_information['GGDM 3.0']['SummaryDomainValues']['ASU2'][7] = u'Earthen'
    field_information['GGDM 3.0']['SummaryDomainValues']['ASU2'][8] = u'Gravel'
    field_information['GGDM 3.0']['SummaryDomainValues']['ASU2'][9] = u'Ice'
    field_information['GGDM 3.0']['SummaryDomainValues']['ASU2'][10] = u'Landing Mat'
    field_information['GGDM 3.0']['SummaryDomainValues']['ASU2'][11] = u'Laterite'
    field_information['GGDM 3.0']['SummaryDomainValues']['ASU2'][12] = u'Macadam'
    field_information['GGDM 3.0']['SummaryDomainValues']['ASU2'][13] = u'Membrane'
    field_information['GGDM 3.0']['SummaryDomainValues']['ASU2'][14] = u'Non-bituminous Mix'
    field_information['GGDM 3.0']['SummaryDomainValues']['ASU2'][15] = u'Pierced Steel Planking'
    field_information['GGDM 3.0']['SummaryDomainValues']['ASU2'][16] = u'Sand'
    field_information['GGDM 3.0']['SummaryDomainValues']['ASU2'][17] = u'Snow'
    field_information['GGDM 3.0']['SummaryDomainValues']['ASU2'][18] = u'Stone'
    field_information['GGDM 3.0']['SummaryDomainValues']['ASU2'][20] = u'Wood'
    field_information['GGDM 3.0']['SummaryDomainValues']['ASU2'][21] = u'Asphalt Over Concrete'
    field_information['GGDM 3.0']['SummaryDomainValues']['ASU2'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['ASU3'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['ASU3'][1] = u'Asphalt'
    field_information['GGDM 3.0']['SummaryDomainValues']['ASU3'][2] = u'Bituminous Mix'
    field_information['GGDM 3.0']['SummaryDomainValues']['ASU3'][3] = u'Brick'
    field_information['GGDM 3.0']['SummaryDomainValues']['ASU3'][4] = u'Clay'
    field_information['GGDM 3.0']['SummaryDomainValues']['ASU3'][5] = u'Concrete'
    field_information['GGDM 3.0']['SummaryDomainValues']['ASU3'][6] = u'Coral'
    field_information['GGDM 3.0']['SummaryDomainValues']['ASU3'][7] = u'Earthen'
    field_information['GGDM 3.0']['SummaryDomainValues']['ASU3'][8] = u'Gravel'
    field_information['GGDM 3.0']['SummaryDomainValues']['ASU3'][9] = u'Ice'
    field_information['GGDM 3.0']['SummaryDomainValues']['ASU3'][10] = u'Landing Mat'
    field_information['GGDM 3.0']['SummaryDomainValues']['ASU3'][11] = u'Laterite'
    field_information['GGDM 3.0']['SummaryDomainValues']['ASU3'][12] = u'Macadam'
    field_information['GGDM 3.0']['SummaryDomainValues']['ASU3'][13] = u'Membrane'
    field_information['GGDM 3.0']['SummaryDomainValues']['ASU3'][14] = u'Non-bituminous Mix'
    field_information['GGDM 3.0']['SummaryDomainValues']['ASU3'][15] = u'Pierced Steel Planking'
    field_information['GGDM 3.0']['SummaryDomainValues']['ASU3'][16] = u'Sand'
    field_information['GGDM 3.0']['SummaryDomainValues']['ASU3'][17] = u'Snow'
    field_information['GGDM 3.0']['SummaryDomainValues']['ASU3'][18] = u'Stone'
    field_information['GGDM 3.0']['SummaryDomainValues']['ASU3'][20] = u'Wood'
    field_information['GGDM 3.0']['SummaryDomainValues']['ASU3'][21] = u'Asphalt Over Concrete'
    field_information['GGDM 3.0']['SummaryDomainValues']['ASU3'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['ASY'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['ASY'][1] = u'A - Active Civilian'
    field_information['GGDM 3.0']['SummaryDomainValues']['ASY'][2] = u'B - Active Joint (Civilian/Military)'
    field_information['GGDM 3.0']['SummaryDomainValues']['ASY'][3] = u'C - Active Military'
    field_information['GGDM 3.0']['SummaryDomainValues']['ASY'][4] = u'D - Active (with less than the minimum facilities)'
    field_information['GGDM 3.0']['SummaryDomainValues']['ASY'][5] = u'E - Abandoned or Closed (with usable runways or landing areas)'
    field_information['GGDM 3.0']['SummaryDomainValues']['ASY'][6] = u'F - Highway Strip'
    field_information['GGDM 3.0']['SummaryDomainValues']['ASY'][7] = u'G - Unusable for landing or take-off'
    field_information['GGDM 3.0']['SummaryDomainValues']['ASY'][8] = u'H - Active Military Heliport'
    field_information['GGDM 3.0']['SummaryDomainValues']['ASY'][9] = u'J - Active Civil Heliport'
    field_information['GGDM 3.0']['SummaryDomainValues']['ASY'][10] = u'K - Active Military Heliport (with less than minimum facilities)'
    field_information['GGDM 3.0']['SummaryDomainValues']['ASY'][11] = u'L - Active Civil Heliport (with less than minimum facilities)'
    field_information['GGDM 3.0']['SummaryDomainValues']['ASY'][12] = u'X - Decoy'
    field_information['GGDM 3.0']['SummaryDomainValues']['ASY'][13] = u'Active Joint (Civilian/Military) Heliport'
    field_information['GGDM 3.0']['SummaryDomainValues']['AT005_CAB'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['AT005_CAB'][2] = u'Power Distribution Line'
    field_information['GGDM 3.0']['SummaryDomainValues']['AT005_CAB'][3] = u'Telephone'
    field_information['GGDM 3.0']['SummaryDomainValues']['AT005_CAB'][4] = u'Telegraph'
    field_information['GGDM 3.0']['SummaryDomainValues']['AT005_CAB'][6] = u'Power Transmission Line'
    field_information['GGDM 3.0']['SummaryDomainValues']['AT005_CAB'][7] = u'Digital Communication Line'
    field_information['GGDM 3.0']['SummaryDomainValues']['AT005_CAB'][8] = u'Communication Line'
    field_information['GGDM 3.0']['SummaryDomainValues']['AT005_CAB'][9] = u'Fibre-optic'
    field_information['GGDM 3.0']['SummaryDomainValues']['AT005_CAB'][10] = u'Tethering'
    field_information['GGDM 3.0']['SummaryDomainValues']['AT005_CAB'][11] = u'Load Bearing'
    field_information['GGDM 3.0']['SummaryDomainValues']['AT005_CAB'][12] = u'Guide'
    field_information['GGDM 3.0']['SummaryDomainValues']['AT005_CAB'][13] = u'Barrier'
    field_information['GGDM 3.0']['SummaryDomainValues']['AT005_CAB'][14] = u'Restraining'
    field_information['GGDM 3.0']['SummaryDomainValues']['AT005_CAB'][15] = u'Towing'
    field_information['GGDM 3.0']['SummaryDomainValues']['AT005_CAB'][19] = u'Cableway'
    field_information['GGDM 3.0']['SummaryDomainValues']['AT005_CAB'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['AT005_CAB2'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['AT005_CAB2'][2] = u'Power Distribution Line'
    field_information['GGDM 3.0']['SummaryDomainValues']['AT005_CAB2'][3] = u'Telephone'
    field_information['GGDM 3.0']['SummaryDomainValues']['AT005_CAB2'][4] = u'Telegraph'
    field_information['GGDM 3.0']['SummaryDomainValues']['AT005_CAB2'][6] = u'Power Transmission Line'
    field_information['GGDM 3.0']['SummaryDomainValues']['AT005_CAB2'][7] = u'Digital Communication Line'
    field_information['GGDM 3.0']['SummaryDomainValues']['AT005_CAB2'][8] = u'Communication Line'
    field_information['GGDM 3.0']['SummaryDomainValues']['AT005_CAB2'][9] = u'Fibre-optic'
    field_information['GGDM 3.0']['SummaryDomainValues']['AT005_CAB2'][10] = u'Tethering'
    field_information['GGDM 3.0']['SummaryDomainValues']['AT005_CAB2'][11] = u'Load Bearing'
    field_information['GGDM 3.0']['SummaryDomainValues']['AT005_CAB2'][12] = u'Guide'
    field_information['GGDM 3.0']['SummaryDomainValues']['AT005_CAB2'][13] = u'Barrier'
    field_information['GGDM 3.0']['SummaryDomainValues']['AT005_CAB2'][14] = u'Restraining'
    field_information['GGDM 3.0']['SummaryDomainValues']['AT005_CAB2'][15] = u'Towing'
    field_information['GGDM 3.0']['SummaryDomainValues']['AT005_CAB2'][19] = u'Cableway'
    field_information['GGDM 3.0']['SummaryDomainValues']['AT005_CAB2'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['AT005_CAB3'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['AT005_CAB3'][2] = u'Power Distribution Line'
    field_information['GGDM 3.0']['SummaryDomainValues']['AT005_CAB3'][3] = u'Telephone'
    field_information['GGDM 3.0']['SummaryDomainValues']['AT005_CAB3'][4] = u'Telegraph'
    field_information['GGDM 3.0']['SummaryDomainValues']['AT005_CAB3'][6] = u'Power Transmission Line'
    field_information['GGDM 3.0']['SummaryDomainValues']['AT005_CAB3'][7] = u'Digital Communication Line'
    field_information['GGDM 3.0']['SummaryDomainValues']['AT005_CAB3'][8] = u'Communication Line'
    field_information['GGDM 3.0']['SummaryDomainValues']['AT005_CAB3'][9] = u'Fibre-optic'
    field_information['GGDM 3.0']['SummaryDomainValues']['AT005_CAB3'][10] = u'Tethering'
    field_information['GGDM 3.0']['SummaryDomainValues']['AT005_CAB3'][11] = u'Load Bearing'
    field_information['GGDM 3.0']['SummaryDomainValues']['AT005_CAB3'][12] = u'Guide'
    field_information['GGDM 3.0']['SummaryDomainValues']['AT005_CAB3'][13] = u'Barrier'
    field_information['GGDM 3.0']['SummaryDomainValues']['AT005_CAB3'][14] = u'Restraining'
    field_information['GGDM 3.0']['SummaryDomainValues']['AT005_CAB3'][15] = u'Towing'
    field_information['GGDM 3.0']['SummaryDomainValues']['AT005_CAB3'][19] = u'Cableway'
    field_information['GGDM 3.0']['SummaryDomainValues']['AT005_CAB3'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['ATB'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['ATB'][1000] = u'False'
    field_information['GGDM 3.0']['SummaryDomainValues']['ATB'][1001] = u'True'
    field_information['GGDM 3.0']['SummaryDomainValues']['ATC'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['ATC'][3] = u'Underground'
    field_information['GGDM 3.0']['SummaryDomainValues']['ATC'][4] = u'Underwater'
    field_information['GGDM 3.0']['SummaryDomainValues']['ATC'][5] = u'Surface'
    field_information['GGDM 3.0']['SummaryDomainValues']['ATC'][6] = u'Qanat'
    field_information['GGDM 3.0']['SummaryDomainValues']['AWP'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['AWP'][1000] = u'False'
    field_information['GGDM 3.0']['SummaryDomainValues']['AWP'][1001] = u'True'
    field_information['GGDM 3.0']['SummaryDomainValues']['AXS'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['AXS'][1] = u'Closed'
    field_information['GGDM 3.0']['SummaryDomainValues']['AXS'][2] = u'Open'
    field_information['GGDM 3.0']['SummaryDomainValues']['AXS'][3] = u'Work in Progress'
    field_information['GGDM 3.0']['SummaryDomainValues']['AXS'][4] = u'Parked or Disabled Aircraft'
    field_information['GGDM 3.0']['SummaryDomainValues']['AYRC'][2] = u'Open Interval'
    field_information['GGDM 3.0']['SummaryDomainValues']['AYRC'][3] = u'Greater-than-or-equal to Less-than Interval'
    field_information['GGDM 3.0']['SummaryDomainValues']['AYRC'][4] = u'Greater-than to Less-than-or-equal Interval'
    field_information['GGDM 3.0']['SummaryDomainValues']['AYRC'][5] = u'Closed Interval'
    field_information['GGDM 3.0']['SummaryDomainValues']['AYRC'][6] = u'Greater-than Semi-interval'
    field_information['GGDM 3.0']['SummaryDomainValues']['AYRC'][7] = u'Greater-than or Equal Semi-interval'
    field_information['GGDM 3.0']['SummaryDomainValues']['AYRC'][8] = u'Less-than Semi-interval'
    field_information['GGDM 3.0']['SummaryDomainValues']['AYRC'][9] = u'Less-than or Equal Semi-interval'
    field_information['GGDM 3.0']['SummaryDomainValues']['AZC'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['AZC'][1000] = u'False'
    field_information['GGDM 3.0']['SummaryDomainValues']['AZC'][1001] = u'True'
    field_information['GGDM 3.0']['SummaryDomainValues']['BA000_VDC'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['BA000_VDC'][4] = u'Indian Spring Low Water'
    field_information['GGDM 3.0']['SummaryDomainValues']['BA000_VDC'][7] = u'Mean High Water'
    field_information['GGDM 3.0']['SummaryDomainValues']['BA000_VDC'][9] = u'Mean High Water Springs'
    field_information['GGDM 3.0']['SummaryDomainValues']['BA000_VDC'][10] = u'Mean Higher High Water'
    field_information['GGDM 3.0']['SummaryDomainValues']['BA000_VDC'][11] = u'Mean Low Water'
    field_information['GGDM 3.0']['SummaryDomainValues']['BA000_VDC'][13] = u'Mean Low Water Springs'
    field_information['GGDM 3.0']['SummaryDomainValues']['BA000_VDC'][14] = u'Mean Lower Low Water'
    field_information['GGDM 3.0']['SummaryDomainValues']['BA000_VDC'][15] = u'Mean Sea Level'
    field_information['GGDM 3.0']['SummaryDomainValues']['BA000_VDC'][19] = u'Mean Lower Low Water Springs'
    field_information['GGDM 3.0']['SummaryDomainValues']['BA000_VDC'][20] = u'Lowest Astronomical Tide'
    field_information['GGDM 3.0']['SummaryDomainValues']['BA000_VDC'][24] = u'Mean Higher High Water Springs'
    field_information['GGDM 3.0']['SummaryDomainValues']['BA000_VDC'][28] = u'Highest High Water'
    field_information['GGDM 3.0']['SummaryDomainValues']['BA000_VDC'][30] = u'Indian Spring High Water'
    field_information['GGDM 3.0']['SummaryDomainValues']['BA000_VDC'][90] = u'Lowest Low Water'
    field_information['GGDM 3.0']['SummaryDomainValues']['BA000_VDC'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['BAC'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['BAC'][1] = u'Sparse'
    field_information['GGDM 3.0']['SummaryDomainValues']['BAC'][2] = u'Dense'
    field_information['GGDM 3.0']['SummaryDomainValues']['BAC'][3] = u'Moderate'
    field_information['GGDM 3.0']['SummaryDomainValues']['BAT'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['BAT'][1] = u'Barbed Wire'
    field_information['GGDM 3.0']['SummaryDomainValues']['BAT'][2] = u'Chain-link'
    field_information['GGDM 3.0']['SummaryDomainValues']['BAT'][3] = u'Concertina Wire'
    field_information['GGDM 3.0']['SummaryDomainValues']['BAT'][4] = u'Electrified Wire'
    field_information['GGDM 3.0']['SummaryDomainValues']['BAT'][5] = u'Spiked'
    field_information['GGDM 3.0']['SummaryDomainValues']['BAT'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['BBMCA'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['BBMCA'][1] = u'Clay and Silt'
    field_information['GGDM 3.0']['SummaryDomainValues']['BBMCA'][2] = u'Silty Sands'
    field_information['GGDM 3.0']['SummaryDomainValues']['BBMCA'][3] = u'Sand and Gravel'
    field_information['GGDM 3.0']['SummaryDomainValues']['BBMCA'][4] = u'Gravel and Cobble'
    field_information['GGDM 3.0']['SummaryDomainValues']['BBMCA'][5] = u'Rocks and Boulders'
    field_information['GGDM 3.0']['SummaryDomainValues']['BBMCA'][6] = u'Bedrock'
    field_information['GGDM 3.0']['SummaryDomainValues']['BBMCA'][7] = u'Paved'
    field_information['GGDM 3.0']['SummaryDomainValues']['BBMCA'][8] = u'Peat'
    field_information['GGDM 3.0']['SummaryDomainValues']['BBMCA'][9] = u'Sand over Mud'
    field_information['GGDM 3.0']['SummaryDomainValues']['BBMCA'][11] = u'Coral'
    field_information['GGDM 3.0']['SummaryDomainValues']['BBMCA'][14] = u'Sand'
    field_information['GGDM 3.0']['SummaryDomainValues']['BBMCA'][15] = u'Concrete'
    field_information['GGDM 3.0']['SummaryDomainValues']['BBMCA'][16] = u'Masonry'
    field_information['GGDM 3.0']['SummaryDomainValues']['BBMCA'][17] = u'Reinforced Concrete'
    field_information['GGDM 3.0']['SummaryDomainValues']['BBMCA'][18] = u'Soil'
    field_information['GGDM 3.0']['SummaryDomainValues']['BBMCA'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['BBMCA2'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['BBMCA2'][1] = u'Clay and Silt'
    field_information['GGDM 3.0']['SummaryDomainValues']['BBMCA2'][2] = u'Silty Sands'
    field_information['GGDM 3.0']['SummaryDomainValues']['BBMCA2'][3] = u'Sand and Gravel'
    field_information['GGDM 3.0']['SummaryDomainValues']['BBMCA2'][4] = u'Gravel and Cobble'
    field_information['GGDM 3.0']['SummaryDomainValues']['BBMCA2'][5] = u'Rocks and Boulders'
    field_information['GGDM 3.0']['SummaryDomainValues']['BBMCA2'][6] = u'Bedrock'
    field_information['GGDM 3.0']['SummaryDomainValues']['BBMCA2'][7] = u'Paved'
    field_information['GGDM 3.0']['SummaryDomainValues']['BBMCA2'][8] = u'Peat'
    field_information['GGDM 3.0']['SummaryDomainValues']['BBMCA2'][9] = u'Sand over Mud'
    field_information['GGDM 3.0']['SummaryDomainValues']['BBMCA2'][11] = u'Coral'
    field_information['GGDM 3.0']['SummaryDomainValues']['BBMCA2'][14] = u'Sand'
    field_information['GGDM 3.0']['SummaryDomainValues']['BBMCA2'][15] = u'Concrete'
    field_information['GGDM 3.0']['SummaryDomainValues']['BBMCA2'][16] = u'Masonry'
    field_information['GGDM 3.0']['SummaryDomainValues']['BBMCA2'][17] = u'Reinforced Concrete'
    field_information['GGDM 3.0']['SummaryDomainValues']['BBMCA2'][18] = u'Soil'
    field_information['GGDM 3.0']['SummaryDomainValues']['BBMCA2'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['BBMCA3'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['BBMCA3'][1] = u'Clay and Silt'
    field_information['GGDM 3.0']['SummaryDomainValues']['BBMCA3'][2] = u'Silty Sands'
    field_information['GGDM 3.0']['SummaryDomainValues']['BBMCA3'][3] = u'Sand and Gravel'
    field_information['GGDM 3.0']['SummaryDomainValues']['BBMCA3'][4] = u'Gravel and Cobble'
    field_information['GGDM 3.0']['SummaryDomainValues']['BBMCA3'][5] = u'Rocks and Boulders'
    field_information['GGDM 3.0']['SummaryDomainValues']['BBMCA3'][6] = u'Bedrock'
    field_information['GGDM 3.0']['SummaryDomainValues']['BBMCA3'][7] = u'Paved'
    field_information['GGDM 3.0']['SummaryDomainValues']['BBMCA3'][8] = u'Peat'
    field_information['GGDM 3.0']['SummaryDomainValues']['BBMCA3'][9] = u'Sand over Mud'
    field_information['GGDM 3.0']['SummaryDomainValues']['BBMCA3'][11] = u'Coral'
    field_information['GGDM 3.0']['SummaryDomainValues']['BBMCA3'][14] = u'Sand'
    field_information['GGDM 3.0']['SummaryDomainValues']['BBMCA3'][15] = u'Concrete'
    field_information['GGDM 3.0']['SummaryDomainValues']['BBMCA3'][16] = u'Masonry'
    field_information['GGDM 3.0']['SummaryDomainValues']['BBMCA3'][17] = u'Reinforced Concrete'
    field_information['GGDM 3.0']['SummaryDomainValues']['BBMCA3'][18] = u'Soil'
    field_information['GGDM 3.0']['SummaryDomainValues']['BBMCA3'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['BBMCB'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['BBMCB'][1] = u'Clay and Silt'
    field_information['GGDM 3.0']['SummaryDomainValues']['BBMCB'][2] = u'Silty Sands'
    field_information['GGDM 3.0']['SummaryDomainValues']['BBMCB'][3] = u'Sand and Gravel'
    field_information['GGDM 3.0']['SummaryDomainValues']['BBMCB'][4] = u'Gravel and Cobble'
    field_information['GGDM 3.0']['SummaryDomainValues']['BBMCB'][5] = u'Rocks and Boulders'
    field_information['GGDM 3.0']['SummaryDomainValues']['BBMCB'][6] = u'Bedrock'
    field_information['GGDM 3.0']['SummaryDomainValues']['BBMCB'][7] = u'Paved'
    field_information['GGDM 3.0']['SummaryDomainValues']['BBMCB'][8] = u'Peat'
    field_information['GGDM 3.0']['SummaryDomainValues']['BBMCB'][9] = u'Sand over Mud'
    field_information['GGDM 3.0']['SummaryDomainValues']['BBMCB'][11] = u'Coral'
    field_information['GGDM 3.0']['SummaryDomainValues']['BBMCB'][14] = u'Sand'
    field_information['GGDM 3.0']['SummaryDomainValues']['BBMCB'][15] = u'Concrete'
    field_information['GGDM 3.0']['SummaryDomainValues']['BBMCB'][16] = u'Masonry'
    field_information['GGDM 3.0']['SummaryDomainValues']['BBMCB'][17] = u'Reinforced Concrete'
    field_information['GGDM 3.0']['SummaryDomainValues']['BBMCB'][18] = u'Soil'
    field_information['GGDM 3.0']['SummaryDomainValues']['BBMCB'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['BBMCB2'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['BBMCB2'][1] = u'Clay and Silt'
    field_information['GGDM 3.0']['SummaryDomainValues']['BBMCB2'][2] = u'Silty Sands'
    field_information['GGDM 3.0']['SummaryDomainValues']['BBMCB2'][3] = u'Sand and Gravel'
    field_information['GGDM 3.0']['SummaryDomainValues']['BBMCB2'][4] = u'Gravel and Cobble'
    field_information['GGDM 3.0']['SummaryDomainValues']['BBMCB2'][5] = u'Rocks and Boulders'
    field_information['GGDM 3.0']['SummaryDomainValues']['BBMCB2'][6] = u'Bedrock'
    field_information['GGDM 3.0']['SummaryDomainValues']['BBMCB2'][7] = u'Paved'
    field_information['GGDM 3.0']['SummaryDomainValues']['BBMCB2'][8] = u'Peat'
    field_information['GGDM 3.0']['SummaryDomainValues']['BBMCB2'][9] = u'Sand over Mud'
    field_information['GGDM 3.0']['SummaryDomainValues']['BBMCB2'][11] = u'Coral'
    field_information['GGDM 3.0']['SummaryDomainValues']['BBMCB2'][14] = u'Sand'
    field_information['GGDM 3.0']['SummaryDomainValues']['BBMCB2'][15] = u'Concrete'
    field_information['GGDM 3.0']['SummaryDomainValues']['BBMCB2'][16] = u'Masonry'
    field_information['GGDM 3.0']['SummaryDomainValues']['BBMCB2'][17] = u'Reinforced Concrete'
    field_information['GGDM 3.0']['SummaryDomainValues']['BBMCB2'][18] = u'Soil'
    field_information['GGDM 3.0']['SummaryDomainValues']['BBMCB2'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['BBMCB3'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['BBMCB3'][1] = u'Clay and Silt'
    field_information['GGDM 3.0']['SummaryDomainValues']['BBMCB3'][2] = u'Silty Sands'
    field_information['GGDM 3.0']['SummaryDomainValues']['BBMCB3'][3] = u'Sand and Gravel'
    field_information['GGDM 3.0']['SummaryDomainValues']['BBMCB3'][4] = u'Gravel and Cobble'
    field_information['GGDM 3.0']['SummaryDomainValues']['BBMCB3'][5] = u'Rocks and Boulders'
    field_information['GGDM 3.0']['SummaryDomainValues']['BBMCB3'][6] = u'Bedrock'
    field_information['GGDM 3.0']['SummaryDomainValues']['BBMCB3'][7] = u'Paved'
    field_information['GGDM 3.0']['SummaryDomainValues']['BBMCB3'][8] = u'Peat'
    field_information['GGDM 3.0']['SummaryDomainValues']['BBMCB3'][9] = u'Sand over Mud'
    field_information['GGDM 3.0']['SummaryDomainValues']['BBMCB3'][11] = u'Coral'
    field_information['GGDM 3.0']['SummaryDomainValues']['BBMCB3'][14] = u'Sand'
    field_information['GGDM 3.0']['SummaryDomainValues']['BBMCB3'][15] = u'Concrete'
    field_information['GGDM 3.0']['SummaryDomainValues']['BBMCB3'][16] = u'Masonry'
    field_information['GGDM 3.0']['SummaryDomainValues']['BBMCB3'][17] = u'Reinforced Concrete'
    field_information['GGDM 3.0']['SummaryDomainValues']['BBMCB3'][18] = u'Soil'
    field_information['GGDM 3.0']['SummaryDomainValues']['BBMCB3'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['BC010_REF'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['BC010_REF'][1000] = u'False'
    field_information['GGDM 3.0']['SummaryDomainValues']['BC010_REF'][1001] = u'True'
    field_information['GGDM 3.0']['SummaryDomainValues']['BC010_TZP'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['BC010_TZP'][1] = u'Cone Point Upward'
    field_information['GGDM 3.0']['SummaryDomainValues']['BC010_TZP'][2] = u'Cone Point Downward'
    field_information['GGDM 3.0']['SummaryDomainValues']['BC010_TZP'][3] = u'Sphere'
    field_information['GGDM 3.0']['SummaryDomainValues']['BC010_TZP'][4] = u'2 Spheres One over Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['BC010_TZP'][5] = u'Cylinder'
    field_information['GGDM 3.0']['SummaryDomainValues']['BC010_TZP'][6] = u'Board'
    field_information['GGDM 3.0']['SummaryDomainValues']['BC010_TZP'][7] = u'X-shaped'
    field_information['GGDM 3.0']['SummaryDomainValues']['BC010_TZP'][8] = u'Upright Cross'
    field_information['GGDM 3.0']['SummaryDomainValues']['BC010_TZP'][9] = u'Cube Point Upward'
    field_information['GGDM 3.0']['SummaryDomainValues']['BC010_TZP'][10] = u'2 Cones Point to Point'
    field_information['GGDM 3.0']['SummaryDomainValues']['BC010_TZP'][11] = u'2 Cones Base to Base'
    field_information['GGDM 3.0']['SummaryDomainValues']['BC010_TZP'][12] = u'Diamond'
    field_information['GGDM 3.0']['SummaryDomainValues']['BC010_TZP'][13] = u'2 Cones Points Upward'
    field_information['GGDM 3.0']['SummaryDomainValues']['BC010_TZP'][14] = u'2 Cones Points Downward'
    field_information['GGDM 3.0']['SummaryDomainValues']['BC010_TZP'][15] = u'Besom Point Upward'
    field_information['GGDM 3.0']['SummaryDomainValues']['BC010_TZP'][16] = u'Besom Point Downward'
    field_information['GGDM 3.0']['SummaryDomainValues']['BC010_TZP'][17] = u'Flag'
    field_information['GGDM 3.0']['SummaryDomainValues']['BC010_TZP'][18] = u'Sphere over Diamond'
    field_information['GGDM 3.0']['SummaryDomainValues']['BC010_TZP'][19] = u'Square'
    field_information['GGDM 3.0']['SummaryDomainValues']['BC010_TZP'][20] = u'Horizontal Rectangle'
    field_information['GGDM 3.0']['SummaryDomainValues']['BC010_TZP'][21] = u'Vertical Rectangle'
    field_information['GGDM 3.0']['SummaryDomainValues']['BC010_TZP'][22] = u'Trapezium Short Upward'
    field_information['GGDM 3.0']['SummaryDomainValues']['BC010_TZP'][23] = u'Trapezium Short Downward'
    field_information['GGDM 3.0']['SummaryDomainValues']['BC010_TZP'][24] = u'Triangle Point Upward'
    field_information['GGDM 3.0']['SummaryDomainValues']['BC010_TZP'][25] = u'Triangle Point Downward'
    field_information['GGDM 3.0']['SummaryDomainValues']['BC010_TZP'][26] = u'Circle'
    field_information['GGDM 3.0']['SummaryDomainValues']['BC010_TZP'][27] = u'2 Upright Crosses'
    field_information['GGDM 3.0']['SummaryDomainValues']['BC010_TZP'][28] = u'T-shaped'
    field_information['GGDM 3.0']['SummaryDomainValues']['BC010_TZP'][29] = u'Triangle Point Upward over Circle'
    field_information['GGDM 3.0']['SummaryDomainValues']['BC010_TZP'][30] = u'Upright Cross over Circle'
    field_information['GGDM 3.0']['SummaryDomainValues']['BC010_TZP'][31] = u'Diamond over Circle'
    field_information['GGDM 3.0']['SummaryDomainValues']['BC010_TZP'][32] = u'Circle over Triangle Point Upward'
    field_information['GGDM 3.0']['SummaryDomainValues']['BC010_TZP'][33] = u'Ball over Cone'
    field_information['GGDM 3.0']['SummaryDomainValues']['BC010_TZP'][34] = u'Can over Ball'
    field_information['GGDM 3.0']['SummaryDomainValues']['BC010_TZP'][35] = u'Cone over Ball'
    field_information['GGDM 3.0']['SummaryDomainValues']['BC010_TZP'][36] = u'Cross over Ball'
    field_information['GGDM 3.0']['SummaryDomainValues']['BC010_TZP'][37] = u'Diamond over Ball'
    field_information['GGDM 3.0']['SummaryDomainValues']['BC010_TZP'][998] = u'Not Applicable'
    field_information['GGDM 3.0']['SummaryDomainValues']['BC010_TZP'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['BC034_MRT'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['BC034_MRT'][1] = u'Automated Identification System (AIS)'
    field_information['GGDM 3.0']['SummaryDomainValues']['BC034_MRT'][2] = u'Circular Radiobeacon'
    field_information['GGDM 3.0']['SummaryDomainValues']['BC034_MRT'][3] = u'Directional Radiobeacon'
    field_information['GGDM 3.0']['SummaryDomainValues']['BC034_MRT'][4] = u'Long Range Air Navigation System (LORAN) C'
    field_information['GGDM 3.0']['SummaryDomainValues']['BC034_MRT'][5] = u'QTG Station'
    field_information['GGDM 3.0']['SummaryDomainValues']['BC034_MRT'][6] = u'Radar Marker (RAMARK)'
    field_information['GGDM 3.0']['SummaryDomainValues']['BC034_MRT'][7] = u'Radar Responder Beacon (RACON)'
    field_information['GGDM 3.0']['SummaryDomainValues']['BC034_MRT'][8] = u'Radio Direction Finding Station'
    field_information['GGDM 3.0']['SummaryDomainValues']['BC034_MRT'][9] = u'Rotating Pattern Radiobeacon'
    field_information['GGDM 3.0']['SummaryDomainValues']['BC034_MRT'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['BC034_MRT2'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['BC034_MRT2'][1] = u'Automated Identification System (AIS)'
    field_information['GGDM 3.0']['SummaryDomainValues']['BC034_MRT2'][2] = u'Circular Radiobeacon'
    field_information['GGDM 3.0']['SummaryDomainValues']['BC034_MRT2'][3] = u'Directional Radiobeacon'
    field_information['GGDM 3.0']['SummaryDomainValues']['BC034_MRT2'][4] = u'Long Range Air Navigation System (LORAN) C'
    field_information['GGDM 3.0']['SummaryDomainValues']['BC034_MRT2'][5] = u'QTG Station'
    field_information['GGDM 3.0']['SummaryDomainValues']['BC034_MRT2'][6] = u'Radar Marker (RAMARK)'
    field_information['GGDM 3.0']['SummaryDomainValues']['BC034_MRT2'][7] = u'Radar Responder Beacon (RACON)'
    field_information['GGDM 3.0']['SummaryDomainValues']['BC034_MRT2'][8] = u'Radio Direction Finding Station'
    field_information['GGDM 3.0']['SummaryDomainValues']['BC034_MRT2'][9] = u'Rotating Pattern Radiobeacon'
    field_information['GGDM 3.0']['SummaryDomainValues']['BC034_MRT2'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['BC034_MRT3'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['BC034_MRT3'][1] = u'Automated Identification System (AIS)'
    field_information['GGDM 3.0']['SummaryDomainValues']['BC034_MRT3'][2] = u'Circular Radiobeacon'
    field_information['GGDM 3.0']['SummaryDomainValues']['BC034_MRT3'][3] = u'Directional Radiobeacon'
    field_information['GGDM 3.0']['SummaryDomainValues']['BC034_MRT3'][4] = u'Long Range Air Navigation System (LORAN) C'
    field_information['GGDM 3.0']['SummaryDomainValues']['BC034_MRT3'][5] = u'QTG Station'
    field_information['GGDM 3.0']['SummaryDomainValues']['BC034_MRT3'][6] = u'Radar Marker (RAMARK)'
    field_information['GGDM 3.0']['SummaryDomainValues']['BC034_MRT3'][7] = u'Radar Responder Beacon (RACON)'
    field_information['GGDM 3.0']['SummaryDomainValues']['BC034_MRT3'][8] = u'Radio Direction Finding Station'
    field_information['GGDM 3.0']['SummaryDomainValues']['BC034_MRT3'][9] = u'Rotating Pattern Radiobeacon'
    field_information['GGDM 3.0']['SummaryDomainValues']['BC034_MRT3'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['BC040_CAA'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['BC040_CAA'][3] = u'Private'
    field_information['GGDM 3.0']['SummaryDomainValues']['BC040_CAA'][5] = u'Military'
    field_information['GGDM 3.0']['SummaryDomainValues']['BC040_CAA'][7] = u'Joint Military and Civilian'
    field_information['GGDM 3.0']['SummaryDomainValues']['BC040_CAA'][16] = u'Civilian'
    field_information['GGDM 3.0']['SummaryDomainValues']['BC040_CAA'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['BC101_SST'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['BC101_SST'][1] = u'Bell'
    field_information['GGDM 3.0']['SummaryDomainValues']['BC101_SST'][2] = u'Diaphone'
    field_information['GGDM 3.0']['SummaryDomainValues']['BC101_SST'][3] = u'Explosive'
    field_information['GGDM 3.0']['SummaryDomainValues']['BC101_SST'][4] = u'Gong'
    field_information['GGDM 3.0']['SummaryDomainValues']['BC101_SST'][6] = u'Horn'
    field_information['GGDM 3.0']['SummaryDomainValues']['BC101_SST'][7] = u'Nautophone'
    field_information['GGDM 3.0']['SummaryDomainValues']['BC101_SST'][8] = u'Radio'
    field_information['GGDM 3.0']['SummaryDomainValues']['BC101_SST'][9] = u'Siren'
    field_information['GGDM 3.0']['SummaryDomainValues']['BC101_SST'][10] = u'Submarine Bell'
    field_information['GGDM 3.0']['SummaryDomainValues']['BC101_SST'][14] = u'Whistle'
    field_information['GGDM 3.0']['SummaryDomainValues']['BC101_SST'][15] = u'Reed'
    field_information['GGDM 3.0']['SummaryDomainValues']['BC101_SST'][16] = u'None'
    field_information['GGDM 3.0']['SummaryDomainValues']['BC101_SST'][98] = u'Tyfon'
    field_information['GGDM 3.0']['SummaryDomainValues']['BC101_SST'][998] = u'Not Applicable'
    field_information['GGDM 3.0']['SummaryDomainValues']['BC101_SST'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['BCC'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['BCC'][1] = u'Easy'
    field_information['GGDM 3.0']['SummaryDomainValues']['BCC'][2] = u'Difficult'
    field_information['GGDM 3.0']['SummaryDomainValues']['BCC'][3] = u'Impossible'
    field_information['GGDM 3.0']['SummaryDomainValues']['BDS'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['BDS'][1000] = u'False'
    field_information['GGDM 3.0']['SummaryDomainValues']['BDS'][1001] = u'True'
    field_information['GGDM 3.0']['SummaryDomainValues']['BET'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['BET'][7] = u'Mooring'
    field_information['GGDM 3.0']['SummaryDomainValues']['BET'][11] = u'Landfall'
    field_information['GGDM 3.0']['SummaryDomainValues']['BET'][20] = u'Fairway'
    field_information['GGDM 3.0']['SummaryDomainValues']['BET'][21] = u'Mid-Channel'
    field_information['GGDM 3.0']['SummaryDomainValues']['BET'][22] = u'Bifurcation'
    field_information['GGDM 3.0']['SummaryDomainValues']['BET'][23] = u'Junction'
    field_information['GGDM 3.0']['SummaryDomainValues']['BET'][24] = u'Wreck'
    field_information['GGDM 3.0']['SummaryDomainValues']['BET'][25] = u'Obstruction'
    field_information['GGDM 3.0']['SummaryDomainValues']['BET'][26] = u'Telegraph Cable'
    field_information['GGDM 3.0']['SummaryDomainValues']['BET'][27] = u'Warping'
    field_information['GGDM 3.0']['SummaryDomainValues']['BET'][28] = u'Quarantine'
    field_information['GGDM 3.0']['SummaryDomainValues']['BET'][29] = u'Exercise Area'
    field_information['GGDM 3.0']['SummaryDomainValues']['BET'][30] = u'Explosive Anchorage'
    field_information['GGDM 3.0']['SummaryDomainValues']['BET'][31] = u'Aeronautical Anchorage'
    field_information['GGDM 3.0']['SummaryDomainValues']['BET'][32] = u'Compass Adjustment'
    field_information['GGDM 3.0']['SummaryDomainValues']['BET'][33] = u'Fish Trap'
    field_information['GGDM 3.0']['SummaryDomainValues']['BET'][34] = u'Spoil Ground'
    field_information['GGDM 3.0']['SummaryDomainValues']['BET'][39] = u'Trot'
    field_information['GGDM 3.0']['SummaryDomainValues']['BET'][44] = u'Firing Danger Area'
    field_information['GGDM 3.0']['SummaryDomainValues']['BET'][45] = u'Target'
    field_information['GGDM 3.0']['SummaryDomainValues']['BET'][46] = u'Marker Ship'
    field_information['GGDM 3.0']['SummaryDomainValues']['BET'][47] = u'Degaussing Range'
    field_information['GGDM 3.0']['SummaryDomainValues']['BET'][48] = u'Barge'
    field_information['GGDM 3.0']['SummaryDomainValues']['BET'][49] = u'Cable'
    field_information['GGDM 3.0']['SummaryDomainValues']['BET'][50] = u'Outfall'
    field_information['GGDM 3.0']['SummaryDomainValues']['BET'][51] = u'Recording'
    field_information['GGDM 3.0']['SummaryDomainValues']['BET'][52] = u'Recreation Zone'
    field_information['GGDM 3.0']['SummaryDomainValues']['BET'][53] = u'Leading Line'
    field_information['GGDM 3.0']['SummaryDomainValues']['BET'][54] = u'Measured Distance'
    field_information['GGDM 3.0']['SummaryDomainValues']['BET'][55] = u'TSS'
    field_information['GGDM 3.0']['SummaryDomainValues']['BET'][56] = u'Anchoring Prohibited'
    field_information['GGDM 3.0']['SummaryDomainValues']['BET'][57] = u'Berthing Prohibited'
    field_information['GGDM 3.0']['SummaryDomainValues']['BET'][58] = u'Overtaking Prohibited'
    field_information['GGDM 3.0']['SummaryDomainValues']['BET'][59] = u'Two-Way Traffic Prohibited'
    field_information['GGDM 3.0']['SummaryDomainValues']['BET'][60] = u'Reduced Wake'
    field_information['GGDM 3.0']['SummaryDomainValues']['BET'][61] = u'Speed Limit'
    field_information['GGDM 3.0']['SummaryDomainValues']['BET'][62] = u'Stop'
    field_information['GGDM 3.0']['SummaryDomainValues']['BET'][63] = u'Sound Ship\'s Siren'
    field_information['GGDM 3.0']['SummaryDomainValues']['BET'][64] = u'Restricted Vertical Clearance'
    field_information['GGDM 3.0']['SummaryDomainValues']['BET'][65] = u'Maximum Vessel\'s Draught'
    field_information['GGDM 3.0']['SummaryDomainValues']['BET'][66] = u'Restricted Horizontal Clearance'
    field_information['GGDM 3.0']['SummaryDomainValues']['BET'][67] = u'Strong Current Warning'
    field_information['GGDM 3.0']['SummaryDomainValues']['BET'][68] = u'Berthing Permitted'
    field_information['GGDM 3.0']['SummaryDomainValues']['BET'][69] = u'Overhead Power Cable'
    field_information['GGDM 3.0']['SummaryDomainValues']['BET'][70] = u'Channel Edge Gradient'
    field_information['GGDM 3.0']['SummaryDomainValues']['BET'][71] = u'Telephone'
    field_information['GGDM 3.0']['SummaryDomainValues']['BET'][72] = u'Ferry Crossing'
    field_information['GGDM 3.0']['SummaryDomainValues']['BET'][73] = u'Pipeline'
    field_information['GGDM 3.0']['SummaryDomainValues']['BET'][74] = u'Clearing Line'
    field_information['GGDM 3.0']['SummaryDomainValues']['BET'][75] = u'Refuge'
    field_information['GGDM 3.0']['SummaryDomainValues']['BET'][76] = u'Foul Ground'
    field_information['GGDM 3.0']['SummaryDomainValues']['BET'][77] = u'Yachting'
    field_information['GGDM 3.0']['SummaryDomainValues']['BET'][78] = u'Heliport'
    field_information['GGDM 3.0']['SummaryDomainValues']['BET'][79] = u'GPS Mark'
    field_information['GGDM 3.0']['SummaryDomainValues']['BET'][80] = u'Seaplane Landing'
    field_information['GGDM 3.0']['SummaryDomainValues']['BET'][81] = u'Diving'
    field_information['GGDM 3.0']['SummaryDomainValues']['BET'][86] = u'Private'
    field_information['GGDM 3.0']['SummaryDomainValues']['BET'][87] = u'Swim'
    field_information['GGDM 3.0']['SummaryDomainValues']['BET'][91] = u'Preferred Channel to Port'
    field_information['GGDM 3.0']['SummaryDomainValues']['BET'][92] = u'Preferred Channel to Starboard'
    field_information['GGDM 3.0']['SummaryDomainValues']['BET'][93] = u'Starboard-hand Edge'
    field_information['GGDM 3.0']['SummaryDomainValues']['BET'][94] = u'Port-hand Edge'
    field_information['GGDM 3.0']['SummaryDomainValues']['BET'][95] = u'West Cardinal'
    field_information['GGDM 3.0']['SummaryDomainValues']['BET'][96] = u'South Cardinal'
    field_information['GGDM 3.0']['SummaryDomainValues']['BET'][97] = u'East Cardinal'
    field_information['GGDM 3.0']['SummaryDomainValues']['BET'][98] = u'North Cardinal'
    field_information['GGDM 3.0']['SummaryDomainValues']['BET'][101] = u'Wavemeter'
    field_information['GGDM 3.0']['SummaryDomainValues']['BET'][102] = u'Entry Prohibited'
    field_information['GGDM 3.0']['SummaryDomainValues']['BET'][103] = u'Work In Progress'
    field_information['GGDM 3.0']['SummaryDomainValues']['BET'][111] = u'Wellhead'
    field_information['GGDM 3.0']['SummaryDomainValues']['BET'][113] = u'Marine Farm'
    field_information['GGDM 3.0']['SummaryDomainValues']['BET'][114] = u'Artificial Reef'
    field_information['GGDM 3.0']['SummaryDomainValues']['BET'][115] = u'Special'
    field_information['GGDM 3.0']['SummaryDomainValues']['BET'][116] = u'Notice'
    field_information['GGDM 3.0']['SummaryDomainValues']['BET'][117] = u'General Warning'
    field_information['GGDM 3.0']['SummaryDomainValues']['BET'][118] = u'Anchorage'
    field_information['GGDM 3.0']['SummaryDomainValues']['BET'][119] = u'Control'
    field_information['GGDM 3.0']['SummaryDomainValues']['BET'][122] = u'Safe Water'
    field_information['GGDM 3.0']['SummaryDomainValues']['BET'][123] = u'Isolated Danger'
    field_information['GGDM 3.0']['SummaryDomainValues']['BET'][998] = u'Not Applicable'
    field_information['GGDM 3.0']['SummaryDomainValues']['BET'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['BGT'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['BGT'][1] = u'Caisson'
    field_information['GGDM 3.0']['SummaryDomainValues']['BGT'][2] = u'Lock Gate'
    field_information['GGDM 3.0']['SummaryDomainValues']['BGT'][3] = u'Tide Lock'
    field_information['GGDM 3.0']['SummaryDomainValues']['BGT'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['BH010_CAA'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['BH010_CAA'][3] = u'Private'
    field_information['GGDM 3.0']['SummaryDomainValues']['BH010_CAA'][5] = u'Military'
    field_information['GGDM 3.0']['SummaryDomainValues']['BH010_CAA'][7] = u'Joint Military and Civilian'
    field_information['GGDM 3.0']['SummaryDomainValues']['BH010_CAA'][16] = u'Civilian'
    field_information['GGDM 3.0']['SummaryDomainValues']['BH010_CAA'][17] = u'Public'
    field_information['GGDM 3.0']['SummaryDomainValues']['BH010_CAA'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['BH141_IBOA'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['BH141_IBOA'][1] = u'Right'
    field_information['GGDM 3.0']['SummaryDomainValues']['BH141_IBOA'][2] = u'Left'
    field_information['GGDM 3.0']['SummaryDomainValues']['BH141_IBOA'][3] = u'Indeterminate'
    field_information['GGDM 3.0']['SummaryDomainValues']['BH141_IBOA'][4] = u'No Flow'
    field_information['GGDM 3.0']['SummaryDomainValues']['BH141_IBOA'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['BH141_IBOB'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['BH141_IBOB'][1] = u'Right'
    field_information['GGDM 3.0']['SummaryDomainValues']['BH141_IBOB'][2] = u'Left'
    field_information['GGDM 3.0']['SummaryDomainValues']['BH141_IBOB'][3] = u'Indeterminate'
    field_information['GGDM 3.0']['SummaryDomainValues']['BH141_IBOB'][4] = u'No Flow'
    field_information['GGDM 3.0']['SummaryDomainValues']['BH141_IBOB'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['BH141_SHDA'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['BH141_SHDA'][1000] = u'False'
    field_information['GGDM 3.0']['SummaryDomainValues']['BH141_SHDA'][1001] = u'True'
    field_information['GGDM 3.0']['SummaryDomainValues']['BH141_SHDB'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['BH141_SHDB'][1000] = u'False'
    field_information['GGDM 3.0']['SummaryDomainValues']['BH141_SHDB'][1001] = u'True'
    field_information['GGDM 3.0']['SummaryDomainValues']['BH141_SLTA'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['BH141_SLTA'][6] = u'Mangrove'
    field_information['GGDM 3.0']['SummaryDomainValues']['BH141_SLTA'][8] = u'Marshy'
    field_information['GGDM 3.0']['SummaryDomainValues']['BH141_SLTA'][10] = u'Stony'
    field_information['GGDM 3.0']['SummaryDomainValues']['BH141_SLTA'][11] = u'Building Rubble'
    field_information['GGDM 3.0']['SummaryDomainValues']['BH141_SLTA'][12] = u'Erosion Rubble'
    field_information['GGDM 3.0']['SummaryDomainValues']['BH141_SLTA'][13] = u'Sandy'
    field_information['GGDM 3.0']['SummaryDomainValues']['BH141_SLTA'][14] = u'Shingly'
    field_information['GGDM 3.0']['SummaryDomainValues']['BH141_SLTA'][16] = u'Coral'
    field_information['GGDM 3.0']['SummaryDomainValues']['BH141_SLTA'][17] = u'Ice'
    field_information['GGDM 3.0']['SummaryDomainValues']['BH141_SLTA'][18] = u'Mud'
    field_information['GGDM 3.0']['SummaryDomainValues']['BH141_SLTA'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['BH141_SLTB'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['BH141_SLTB'][6] = u'Mangrove'
    field_information['GGDM 3.0']['SummaryDomainValues']['BH141_SLTB'][8] = u'Marshy'
    field_information['GGDM 3.0']['SummaryDomainValues']['BH141_SLTB'][10] = u'Stony'
    field_information['GGDM 3.0']['SummaryDomainValues']['BH141_SLTB'][11] = u'Building Rubble'
    field_information['GGDM 3.0']['SummaryDomainValues']['BH141_SLTB'][12] = u'Erosion Rubble'
    field_information['GGDM 3.0']['SummaryDomainValues']['BH141_SLTB'][13] = u'Sandy'
    field_information['GGDM 3.0']['SummaryDomainValues']['BH141_SLTB'][14] = u'Shingly'
    field_information['GGDM 3.0']['SummaryDomainValues']['BH141_SLTB'][16] = u'Coral'
    field_information['GGDM 3.0']['SummaryDomainValues']['BH141_SLTB'][17] = u'Ice'
    field_information['GGDM 3.0']['SummaryDomainValues']['BH141_SLTB'][18] = u'Mud'
    field_information['GGDM 3.0']['SummaryDomainValues']['BH141_SLTB'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['BMC'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['BMC'][1] = u'Clay and Silt'
    field_information['GGDM 3.0']['SummaryDomainValues']['BMC'][2] = u'Silty Sands'
    field_information['GGDM 3.0']['SummaryDomainValues']['BMC'][3] = u'Sand and Gravel'
    field_information['GGDM 3.0']['SummaryDomainValues']['BMC'][4] = u'Gravel and Cobble'
    field_information['GGDM 3.0']['SummaryDomainValues']['BMC'][5] = u'Rocks and Boulders'
    field_information['GGDM 3.0']['SummaryDomainValues']['BMC'][6] = u'Bedrock'
    field_information['GGDM 3.0']['SummaryDomainValues']['BMC'][7] = u'Paved'
    field_information['GGDM 3.0']['SummaryDomainValues']['BMC'][8] = u'Peat'
    field_information['GGDM 3.0']['SummaryDomainValues']['BMC'][9] = u'Sand over Mud'
    field_information['GGDM 3.0']['SummaryDomainValues']['BMC'][11] = u'Coral'
    field_information['GGDM 3.0']['SummaryDomainValues']['BMC'][14] = u'Sand'
    field_information['GGDM 3.0']['SummaryDomainValues']['BMC'][15] = u'Concrete'
    field_information['GGDM 3.0']['SummaryDomainValues']['BMC'][16] = u'Masonry'
    field_information['GGDM 3.0']['SummaryDomainValues']['BMC'][17] = u'Reinforced Concrete'
    field_information['GGDM 3.0']['SummaryDomainValues']['BMC'][18] = u'Soil'
    field_information['GGDM 3.0']['SummaryDomainValues']['BMC'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['BMC2'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['BMC2'][1] = u'Clay and Silt'
    field_information['GGDM 3.0']['SummaryDomainValues']['BMC2'][2] = u'Silty Sands'
    field_information['GGDM 3.0']['SummaryDomainValues']['BMC2'][3] = u'Sand and Gravel'
    field_information['GGDM 3.0']['SummaryDomainValues']['BMC2'][4] = u'Gravel and Cobble'
    field_information['GGDM 3.0']['SummaryDomainValues']['BMC2'][5] = u'Rocks and Boulders'
    field_information['GGDM 3.0']['SummaryDomainValues']['BMC2'][6] = u'Bedrock'
    field_information['GGDM 3.0']['SummaryDomainValues']['BMC2'][7] = u'Paved'
    field_information['GGDM 3.0']['SummaryDomainValues']['BMC2'][8] = u'Peat'
    field_information['GGDM 3.0']['SummaryDomainValues']['BMC2'][9] = u'Sand over Mud'
    field_information['GGDM 3.0']['SummaryDomainValues']['BMC2'][11] = u'Coral'
    field_information['GGDM 3.0']['SummaryDomainValues']['BMC2'][14] = u'Sand'
    field_information['GGDM 3.0']['SummaryDomainValues']['BMC2'][15] = u'Concrete'
    field_information['GGDM 3.0']['SummaryDomainValues']['BMC2'][16] = u'Masonry'
    field_information['GGDM 3.0']['SummaryDomainValues']['BMC2'][17] = u'Reinforced Concrete'
    field_information['GGDM 3.0']['SummaryDomainValues']['BMC2'][18] = u'Soil'
    field_information['GGDM 3.0']['SummaryDomainValues']['BMC2'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['BMC3'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['BMC3'][1] = u'Clay and Silt'
    field_information['GGDM 3.0']['SummaryDomainValues']['BMC3'][2] = u'Silty Sands'
    field_information['GGDM 3.0']['SummaryDomainValues']['BMC3'][3] = u'Sand and Gravel'
    field_information['GGDM 3.0']['SummaryDomainValues']['BMC3'][4] = u'Gravel and Cobble'
    field_information['GGDM 3.0']['SummaryDomainValues']['BMC3'][5] = u'Rocks and Boulders'
    field_information['GGDM 3.0']['SummaryDomainValues']['BMC3'][6] = u'Bedrock'
    field_information['GGDM 3.0']['SummaryDomainValues']['BMC3'][7] = u'Paved'
    field_information['GGDM 3.0']['SummaryDomainValues']['BMC3'][8] = u'Peat'
    field_information['GGDM 3.0']['SummaryDomainValues']['BMC3'][9] = u'Sand over Mud'
    field_information['GGDM 3.0']['SummaryDomainValues']['BMC3'][11] = u'Coral'
    field_information['GGDM 3.0']['SummaryDomainValues']['BMC3'][14] = u'Sand'
    field_information['GGDM 3.0']['SummaryDomainValues']['BMC3'][15] = u'Concrete'
    field_information['GGDM 3.0']['SummaryDomainValues']['BMC3'][16] = u'Masonry'
    field_information['GGDM 3.0']['SummaryDomainValues']['BMC3'][17] = u'Reinforced Concrete'
    field_information['GGDM 3.0']['SummaryDomainValues']['BMC3'][18] = u'Soil'
    field_information['GGDM 3.0']['SummaryDomainValues']['BMC3'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['BOC'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['BOC'][1] = u'Palsa Bog'
    field_information['GGDM 3.0']['SummaryDomainValues']['BOC'][2] = u'String Bog'
    field_information['GGDM 3.0']['SummaryDomainValues']['BOC'][3] = u'Atlantic Plateau Bog'
    field_information['GGDM 3.0']['SummaryDomainValues']['BOC'][4] = u'Basin Bog'
    field_information['GGDM 3.0']['SummaryDomainValues']['BOC'][6] = u'Blanket Bog'
    field_information['GGDM 3.0']['SummaryDomainValues']['BOC'][7] = u'Cranberry Bog'
    field_information['GGDM 3.0']['SummaryDomainValues']['BOC'][8] = u'Domed Bog'
    field_information['GGDM 3.0']['SummaryDomainValues']['BOC'][9] = u'Fen'
    field_information['GGDM 3.0']['SummaryDomainValues']['BOC'][10] = u'Flat Bog'
    field_information['GGDM 3.0']['SummaryDomainValues']['BOC'][11] = u'Horizontal Fen'
    field_information['GGDM 3.0']['SummaryDomainValues']['BOC'][12] = u'Lowland Polygon Bog'
    field_information['GGDM 3.0']['SummaryDomainValues']['BOC'][13] = u'Northern Ribbed Fen'
    field_information['GGDM 3.0']['SummaryDomainValues']['BOC'][14] = u'Peat Bog'
    field_information['GGDM 3.0']['SummaryDomainValues']['BOC'][15] = u'Peat Plateau Bog'
    field_information['GGDM 3.0']['SummaryDomainValues']['BOC'][16] = u'Polygonal Peat Plateau Bog'
    field_information['GGDM 3.0']['SummaryDomainValues']['BOC'][17] = u'Shore Fen'
    field_information['GGDM 3.0']['SummaryDomainValues']['BOC'][18] = u'Slope Bog'
    field_information['GGDM 3.0']['SummaryDomainValues']['BOC'][19] = u'Slope Fen'
    field_information['GGDM 3.0']['SummaryDomainValues']['BOC'][20] = u'Veneer Bog'
    field_information['GGDM 3.0']['SummaryDomainValues']['BOC'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['BOT'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['BOT'][4] = u'Bascule'
    field_information['GGDM 3.0']['SummaryDomainValues']['BOT'][10] = u'Swing-bridge'
    field_information['GGDM 3.0']['SummaryDomainValues']['BOT'][11] = u'Lift-bridge'
    field_information['GGDM 3.0']['SummaryDomainValues']['BOT'][12] = u'Retractable'
    field_information['GGDM 3.0']['SummaryDomainValues']['BOT'][14] = u'Submersible'
    field_information['GGDM 3.0']['SummaryDomainValues']['BOT'][15] = u'Drawbridge'
    field_information['GGDM 3.0']['SummaryDomainValues']['BOT'][16] = u'Opening'
    field_information['GGDM 3.0']['SummaryDomainValues']['BOT'][17] = u'Fixed'
    field_information['GGDM 3.0']['SummaryDomainValues']['BOT'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['BPWHAC'][2] = u'Open Interval'
    field_information['GGDM 3.0']['SummaryDomainValues']['BPWHAC'][3] = u'Greater-than-or-equal to Less-than Interval'
    field_information['GGDM 3.0']['SummaryDomainValues']['BPWHAC'][4] = u'Greater-than to Less-than-or-equal Interval'
    field_information['GGDM 3.0']['SummaryDomainValues']['BPWHAC'][5] = u'Closed Interval'
    field_information['GGDM 3.0']['SummaryDomainValues']['BPWHAC'][6] = u'Greater-than Semi-interval'
    field_information['GGDM 3.0']['SummaryDomainValues']['BPWHAC'][7] = u'Greater-than or Equal Semi-interval'
    field_information['GGDM 3.0']['SummaryDomainValues']['BPWHAC'][8] = u'Less-than Semi-interval'
    field_information['GGDM 3.0']['SummaryDomainValues']['BPWHAC'][9] = u'Less-than or Equal Semi-interval'
    field_information['GGDM 3.0']['SummaryDomainValues']['BPWHBC'][2] = u'Open Interval'
    field_information['GGDM 3.0']['SummaryDomainValues']['BPWHBC'][3] = u'Greater-than-or-equal to Less-than Interval'
    field_information['GGDM 3.0']['SummaryDomainValues']['BPWHBC'][4] = u'Greater-than to Less-than-or-equal Interval'
    field_information['GGDM 3.0']['SummaryDomainValues']['BPWHBC'][5] = u'Closed Interval'
    field_information['GGDM 3.0']['SummaryDomainValues']['BPWHBC'][6] = u'Greater-than Semi-interval'
    field_information['GGDM 3.0']['SummaryDomainValues']['BPWHBC'][7] = u'Greater-than or Equal Semi-interval'
    field_information['GGDM 3.0']['SummaryDomainValues']['BPWHBC'][8] = u'Less-than Semi-interval'
    field_information['GGDM 3.0']['SummaryDomainValues']['BPWHBC'][9] = u'Less-than or Equal Semi-interval'
    field_information['GGDM 3.0']['SummaryDomainValues']['BPWSAC'][2] = u'Open Interval'
    field_information['GGDM 3.0']['SummaryDomainValues']['BPWSAC'][3] = u'Greater-than-or-equal to Less-than Interval'
    field_information['GGDM 3.0']['SummaryDomainValues']['BPWSAC'][4] = u'Greater-than to Less-than-or-equal Interval'
    field_information['GGDM 3.0']['SummaryDomainValues']['BPWSAC'][5] = u'Closed Interval'
    field_information['GGDM 3.0']['SummaryDomainValues']['BPWSAC'][6] = u'Greater-than Semi-interval'
    field_information['GGDM 3.0']['SummaryDomainValues']['BPWSAC'][7] = u'Greater-than or Equal Semi-interval'
    field_information['GGDM 3.0']['SummaryDomainValues']['BPWSAC'][8] = u'Less-than Semi-interval'
    field_information['GGDM 3.0']['SummaryDomainValues']['BPWSAC'][9] = u'Less-than or Equal Semi-interval'
    field_information['GGDM 3.0']['SummaryDomainValues']['BPWSBC'][2] = u'Open Interval'
    field_information['GGDM 3.0']['SummaryDomainValues']['BPWSBC'][3] = u'Greater-than-or-equal to Less-than Interval'
    field_information['GGDM 3.0']['SummaryDomainValues']['BPWSBC'][4] = u'Greater-than to Less-than-or-equal Interval'
    field_information['GGDM 3.0']['SummaryDomainValues']['BPWSBC'][5] = u'Closed Interval'
    field_information['GGDM 3.0']['SummaryDomainValues']['BPWSBC'][6] = u'Greater-than Semi-interval'
    field_information['GGDM 3.0']['SummaryDomainValues']['BPWSBC'][7] = u'Greater-than or Equal Semi-interval'
    field_information['GGDM 3.0']['SummaryDomainValues']['BPWSBC'][8] = u'Less-than Semi-interval'
    field_information['GGDM 3.0']['SummaryDomainValues']['BPWSBC'][9] = u'Less-than or Equal Semi-interval'
    field_information['GGDM 3.0']['SummaryDomainValues']['BSC'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['BSC'][1] = u'Open Spandrel Arch'
    field_information['GGDM 3.0']['SummaryDomainValues']['BSC'][2] = u'Cantilever'
    field_information['GGDM 3.0']['SummaryDomainValues']['BSC'][3] = u'Deck'
    field_information['GGDM 3.0']['SummaryDomainValues']['BSC'][5] = u'Floating'
    field_information['GGDM 3.0']['SummaryDomainValues']['BSC'][6] = u'Girder'
    field_information['GGDM 3.0']['SummaryDomainValues']['BSC'][7] = u'Tower Suspension'
    field_information['GGDM 3.0']['SummaryDomainValues']['BSC'][8] = u'Truss'
    field_information['GGDM 3.0']['SummaryDomainValues']['BSC'][9] = u'Suspension'
    field_information['GGDM 3.0']['SummaryDomainValues']['BSC'][12] = u'Transporter'
    field_information['GGDM 3.0']['SummaryDomainValues']['BSC'][15] = u'Slab'
    field_information['GGDM 3.0']['SummaryDomainValues']['BSC'][16] = u'Stringer Beam'
    field_information['GGDM 3.0']['SummaryDomainValues']['BSC'][19] = u'Bowstring-bridge'
    field_information['GGDM 3.0']['SummaryDomainValues']['BSC'][22] = u'Covered'
    field_information['GGDM 3.0']['SummaryDomainValues']['BSC'][26] = u'Closed Spandrel Arch'
    field_information['GGDM 3.0']['SummaryDomainValues']['BSC'][27] = u'Cable Stayed'
    field_information['GGDM 3.0']['SummaryDomainValues']['BSC'][28] = u'Viaduct'
    field_information['GGDM 3.0']['SummaryDomainValues']['BSC'][31] = u'Arch'
    field_information['GGDM 3.0']['SummaryDomainValues']['BSC'][32] = u'Trestle'
    field_information['GGDM 3.0']['SummaryDomainValues']['BSC'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['BSC2'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['BSC2'][1] = u'Open Spandrel Arch'
    field_information['GGDM 3.0']['SummaryDomainValues']['BSC2'][2] = u'Cantilever'
    field_information['GGDM 3.0']['SummaryDomainValues']['BSC2'][5] = u'Floating'
    field_information['GGDM 3.0']['SummaryDomainValues']['BSC2'][6] = u'Girder'
    field_information['GGDM 3.0']['SummaryDomainValues']['BSC2'][7] = u'Tower Suspension'
    field_information['GGDM 3.0']['SummaryDomainValues']['BSC2'][8] = u'Truss'
    field_information['GGDM 3.0']['SummaryDomainValues']['BSC2'][9] = u'Suspension'
    field_information['GGDM 3.0']['SummaryDomainValues']['BSC2'][12] = u'Transporter'
    field_information['GGDM 3.0']['SummaryDomainValues']['BSC2'][15] = u'Slab'
    field_information['GGDM 3.0']['SummaryDomainValues']['BSC2'][16] = u'Stringer Beam'
    field_information['GGDM 3.0']['SummaryDomainValues']['BSC2'][19] = u'Bowstring-bridge'
    field_information['GGDM 3.0']['SummaryDomainValues']['BSC2'][22] = u'Covered'
    field_information['GGDM 3.0']['SummaryDomainValues']['BSC2'][26] = u'Closed Spandrel Arch'
    field_information['GGDM 3.0']['SummaryDomainValues']['BSC2'][27] = u'Cable Stayed'
    field_information['GGDM 3.0']['SummaryDomainValues']['BSC2'][31] = u'Arch'
    field_information['GGDM 3.0']['SummaryDomainValues']['BSC2'][32] = u'Trestle'
    field_information['GGDM 3.0']['SummaryDomainValues']['BSC2'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['BSC3'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['BSC3'][1] = u'Open Spandrel Arch'
    field_information['GGDM 3.0']['SummaryDomainValues']['BSC3'][2] = u'Cantilever'
    field_information['GGDM 3.0']['SummaryDomainValues']['BSC3'][5] = u'Floating'
    field_information['GGDM 3.0']['SummaryDomainValues']['BSC3'][6] = u'Girder'
    field_information['GGDM 3.0']['SummaryDomainValues']['BSC3'][7] = u'Tower Suspension'
    field_information['GGDM 3.0']['SummaryDomainValues']['BSC3'][8] = u'Truss'
    field_information['GGDM 3.0']['SummaryDomainValues']['BSC3'][9] = u'Suspension'
    field_information['GGDM 3.0']['SummaryDomainValues']['BSC3'][12] = u'Transporter'
    field_information['GGDM 3.0']['SummaryDomainValues']['BSC3'][15] = u'Slab'
    field_information['GGDM 3.0']['SummaryDomainValues']['BSC3'][16] = u'Stringer Beam'
    field_information['GGDM 3.0']['SummaryDomainValues']['BSC3'][19] = u'Bowstring-bridge'
    field_information['GGDM 3.0']['SummaryDomainValues']['BSC3'][22] = u'Covered'
    field_information['GGDM 3.0']['SummaryDomainValues']['BSC3'][26] = u'Closed Spandrel Arch'
    field_information['GGDM 3.0']['SummaryDomainValues']['BSC3'][27] = u'Cable Stayed'
    field_information['GGDM 3.0']['SummaryDomainValues']['BSC3'][31] = u'Arch'
    field_information['GGDM 3.0']['SummaryDomainValues']['BSC3'][32] = u'Trestle'
    field_information['GGDM 3.0']['SummaryDomainValues']['BSC3'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['BSM'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['BSM'][1000] = u'False'
    field_information['GGDM 3.0']['SummaryDomainValues']['BSM'][1001] = u'True'
    field_information['GGDM 3.0']['SummaryDomainValues']['BST'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['BST'][1] = u'Definite'
    field_information['GGDM 3.0']['SummaryDomainValues']['BST'][2] = u'Indefinite'
    field_information['GGDM 3.0']['SummaryDomainValues']['BST'][3] = u'In Dispute'
    field_information['GGDM 3.0']['SummaryDomainValues']['BST'][4] = u'No Defined Boundary'
    field_information['GGDM 3.0']['SummaryDomainValues']['BSU'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['BSU'][1] = u'Chimney'
    field_information['GGDM 3.0']['SummaryDomainValues']['BSU'][2] = u'Elevator Machine Room'
    field_information['GGDM 3.0']['SummaryDomainValues']['BSU'][3] = u'HVAC Equipment'
    field_information['GGDM 3.0']['SummaryDomainValues']['BSU'][4] = u'Lightning Rod'
    field_information['GGDM 3.0']['SummaryDomainValues']['BSU'][5] = u'Minaret'
    field_information['GGDM 3.0']['SummaryDomainValues']['BSU'][6] = u'Ornamental Element'
    field_information['GGDM 3.0']['SummaryDomainValues']['BSU'][7] = u'Parapet'
    field_information['GGDM 3.0']['SummaryDomainValues']['BSU'][8] = u'Roof Deck'
    field_information['GGDM 3.0']['SummaryDomainValues']['BSU'][9] = u'Roof Garden'
    field_information['GGDM 3.0']['SummaryDomainValues']['BSU'][10] = u'Signage'
    field_information['GGDM 3.0']['SummaryDomainValues']['BSU'][11] = u'Skylight'
    field_information['GGDM 3.0']['SummaryDomainValues']['BSU'][13] = u'Tower'
    field_information['GGDM 3.0']['SummaryDomainValues']['BSU'][14] = u'Cupola'
    field_information['GGDM 3.0']['SummaryDomainValues']['BSU'][15] = u'Steeple'
    field_information['GGDM 3.0']['SummaryDomainValues']['BSU'][16] = u'Turret'
    field_information['GGDM 3.0']['SummaryDomainValues']['BSU'][17] = u'Dome'
    field_information['GGDM 3.0']['SummaryDomainValues']['BSU'][18] = u'Solar Panels'
    field_information['GGDM 3.0']['SummaryDomainValues']['BSU'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['BUS'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['BUS'][1] = u'Conical'
    field_information['GGDM 3.0']['SummaryDomainValues']['BUS'][2] = u'Can'
    field_information['GGDM 3.0']['SummaryDomainValues']['BUS'][3] = u'Spherical'
    field_information['GGDM 3.0']['SummaryDomainValues']['BUS'][4] = u'Pillar'
    field_information['GGDM 3.0']['SummaryDomainValues']['BUS'][5] = u'Spar'
    field_information['GGDM 3.0']['SummaryDomainValues']['BUS'][6] = u'Barrel'
    field_information['GGDM 3.0']['SummaryDomainValues']['BUS'][7] = u'Super-buoy'
    field_information['GGDM 3.0']['SummaryDomainValues']['BUS'][8] = u'Ice Buoy'
    field_information['GGDM 3.0']['SummaryDomainValues']['BUS'][9] = u'Diamond'
    field_information['GGDM 3.0']['SummaryDomainValues']['BUS'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['BUT'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['BUT'][3] = u'Isolated Danger'
    field_information['GGDM 3.0']['SummaryDomainValues']['BUT'][4] = u'Large Automatic Navigation Buoy'
    field_information['GGDM 3.0']['SummaryDomainValues']['BUT'][6] = u'Light Float'
    field_information['GGDM 3.0']['SummaryDomainValues']['BUT'][7] = u'Mooring'
    field_information['GGDM 3.0']['SummaryDomainValues']['BUT'][10] = u'Ocean Data Acquisition System (ODAS) Buoy'
    field_information['GGDM 3.0']['SummaryDomainValues']['BUT'][11] = u'Landfall'
    field_information['GGDM 3.0']['SummaryDomainValues']['BUT'][15] = u'Special'
    field_information['GGDM 3.0']['SummaryDomainValues']['BUT'][18] = u'Safe Water'
    field_information['GGDM 3.0']['SummaryDomainValues']['BUT'][19] = u'Anchorage'
    field_information['GGDM 3.0']['SummaryDomainValues']['BUT'][20] = u'Fairway'
    field_information['GGDM 3.0']['SummaryDomainValues']['BUT'][21] = u'Mid-Channel'
    field_information['GGDM 3.0']['SummaryDomainValues']['BUT'][22] = u'Bifurcation'
    field_information['GGDM 3.0']['SummaryDomainValues']['BUT'][23] = u'Junction'
    field_information['GGDM 3.0']['SummaryDomainValues']['BUT'][24] = u'Wreck'
    field_information['GGDM 3.0']['SummaryDomainValues']['BUT'][25] = u'Obstruction'
    field_information['GGDM 3.0']['SummaryDomainValues']['BUT'][26] = u'Telegraph Cable'
    field_information['GGDM 3.0']['SummaryDomainValues']['BUT'][27] = u'Warping'
    field_information['GGDM 3.0']['SummaryDomainValues']['BUT'][28] = u'Quarantine'
    field_information['GGDM 3.0']['SummaryDomainValues']['BUT'][29] = u'Exercise Area'
    field_information['GGDM 3.0']['SummaryDomainValues']['BUT'][30] = u'Explosive Anchorage'
    field_information['GGDM 3.0']['SummaryDomainValues']['BUT'][31] = u'Aeronautical Anchorage'
    field_information['GGDM 3.0']['SummaryDomainValues']['BUT'][32] = u'Compass Adjustment'
    field_information['GGDM 3.0']['SummaryDomainValues']['BUT'][33] = u'Fish Trap'
    field_information['GGDM 3.0']['SummaryDomainValues']['BUT'][34] = u'Spoil Ground'
    field_information['GGDM 3.0']['SummaryDomainValues']['BUT'][35] = u'Articulated Light'
    field_information['GGDM 3.0']['SummaryDomainValues']['BUT'][39] = u'Trot'
    field_information['GGDM 3.0']['SummaryDomainValues']['BUT'][81] = u'Diving'
    field_information['GGDM 3.0']['SummaryDomainValues']['BUT'][82] = u'Notice'
    field_information['GGDM 3.0']['SummaryDomainValues']['BUT'][84] = u'APEX Float'
    field_information['GGDM 3.0']['SummaryDomainValues']['BUT'][85] = u'General Warning'
    field_information['GGDM 3.0']['SummaryDomainValues']['BUT'][86] = u'Private'
    field_information['GGDM 3.0']['SummaryDomainValues']['BUT'][87] = u'Swim'
    field_information['GGDM 3.0']['SummaryDomainValues']['BUT'][88] = u'Control'
    field_information['GGDM 3.0']['SummaryDomainValues']['BUT'][89] = u'Entry Prohibited'
    field_information['GGDM 3.0']['SummaryDomainValues']['BUT'][91] = u'Preferred Channel to Port'
    field_information['GGDM 3.0']['SummaryDomainValues']['BUT'][92] = u'Preferred Channel to Starboard'
    field_information['GGDM 3.0']['SummaryDomainValues']['BUT'][93] = u'Starboard-hand Edge'
    field_information['GGDM 3.0']['SummaryDomainValues']['BUT'][94] = u'Port-hand Edge'
    field_information['GGDM 3.0']['SummaryDomainValues']['BUT'][95] = u'West Cardinal'
    field_information['GGDM 3.0']['SummaryDomainValues']['BUT'][96] = u'South Cardinal'
    field_information['GGDM 3.0']['SummaryDomainValues']['BUT'][97] = u'East Cardinal'
    field_information['GGDM 3.0']['SummaryDomainValues']['BUT'][98] = u'North Cardinal'
    field_information['GGDM 3.0']['SummaryDomainValues']['BUT'][99] = u'Installation'
    field_information['GGDM 3.0']['SummaryDomainValues']['BUT'][100] = u'Accelerometer'
    field_information['GGDM 3.0']['SummaryDomainValues']['BUT'][101] = u'Wavemeter'
    field_information['GGDM 3.0']['SummaryDomainValues']['BUT'][102] = u'Navigation, communication and control buoy (NCCB)'
    field_information['GGDM 3.0']['SummaryDomainValues']['BUT'][103] = u'Ice Buoy'
    field_information['GGDM 3.0']['SummaryDomainValues']['BUT'][104] = u'Firing Danger Area'
    field_information['GGDM 3.0']['SummaryDomainValues']['BUT'][105] = u'Target'
    field_information['GGDM 3.0']['SummaryDomainValues']['BUT'][106] = u'Marker Ship'
    field_information['GGDM 3.0']['SummaryDomainValues']['BUT'][107] = u'Degaussing Range'
    field_information['GGDM 3.0']['SummaryDomainValues']['BUT'][108] = u'Barge'
    field_information['GGDM 3.0']['SummaryDomainValues']['BUT'][109] = u'Cable'
    field_information['GGDM 3.0']['SummaryDomainValues']['BUT'][110] = u'Outfall'
    field_information['GGDM 3.0']['SummaryDomainValues']['BUT'][111] = u'Recording'
    field_information['GGDM 3.0']['SummaryDomainValues']['BUT'][112] = u'Recreation Zone'
    field_information['GGDM 3.0']['SummaryDomainValues']['BUT'][113] = u'Leading Line'
    field_information['GGDM 3.0']['SummaryDomainValues']['BUT'][114] = u'Measured Distance'
    field_information['GGDM 3.0']['SummaryDomainValues']['BUT'][115] = u'TSS'
    field_information['GGDM 3.0']['SummaryDomainValues']['BUT'][116] = u'Anchoring Prohibited'
    field_information['GGDM 3.0']['SummaryDomainValues']['BUT'][117] = u'Berthing Prohibited'
    field_information['GGDM 3.0']['SummaryDomainValues']['BUT'][118] = u'Overtaking Prohibited'
    field_information['GGDM 3.0']['SummaryDomainValues']['BUT'][119] = u'Two-Way Traffic Prohibited'
    field_information['GGDM 3.0']['SummaryDomainValues']['BUT'][120] = u'Reduced Wake'
    field_information['GGDM 3.0']['SummaryDomainValues']['BUT'][121] = u'Speed Limit'
    field_information['GGDM 3.0']['SummaryDomainValues']['BUT'][122] = u'Stop'
    field_information['GGDM 3.0']['SummaryDomainValues']['BUT'][123] = u'Sound Ship\'s Siren'
    field_information['GGDM 3.0']['SummaryDomainValues']['BUT'][124] = u'Restricted Vertical Clearance'
    field_information['GGDM 3.0']['SummaryDomainValues']['BUT'][125] = u'Maximum Vessel\'s Draft'
    field_information['GGDM 3.0']['SummaryDomainValues']['BUT'][126] = u'Restricted Horizontal Clearance'
    field_information['GGDM 3.0']['SummaryDomainValues']['BUT'][127] = u'Strong Current Warning'
    field_information['GGDM 3.0']['SummaryDomainValues']['BUT'][128] = u'Berthing Permitted'
    field_information['GGDM 3.0']['SummaryDomainValues']['BUT'][129] = u'Overhead Power Cable'
    field_information['GGDM 3.0']['SummaryDomainValues']['BUT'][130] = u'Channel Edge Gradient'
    field_information['GGDM 3.0']['SummaryDomainValues']['BUT'][131] = u'Telephone'
    field_information['GGDM 3.0']['SummaryDomainValues']['BUT'][132] = u'Ferry Crossing'
    field_information['GGDM 3.0']['SummaryDomainValues']['BUT'][133] = u'Pipeline'
    field_information['GGDM 3.0']['SummaryDomainValues']['BUT'][134] = u'Clearing Line'
    field_information['GGDM 3.0']['SummaryDomainValues']['BUT'][135] = u'Refuge'
    field_information['GGDM 3.0']['SummaryDomainValues']['BUT'][136] = u'Foul Ground'
    field_information['GGDM 3.0']['SummaryDomainValues']['BUT'][137] = u'Yachting'
    field_information['GGDM 3.0']['SummaryDomainValues']['BUT'][138] = u'Heliport'
    field_information['GGDM 3.0']['SummaryDomainValues']['BUT'][139] = u'GPS Mark'
    field_information['GGDM 3.0']['SummaryDomainValues']['BUT'][140] = u'Work In Progress'
    field_information['GGDM 3.0']['SummaryDomainValues']['BUT'][141] = u'Artificial Reef'
    field_information['GGDM 3.0']['SummaryDomainValues']['BUT'][142] = u'Marine Farm'
    field_information['GGDM 3.0']['SummaryDomainValues']['BUT'][143] = u'Seaplane Landing'
    field_information['GGDM 3.0']['SummaryDomainValues']['BUT'][144] = u'Wellhead'
    field_information['GGDM 3.0']['SummaryDomainValues']['BUT'][145] = u'Water Column Sensor'
    field_information['GGDM 3.0']['SummaryDomainValues']['BUT'][149] = u'Emergency Wreck'
    field_information['GGDM 3.0']['SummaryDomainValues']['BUT'][150] = u'Mark of Unknown Intent'
    field_information['GGDM 3.0']['SummaryDomainValues']['BUT'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['BWVCAC'][2] = u'Open Interval'
    field_information['GGDM 3.0']['SummaryDomainValues']['BWVCAC'][3] = u'Greater-than-or-equal to Less-than Interval'
    field_information['GGDM 3.0']['SummaryDomainValues']['BWVCAC'][4] = u'Greater-than to Less-than-or-equal Interval'
    field_information['GGDM 3.0']['SummaryDomainValues']['BWVCAC'][5] = u'Closed Interval'
    field_information['GGDM 3.0']['SummaryDomainValues']['BWVCAC'][6] = u'Greater-than Semi-interval'
    field_information['GGDM 3.0']['SummaryDomainValues']['BWVCAC'][7] = u'Greater-than or Equal Semi-interval'
    field_information['GGDM 3.0']['SummaryDomainValues']['BWVCAC'][8] = u'Less-than Semi-interval'
    field_information['GGDM 3.0']['SummaryDomainValues']['BWVCAC'][9] = u'Less-than or Equal Semi-interval'
    field_information['GGDM 3.0']['SummaryDomainValues']['BWVCBC'][2] = u'Open Interval'
    field_information['GGDM 3.0']['SummaryDomainValues']['BWVCBC'][3] = u'Greater-than-or-equal to Less-than Interval'
    field_information['GGDM 3.0']['SummaryDomainValues']['BWVCBC'][4] = u'Greater-than to Less-than-or-equal Interval'
    field_information['GGDM 3.0']['SummaryDomainValues']['BWVCBC'][5] = u'Closed Interval'
    field_information['GGDM 3.0']['SummaryDomainValues']['BWVCBC'][6] = u'Greater-than Semi-interval'
    field_information['GGDM 3.0']['SummaryDomainValues']['BWVCBC'][7] = u'Greater-than or Equal Semi-interval'
    field_information['GGDM 3.0']['SummaryDomainValues']['BWVCBC'][8] = u'Less-than Semi-interval'
    field_information['GGDM 3.0']['SummaryDomainValues']['BWVCBC'][9] = u'Less-than or Equal Semi-interval'
    field_information['GGDM 3.0']['SummaryDomainValues']['CAA'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['CAA'][1] = u'National'
    field_information['GGDM 3.0']['SummaryDomainValues']['CAA'][2] = u'State'
    field_information['GGDM 3.0']['SummaryDomainValues']['CAA'][3] = u'Private'
    field_information['GGDM 3.0']['SummaryDomainValues']['CAA'][4] = u'Tribal'
    field_information['GGDM 3.0']['SummaryDomainValues']['CAA'][5] = u'Military'
    field_information['GGDM 3.0']['SummaryDomainValues']['CAA'][6] = u'Municipal'
    field_information['GGDM 3.0']['SummaryDomainValues']['CAA'][7] = u'Joint Military and Civilian'
    field_information['GGDM 3.0']['SummaryDomainValues']['CAA'][8] = u'International'
    field_information['GGDM 3.0']['SummaryDomainValues']['CAA'][11] = u'Province'
    field_information['GGDM 3.0']['SummaryDomainValues']['CAA'][13] = u'Regional'
    field_information['GGDM 3.0']['SummaryDomainValues']['CAA'][16] = u'Civilian'
    field_information['GGDM 3.0']['SummaryDomainValues']['CAA'][17] = u'Public'
    field_information['GGDM 3.0']['SummaryDomainValues']['CAA'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['CAB'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['CAB'][2] = u'Power Distribution Line'
    field_information['GGDM 3.0']['SummaryDomainValues']['CAB'][3] = u'Telephone'
    field_information['GGDM 3.0']['SummaryDomainValues']['CAB'][4] = u'Telegraph'
    field_information['GGDM 3.0']['SummaryDomainValues']['CAB'][6] = u'Power Transmission Line'
    field_information['GGDM 3.0']['SummaryDomainValues']['CAB'][7] = u'Digital Communication Line'
    field_information['GGDM 3.0']['SummaryDomainValues']['CAB'][8] = u'Communication Line'
    field_information['GGDM 3.0']['SummaryDomainValues']['CAB'][9] = u'Fibre-optic'
    field_information['GGDM 3.0']['SummaryDomainValues']['CAB'][10] = u'Tethering'
    field_information['GGDM 3.0']['SummaryDomainValues']['CAB'][11] = u'Load Bearing'
    field_information['GGDM 3.0']['SummaryDomainValues']['CAB'][12] = u'Guide'
    field_information['GGDM 3.0']['SummaryDomainValues']['CAB'][13] = u'Barrier'
    field_information['GGDM 3.0']['SummaryDomainValues']['CAB'][14] = u'Restraining'
    field_information['GGDM 3.0']['SummaryDomainValues']['CAB'][15] = u'Towing'
    field_information['GGDM 3.0']['SummaryDomainValues']['CAB'][19] = u'Cableway'
    field_information['GGDM 3.0']['SummaryDomainValues']['CAB'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['CAB2'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['CAB2'][2] = u'Power Distribution Line'
    field_information['GGDM 3.0']['SummaryDomainValues']['CAB2'][3] = u'Telephone'
    field_information['GGDM 3.0']['SummaryDomainValues']['CAB2'][4] = u'Telegraph'
    field_information['GGDM 3.0']['SummaryDomainValues']['CAB2'][6] = u'Power Transmission Line'
    field_information['GGDM 3.0']['SummaryDomainValues']['CAB2'][7] = u'Digital Communication Line'
    field_information['GGDM 3.0']['SummaryDomainValues']['CAB2'][8] = u'Communication Line'
    field_information['GGDM 3.0']['SummaryDomainValues']['CAB2'][9] = u'Fibre-optic'
    field_information['GGDM 3.0']['SummaryDomainValues']['CAB2'][10] = u'Tethering'
    field_information['GGDM 3.0']['SummaryDomainValues']['CAB2'][11] = u'Load Bearing'
    field_information['GGDM 3.0']['SummaryDomainValues']['CAB2'][12] = u'Guide'
    field_information['GGDM 3.0']['SummaryDomainValues']['CAB2'][13] = u'Barrier'
    field_information['GGDM 3.0']['SummaryDomainValues']['CAB2'][14] = u'Restraining'
    field_information['GGDM 3.0']['SummaryDomainValues']['CAB2'][15] = u'Towing'
    field_information['GGDM 3.0']['SummaryDomainValues']['CAB2'][19] = u'Cableway'
    field_information['GGDM 3.0']['SummaryDomainValues']['CAB2'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['CAB3'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['CAB3'][2] = u'Power Distribution Line'
    field_information['GGDM 3.0']['SummaryDomainValues']['CAB3'][3] = u'Telephone'
    field_information['GGDM 3.0']['SummaryDomainValues']['CAB3'][4] = u'Telegraph'
    field_information['GGDM 3.0']['SummaryDomainValues']['CAB3'][6] = u'Power Transmission Line'
    field_information['GGDM 3.0']['SummaryDomainValues']['CAB3'][7] = u'Digital Communication Line'
    field_information['GGDM 3.0']['SummaryDomainValues']['CAB3'][8] = u'Communication Line'
    field_information['GGDM 3.0']['SummaryDomainValues']['CAB3'][9] = u'Fibre-optic'
    field_information['GGDM 3.0']['SummaryDomainValues']['CAB3'][10] = u'Tethering'
    field_information['GGDM 3.0']['SummaryDomainValues']['CAB3'][11] = u'Load Bearing'
    field_information['GGDM 3.0']['SummaryDomainValues']['CAB3'][12] = u'Guide'
    field_information['GGDM 3.0']['SummaryDomainValues']['CAB3'][13] = u'Barrier'
    field_information['GGDM 3.0']['SummaryDomainValues']['CAB3'][14] = u'Restraining'
    field_information['GGDM 3.0']['SummaryDomainValues']['CAB3'][15] = u'Towing'
    field_information['GGDM 3.0']['SummaryDomainValues']['CAB3'][19] = u'Cableway'
    field_information['GGDM 3.0']['SummaryDomainValues']['CAB3'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['CAM'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['CAM'][1] = u'Strict Nature Reserve'
    field_information['GGDM 3.0']['SummaryDomainValues']['CAM'][2] = u'Wilderness Area'
    field_information['GGDM 3.0']['SummaryDomainValues']['CAM'][3] = u'National Park'
    field_information['GGDM 3.0']['SummaryDomainValues']['CAM'][4] = u'Natural Monument'
    field_information['GGDM 3.0']['SummaryDomainValues']['CAM'][5] = u'Habitat and/or Species Management Area'
    field_information['GGDM 3.0']['SummaryDomainValues']['CAM'][6] = u'    Habitat Management Area'
    field_information['GGDM 3.0']['SummaryDomainValues']['CAM'][7] = u'    Species Management Area'
    field_information['GGDM 3.0']['SummaryDomainValues']['CAM'][8] = u'Breeding Ground'
    field_information['GGDM 3.0']['SummaryDomainValues']['CAM'][9] = u'Protected Landscape or Seascape'
    field_information['GGDM 3.0']['SummaryDomainValues']['CAM'][10] = u'Managed Resource Protected Area'
    field_information['GGDM 3.0']['SummaryDomainValues']['CAM'][11] = u'    Managed Forest Protected Area'
    field_information['GGDM 3.0']['SummaryDomainValues']['CAM'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['CAT'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['CAT'][2] = u'Chair-lift'
    field_information['GGDM 3.0']['SummaryDomainValues']['CAT'][3] = u'Ski Tow'
    field_information['GGDM 3.0']['SummaryDomainValues']['CAT'][5] = u'Aerial Tramway'
    field_information['GGDM 3.0']['SummaryDomainValues']['CAT'][6] = u'Gondola Lift'
    field_information['GGDM 3.0']['SummaryDomainValues']['CAT'][7] = u'T-bar Lift'
    field_information['GGDM 3.0']['SummaryDomainValues']['CAT'][8] = u'Industrial Ropeway'
    field_information['GGDM 3.0']['SummaryDomainValues']['CAT'][9] = u'Material Tramway'
    field_information['GGDM 3.0']['SummaryDomainValues']['CAT'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['CBP'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['CBP'][1000] = u'False'
    field_information['GGDM 3.0']['SummaryDomainValues']['CBP'][1001] = u'True'
    field_information['GGDM 3.0']['SummaryDomainValues']['CCG'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['CCG'][1] = u'Biological'
    field_information['GGDM 3.0']['SummaryDomainValues']['CCG'][2] = u'Chemical'
    field_information['GGDM 3.0']['SummaryDomainValues']['CCG'][3] = u'Nuclear and/or Radiological'
    field_information['GGDM 3.0']['SummaryDomainValues']['CCG'][4] = u'Thermal'
    field_information['GGDM 3.0']['SummaryDomainValues']['CCG'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['CCT'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['CCT'][1] = u'Open'
    field_information['GGDM 3.0']['SummaryDomainValues']['CCT'][2] = u'Partial'
    field_information['GGDM 3.0']['SummaryDomainValues']['CCT'][3] = u'Moveable'
    field_information['GGDM 3.0']['SummaryDomainValues']['CCT'][4] = u'Complete'
    field_information['GGDM 3.0']['SummaryDomainValues']['CDA'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['CDA'][1000] = u'False'
    field_information['GGDM 3.0']['SummaryDomainValues']['CDA'][1001] = u'True'
    field_information['GGDM 3.0']['SummaryDomainValues']['CDY'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['CDY'][1] = u'Collateral Evidence'
    field_information['GGDM 3.0']['SummaryDomainValues']['CDY'][2] = u'Field Notes'
    field_information['GGDM 3.0']['SummaryDomainValues']['CDY'][3] = u'Field Sketch'
    field_information['GGDM 3.0']['SummaryDomainValues']['CDY'][4] = u'GNSS Survey'
    field_information['GGDM 3.0']['SummaryDomainValues']['CDY'][5] = u'Official Cadastral Survey'
    field_information['GGDM 3.0']['SummaryDomainValues']['CDY'][6] = u'Orthophoto'
    field_information['GGDM 3.0']['SummaryDomainValues']['CDY'][7] = u'Plat'
    field_information['GGDM 3.0']['SummaryDomainValues']['CDY'][8] = u'Relative Measurement'
    field_information['GGDM 3.0']['SummaryDomainValues']['CDY'][9] = u'Resurvey'
    field_information['GGDM 3.0']['SummaryDomainValues']['CDY'][10] = u'Survey'
    field_information['GGDM 3.0']['SummaryDomainValues']['CDY'][11] = u'Tenure Map'
    field_information['GGDM 3.0']['SummaryDomainValues']['CDY'][12] = u'Topographic Map'
    field_information['GGDM 3.0']['SummaryDomainValues']['CDY'][13] = u'Use Plat'
    field_information['GGDM 3.0']['SummaryDomainValues']['CDY'][14] = u'Video'
    field_information['GGDM 3.0']['SummaryDomainValues']['CDY'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['CET'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['CET'][1] = u'One Side'
    field_information['GGDM 3.0']['SummaryDomainValues']['CET'][2] = u'Two Sides'
    field_information['GGDM 3.0']['SummaryDomainValues']['CET'][3] = u'Many Sides'
    field_information['GGDM 3.0']['SummaryDomainValues']['CET'][4] = u'No Sides'
    field_information['GGDM 3.0']['SummaryDomainValues']['CET'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['CFT'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['CFT'][3] = u'Cadastral'
    field_information['GGDM 3.0']['SummaryDomainValues']['CFT'][6] = u'Economic'
    field_information['GGDM 3.0']['SummaryDomainValues']['CFT'][12] = u'Left Bank'
    field_information['GGDM 3.0']['SummaryDomainValues']['CFT'][13] = u'Right Bank'
    field_information['GGDM 3.0']['SummaryDomainValues']['CFT'][14] = u'Shoreline'
    field_information['GGDM 3.0']['SummaryDomainValues']['CFT'][16] = u'Meridian'
    field_information['GGDM 3.0']['SummaryDomainValues']['CFT'][17] = u'Median'
    field_information['GGDM 3.0']['SummaryDomainValues']['CFT'][18] = u'Parallel'
    field_information['GGDM 3.0']['SummaryDomainValues']['CFT'][19] = u'Straight Segmented'
    field_information['GGDM 3.0']['SummaryDomainValues']['CFT'][20] = u'Straight'
    field_information['GGDM 3.0']['SummaryDomainValues']['CFT'][21] = u'Geodesic'
    field_information['GGDM 3.0']['SummaryDomainValues']['CFT'][22] = u'Great Circle'
    field_information['GGDM 3.0']['SummaryDomainValues']['CFT'][23] = u'Arc'
    field_information['GGDM 3.0']['SummaryDomainValues']['CFT'][24] = u'Normal Baseline'
    field_information['GGDM 3.0']['SummaryDomainValues']['CFT'][25] = u'Straight Baseline'
    field_information['GGDM 3.0']['SummaryDomainValues']['CFT'][27] = u'Normal Continental Shelf'
    field_information['GGDM 3.0']['SummaryDomainValues']['CFT'][28] = u'Extended Continental Shelf'
    field_information['GGDM 3.0']['SummaryDomainValues']['CFT'][29] = u'Main Channel'
    field_information['GGDM 3.0']['SummaryDomainValues']['CFT'][30] = u'Archipelagic Baseline'
    field_information['GGDM 3.0']['SummaryDomainValues']['CFT'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['CHA'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['CHA'][1] = u'Alternating'
    field_information['GGDM 3.0']['SummaryDomainValues']['CHA'][4] = u'Ultra Quick-flashing'
    field_information['GGDM 3.0']['SummaryDomainValues']['CHA'][5] = u'Fixed'
    field_information['GGDM 3.0']['SummaryDomainValues']['CHA'][6] = u'Fixed and Flashing'
    field_information['GGDM 3.0']['SummaryDomainValues']['CHA'][8] = u'Flashing'
    field_information['GGDM 3.0']['SummaryDomainValues']['CHA'][11] = u'Interrupted Quick-flashing'
    field_information['GGDM 3.0']['SummaryDomainValues']['CHA'][12] = u'Interrupted Ultra Quick-flashing'
    field_information['GGDM 3.0']['SummaryDomainValues']['CHA'][13] = u'Interrupted Very Quick-flashing'
    field_information['GGDM 3.0']['SummaryDomainValues']['CHA'][14] = u'Isophase'
    field_information['GGDM 3.0']['SummaryDomainValues']['CHA'][15] = u'Long-flashing'
    field_information['GGDM 3.0']['SummaryDomainValues']['CHA'][16] = u'Morse Code'
    field_information['GGDM 3.0']['SummaryDomainValues']['CHA'][17] = u'Occulting'
    field_information['GGDM 3.0']['SummaryDomainValues']['CHA'][28] = u'Group Quick-flashing'
    field_information['GGDM 3.0']['SummaryDomainValues']['CHA'][29] = u'Group Very Quick-flashing'
    field_information['GGDM 3.0']['SummaryDomainValues']['CHA'][44] = u'Quick-flashing'
    field_information['GGDM 3.0']['SummaryDomainValues']['CHA'][45] = u'Very Quick-flashing'
    field_information['GGDM 3.0']['SummaryDomainValues']['CHA'][46] = u'Flashing with Long-flash'
    field_information['GGDM 3.0']['SummaryDomainValues']['CHA'][47] = u'Occulting Flashing'
    field_information['GGDM 3.0']['SummaryDomainValues']['CHA'][48] = u'Fixed Long-flashing'
    field_information['GGDM 3.0']['SummaryDomainValues']['CHA'][49] = u'Occulting Alternating'
    field_information['GGDM 3.0']['SummaryDomainValues']['CHA'][50] = u'Long-flashing Alternating'
    field_information['GGDM 3.0']['SummaryDomainValues']['CHA'][51] = u'Flashing Alternating'
    field_information['GGDM 3.0']['SummaryDomainValues']['CHA'][57] = u'Quick-flashing with Long-flash'
    field_information['GGDM 3.0']['SummaryDomainValues']['CHA'][58] = u'Very Quick-flashing with Long-flash'
    field_information['GGDM 3.0']['SummaryDomainValues']['CHA'][59] = u'Ultra Quick-flashing with Long-flash'
    field_information['GGDM 3.0']['SummaryDomainValues']['CHA'][60] = u'Fixed with Alternating Flashing'
    field_information['GGDM 3.0']['SummaryDomainValues']['CIW'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['CIW'][1000] = u'False'
    field_information['GGDM 3.0']['SummaryDomainValues']['CIW'][1001] = u'True'
    field_information['GGDM 3.0']['SummaryDomainValues']['CMS'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['CMS'][1] = u'Commissioned and Operational'
    field_information['GGDM 3.0']['SummaryDomainValues']['CMS'][2] = u'Commissioned and on Test'
    field_information['GGDM 3.0']['SummaryDomainValues']['CMS'][3] = u'Commissioned but Out of Service'
    field_information['GGDM 3.0']['SummaryDomainValues']['CMS'][4] = u'Operational but Not Commissioned'
    field_information['GGDM 3.0']['SummaryDomainValues']['CMS'][5] = u'On Test but Not Commissioned'
    field_information['GGDM 3.0']['SummaryDomainValues']['CMS'][6] = u'Not Commissioned and Out of Service'
    field_information['GGDM 3.0']['SummaryDomainValues']['CNF'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['CNF'][1000] = u'False'
    field_information['GGDM 3.0']['SummaryDomainValues']['CNF'][1001] = u'True'
    field_information['GGDM 3.0']['SummaryDomainValues']['COA'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['COA'][2] = u'Visual'
    field_information['GGDM 3.0']['SummaryDomainValues']['COA'][4] = u'Not Conspicuous'
    field_information['GGDM 3.0']['SummaryDomainValues']['COC'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['COC'][1] = u'Visual and Radar'
    field_information['GGDM 3.0']['SummaryDomainValues']['COC'][2] = u'Visual'
    field_information['GGDM 3.0']['SummaryDomainValues']['COC'][3] = u'Radar'
    field_information['GGDM 3.0']['SummaryDomainValues']['COC'][4] = u'Not Conspicuous'
    field_information['GGDM 3.0']['SummaryDomainValues']['COG'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['COG'][2] = u'Visual'
    field_information['GGDM 3.0']['SummaryDomainValues']['COG'][4] = u'Not Conspicuous'
    field_information['GGDM 3.0']['SummaryDomainValues']['CON'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['CON'][1] = u'Dropgate'
    field_information['GGDM 3.0']['SummaryDomainValues']['CON'][2] = u'Pass'
    field_information['GGDM 3.0']['SummaryDomainValues']['CON'][3] = u'Building'
    field_information['GGDM 3.0']['SummaryDomainValues']['CON'][4] = u'Underpass'
    field_information['GGDM 3.0']['SummaryDomainValues']['CON'][5] = u'Arcade'
    field_information['GGDM 3.0']['SummaryDomainValues']['CON'][6] = u'Bridge Pier'
    field_information['GGDM 3.0']['SummaryDomainValues']['CON'][7] = u'Bridge Superstructure'
    field_information['GGDM 3.0']['SummaryDomainValues']['CON'][8] = u'Bridge Tower'
    field_information['GGDM 3.0']['SummaryDomainValues']['CON'][9] = u'Causeway Structure'
    field_information['GGDM 3.0']['SummaryDomainValues']['CON'][10] = u'Cave'
    field_information['GGDM 3.0']['SummaryDomainValues']['CON'][11] = u'Culvert'
    field_information['GGDM 3.0']['SummaryDomainValues']['CON'][12] = u'Curb'
    field_information['GGDM 3.0']['SummaryDomainValues']['CON'][13] = u'Cut'
    field_information['GGDM 3.0']['SummaryDomainValues']['CON'][14] = u'Dam'
    field_information['GGDM 3.0']['SummaryDomainValues']['CON'][15] = u'Embankment'
    field_information['GGDM 3.0']['SummaryDomainValues']['CON'][16] = u'Entrance and/or Exit'
    field_information['GGDM 3.0']['SummaryDomainValues']['CON'][17] = u'Fence'
    field_information['GGDM 3.0']['SummaryDomainValues']['CON'][18] = u'Fire Hydrant'
    field_information['GGDM 3.0']['SummaryDomainValues']['CON'][19] = u'Ford'
    field_information['GGDM 3.0']['SummaryDomainValues']['CON'][20] = u'Gallery'
    field_information['GGDM 3.0']['SummaryDomainValues']['CON'][21] = u'Gantry'
    field_information['GGDM 3.0']['SummaryDomainValues']['CON'][22] = u'Gate'
    field_information['GGDM 3.0']['SummaryDomainValues']['CON'][23] = u'Hedgerow'
    field_information['GGDM 3.0']['SummaryDomainValues']['CON'][24] = u'Memorial Monument'
    field_information['GGDM 3.0']['SummaryDomainValues']['CON'][25] = u'Non-building Structure'
    field_information['GGDM 3.0']['SummaryDomainValues']['CON'][26] = u'Parking Garage'
    field_information['GGDM 3.0']['SummaryDomainValues']['CON'][27] = u'Pipeline'
    field_information['GGDM 3.0']['SummaryDomainValues']['CON'][28] = u'Pipeline Crossing Point'
    field_information['GGDM 3.0']['SummaryDomainValues']['CON'][29] = u'Prepared Watercourse Crossing'
    field_information['GGDM 3.0']['SummaryDomainValues']['CON'][30] = u'Railway Signal'
    field_information['GGDM 3.0']['SummaryDomainValues']['CON'][31] = u'Railway Switch'
    field_information['GGDM 3.0']['SummaryDomainValues']['CON'][32] = u'Ramp'
    field_information['GGDM 3.0']['SummaryDomainValues']['CON'][33] = u'Reduced Track or Lane Count'
    field_information['GGDM 3.0']['SummaryDomainValues']['CON'][34] = u'Retail Stand'
    field_information['GGDM 3.0']['SummaryDomainValues']['CON'][35] = u'Road Interchange'
    field_information['GGDM 3.0']['SummaryDomainValues']['CON'][36] = u'Rock Formation'
    field_information['GGDM 3.0']['SummaryDomainValues']['CON'][37] = u'Route-related Structure'
    field_information['GGDM 3.0']['SummaryDomainValues']['CON'][38] = u'Stair'
    field_information['GGDM 3.0']['SummaryDomainValues']['CON'][39] = u'Steep Terrain Face'
    field_information['GGDM 3.0']['SummaryDomainValues']['CON'][40] = u'Transportation Block'
    field_information['GGDM 3.0']['SummaryDomainValues']['CON'][41] = u'Transportation Route Protection Structure'
    field_information['GGDM 3.0']['SummaryDomainValues']['CON'][42] = u'Tunnel'
    field_information['GGDM 3.0']['SummaryDomainValues']['CON'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['COS'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['COS'][1] = u'Continuous'
    field_information['GGDM 3.0']['SummaryDomainValues']['COS'][2] = u'Intermittent'
    field_information['GGDM 3.0']['SummaryDomainValues']['COS'][3] = u'Scheduled'
    field_information['GGDM 3.0']['SummaryDomainValues']['COS'][4] = u'Non-operational'
    field_information['GGDM 3.0']['SummaryDomainValues']['COS'][6] = u'Planned'
    field_information['GGDM 3.0']['SummaryDomainValues']['COS'][8] = u'Not in Operation'
    field_information['GGDM 3.0']['SummaryDomainValues']['COS'][9] = u'Temporarily Non-operational'
    field_information['GGDM 3.0']['SummaryDomainValues']['COS'][13] = u'Operational'
    field_information['GGDM 3.0']['SummaryDomainValues']['COS'][14] = u'Partially Operational'
    field_information['GGDM 3.0']['SummaryDomainValues']['CPA'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['CPA'][1] = u'Benchmark'
    field_information['GGDM 3.0']['SummaryDomainValues']['CPA'][2] = u'Horizontal Position'
    field_information['GGDM 3.0']['SummaryDomainValues']['CPA'][3] = u'Horizontal Position and Benchmark'
    field_information['GGDM 3.0']['SummaryDomainValues']['CPA'][5] = u'Vertical Position'
    field_information['GGDM 3.0']['SummaryDomainValues']['CPS'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['CPS'][1] = u'Fixed Cells, 5 Arc Degree'
    field_information['GGDM 3.0']['SummaryDomainValues']['CPS'][2] = u'Fixed Cells, 1 Arc Degree'
    field_information['GGDM 3.0']['SummaryDomainValues']['CPS'][3] = u'Fixed Cells, 0.5 Arc Degree'
    field_information['GGDM 3.0']['SummaryDomainValues']['CPS'][4] = u'Fixed Cells, 0.25 Arc Degree'
    field_information['GGDM 3.0']['SummaryDomainValues']['CPS'][5] = u'Variable Cells'
    field_information['GGDM 3.0']['SummaryDomainValues']['CPS'][998] = u'Not Applicable'
    field_information['GGDM 3.0']['SummaryDomainValues']['CPS'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['CPT'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['CPT'][1] = u'Horizontal Stripes'
    field_information['GGDM 3.0']['SummaryDomainValues']['CPT'][2] = u'Vertical Stripes'
    field_information['GGDM 3.0']['SummaryDomainValues']['CPT'][3] = u'Diagonal Stripes'
    field_information['GGDM 3.0']['SummaryDomainValues']['CPT'][4] = u'Squared'
    field_information['GGDM 3.0']['SummaryDomainValues']['CPT'][5] = u'Stripes'
    field_information['GGDM 3.0']['SummaryDomainValues']['CPT'][6] = u'Border Stripe'
    field_information['GGDM 3.0']['SummaryDomainValues']['CPT'][7] = u'Single Colour'
    field_information['GGDM 3.0']['SummaryDomainValues']['CRA'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['CRA'][2] = u'Bridge Crane'
    field_information['GGDM 3.0']['SummaryDomainValues']['CRA'][3] = u'Rotating Crane'
    field_information['GGDM 3.0']['SummaryDomainValues']['CRA'][7] = u'Tower Crane'
    field_information['GGDM 3.0']['SummaryDomainValues']['CRA'][8] = u'Shear-Legs'
    field_information['GGDM 3.0']['SummaryDomainValues']['CRA'][9] = u'A-frame Crane'
    field_information['GGDM 3.0']['SummaryDomainValues']['CRA'][10] = u'Goliath Crane'
    field_information['GGDM 3.0']['SummaryDomainValues']['CRA'][99] = u'Container Crane'
    field_information['GGDM 3.0']['SummaryDomainValues']['CRA'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['CRM'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['CRM'][1] = u'Fixed'
    field_information['GGDM 3.0']['SummaryDomainValues']['CRM'][2] = u'Travelling'
    field_information['GGDM 3.0']['SummaryDomainValues']['CRM'][3] = u'Floating'
    field_information['GGDM 3.0']['SummaryDomainValues']['CRM'][4] = u'Mobile'
    field_information['GGDM 3.0']['SummaryDomainValues']['CRM'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['CSC'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['CSC'][2] = u'Signal Device'
    field_information['GGDM 3.0']['SummaryDomainValues']['CSC'][3] = u'Stop Sign'
    field_information['GGDM 3.0']['SummaryDomainValues']['CSC'][4] = u'No Control'
    field_information['GGDM 3.0']['SummaryDomainValues']['CSC'][5] = u'Ground Marking'
    field_information['GGDM 3.0']['SummaryDomainValues']['CSC'][6] = u'Yield Sign'
    field_information['GGDM 3.0']['SummaryDomainValues']['CSC'][7] = u'Priority Sign'
    field_information['GGDM 3.0']['SummaryDomainValues']['CSC'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['CSC2'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['CSC2'][2] = u'Signal Device'
    field_information['GGDM 3.0']['SummaryDomainValues']['CSC2'][3] = u'Stop Sign'
    field_information['GGDM 3.0']['SummaryDomainValues']['CSC2'][4] = u'No Control'
    field_information['GGDM 3.0']['SummaryDomainValues']['CSC2'][5] = u'Ground Marking'
    field_information['GGDM 3.0']['SummaryDomainValues']['CSC2'][6] = u'Yield Sign'
    field_information['GGDM 3.0']['SummaryDomainValues']['CSC2'][7] = u'Priority Sign'
    field_information['GGDM 3.0']['SummaryDomainValues']['CSC2'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['CSC3'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['CSC3'][2] = u'Signal Device'
    field_information['GGDM 3.0']['SummaryDomainValues']['CSC3'][3] = u'Stop Sign'
    field_information['GGDM 3.0']['SummaryDomainValues']['CSC3'][4] = u'No Control'
    field_information['GGDM 3.0']['SummaryDomainValues']['CSC3'][5] = u'Ground Marking'
    field_information['GGDM 3.0']['SummaryDomainValues']['CSC3'][6] = u'Yield Sign'
    field_information['GGDM 3.0']['SummaryDomainValues']['CSC3'][7] = u'Priority Sign'
    field_information['GGDM 3.0']['SummaryDomainValues']['CSC3'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['CSO'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['CSO'][1] = u'Dredging'
    field_information['GGDM 3.0']['SummaryDomainValues']['CSO'][2] = u'Factories'
    field_information['GGDM 3.0']['SummaryDomainValues']['CSO'][3] = u'Farm Run-off'
    field_information['GGDM 3.0']['SummaryDomainValues']['CSO'][4] = u'Military Operations'
    field_information['GGDM 3.0']['SummaryDomainValues']['CSO'][5] = u'Naturally Occurring'
    field_information['GGDM 3.0']['SummaryDomainValues']['CSO'][6] = u'Sewers'
    field_information['GGDM 3.0']['SummaryDomainValues']['CSO'][7] = u'Spoil'
    field_information['GGDM 3.0']['SummaryDomainValues']['CSO'][8] = u'Wrecks'
    field_information['GGDM 3.0']['SummaryDomainValues']['CSO'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['CSS'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['CSS'][1] = u'Irregular'
    field_information['GGDM 3.0']['SummaryDomainValues']['CSS'][4] = u'Circular'
    field_information['GGDM 3.0']['SummaryDomainValues']['CSS'][5] = u'Square'
    field_information['GGDM 3.0']['SummaryDomainValues']['CSS'][6] = u'Triangular'
    field_information['GGDM 3.0']['SummaryDomainValues']['CSS'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['CST'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['CST'][1000] = u'False'
    field_information['GGDM 3.0']['SummaryDomainValues']['CST'][1001] = u'True'
    field_information['GGDM 3.0']['SummaryDomainValues']['CTC'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['CTC'][1] = u'Regular with Soil'
    field_information['GGDM 3.0']['SummaryDomainValues']['CTC'][2] = u'Box with Soil'
    field_information['GGDM 3.0']['SummaryDomainValues']['CTC'][3] = u'Box with Load'
    field_information['GGDM 3.0']['SummaryDomainValues']['CTC'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['CUL'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['CUL'][1] = u'National Identity'
    field_information['GGDM 3.0']['SummaryDomainValues']['CUL'][2] = u'Ethnic Group'
    field_information['GGDM 3.0']['SummaryDomainValues']['CUL'][3] = u'Tribe'
    field_information['GGDM 3.0']['SummaryDomainValues']['CUL'][4] = u'Clan'
    field_information['GGDM 3.0']['SummaryDomainValues']['CUL'][5] = u'Language'
    field_information['GGDM 3.0']['SummaryDomainValues']['CUL'][6] = u'Religion'
    field_information['GGDM 3.0']['SummaryDomainValues']['CUL'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['CUR'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['CUR'][1] = u'Ebb Stream'
    field_information['GGDM 3.0']['SummaryDomainValues']['CUR'][2] = u'Flood Stream'
    field_information['GGDM 3.0']['SummaryDomainValues']['CUR'][4] = u'River Flow'
    field_information['GGDM 3.0']['SummaryDomainValues']['CUR'][5] = u'Ocean Current'
    field_information['GGDM 3.0']['SummaryDomainValues']['CUR'][6] = u'Rip'
    field_information['GGDM 3.0']['SummaryDomainValues']['CUR'][7] = u'Longshore'
    field_information['GGDM 3.0']['SummaryDomainValues']['CUR'][8] = u'Underwater River Flow'
    field_information['GGDM 3.0']['SummaryDomainValues']['CUR'][9] = u'Tidal Flow'
    field_information['GGDM 3.0']['SummaryDomainValues']['CUR'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['CVT'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['CVT'][1] = u'Not visible'
    field_information['GGDM 3.0']['SummaryDomainValues']['CVT'][2] = u'Belt'
    field_information['GGDM 3.0']['SummaryDomainValues']['CVT'][3] = u'Rollers'
    field_information['GGDM 3.0']['SummaryDomainValues']['CVT'][4] = u'Bucket'
    field_information['GGDM 3.0']['SummaryDomainValues']['CVT'][5] = u'Screw Auger'
    field_information['GGDM 3.0']['SummaryDomainValues']['CVT'][6] = u'Apron'
    field_information['GGDM 3.0']['SummaryDomainValues']['CVT'][7] = u'Flight'
    field_information['GGDM 3.0']['SummaryDomainValues']['CVT'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['CVT2'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['CVT2'][1] = u'Not visible'
    field_information['GGDM 3.0']['SummaryDomainValues']['CVT2'][2] = u'Belt'
    field_information['GGDM 3.0']['SummaryDomainValues']['CVT2'][3] = u'Rollers'
    field_information['GGDM 3.0']['SummaryDomainValues']['CVT2'][4] = u'Bucket'
    field_information['GGDM 3.0']['SummaryDomainValues']['CVT2'][5] = u'Screw Auger'
    field_information['GGDM 3.0']['SummaryDomainValues']['CVT2'][6] = u'Apron'
    field_information['GGDM 3.0']['SummaryDomainValues']['CVT2'][7] = u'Flight'
    field_information['GGDM 3.0']['SummaryDomainValues']['CVT2'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['CVT3'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['CVT3'][1] = u'Not visible'
    field_information['GGDM 3.0']['SummaryDomainValues']['CVT3'][2] = u'Belt'
    field_information['GGDM 3.0']['SummaryDomainValues']['CVT3'][3] = u'Rollers'
    field_information['GGDM 3.0']['SummaryDomainValues']['CVT3'][4] = u'Bucket'
    field_information['GGDM 3.0']['SummaryDomainValues']['CVT3'][5] = u'Screw Auger'
    field_information['GGDM 3.0']['SummaryDomainValues']['CVT3'][6] = u'Apron'
    field_information['GGDM 3.0']['SummaryDomainValues']['CVT3'][7] = u'Flight'
    field_information['GGDM 3.0']['SummaryDomainValues']['CVT3'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['CWT'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['CWT'][1000] = u'False'
    field_information['GGDM 3.0']['SummaryDomainValues']['CWT'][1001] = u'True'
    field_information['GGDM 3.0']['SummaryDomainValues']['DFT'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['DFT'][1] = u'Vertical'
    field_information['GGDM 3.0']['SummaryDomainValues']['DFT'][2] = u'Slope'
    field_information['GGDM 3.0']['SummaryDomainValues']['DFU'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['DFU'][1] = u'Impoundment'
    field_information['GGDM 3.0']['SummaryDomainValues']['DFU'][2] = u'    Navigation'
    field_information['GGDM 3.0']['SummaryDomainValues']['DFU'][3] = u'    Flood Control'
    field_information['GGDM 3.0']['SummaryDomainValues']['DFU'][4] = u'    Hydroelectric Power Generation'
    field_information['GGDM 3.0']['SummaryDomainValues']['DFU'][5] = u'    Weir'
    field_information['GGDM 3.0']['SummaryDomainValues']['DFU'][6] = u'    Irrigation'
    field_information['GGDM 3.0']['SummaryDomainValues']['DFU'][7] = u'    Recreation'
    field_information['GGDM 3.0']['SummaryDomainValues']['DFU'][8] = u'    Water Supply'
    field_information['GGDM 3.0']['SummaryDomainValues']['DFU'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['DFU2'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['DFU2'][1] = u'Impoundment'
    field_information['GGDM 3.0']['SummaryDomainValues']['DFU2'][2] = u'    Navigation'
    field_information['GGDM 3.0']['SummaryDomainValues']['DFU2'][3] = u'    Flood Control'
    field_information['GGDM 3.0']['SummaryDomainValues']['DFU2'][4] = u'    Hydroelectric Power Generation'
    field_information['GGDM 3.0']['SummaryDomainValues']['DFU2'][5] = u'    Weir'
    field_information['GGDM 3.0']['SummaryDomainValues']['DFU2'][6] = u'    Irrigation'
    field_information['GGDM 3.0']['SummaryDomainValues']['DFU2'][7] = u'    Recreation'
    field_information['GGDM 3.0']['SummaryDomainValues']['DFU2'][8] = u'    Water Supply'
    field_information['GGDM 3.0']['SummaryDomainValues']['DFU2'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['DFU3'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['DFU3'][1] = u'Impoundment'
    field_information['GGDM 3.0']['SummaryDomainValues']['DFU3'][2] = u'    Navigation'
    field_information['GGDM 3.0']['SummaryDomainValues']['DFU3'][3] = u'    Flood Control'
    field_information['GGDM 3.0']['SummaryDomainValues']['DFU3'][4] = u'    Hydroelectric Power Generation'
    field_information['GGDM 3.0']['SummaryDomainValues']['DFU3'][5] = u'    Weir'
    field_information['GGDM 3.0']['SummaryDomainValues']['DFU3'][6] = u'    Irrigation'
    field_information['GGDM 3.0']['SummaryDomainValues']['DFU3'][7] = u'    Recreation'
    field_information['GGDM 3.0']['SummaryDomainValues']['DFU3'][8] = u'    Water Supply'
    field_information['GGDM 3.0']['SummaryDomainValues']['DFU3'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['DGC'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['DGC'][1] = u'Drop Gate'
    field_information['GGDM 3.0']['SummaryDomainValues']['DGC'][2] = u'Rolling Block'
    field_information['GGDM 3.0']['SummaryDomainValues']['DGC'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['DINF'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['DINF'][1] = u'Chlorination'
    field_information['GGDM 3.0']['SummaryDomainValues']['DINF'][2] = u'Ozone'
    field_information['GGDM 3.0']['SummaryDomainValues']['DINF'][3] = u'UV Light'
    field_information['GGDM 3.0']['SummaryDomainValues']['DINF'][4] = u'Iodine'
    field_information['GGDM 3.0']['SummaryDomainValues']['DINF'][5] = u'Bromine'
    field_information['GGDM 3.0']['SummaryDomainValues']['DINF'][6] = u'Bases - Sodium hydroxide or lime'
    field_information['GGDM 3.0']['SummaryDomainValues']['DINF'][7] = u'Ultrasonic'
    field_information['GGDM 3.0']['SummaryDomainValues']['DINF'][8] = u'Heat'
    field_information['GGDM 3.0']['SummaryDomainValues']['DINF'][998] = u'Not Applicable'
    field_information['GGDM 3.0']['SummaryDomainValues']['DINF'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['DIR'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['DIR'][1] = u'Unidirectional'
    field_information['GGDM 3.0']['SummaryDomainValues']['DIR'][2] = u'Bidirectional'
    field_information['GGDM 3.0']['SummaryDomainValues']['DIR'][3] = u'Omnidirectional'
    field_information['GGDM 3.0']['SummaryDomainValues']['DIT'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['DIT'][1] = u'Irrigation'
    field_information['GGDM 3.0']['SummaryDomainValues']['DIT'][2] = u'Drainage'
    field_information['GGDM 3.0']['SummaryDomainValues']['DIT'][3] = u'Sewage'
    field_information['GGDM 3.0']['SummaryDomainValues']['DIT'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['DKC'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['DKC'][1] = u'Depth Known'
    field_information['GGDM 3.0']['SummaryDomainValues']['DKC'][3] = u'Safe Clearance Known'
    field_information['GGDM 3.0']['SummaryDomainValues']['DKC'][4] = u'Depth Unknown'
    field_information['GGDM 3.0']['SummaryDomainValues']['DKC'][5] = u'Depth Doubtful'
    field_information['GGDM 3.0']['SummaryDomainValues']['DKC'][6] = u'Depth Unreliable'
    field_information['GGDM 3.0']['SummaryDomainValues']['DKC'][8] = u'Least Depth'
    field_information['GGDM 3.0']['SummaryDomainValues']['DKC'][9] = u'Reported Depth'
    field_information['GGDM 3.0']['SummaryDomainValues']['DKC'][998] = u'Not Applicable'
    field_information['GGDM 3.0']['SummaryDomainValues']['DKC'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['DKC2'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['DKC2'][1] = u'Depth Known'
    field_information['GGDM 3.0']['SummaryDomainValues']['DKC2'][3] = u'Safe Clearance Known'
    field_information['GGDM 3.0']['SummaryDomainValues']['DKC2'][4] = u'Depth Unknown'
    field_information['GGDM 3.0']['SummaryDomainValues']['DKC2'][5] = u'Depth Doubtful'
    field_information['GGDM 3.0']['SummaryDomainValues']['DKC2'][6] = u'Depth Unreliable'
    field_information['GGDM 3.0']['SummaryDomainValues']['DKC2'][8] = u'Least Depth'
    field_information['GGDM 3.0']['SummaryDomainValues']['DKC2'][9] = u'Reported Depth'
    field_information['GGDM 3.0']['SummaryDomainValues']['DKC2'][998] = u'Not Applicable'
    field_information['GGDM 3.0']['SummaryDomainValues']['DKC2'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['DKC3'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['DKC3'][1] = u'Depth Known'
    field_information['GGDM 3.0']['SummaryDomainValues']['DKC3'][3] = u'Safe Clearance Known'
    field_information['GGDM 3.0']['SummaryDomainValues']['DKC3'][4] = u'Depth Unknown'
    field_information['GGDM 3.0']['SummaryDomainValues']['DKC3'][5] = u'Depth Doubtful'
    field_information['GGDM 3.0']['SummaryDomainValues']['DKC3'][6] = u'Depth Unreliable'
    field_information['GGDM 3.0']['SummaryDomainValues']['DKC3'][8] = u'Least Depth'
    field_information['GGDM 3.0']['SummaryDomainValues']['DKC3'][9] = u'Reported Depth'
    field_information['GGDM 3.0']['SummaryDomainValues']['DKC3'][998] = u'Not Applicable'
    field_information['GGDM 3.0']['SummaryDomainValues']['DKC3'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['DKS'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['DKS'][1] = u'Rectangle'
    field_information['GGDM 3.0']['SummaryDomainValues']['DKS'][2] = u'Square'
    field_information['GGDM 3.0']['SummaryDomainValues']['DKS'][3] = u'Triangle'
    field_information['GGDM 3.0']['SummaryDomainValues']['DKS'][4] = u'Cage'
    field_information['GGDM 3.0']['SummaryDomainValues']['DKS'][5] = u'Diamond'
    field_information['GGDM 3.0']['SummaryDomainValues']['DKS'][6] = u'Circular'
    field_information['GGDM 3.0']['SummaryDomainValues']['DKS'][7] = u'Trapezoidal'
    field_information['GGDM 3.0']['SummaryDomainValues']['DMBC'][2] = u'Open Interval'
    field_information['GGDM 3.0']['SummaryDomainValues']['DMBC'][3] = u'Greater-than-or-equal to Less-than Interval'
    field_information['GGDM 3.0']['SummaryDomainValues']['DMBC'][4] = u'Greater-than to Less-than-or-equal Interval'
    field_information['GGDM 3.0']['SummaryDomainValues']['DMBC'][5] = u'Closed Interval'
    field_information['GGDM 3.0']['SummaryDomainValues']['DMBC'][6] = u'Greater-than Semi-interval'
    field_information['GGDM 3.0']['SummaryDomainValues']['DMBC'][7] = u'Greater-than or Equal Semi-interval'
    field_information['GGDM 3.0']['SummaryDomainValues']['DMBC'][8] = u'Less-than Semi-interval'
    field_information['GGDM 3.0']['SummaryDomainValues']['DMBC'][9] = u'Less-than or Equal Semi-interval'
    field_information['GGDM 3.0']['SummaryDomainValues']['DMC'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['DMC'][1000] = u'False'
    field_information['GGDM 3.0']['SummaryDomainValues']['DMC'][1001] = u'True'
    field_information['GGDM 3.0']['SummaryDomainValues']['DMD'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['DMD'][1000] = u'False'
    field_information['GGDM 3.0']['SummaryDomainValues']['DMD'][1001] = u'True'
    field_information['GGDM 3.0']['SummaryDomainValues']['DNE'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['DNE'][1] = u'Highest Development'
    field_information['GGDM 3.0']['SummaryDomainValues']['DNE'][2] = u'High Development'
    field_information['GGDM 3.0']['SummaryDomainValues']['DNE'][3] = u'Rapid Development'
    field_information['GGDM 3.0']['SummaryDomainValues']['DNE'][4] = u'Developing'
    field_information['GGDM 3.0']['SummaryDomainValues']['DNE'][5] = u'Low Development'
    field_information['GGDM 3.0']['SummaryDomainValues']['DPAC'][2] = u'Open Interval'
    field_information['GGDM 3.0']['SummaryDomainValues']['DPAC'][3] = u'Greater-than-or-equal to Less-than Interval'
    field_information['GGDM 3.0']['SummaryDomainValues']['DPAC'][4] = u'Greater-than to Less-than-or-equal Interval'
    field_information['GGDM 3.0']['SummaryDomainValues']['DPAC'][5] = u'Closed Interval'
    field_information['GGDM 3.0']['SummaryDomainValues']['DPAC'][6] = u'Greater-than Semi-interval'
    field_information['GGDM 3.0']['SummaryDomainValues']['DPAC'][7] = u'Greater-than or Equal Semi-interval'
    field_information['GGDM 3.0']['SummaryDomainValues']['DPAC'][8] = u'Less-than Semi-interval'
    field_information['GGDM 3.0']['SummaryDomainValues']['DPAC'][9] = u'Less-than or Equal Semi-interval'
    field_information['GGDM 3.0']['SummaryDomainValues']['DPG'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['DPG'][1] = u'Hazardous Material'
    field_information['GGDM 3.0']['SummaryDomainValues']['DPG'][2] = u'Chemical Waste'
    field_information['GGDM 3.0']['SummaryDomainValues']['DPG'][3] = u'Nuclear Waste'
    field_information['GGDM 3.0']['SummaryDomainValues']['DPG'][4] = u'Explosives'
    field_information['GGDM 3.0']['SummaryDomainValues']['DPG'][5] = u'Spoil'
    field_information['GGDM 3.0']['SummaryDomainValues']['DPG'][6] = u'Vessels'
    field_information['GGDM 3.0']['SummaryDomainValues']['DPG'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['DPG2'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['DPG2'][1] = u'Hazardous Material'
    field_information['GGDM 3.0']['SummaryDomainValues']['DPG2'][2] = u'Chemical Waste'
    field_information['GGDM 3.0']['SummaryDomainValues']['DPG2'][3] = u'Nuclear Waste'
    field_information['GGDM 3.0']['SummaryDomainValues']['DPG2'][4] = u'Explosives'
    field_information['GGDM 3.0']['SummaryDomainValues']['DPG2'][5] = u'Spoil'
    field_information['GGDM 3.0']['SummaryDomainValues']['DPG2'][6] = u'Vessels'
    field_information['GGDM 3.0']['SummaryDomainValues']['DPG2'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['DPG3'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['DPG3'][1] = u'Hazardous Material'
    field_information['GGDM 3.0']['SummaryDomainValues']['DPG3'][2] = u'Chemical Waste'
    field_information['GGDM 3.0']['SummaryDomainValues']['DPG3'][3] = u'Nuclear Waste'
    field_information['GGDM 3.0']['SummaryDomainValues']['DPG3'][4] = u'Explosives'
    field_information['GGDM 3.0']['SummaryDomainValues']['DPG3'][5] = u'Spoil'
    field_information['GGDM 3.0']['SummaryDomainValues']['DPG3'][6] = u'Vessels'
    field_information['GGDM 3.0']['SummaryDomainValues']['DPG3'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['DSD'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['DSD'][101] = u'Arch'
    field_information['GGDM 3.0']['SummaryDomainValues']['DSD'][102] = u'Buttress'
    field_information['GGDM 3.0']['SummaryDomainValues']['DSD'][103] = u'Gravity'
    field_information['GGDM 3.0']['SummaryDomainValues']['DSD'][104] = u'Multi-Arch'
    field_information['GGDM 3.0']['SummaryDomainValues']['DSD'][105] = u'Earthen'
    field_information['GGDM 3.0']['SummaryDomainValues']['DSD'][106] = u'Rockfill'
    field_information['GGDM 3.0']['SummaryDomainValues']['DSD'][107] = u'Asphalt-concrete core'
    field_information['GGDM 3.0']['SummaryDomainValues']['DSD'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['DSP'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['DSP'][1] = u'In Dispute'
    field_information['GGDM 3.0']['SummaryDomainValues']['DSP'][2] = u'Undisputed'
    field_information['GGDM 3.0']['SummaryDomainValues']['DSP'][3] = u'De Facto'
    field_information['GGDM 3.0']['SummaryDomainValues']['DSP'][4] = u'De Jure'
    field_information['GGDM 3.0']['SummaryDomainValues']['DTN'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['DTN'][1000] = u'False'
    field_information['GGDM 3.0']['SummaryDomainValues']['DTN'][1001] = u'True'
    field_information['GGDM 3.0']['SummaryDomainValues']['EET'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['EET'][1] = u'Battery'
    field_information['GGDM 3.0']['SummaryDomainValues']['EET'][2] = u'Military Parapet'
    field_information['GGDM 3.0']['SummaryDomainValues']['EET'][3] = u'Military Trench'
    field_information['GGDM 3.0']['SummaryDomainValues']['EET'][4] = u'Rampart'
    field_information['GGDM 3.0']['SummaryDomainValues']['EET'][5] = u'Redoubt'
    field_information['GGDM 3.0']['SummaryDomainValues']['EET'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['ESC'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['ESC'][1] = u'Land'
    field_information['GGDM 3.0']['SummaryDomainValues']['ESC'][2] = u'Snow Field and/or Ice-field'
    field_information['GGDM 3.0']['SummaryDomainValues']['ESC'][4] = u'Vegetation'
    field_information['GGDM 3.0']['SummaryDomainValues']['ESC'][5] = u'Inland Water'
    field_information['GGDM 3.0']['SummaryDomainValues']['ESC'][6] = u'Tidal Water'
    field_information['GGDM 3.0']['SummaryDomainValues']['ETS'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['ETS'][1] = u'1AA-TPC'
    field_information['GGDM 3.0']['SummaryDomainValues']['ETS'][2] = u'1AB-ONC'
    field_information['GGDM 3.0']['SummaryDomainValues']['ETS'][3] = u'1AE-JOG-A/G'
    field_information['GGDM 3.0']['SummaryDomainValues']['ETS'][4] = u'1CD-DTED-1'
    field_information['GGDM 3.0']['SummaryDomainValues']['ETS'][5] = u'1CE-DFAD-1'
    field_information['GGDM 3.0']['SummaryDomainValues']['ETS'][6] = u'1CF-DTED-2'
    field_information['GGDM 3.0']['SummaryDomainValues']['ETS'][7] = u'1CG-DFAD-2'
    field_information['GGDM 3.0']['SummaryDomainValues']['ETS'][8] = u'2AA/001-HAC-1'
    field_information['GGDM 3.0']['SummaryDomainValues']['ETS'][9] = u'2AA/002-HAC-2'
    field_information['GGDM 3.0']['SummaryDomainValues']['ETS'][10] = u'2AA/003-HAC-3'
    field_information['GGDM 3.0']['SummaryDomainValues']['ETS'][11] = u'2AA/004-HAC-4'
    field_information['GGDM 3.0']['SummaryDomainValues']['ETS'][12] = u'2AA/005-HAC-5'
    field_information['GGDM 3.0']['SummaryDomainValues']['ETS'][13] = u'2AA/006-HAC-6'
    field_information['GGDM 3.0']['SummaryDomainValues']['ETS'][14] = u'2AA/007-HAC-7'
    field_information['GGDM 3.0']['SummaryDomainValues']['ETS'][15] = u'2AA/008-HAC-8'
    field_information['GGDM 3.0']['SummaryDomainValues']['ETS'][16] = u'2AA/009-HAC-9'
    field_information['GGDM 3.0']['SummaryDomainValues']['ETS'][17] = u'2AD-Combat'
    field_information['GGDM 3.0']['SummaryDomainValues']['ETS'][18] = u'3AA-TLM50'
    field_information['GGDM 3.0']['SummaryDomainValues']['ETS'][19] = u'3AG-TLM100'
    field_information['GGDM 3.0']['SummaryDomainValues']['ETS'][20] = u'3KA-VITD'
    field_information['GGDM 3.0']['SummaryDomainValues']['ETS'][21] = u'3KC/001-DTOP'
    field_information['GGDM 3.0']['SummaryDomainValues']['ETS'][22] = u'3KH-VMap-2'
    field_information['GGDM 3.0']['SummaryDomainValues']['ETS'][23] = u'3KL-VMap-0'
    field_information['GGDM 3.0']['SummaryDomainValues']['ETS'][24] = u'3KM-VMap-1'
    field_information['GGDM 3.0']['SummaryDomainValues']['ETS'][25] = u'3KU-UVMap'
    field_information['GGDM 3.0']['SummaryDomainValues']['ETS'][26] = u'4AA-ATC'
    field_information['GGDM 3.0']['SummaryDomainValues']['ETS'][27] = u'4AC-JOG-R'
    field_information['GGDM 3.0']['SummaryDomainValues']['ETS'][28] = u'4GE-TERCOM-L'
    field_information['GGDM 3.0']['SummaryDomainValues']['ETS'][29] = u'4GF-TERCOM-E'
    field_information['GGDM 3.0']['SummaryDomainValues']['ETS'][30] = u'4GG-TERCOM-T'
    field_information['GGDM 3.0']['SummaryDomainValues']['ETS'][31] = u'5EE-FFD'
    field_information['GGDM 3.0']['SummaryDomainValues']['ETS'][43] = u'DNC'
    field_information['GGDM 3.0']['SummaryDomainValues']['ETS'][44] = u'MSD1'
    field_information['GGDM 3.0']['SummaryDomainValues']['ETS'][45] = u'MSD2'
    field_information['GGDM 3.0']['SummaryDomainValues']['ETS'][46] = u'MSD3'
    field_information['GGDM 3.0']['SummaryDomainValues']['ETS'][47] = u'MSD4'
    field_information['GGDM 3.0']['SummaryDomainValues']['ETS'][48] = u'MSD5'
    field_information['GGDM 3.0']['SummaryDomainValues']['ETS'][49] = u'TOD0'
    field_information['GGDM 3.0']['SummaryDomainValues']['ETS'][50] = u'TOD1'
    field_information['GGDM 3.0']['SummaryDomainValues']['ETS'][51] = u'TOD2'
    field_information['GGDM 3.0']['SummaryDomainValues']['ETS'][52] = u'TOD3'
    field_information['GGDM 3.0']['SummaryDomainValues']['ETS'][53] = u'TOD4'
    field_information['GGDM 3.0']['SummaryDomainValues']['ETS'][56] = u'DFEG'
    field_information['GGDM 3.0']['SummaryDomainValues']['ETS'][57] = u'GTDS-EG'
    field_information['GGDM 3.0']['SummaryDomainValues']['ETS'][58] = u'RTDS-EG'
    field_information['GGDM 3.0']['SummaryDomainValues']['ETS'][59] = u'LTDS-EG'
    field_information['GGDM 3.0']['SummaryDomainValues']['ETS'][60] = u'S-UTDS-EG'
    field_information['GGDM 3.0']['SummaryDomainValues']['ETS'][61] = u'MGCP TRD'
    field_information['GGDM 3.0']['SummaryDomainValues']['ETS'][998] = u'Not Applicable'
    field_information['GGDM 3.0']['SummaryDomainValues']['ETS'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['ETY'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['ETY'][1] = u'Jet Engine Dismounted'
    field_information['GGDM 3.0']['SummaryDomainValues']['ETY'][2] = u'Jet Engine Mounted'
    field_information['GGDM 3.0']['SummaryDomainValues']['ETY'][3] = u'Rocket Engine Upright'
    field_information['GGDM 3.0']['SummaryDomainValues']['ETY'][4] = u'Rocket Engine Horizontal'
    field_information['GGDM 3.0']['SummaryDomainValues']['ETY'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['EXP'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['EXP'][1] = u'Siding'
    field_information['GGDM 3.0']['SummaryDomainValues']['EXP'][2] = u'Increased Track or Lane Count'
    field_information['GGDM 3.0']['SummaryDomainValues']['EXP'][3] = u'Railway Sidetrack'
    field_information['GGDM 3.0']['SummaryDomainValues']['EXP'][4] = u'Roadside Rest Area'
    field_information['GGDM 3.0']['SummaryDomainValues']['EXP'][5] = u'Shoulder'
    field_information['GGDM 3.0']['SummaryDomainValues']['EXP'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['FA003_BAL'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['FA003_BAL'][1] = u'First-order'
    field_information['GGDM 3.0']['SummaryDomainValues']['FA003_BAL'][2] = u'Second-order'
    field_information['GGDM 3.0']['SummaryDomainValues']['FA003_BAL'][3] = u'Third-order'
    field_information['GGDM 3.0']['SummaryDomainValues']['FA003_BAL'][4] = u'Fourth-order'
    field_information['GGDM 3.0']['SummaryDomainValues']['FA003_BAL'][5] = u'Undifferentiated'
    field_information['GGDM 3.0']['SummaryDomainValues']['FA003_BAL'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['FAC'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['FAC'][1000] = u'False'
    field_information['GGDM 3.0']['SummaryDomainValues']['FAC'][1001] = u'True'
    field_information['GGDM 3.0']['SummaryDomainValues']['FCO'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['FCO'][5] = u'Divided Same'
    field_information['GGDM 3.0']['SummaryDomainValues']['FCO'][6] = u'Divided Different'
    field_information['GGDM 3.0']['SummaryDomainValues']['FCO'][7] = u'Non-divided'
    field_information['GGDM 3.0']['SummaryDomainValues']['FCS'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['FCS'][1] = u'Dyke Gate'
    field_information['GGDM 3.0']['SummaryDomainValues']['FCS'][2] = u'Emergency Gate'
    field_information['GGDM 3.0']['SummaryDomainValues']['FCS'][3] = u'Flood Gate'
    field_information['GGDM 3.0']['SummaryDomainValues']['FCS'][4] = u'Fixed Barrage'
    field_information['GGDM 3.0']['SummaryDomainValues']['FCS'][5] = u'Movable Barrage'
    field_information['GGDM 3.0']['SummaryDomainValues']['FCS'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['FEF'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['FEF'][1] = u'Animal Containment'
    field_information['GGDM 3.0']['SummaryDomainValues']['FEF'][2] = u'Erosion-control'
    field_information['GGDM 3.0']['SummaryDomainValues']['FEF'][3] = u'Exclusion'
    field_information['GGDM 3.0']['SummaryDomainValues']['FEF'][4] = u'Security'
    field_information['GGDM 3.0']['SummaryDomainValues']['FEF'][5] = u'Wind'
    field_information['GGDM 3.0']['SummaryDomainValues']['FEF'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['FER'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['FER'][1] = u'Cable'
    field_information['GGDM 3.0']['SummaryDomainValues']['FER'][2] = u'Free-moving'
    field_information['GGDM 3.0']['SummaryDomainValues']['FER'][3] = u'Ice'
    field_information['GGDM 3.0']['SummaryDomainValues']['FER'][4] = u'High-speed Crossing'
    field_information['GGDM 3.0']['SummaryDomainValues']['FER'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][2] = u'Agriculture'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][3] = u'    Growing of Crops'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][9] = u'    Raising of Animals'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][14] = u'    Grazing'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][15] = u'    Mixed Farming'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][16] = u'Migrant Labour'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][19] = u'Hunting'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][20] = u'Forestry and/or Logging'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][21] = u'    Silviculture'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][27] = u'    Forest Warden'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][30] = u'Fishing'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][35] = u'    Aquaculture'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][40] = u'Mining and Quarrying'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][50] = u'    Solid Mineral Fuel Mining'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][60] = u'    Petroleum and/or Gas Extraction'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][70] = u'    Metal Ore Mining'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][83] = u'    Chemical Mining'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][84] = u'    Peat Extraction'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][85] = u'    Salt Extraction'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][87] = u'    Mineral Mining'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][91] = u'    Gas Oil Separation'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][95] = u'    Ore Dressing'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][99] = u'Manufacturing'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][100] = u'    Food Product Manufacture'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][101] = u'        Food Processing'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][102] = u'            Meat Processing'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][103] = u'            Seafood Processing'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][104] = u'            Fruit and/or Vegetable Processing'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][105] = u'        Oil-mill'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][106] = u'        Dairying'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][107] = u'        Grain Milling'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][110] = u'        Baking'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][111] = u'        Sugar Manufacture'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][112] = u'            Sugar Milling'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][113] = u'            Sugar Refining'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][114] = u'        Confection Manufacture'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][115] = u'        Pasta Manufacture'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][116] = u'        Prepared Meal Manufacture'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][118] = u'    Beverage Manufacture'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][119] = u'        Animal Feed Manufacture'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][120] = u'        Ice Manufacture'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][121] = u'        Spirit Distillery'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][122] = u'        Winery'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][123] = u'        Brewing'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][124] = u'        Soft Drink Manufacture'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][125] = u'    Tobacco Product Manufacture'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][129] = u'    Textile, Apparel and Leather Manufacture'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][130] = u'        Textile Manufacture'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][140] = u'        Apparel Manufacture'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][150] = u'        Leather Product Manufacture'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][155] = u'        Footwear Manufacturing'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][160] = u'    Wood-based Manufacturing'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][161] = u'        Sawmilling'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][165] = u'        Wooden Construction Product Manufacture'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][171] = u'    Paper-mill'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][181] = u'    Printing'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][190] = u'    Petroleum and Coal Products Manufacturing'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][191] = u'        Coke Manufacture'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][192] = u'        Petroleum Refining'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][195] = u'    Chemical Manufacture'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][210] = u'    Medicinal Product Manufacture'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][221] = u'    Rubber Product Manufacture'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][225] = u'    Plastic Product Manufacture'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][230] = u'    Nonmetallic Mineral Product Manufacturing'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][231] = u'        Glass Product Manufacture'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][232] = u'        Refractory Product Manufacture'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][233] = u'        Clay Product Manufacture'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][234] = u'        Ceramic Product Manufacture'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][235] = u'        Cement Mill'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][236] = u'        Cement Product Manufacture'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][237] = u'        Stone Product Manufacture'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][240] = u'    Primary Metal Manufacturing'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][241] = u'        Steel Mill'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][242] = u'        Metal Refining'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][243] = u'        Foundry'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][250] = u'    Metal Product Manufacturing'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][251] = u'        Structural Metal Product Manufacture'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][255] = u'    Munitions Manufacture'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][257] = u'        Fabricated Metal Product Manufacture'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][260] = u'    Electronic Equipment Manufacture'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][270] = u'    Electrical Equipment Manufacture'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][272] = u'            Propane Sale'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][280] = u'    Machinery Manufacture'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][289] = u'    Transportation Equipment Manufacturing'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][290] = u'        Motor Vehicle Manufacture'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][301] = u'        Ship Construction'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][304] = u'        Railway Vehicle Manufacture'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][305] = u'        Aircraft Manufacture'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][306] = u'        Military Vehicle Manufacture'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][310] = u'    Furniture Manufacture'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][320] = u'    Miscellaneous Manufacturing'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][321] = u'        Jewellery Manufacture'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][322] = u'        Musical Instrument Manufacture'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][323] = u'        Sports Goods Manufacture'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][324] = u'        Game and/or Toy Manufacture'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][325] = u'        Medical and/or Dental Equipment Manufacture'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][330] = u'    General Repair'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][331] = u'        Fabricated Metal Product Repair'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][332] = u'        Electronic Equipment Repair'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][333] = u'        Electrical Equipment Repair'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][334] = u'        Machinery Repair'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][340] = u'        Ship Repair'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][341] = u'        Aircraft Repair'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][342] = u'        Railway Vehicle Repair'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][343] = u'        Motor Vehicle Repair'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][350] = u'Utilities'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][351] = u'    Power Generation'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][352] = u'    Climate Control'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][355] = u'        Cooling'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][356] = u'        Heating'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][360] = u'    Water Supply'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][361] = u'        Water Collection'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][362] = u'        Water Treatment'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][363] = u'        Water Distribution'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][370] = u'    Sewerage'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][372] = u'        Sewerage Screening'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][382] = u'        Restroom'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][383] = u'    Waste Treatment and Disposal'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][385] = u'    Materials Recovery'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][440] = u'Commerce'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][459] = u'    Wholesale Merchant'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][460] = u'    Retail Sale'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][464] = u'        Specialized Store'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][465] = u'        Non-specialized Store'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][466] = u'            Convenience Store'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][470] = u'            Petrol Sale'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][473] = u'            Sales Yard'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][474] = u'            Precious Metal Merchant'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][475] = u'            Market'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][476] = u'            Grocery'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][477] = u'            Pharmacy'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][478] = u'            Pet-shop'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][480] = u'Transport'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][481] = u'        Terminal'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][482] = u'        Station'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][483] = u'        Stop'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][484] = u'        Transfer Hub'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][486] = u'        Signalling'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][487] = u'        Transport System Maintenance'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][488] = u'        Navigation'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][489] = u'    Transportation Hub'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][490] = u'    Railway Transport'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][491] = u'        Railway Passenger Transport'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][494] = u'    Pedestrian Transport'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][495] = u'    Road Transport'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][496] = u'        Road Passenger Transport'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][497] = u'        Road Freight Transport'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][500] = u'    Pipeline Transport'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][501] = u'        Pumping'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][505] = u'    Water Transport'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][507] = u'        Inland Waters Transport'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][508] = u'            Canal Transport'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][510] = u'        Port Control'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][511] = u'        Maritime Pilotage'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][512] = u'        Pilot Station'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][513] = u'        Harbour Control'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][520] = u'    Air Transport'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][525] = u'        Air Traffic Control'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][529] = u'    Transportation Support'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][530] = u'        Warehousing and Storage'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][535] = u'            Motor Vehicle Parking'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][536] = u'            Cargo Handling'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][537] = u'            Customs Checkpoint'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][538] = u'            Inspection Station'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][539] = u'        Inspection'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][540] = u'        Postal Activities'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][541] = u'    Mail and Package Transport'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][545] = u'        Courier Activities'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][548] = u'    Short-term Accommodation'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][549] = u'    Long-term Accommodation'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][550] = u'Accommodation'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][551] = u'        Hotel'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][552] = u'        Resort'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][553] = u'        Motel'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][554] = u'        Guest-house'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][555] = u'        Hostel'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][556] = u'        Dormitory'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][557] = u'        Vacation Cottage'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][558] = u'        Dependents Housing'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][559] = u'        Communal Bath'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][563] = u'        Residence'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][570] = u'Food Service'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][572] = u'    Restaurant'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][573] = u'    Bar'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][574] = u'    Dining Hall'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][578] = u'    Banquet Hall'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][579] = u'    Convention Centre'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][580] = u'Publishing and Broadcasting'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][582] = u'    Print Publishing'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][594] = u'    Cinema'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][601] = u'    Radio Broadcasting'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][604] = u'    Television Broadcasting'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][610] = u'Telecommunications'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][612] = u'    Retail Telecommunications'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][614] = u'    Wired Telecommunications'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][615] = u'        Main Telephone Exchange'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][616] = u'        Branch Telephone Exchange'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][617] = u'        Wired Repeater'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][620] = u'    Wireless Telecommunications'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][621] = u'        Mobile Phone Service'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][622] = u'        Wireless Repeater'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][625] = u'    Satellite Telecommunications'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][626] = u'        Satellite Ground Control'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][632] = u'    Information Service'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][633] = u'        Public Records'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][640] = u'Financial Services'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][642] = u'    Central Banking'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][643] = u'    Retail Banking'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][651] = u'    Insurance'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][662] = u'    Financial Market Administration'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][663] = u'    Security Brokerage'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][671] = u'    Fund Management'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][680] = u'Real Estate Activities'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][681] = u'Professional, Scientific and Technical'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][691] = u'    Legal Activities'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][696] = u'    Accounting'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][701] = u'    Head Office'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][706] = u'    Business Management'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][711] = u'    Architecture Consulting'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][714] = u'    Engineering Design'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][717] = u'    Surveying'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][720] = u'    Scientific Research and Development'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][721] = u'        Observation Station'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][722] = u'        Weather Station'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][725] = u'        Nuclear Research Centre'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][730] = u'        Wind Tunnel'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][741] = u'    Advertising'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][752] = u'    Photography'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][757] = u'    Veterinary'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][760] = u'Business and Personal Support Services'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][761] = u'    Motor Vehicle Rental'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][770] = u'    Employment Agency'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][775] = u'    Travel Agency'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][780] = u'        Security Enforcement'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][781] = u'        Guard'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][791] = u'    Custodial Service'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][795] = u'    Landscaping Service'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][801] = u'    Office Administration'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][807] = u'    Call Centre'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][808] = u'Public Administration'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][809] = u'    Headquarters'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][810] = u'    Administration'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][811] = u'    Government'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][812] = u'        Local Government'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][813] = u'        Subnational Government'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][814] = u'        National Government'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][815] = u'        Palace'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][817] = u'        Capitol'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][818] = u'        Executive Activities'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][819] = u'        Legislative Activities'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][821] = u'        Polling Station'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][822] = u'        Civil Activities'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][825] = u'    Diplomacy'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][826] = u'        Diplomatic Mission'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][827] = u'        Embassy'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][828] = u'        Consul'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][829] = u'        Maritime Defence'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][830] = u'Public Order, Safety and Security Services'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][831] = u'    Public Order'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][832] = u'    Safety'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][833] = u'    Security Services'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][835] = u'    Defence Activities'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][836] = u'        Armoury'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][837] = u'        Military Reserve Activities'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][838] = u'        Military Recruitment'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][839] = u'        CBRNE Civilian Support'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][840] = u'        Judicial Activities'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][841] = u'        Law Enforcement'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][842] = u'        Immigration Control'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][843] = u'        Imprisonment'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][844] = u'        Juvenile Corrections'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][845] = u'        Firefighting'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][846] = u'        Rescue and Paramedical Services'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][847] = u'        Emergency Operations'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][848] = u'        Civil Intelligence'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][850] = u'Education'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][851] = u'    Primary Education'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][852] = u'    Secondary Education'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][855] = u'    Higher Education'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][857] = u'    Vocational Education'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][860] = u'Human Health Activities'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][861] = u'    In-patient Care'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][862] = u'    Out-patient Care'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][863] = u'        Urgent Medical Care'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][864] = u'    Human Tissue Repository'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][865] = u'    Public Health Activities'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][866] = u'    Leprosy Care'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][871] = u'        Intermediate Care'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][873] = u'        Psychiatric In-patient Care'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][875] = u'        Residential Care'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][881] = u'    Emergency Shelter'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][882] = u'    Homeless Shelter'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][883] = u'    Refugee Shelter'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][884] = u'        Emergency Youth Shelter'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][885] = u'    Day Care'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][887] = u'Social Work'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][888] = u'        Emergency Relief Services'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][890] = u'Cultural, Arts and Entertainment'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][891] = u'    Theatre'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][892] = u'    Auditorium'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][893] = u'    Community Centre'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][894] = u'    Opera House'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][895] = u'    Night Club'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][900] = u'Sports, Amusement and Recreation'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][902] = u'    Library'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][905] = u'    Museum'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][906] = u'    Aquarium'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][907] = u'    Botanical and/or Zoological Reserve Activities'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][909] = u'    Gambling'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][912] = u'    Sports Centre'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][913] = u'    Fitness Centre'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][914] = u'    Shooting Range'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][915] = u'    Water Park'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][919] = u'    Animal Boarding'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][921] = u'    Recreation'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][922] = u'    Amusement'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][923] = u'    Hobbies and/or Leisure Activities'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][930] = u'Religious Activities'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][931] = u'    Place of Worship'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][950] = u'Membership Organization'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][954] = u'    Club'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][955] = u'    Yacht-club'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][961] = u'    Laundry'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][962] = u'    Beauty Treatment'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][963] = u'    Funeral Services'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][964] = u'    Cremation'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][965] = u'    Mortuary Services'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][966] = u'    Adult Entertainment'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][967] = u'    Storage of Human Remains'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][970] = u'Meeting Place'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][980] = u'Death Care Services'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][2] = u'Agriculture'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][3] = u'    Growing of Crops'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][9] = u'    Raising of Animals'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][14] = u'    Grazing'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][15] = u'    Mixed Farming'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][16] = u'Migrant Labour'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][19] = u'Hunting'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][20] = u'Forestry and/or Logging'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][21] = u'    Silviculture'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][27] = u'    Forest Warden'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][30] = u'Fishing'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][35] = u'    Aquaculture'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][40] = u'Mining and Quarrying'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][50] = u'    Solid Mineral Fuel Mining'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][60] = u'    Petroleum and/or Gas Extraction'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][70] = u'    Metal Ore Mining'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][83] = u'    Chemical Mining'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][84] = u'    Peat Extraction'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][85] = u'    Salt Extraction'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][87] = u'    Mineral Mining'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][91] = u'    Gas Oil Separation'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][95] = u'    Ore Dressing'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][99] = u'Manufacturing'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][100] = u'    Food Product Manufacture'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][101] = u'        Food Processing'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][102] = u'            Meat Processing'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][103] = u'            Seafood Processing'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][104] = u'            Fruit and/or Vegetable Processing'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][105] = u'        Oil-mill'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][106] = u'        Dairying'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][107] = u'        Grain Milling'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][110] = u'        Baking'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][111] = u'        Sugar Manufacture'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][112] = u'            Sugar Milling'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][113] = u'            Sugar Refining'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][114] = u'        Confection Manufacture'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][115] = u'        Pasta Manufacture'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][116] = u'        Prepared Meal Manufacture'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][118] = u'    Beverage Manufacture'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][119] = u'        Animal Feed Manufacture'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][120] = u'        Ice Manufacture'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][121] = u'        Spirit Distillery'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][122] = u'        Winery'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][123] = u'        Brewing'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][124] = u'        Soft Drink Manufacture'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][125] = u'    Tobacco Product Manufacture'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][129] = u'    Textile, Apparel and Leather Manufacture'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][130] = u'        Textile Manufacture'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][140] = u'        Apparel Manufacture'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][150] = u'        Leather Product Manufacture'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][155] = u'        Footwear Manufacturing'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][160] = u'    Wood-based Manufacturing'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][161] = u'        Sawmilling'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][165] = u'        Wooden Construction Product Manufacture'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][171] = u'    Paper-mill'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][181] = u'    Printing'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][190] = u'    Petroleum and Coal Products Manufacturing'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][191] = u'        Coke Manufacture'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][192] = u'        Petroleum Refining'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][195] = u'    Chemical Manufacture'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][210] = u'    Medicinal Product Manufacture'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][221] = u'    Rubber Product Manufacture'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][225] = u'    Plastic Product Manufacture'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][230] = u'    Nonmetallic Mineral Product Manufacturing'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][231] = u'        Glass Product Manufacture'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][232] = u'        Refractory Product Manufacture'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][233] = u'        Clay Product Manufacture'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][234] = u'        Ceramic Product Manufacture'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][235] = u'        Cement Mill'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][236] = u'        Cement Product Manufacture'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][237] = u'        Stone Product Manufacture'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][240] = u'    Primary Metal Manufacturing'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][241] = u'        Steel Mill'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][242] = u'        Metal Refining'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][243] = u'        Foundry'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][250] = u'    Metal Product Manufacturing'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][251] = u'        Structural Metal Product Manufacture'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][255] = u'    Munitions Manufacture'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][257] = u'        Fabricated Metal Product Manufacture'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][260] = u'    Electronic Equipment Manufacture'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][270] = u'    Electrical Equipment Manufacture'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][272] = u'            Propane Sale'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][280] = u'    Machinery Manufacture'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][289] = u'    Transportation Equipment Manufacturing'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][290] = u'        Motor Vehicle Manufacture'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][301] = u'        Ship Construction'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][304] = u'        Railway Vehicle Manufacture'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][305] = u'        Aircraft Manufacture'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][306] = u'        Military Vehicle Manufacture'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][310] = u'    Furniture Manufacture'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][320] = u'    Miscellaneous Manufacturing'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][321] = u'        Jewellery Manufacture'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][322] = u'        Musical Instrument Manufacture'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][323] = u'        Sports Goods Manufacture'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][324] = u'        Game and/or Toy Manufacture'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][325] = u'        Medical and/or Dental Equipment Manufacture'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][330] = u'    General Repair'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][331] = u'        Fabricated Metal Product Repair'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][332] = u'        Electronic Equipment Repair'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][333] = u'        Electrical Equipment Repair'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][334] = u'        Machinery Repair'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][340] = u'        Ship Repair'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][341] = u'        Aircraft Repair'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][342] = u'        Railway Vehicle Repair'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][343] = u'        Motor Vehicle Repair'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][350] = u'Utilities'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][351] = u'    Power Generation'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][352] = u'    Climate Control'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][355] = u'        Cooling'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][356] = u'        Heating'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][360] = u'    Water Supply'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][361] = u'        Water Collection'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][362] = u'        Water Treatment'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][363] = u'        Water Distribution'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][370] = u'    Sewerage'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][372] = u'        Sewerage Screening'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][382] = u'        Restroom'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][383] = u'    Waste Treatment and Disposal'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][385] = u'    Materials Recovery'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][440] = u'Commerce'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][459] = u'    Wholesale Merchant'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][460] = u'    Retail Sale'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][464] = u'        Specialized Store'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][465] = u'        Non-specialized Store'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][466] = u'            Convenience Store'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][470] = u'            Petrol Sale'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][473] = u'            Sales Yard'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][474] = u'            Precious Metal Merchant'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][475] = u'            Market'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][476] = u'            Grocery'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][477] = u'            Pharmacy'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][478] = u'            Pet-shop'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][480] = u'Transport'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][481] = u'        Terminal'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][482] = u'        Station'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][483] = u'        Stop'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][484] = u'        Transfer Hub'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][486] = u'        Signalling'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][487] = u'        Transport System Maintenance'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][488] = u'        Navigation'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][489] = u'    Transportation Hub'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][490] = u'    Railway Transport'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][491] = u'        Railway Passenger Transport'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][494] = u'    Pedestrian Transport'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][495] = u'    Road Transport'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][496] = u'        Road Passenger Transport'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][497] = u'        Road Freight Transport'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][500] = u'    Pipeline Transport'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][501] = u'        Pumping'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][505] = u'    Water Transport'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][507] = u'        Inland Waters Transport'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][508] = u'            Canal Transport'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][510] = u'        Port Control'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][511] = u'        Maritime Pilotage'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][512] = u'        Pilot Station'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][513] = u'        Harbour Control'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][520] = u'    Air Transport'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][525] = u'        Air Traffic Control'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][529] = u'    Transportation Support'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][530] = u'        Warehousing and Storage'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][535] = u'            Motor Vehicle Parking'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][536] = u'            Cargo Handling'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][537] = u'            Customs Checkpoint'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][538] = u'            Inspection Station'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][539] = u'        Inspection'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][540] = u'        Postal Activities'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][541] = u'    Mail and Package Transport'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][545] = u'        Courier Activities'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][548] = u'    Short-term Accommodation'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][549] = u'    Long-term Accommodation'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][550] = u'Accommodation'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][551] = u'        Hotel'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][552] = u'        Resort'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][553] = u'        Motel'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][554] = u'        Guest-house'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][555] = u'        Hostel'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][556] = u'        Dormitory'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][557] = u'        Vacation Cottage'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][558] = u'        Dependents Housing'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][559] = u'        Communal Bath'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][563] = u'        Residence'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][570] = u'Food Service'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][572] = u'    Restaurant'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][573] = u'    Bar'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][574] = u'    Dining Hall'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][578] = u'    Banquet Hall'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][579] = u'    Convention Centre'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][580] = u'Publishing and Broadcasting'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][582] = u'    Print Publishing'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][594] = u'    Cinema'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][601] = u'    Radio Broadcasting'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][604] = u'    Television Broadcasting'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][610] = u'Telecommunications'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][612] = u'    Retail Telecommunications'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][614] = u'    Wired Telecommunications'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][615] = u'        Main Telephone Exchange'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][616] = u'        Branch Telephone Exchange'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][617] = u'        Wired Repeater'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][620] = u'    Wireless Telecommunications'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][621] = u'        Mobile Phone Service'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][622] = u'        Wireless Repeater'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][625] = u'    Satellite Telecommunications'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][626] = u'        Satellite Ground Control'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][632] = u'    Information Service'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][633] = u'        Public Records'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][640] = u'Financial Services'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][642] = u'    Central Banking'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][643] = u'    Retail Banking'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][651] = u'    Insurance'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][662] = u'    Financial Market Administration'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][663] = u'    Security Brokerage'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][671] = u'    Fund Management'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][680] = u'Real Estate Activities'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][681] = u'Professional, Scientific and Technical'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][691] = u'    Legal Activities'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][696] = u'    Accounting'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][701] = u'    Head Office'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][706] = u'    Business Management'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][711] = u'    Architecture Consulting'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][714] = u'    Engineering Design'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][717] = u'    Surveying'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][720] = u'    Scientific Research and Development'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][721] = u'        Observation Station'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][722] = u'        Weather Station'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][725] = u'        Nuclear Research Centre'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][730] = u'        Wind Tunnel'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][741] = u'    Advertising'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][752] = u'    Photography'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][757] = u'    Veterinary'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][760] = u'Business and Personal Support Services'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][761] = u'    Motor Vehicle Rental'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][770] = u'    Employment Agency'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][775] = u'    Travel Agency'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][780] = u'        Security Enforcement'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][781] = u'        Guard'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][791] = u'    Custodial Service'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][795] = u'    Landscaping Service'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][801] = u'    Office Administration'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][807] = u'    Call Centre'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][808] = u'Public Administration'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][809] = u'    Headquarters'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][810] = u'    Administration'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][811] = u'    Government'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][812] = u'        Local Government'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][813] = u'        Subnational Government'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][814] = u'        National Government'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][815] = u'        Palace'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][817] = u'        Capitol'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][818] = u'        Executive Activities'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][819] = u'        Legislative Activities'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][821] = u'        Polling Station'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][822] = u'        Civil Activities'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][825] = u'    Diplomacy'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][826] = u'        Diplomatic Mission'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][827] = u'        Embassy'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][828] = u'        Consul'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][829] = u'        Maritime Defence'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][830] = u'Public Order, Safety and Security Services'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][831] = u'    Public Order'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][832] = u'    Safety'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][833] = u'    Security Services'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][835] = u'    Defence Activities'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][836] = u'        Armoury'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][837] = u'        Military Reserve Activities'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][838] = u'        Military Recruitment'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][839] = u'        CBRNE Civilian Support'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][840] = u'        Judicial Activities'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][841] = u'        Law Enforcement'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][842] = u'        Immigration Control'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][843] = u'        Imprisonment'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][844] = u'        Juvenile Corrections'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][845] = u'        Firefighting'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][846] = u'        Rescue and Paramedical Services'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][847] = u'        Emergency Operations'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][848] = u'        Civil Intelligence'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][850] = u'Education'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][851] = u'    Primary Education'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][852] = u'    Secondary Education'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][855] = u'    Higher Education'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][857] = u'    Vocational Education'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][860] = u'Human Health Activities'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][861] = u'    In-patient Care'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][862] = u'    Out-patient Care'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][863] = u'        Urgent Medical Care'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][864] = u'    Human Tissue Repository'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][865] = u'    Public Health Activities'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][866] = u'    Leprosy Care'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][871] = u'        Intermediate Care'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][873] = u'        Psychiatric In-patient Care'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][875] = u'        Residential Care'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][881] = u'    Emergency Shelter'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][882] = u'    Homeless Shelter'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][883] = u'    Refugee Shelter'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][884] = u'        Emergency Youth Shelter'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][885] = u'    Day Care'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][887] = u'Social Work'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][888] = u'        Emergency Relief Services'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][890] = u'Cultural, Arts and Entertainment'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][891] = u'    Theatre'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][892] = u'    Auditorium'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][893] = u'    Community Centre'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][894] = u'    Opera House'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][895] = u'    Night Club'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][900] = u'Sports, Amusement and Recreation'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][902] = u'    Library'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][905] = u'    Museum'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][906] = u'    Aquarium'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][907] = u'    Botanical and/or Zoological Reserve Activities'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][909] = u'    Gambling'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][912] = u'    Sports Centre'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][913] = u'    Fitness Centre'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][914] = u'    Shooting Range'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][915] = u'    Water Park'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][919] = u'    Animal Boarding'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][921] = u'    Recreation'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][922] = u'    Amusement'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][923] = u'    Hobbies and/or Leisure Activities'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][930] = u'Religious Activities'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][931] = u'    Place of Worship'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][950] = u'Membership Organization'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][954] = u'    Club'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][955] = u'    Yacht-club'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][961] = u'    Laundry'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][962] = u'    Beauty Treatment'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][963] = u'    Funeral Services'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][964] = u'    Cremation'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][965] = u'    Mortuary Services'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][966] = u'    Adult Entertainment'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][967] = u'    Storage of Human Remains'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][970] = u'Meeting Place'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][980] = u'Death Care Services'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN2'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][2] = u'Agriculture'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][3] = u'    Growing of Crops'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][9] = u'    Raising of Animals'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][14] = u'    Grazing'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][15] = u'    Mixed Farming'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][16] = u'Migrant Labour'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][19] = u'Hunting'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][20] = u'Forestry and/or Logging'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][21] = u'    Silviculture'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][27] = u'    Forest Warden'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][30] = u'Fishing'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][35] = u'    Aquaculture'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][40] = u'Mining and Quarrying'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][50] = u'    Solid Mineral Fuel Mining'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][60] = u'    Petroleum and/or Gas Extraction'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][70] = u'    Metal Ore Mining'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][83] = u'    Chemical Mining'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][84] = u'    Peat Extraction'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][85] = u'    Salt Extraction'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][87] = u'    Mineral Mining'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][91] = u'    Gas Oil Separation'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][95] = u'    Ore Dressing'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][99] = u'Manufacturing'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][100] = u'    Food Product Manufacture'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][101] = u'        Food Processing'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][102] = u'            Meat Processing'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][103] = u'            Seafood Processing'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][104] = u'            Fruit and/or Vegetable Processing'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][105] = u'        Oil-mill'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][106] = u'        Dairying'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][107] = u'        Grain Milling'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][110] = u'        Baking'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][111] = u'        Sugar Manufacture'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][112] = u'            Sugar Milling'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][113] = u'            Sugar Refining'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][114] = u'        Confection Manufacture'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][115] = u'        Pasta Manufacture'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][116] = u'        Prepared Meal Manufacture'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][118] = u'    Beverage Manufacture'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][119] = u'        Animal Feed Manufacture'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][120] = u'        Ice Manufacture'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][121] = u'        Spirit Distillery'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][122] = u'        Winery'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][123] = u'        Brewing'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][124] = u'        Soft Drink Manufacture'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][125] = u'    Tobacco Product Manufacture'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][129] = u'    Textile, Apparel and Leather Manufacture'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][130] = u'        Textile Manufacture'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][140] = u'        Apparel Manufacture'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][150] = u'        Leather Product Manufacture'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][155] = u'        Footwear Manufacturing'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][160] = u'    Wood-based Manufacturing'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][161] = u'        Sawmilling'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][165] = u'        Wooden Construction Product Manufacture'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][171] = u'    Paper-mill'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][181] = u'    Printing'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][190] = u'    Petroleum and Coal Products Manufacturing'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][191] = u'        Coke Manufacture'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][192] = u'        Petroleum Refining'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][195] = u'    Chemical Manufacture'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][210] = u'    Medicinal Product Manufacture'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][221] = u'    Rubber Product Manufacture'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][225] = u'    Plastic Product Manufacture'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][230] = u'    Nonmetallic Mineral Product Manufacturing'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][231] = u'        Glass Product Manufacture'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][232] = u'        Refractory Product Manufacture'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][233] = u'        Clay Product Manufacture'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][234] = u'        Ceramic Product Manufacture'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][235] = u'        Cement Mill'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][236] = u'        Cement Product Manufacture'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][237] = u'        Stone Product Manufacture'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][240] = u'    Primary Metal Manufacturing'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][241] = u'        Steel Mill'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][242] = u'        Metal Refining'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][243] = u'        Foundry'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][250] = u'    Metal Product Manufacturing'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][251] = u'        Structural Metal Product Manufacture'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][255] = u'    Munitions Manufacture'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][257] = u'        Fabricated Metal Product Manufacture'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][260] = u'    Electronic Equipment Manufacture'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][270] = u'    Electrical Equipment Manufacture'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][272] = u'            Propane Sale'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][280] = u'    Machinery Manufacture'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][289] = u'    Transportation Equipment Manufacturing'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][290] = u'        Motor Vehicle Manufacture'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][301] = u'        Ship Construction'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][304] = u'        Railway Vehicle Manufacture'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][305] = u'        Aircraft Manufacture'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][306] = u'        Military Vehicle Manufacture'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][310] = u'    Furniture Manufacture'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][320] = u'    Miscellaneous Manufacturing'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][321] = u'        Jewellery Manufacture'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][322] = u'        Musical Instrument Manufacture'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][323] = u'        Sports Goods Manufacture'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][324] = u'        Game and/or Toy Manufacture'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][325] = u'        Medical and/or Dental Equipment Manufacture'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][330] = u'    General Repair'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][331] = u'        Fabricated Metal Product Repair'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][332] = u'        Electronic Equipment Repair'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][333] = u'        Electrical Equipment Repair'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][334] = u'        Machinery Repair'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][340] = u'        Ship Repair'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][341] = u'        Aircraft Repair'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][342] = u'        Railway Vehicle Repair'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][343] = u'        Motor Vehicle Repair'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][350] = u'Utilities'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][351] = u'    Power Generation'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][352] = u'    Climate Control'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][355] = u'        Cooling'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][356] = u'        Heating'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][360] = u'    Water Supply'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][361] = u'        Water Collection'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][362] = u'        Water Treatment'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][363] = u'        Water Distribution'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][370] = u'    Sewerage'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][372] = u'        Sewerage Screening'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][382] = u'        Restroom'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][383] = u'    Waste Treatment and Disposal'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][385] = u'    Materials Recovery'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][440] = u'Commerce'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][459] = u'    Wholesale Merchant'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][460] = u'    Retail Sale'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][464] = u'        Specialized Store'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][465] = u'        Non-specialized Store'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][466] = u'            Convenience Store'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][470] = u'            Petrol Sale'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][473] = u'            Sales Yard'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][474] = u'            Precious Metal Merchant'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][475] = u'            Market'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][476] = u'            Grocery'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][477] = u'            Pharmacy'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][478] = u'            Pet-shop'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][480] = u'Transport'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][481] = u'        Terminal'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][482] = u'        Station'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][483] = u'        Stop'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][484] = u'        Transfer Hub'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][486] = u'        Signalling'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][487] = u'        Transport System Maintenance'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][488] = u'        Navigation'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][489] = u'    Transportation Hub'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][490] = u'    Railway Transport'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][491] = u'        Railway Passenger Transport'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][494] = u'    Pedestrian Transport'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][495] = u'    Road Transport'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][496] = u'        Road Passenger Transport'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][497] = u'        Road Freight Transport'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][500] = u'    Pipeline Transport'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][501] = u'        Pumping'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][505] = u'    Water Transport'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][507] = u'        Inland Waters Transport'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][508] = u'            Canal Transport'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][510] = u'        Port Control'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][511] = u'        Maritime Pilotage'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][512] = u'        Pilot Station'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][513] = u'        Harbour Control'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][520] = u'    Air Transport'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][525] = u'        Air Traffic Control'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][529] = u'    Transportation Support'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][530] = u'        Warehousing and Storage'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][535] = u'            Motor Vehicle Parking'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][536] = u'            Cargo Handling'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][537] = u'            Customs Checkpoint'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][538] = u'            Inspection Station'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][539] = u'        Inspection'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][540] = u'        Postal Activities'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][541] = u'    Mail and Package Transport'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][545] = u'        Courier Activities'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][548] = u'    Short-term Accommodation'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][549] = u'    Long-term Accommodation'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][550] = u'Accommodation'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][551] = u'        Hotel'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][552] = u'        Resort'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][553] = u'        Motel'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][554] = u'        Guest-house'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][555] = u'        Hostel'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][556] = u'        Dormitory'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][557] = u'        Vacation Cottage'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][558] = u'        Dependents Housing'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][559] = u'        Communal Bath'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][563] = u'        Residence'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][570] = u'Food Service'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][572] = u'    Restaurant'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][573] = u'    Bar'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][574] = u'    Dining Hall'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][578] = u'    Banquet Hall'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][579] = u'    Convention Centre'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][580] = u'Publishing and Broadcasting'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][582] = u'    Print Publishing'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][594] = u'    Cinema'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][601] = u'    Radio Broadcasting'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][604] = u'    Television Broadcasting'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][610] = u'Telecommunications'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][612] = u'    Retail Telecommunications'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][614] = u'    Wired Telecommunications'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][615] = u'        Main Telephone Exchange'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][616] = u'        Branch Telephone Exchange'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][617] = u'        Wired Repeater'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][620] = u'    Wireless Telecommunications'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][621] = u'        Mobile Phone Service'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][622] = u'        Wireless Repeater'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][625] = u'    Satellite Telecommunications'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][626] = u'        Satellite Ground Control'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][632] = u'    Information Service'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][633] = u'        Public Records'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][640] = u'Financial Services'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][642] = u'    Central Banking'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][643] = u'    Retail Banking'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][651] = u'    Insurance'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][662] = u'    Financial Market Administration'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][663] = u'    Security Brokerage'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][671] = u'    Fund Management'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][680] = u'Real Estate Activities'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][681] = u'Professional, Scientific and Technical'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][691] = u'    Legal Activities'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][696] = u'    Accounting'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][701] = u'    Head Office'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][706] = u'    Business Management'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][711] = u'    Architecture Consulting'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][714] = u'    Engineering Design'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][717] = u'    Surveying'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][720] = u'    Scientific Research and Development'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][721] = u'        Observation Station'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][722] = u'        Weather Station'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][725] = u'        Nuclear Research Centre'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][730] = u'        Wind Tunnel'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][741] = u'    Advertising'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][752] = u'    Photography'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][757] = u'    Veterinary'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][760] = u'Business and Personal Support Services'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][761] = u'    Motor Vehicle Rental'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][770] = u'    Employment Agency'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][775] = u'    Travel Agency'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][780] = u'        Security Enforcement'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][781] = u'        Guard'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][791] = u'    Custodial Service'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][795] = u'    Landscaping Service'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][801] = u'    Office Administration'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][807] = u'    Call Centre'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][808] = u'Public Administration'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][809] = u'    Headquarters'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][810] = u'    Administration'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][811] = u'    Government'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][812] = u'        Local Government'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][813] = u'        Subnational Government'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][814] = u'        National Government'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][815] = u'        Palace'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][817] = u'        Capitol'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][818] = u'        Executive Activities'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][819] = u'        Legislative Activities'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][821] = u'        Polling Station'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][822] = u'        Civil Activities'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][825] = u'    Diplomacy'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][826] = u'        Diplomatic Mission'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][827] = u'        Embassy'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][828] = u'        Consul'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][829] = u'        Maritime Defence'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][830] = u'Public Order, Safety and Security Services'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][831] = u'    Public Order'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][832] = u'    Safety'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][833] = u'    Security Services'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][835] = u'    Defence Activities'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][836] = u'        Armoury'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][837] = u'        Military Reserve Activities'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][838] = u'        Military Recruitment'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][839] = u'        CBRNE Civilian Support'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][840] = u'        Judicial Activities'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][841] = u'        Law Enforcement'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][842] = u'        Immigration Control'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][843] = u'        Imprisonment'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][844] = u'        Juvenile Corrections'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][845] = u'        Firefighting'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][846] = u'        Rescue and Paramedical Services'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][847] = u'        Emergency Operations'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][848] = u'        Civil Intelligence'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][850] = u'Education'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][851] = u'    Primary Education'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][852] = u'    Secondary Education'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][855] = u'    Higher Education'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][857] = u'    Vocational Education'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][860] = u'Human Health Activities'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][861] = u'    In-patient Care'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][862] = u'    Out-patient Care'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][863] = u'        Urgent Medical Care'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][864] = u'    Human Tissue Repository'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][865] = u'    Public Health Activities'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][866] = u'    Leprosy Care'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][871] = u'        Intermediate Care'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][873] = u'        Psychiatric In-patient Care'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][875] = u'        Residential Care'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][881] = u'    Emergency Shelter'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][882] = u'    Homeless Shelter'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][883] = u'    Refugee Shelter'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][884] = u'        Emergency Youth Shelter'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][885] = u'    Day Care'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][887] = u'Social Work'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][888] = u'        Emergency Relief Services'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][890] = u'Cultural, Arts and Entertainment'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][891] = u'    Theatre'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][892] = u'    Auditorium'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][893] = u'    Community Centre'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][894] = u'    Opera House'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][895] = u'    Night Club'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][900] = u'Sports, Amusement and Recreation'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][902] = u'    Library'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][905] = u'    Museum'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][906] = u'    Aquarium'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][907] = u'    Botanical and/or Zoological Reserve Activities'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][909] = u'    Gambling'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][912] = u'    Sports Centre'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][913] = u'    Fitness Centre'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][914] = u'    Shooting Range'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][915] = u'    Water Park'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][919] = u'    Animal Boarding'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][921] = u'    Recreation'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][922] = u'    Amusement'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][923] = u'    Hobbies and/or Leisure Activities'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][930] = u'Religious Activities'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][931] = u'    Place of Worship'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][950] = u'Membership Organization'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][954] = u'    Club'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][955] = u'    Yacht-club'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][961] = u'    Laundry'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][962] = u'    Beauty Treatment'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][963] = u'    Funeral Services'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][964] = u'    Cremation'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][965] = u'    Mortuary Services'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][966] = u'    Adult Entertainment'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][967] = u'    Storage of Human Remains'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][970] = u'Meeting Place'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][980] = u'Death Care Services'
    field_information['GGDM 3.0']['SummaryDomainValues']['FFN3'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['FHC'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['FHC'][1] = u'Ro-Ro Terminal'
    field_information['GGDM 3.0']['SummaryDomainValues']['FHC'][2] = u'Timber-yard'
    field_information['GGDM 3.0']['SummaryDomainValues']['FHC'][3] = u'Ferry Terminal'
    field_information['GGDM 3.0']['SummaryDomainValues']['FHC'][4] = u'Fishing Harbour'
    field_information['GGDM 3.0']['SummaryDomainValues']['FHC'][5] = u'Marina'
    field_information['GGDM 3.0']['SummaryDomainValues']['FHC'][6] = u'Naval Base'
    field_information['GGDM 3.0']['SummaryDomainValues']['FHC'][7] = u'Tanker Terminal'
    field_information['GGDM 3.0']['SummaryDomainValues']['FHC'][8] = u'Passenger Terminal'
    field_information['GGDM 3.0']['SummaryDomainValues']['FHC'][9] = u'Shipyard'
    field_information['GGDM 3.0']['SummaryDomainValues']['FHC'][10] = u'Container Terminal'
    field_information['GGDM 3.0']['SummaryDomainValues']['FHC'][11] = u'Bulk Terminal'
    field_information['GGDM 3.0']['SummaryDomainValues']['FHC'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['FHC2'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['FHC2'][1] = u'Ro-Ro Terminal'
    field_information['GGDM 3.0']['SummaryDomainValues']['FHC2'][2] = u'Timber-yard'
    field_information['GGDM 3.0']['SummaryDomainValues']['FHC2'][3] = u'Ferry Terminal'
    field_information['GGDM 3.0']['SummaryDomainValues']['FHC2'][4] = u'Fishing Harbour'
    field_information['GGDM 3.0']['SummaryDomainValues']['FHC2'][5] = u'Marina'
    field_information['GGDM 3.0']['SummaryDomainValues']['FHC2'][6] = u'Naval Base'
    field_information['GGDM 3.0']['SummaryDomainValues']['FHC2'][7] = u'Tanker Terminal'
    field_information['GGDM 3.0']['SummaryDomainValues']['FHC2'][8] = u'Passenger Terminal'
    field_information['GGDM 3.0']['SummaryDomainValues']['FHC2'][9] = u'Shipyard'
    field_information['GGDM 3.0']['SummaryDomainValues']['FHC2'][10] = u'Container Terminal'
    field_information['GGDM 3.0']['SummaryDomainValues']['FHC2'][11] = u'Bulk Terminal'
    field_information['GGDM 3.0']['SummaryDomainValues']['FHC2'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['FHC3'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['FHC3'][1] = u'Ro-Ro Terminal'
    field_information['GGDM 3.0']['SummaryDomainValues']['FHC3'][2] = u'Timber-yard'
    field_information['GGDM 3.0']['SummaryDomainValues']['FHC3'][3] = u'Ferry Terminal'
    field_information['GGDM 3.0']['SummaryDomainValues']['FHC3'][4] = u'Fishing Harbour'
    field_information['GGDM 3.0']['SummaryDomainValues']['FHC3'][5] = u'Marina'
    field_information['GGDM 3.0']['SummaryDomainValues']['FHC3'][6] = u'Naval Base'
    field_information['GGDM 3.0']['SummaryDomainValues']['FHC3'][7] = u'Tanker Terminal'
    field_information['GGDM 3.0']['SummaryDomainValues']['FHC3'][8] = u'Passenger Terminal'
    field_information['GGDM 3.0']['SummaryDomainValues']['FHC3'][9] = u'Shipyard'
    field_information['GGDM 3.0']['SummaryDomainValues']['FHC3'][10] = u'Container Terminal'
    field_information['GGDM 3.0']['SummaryDomainValues']['FHC3'][11] = u'Bulk Terminal'
    field_information['GGDM 3.0']['SummaryDomainValues']['FHC3'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['FIC'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['FIC'][1] = u'Mound'
    field_information['GGDM 3.0']['SummaryDomainValues']['FIC'][2] = u'Fill'
    field_information['GGDM 3.0']['SummaryDomainValues']['FIC'][3] = u'Dyke'
    field_information['GGDM 3.0']['SummaryDomainValues']['FIC'][5] = u'Levee'
    field_information['GGDM 3.0']['SummaryDomainValues']['FIC'][6] = u'Divider'
    field_information['GGDM 3.0']['SummaryDomainValues']['FIC'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['FLO'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['FLO'][1000] = u'False'
    field_information['GGDM 3.0']['SummaryDomainValues']['FLO'][1001] = u'True'
    field_information['GGDM 3.0']['SummaryDomainValues']['FLT'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['FLT'][1000] = u'False'
    field_information['GGDM 3.0']['SummaryDomainValues']['FLT'][1001] = u'True'
    field_information['GGDM 3.0']['SummaryDomainValues']['FPT'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['FPT'][1] = u'Major'
    field_information['GGDM 3.0']['SummaryDomainValues']['FPT'][2] = u'Minor and Hard'
    field_information['GGDM 3.0']['SummaryDomainValues']['FPT'][3] = u'Minor and Soft'
    field_information['GGDM 3.0']['SummaryDomainValues']['FPT'][4] = u'Minor'
    field_information['GGDM 3.0']['SummaryDomainValues']['FPT'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['FRT'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['FRT'][1] = u'Small Arms'
    field_information['GGDM 3.0']['SummaryDomainValues']['FRT'][2] = u'Tank'
    field_information['GGDM 3.0']['SummaryDomainValues']['FRT'][3] = u'Field Artillery'
    field_information['GGDM 3.0']['SummaryDomainValues']['FRT'][4] = u'Grenade'
    field_information['GGDM 3.0']['SummaryDomainValues']['FRT'][5] = u'Demolition Area'
    field_information['GGDM 3.0']['SummaryDomainValues']['FRT'][6] = u'Impact Area'
    field_information['GGDM 3.0']['SummaryDomainValues']['FRT'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['FRT2'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['FRT2'][1] = u'Small Arms'
    field_information['GGDM 3.0']['SummaryDomainValues']['FRT2'][2] = u'Tank'
    field_information['GGDM 3.0']['SummaryDomainValues']['FRT2'][3] = u'Field Artillery'
    field_information['GGDM 3.0']['SummaryDomainValues']['FRT2'][4] = u'Grenade'
    field_information['GGDM 3.0']['SummaryDomainValues']['FRT2'][5] = u'Demolition Area'
    field_information['GGDM 3.0']['SummaryDomainValues']['FRT2'][6] = u'Impact Area'
    field_information['GGDM 3.0']['SummaryDomainValues']['FRT2'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['FRT3'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['FRT3'][1] = u'Small Arms'
    field_information['GGDM 3.0']['SummaryDomainValues']['FRT3'][2] = u'Tank'
    field_information['GGDM 3.0']['SummaryDomainValues']['FRT3'][3] = u'Field Artillery'
    field_information['GGDM 3.0']['SummaryDomainValues']['FRT3'][4] = u'Grenade'
    field_information['GGDM 3.0']['SummaryDomainValues']['FRT3'][5] = u'Demolition Area'
    field_information['GGDM 3.0']['SummaryDomainValues']['FRT3'][6] = u'Impact Area'
    field_information['GGDM 3.0']['SummaryDomainValues']['FRT3'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['FRZ'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['FRZ'][1000] = u'False'
    field_information['GGDM 3.0']['SummaryDomainValues']['FRZ'][1001] = u'True'
    field_information['GGDM 3.0']['SummaryDomainValues']['FSC'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['FSC'][1000] = u'False'
    field_information['GGDM 3.0']['SummaryDomainValues']['FSC'][1001] = u'True'
    field_information['GGDM 3.0']['SummaryDomainValues']['FTI'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['FTI'][1] = u'Metal'
    field_information['GGDM 3.0']['SummaryDomainValues']['FTI'][2] = u'Wood'
    field_information['GGDM 3.0']['SummaryDomainValues']['FTI'][5] = u'Barbed Wire'
    field_information['GGDM 3.0']['SummaryDomainValues']['FTI'][6] = u'Chain-link'
    field_information['GGDM 3.0']['SummaryDomainValues']['FTI'][7] = u'Electrified Wire'
    field_information['GGDM 3.0']['SummaryDomainValues']['FTI'][8] = u'Geotextile'
    field_information['GGDM 3.0']['SummaryDomainValues']['FTI'][9] = u'Netting'
    field_information['GGDM 3.0']['SummaryDomainValues']['FTI'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['FURL'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['FZR'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['FZR'][1] = u'Blockhouse'
    field_information['GGDM 3.0']['SummaryDomainValues']['FZR'][2] = u'Casement'
    field_information['GGDM 3.0']['SummaryDomainValues']['FZR'][3] = u'Keep'
    field_information['GGDM 3.0']['SummaryDomainValues']['FZR'][4] = u'Martello Tower'
    field_information['GGDM 3.0']['SummaryDomainValues']['FZR'][5] = u'Non-specific Fortified'
    field_information['GGDM 3.0']['SummaryDomainValues']['FZR'][6] = u'Pillbox'
    field_information['GGDM 3.0']['SummaryDomainValues']['FZR'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['GDBV'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['GDBV'][1] = u'TDS_4_0'
    field_information['GGDM 3.0']['SummaryDomainValues']['GDBV'][2] = u'TDS_6_0'
    field_information['GGDM 3.0']['SummaryDomainValues']['GDBV'][3] = u'TDS_6_1'
    field_information['GGDM 3.0']['SummaryDomainValues']['GDBV'][4] = u'GGDM_2_0'
    field_information['GGDM 3.0']['SummaryDomainValues']['GDBV'][5] = u'GGDM_2_1'
    field_information['GGDM 3.0']['SummaryDomainValues']['GDBV'][6] = u'GGDM_2_2'
    field_information['GGDM 3.0']['SummaryDomainValues']['GDBV'][7] = u'GGDM_3_0'
    field_information['GGDM 3.0']['SummaryDomainValues']['GDBV'][8] = u'TDS_7_0'
    field_information['GGDM 3.0']['SummaryDomainValues']['GDBV'][9] = u'TDS_7_1'
    field_information['GGDM 3.0']['SummaryDomainValues']['GDBV'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['GEC'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['GEC'][5] = u'Area of No Sovereignty'
    field_information['GGDM 3.0']['SummaryDomainValues']['GEC'][7] = u'Demilitarized Zone (DMZ)'
    field_information['GGDM 3.0']['SummaryDomainValues']['GEC'][8] = u'Zone of Occupation'
    field_information['GGDM 3.0']['SummaryDomainValues']['GEC'][9] = u'Leased Area'
    field_information['GGDM 3.0']['SummaryDomainValues']['GEC'][10] = u'Political Entity'
    field_information['GGDM 3.0']['SummaryDomainValues']['GEC'][11] = u'Dependent Political Entity'
    field_information['GGDM 3.0']['SummaryDomainValues']['GEC'][12] = u'Freely Associated State'
    field_information['GGDM 3.0']['SummaryDomainValues']['GEC'][13] = u'Independent Political Entity'
    field_information['GGDM 3.0']['SummaryDomainValues']['GEC'][14] = u'Semi-independent Political Entity'
    field_information['GGDM 3.0']['SummaryDomainValues']['GEC'][15] = u'Economic Region'
    field_information['GGDM 3.0']['SummaryDomainValues']['GEC'][16] = u'Territory'
    field_information['GGDM 3.0']['SummaryDomainValues']['GEC'][17] = u'Buffer Zone'
    field_information['GGDM 3.0']['SummaryDomainValues']['GEC'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['GFT'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['GFT'][1000] = u'False'
    field_information['GGDM 3.0']['SummaryDomainValues']['GFT'][1001] = u'True'
    field_information['GGDM 3.0']['SummaryDomainValues']['GFY'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['GFY'][1] = u'Normal'
    field_information['GGDM 3.0']['SummaryDomainValues']['GFY'][2] = u'Thrust'
    field_information['GGDM 3.0']['SummaryDomainValues']['GFY'][3] = u'Reverse'
    field_information['GGDM 3.0']['SummaryDomainValues']['GFY'][4] = u'Strike-slip'
    field_information['GGDM 3.0']['SummaryDomainValues']['GFY'][5] = u'Extension'
    field_information['GGDM 3.0']['SummaryDomainValues']['GFY'][6] = u'Transpression'
    field_information['GGDM 3.0']['SummaryDomainValues']['GFY'][7] = u'Restraining Bend'
    field_information['GGDM 3.0']['SummaryDomainValues']['GFY'][8] = u'Transextension'
    field_information['GGDM 3.0']['SummaryDomainValues']['GFY'][9] = u'Releasing Bend'
    field_information['GGDM 3.0']['SummaryDomainValues']['GFY'][10] = u'Oblique'
    field_information['GGDM 3.0']['SummaryDomainValues']['GFY'][11] = u'Decollement'
    field_information['GGDM 3.0']['SummaryDomainValues']['GFY'][12] = u'Shear Zone'
    field_information['GGDM 3.0']['SummaryDomainValues']['GFY'][13] = u'Transverse'
    field_information['GGDM 3.0']['SummaryDomainValues']['GFY'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['GOT'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['GOT'][1] = u'Fissure'
    field_information['GGDM 3.0']['SummaryDomainValues']['GOT'][2] = u'Fumarole'
    field_information['GGDM 3.0']['SummaryDomainValues']['GOT'][3] = u'Hot Spring'
    field_information['GGDM 3.0']['SummaryDomainValues']['GOT'][4] = u'Sulphur Spring'
    field_information['GGDM 3.0']['SummaryDomainValues']['GOT'][5] = u'Geyser'
    field_information['GGDM 3.0']['SummaryDomainValues']['GOT'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['GRD'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['GRD'][1000] = u'False'
    field_information['GGDM 3.0']['SummaryDomainValues']['GRD'][1001] = u'True'
    field_information['GGDM 3.0']['SummaryDomainValues']['GSGCHC'][2] = u'Open Interval'
    field_information['GGDM 3.0']['SummaryDomainValues']['GSGCHC'][3] = u'Greater-than-or-equal to Less-than Interval'
    field_information['GGDM 3.0']['SummaryDomainValues']['GSGCHC'][4] = u'Greater-than to Less-than-or-equal Interval'
    field_information['GGDM 3.0']['SummaryDomainValues']['GSGCHC'][5] = u'Closed Interval'
    field_information['GGDM 3.0']['SummaryDomainValues']['GSGCHC'][6] = u'Greater-than Semi-interval'
    field_information['GGDM 3.0']['SummaryDomainValues']['GSGCHC'][7] = u'Greater-than or Equal Semi-interval'
    field_information['GGDM 3.0']['SummaryDomainValues']['GSGCHC'][8] = u'Less-than Semi-interval'
    field_information['GGDM 3.0']['SummaryDomainValues']['GSGCHC'][9] = u'Less-than or Equal Semi-interval'
    field_information['GGDM 3.0']['SummaryDomainValues']['GSGCLC'][2] = u'Open Interval'
    field_information['GGDM 3.0']['SummaryDomainValues']['GSGCLC'][3] = u'Greater-than-or-equal to Less-than Interval'
    field_information['GGDM 3.0']['SummaryDomainValues']['GSGCLC'][4] = u'Greater-than to Less-than-or-equal Interval'
    field_information['GGDM 3.0']['SummaryDomainValues']['GSGCLC'][5] = u'Closed Interval'
    field_information['GGDM 3.0']['SummaryDomainValues']['GSGCLC'][6] = u'Greater-than Semi-interval'
    field_information['GGDM 3.0']['SummaryDomainValues']['GSGCLC'][7] = u'Greater-than or Equal Semi-interval'
    field_information['GGDM 3.0']['SummaryDomainValues']['GSGCLC'][8] = u'Less-than Semi-interval'
    field_information['GGDM 3.0']['SummaryDomainValues']['GSGCLC'][9] = u'Less-than or Equal Semi-interval'
    field_information['GGDM 3.0']['SummaryDomainValues']['GTC'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['GTC'][1] = u'Toll-gate'
    field_information['GGDM 3.0']['SummaryDomainValues']['GTC'][2] = u'Crossing'
    field_information['GGDM 3.0']['SummaryDomainValues']['GTC'][3] = u'Entrance'
    field_information['GGDM 3.0']['SummaryDomainValues']['GTC'][4] = u'Border Crossing'
    field_information['GGDM 3.0']['SummaryDomainValues']['GTC'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['GUG'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['GUG'][1000] = u'False'
    field_information['GGDM 3.0']['SummaryDomainValues']['GUG'][1001] = u'True'
    field_information['GGDM 3.0']['SummaryDomainValues']['GWS'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['GWS'][1] = u'Unsuitable'
    field_information['GGDM 3.0']['SummaryDomainValues']['GWS'][2] = u'Poor'
    field_information['GGDM 3.0']['SummaryDomainValues']['GWS'][3] = u'Moderate'
    field_information['GGDM 3.0']['SummaryDomainValues']['GWS'][4] = u'Good'
    field_information['GGDM 3.0']['SummaryDomainValues']['HAF'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['HAF'][1] = u'Heliport'
    field_information['GGDM 3.0']['SummaryDomainValues']['HAF'][2] = u'Land Aerodrome'
    field_information['GGDM 3.0']['SummaryDomainValues']['HAF'][3] = u'Hospital'
    field_information['GGDM 3.0']['SummaryDomainValues']['HAF'][4] = u'Non-hospital Building'
    field_information['GGDM 3.0']['SummaryDomainValues']['HAF'][6] = u'Rig'
    field_information['GGDM 3.0']['SummaryDomainValues']['HAF'][9] = u'Offshore Construction'
    field_information['GGDM 3.0']['SummaryDomainValues']['HAF'][10] = u'Water Aerodrome'
    field_information['GGDM 3.0']['SummaryDomainValues']['HAF'][11] = u'Military Installation'
    field_information['GGDM 3.0']['SummaryDomainValues']['HAF'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['HHD'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['HHD'][1000] = u'False'
    field_information['GGDM 3.0']['SummaryDomainValues']['HHD'][1001] = u'True'
    field_information['GGDM 3.0']['SummaryDomainValues']['HQC'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['HQC'][1] = u'Index Contour'
    field_information['GGDM 3.0']['SummaryDomainValues']['HQC'][2] = u'Intermediate Contour'
    field_information['GGDM 3.0']['SummaryDomainValues']['HQC'][3] = u'Half Auxiliary Contour'
    field_information['GGDM 3.0']['SummaryDomainValues']['HQC'][4] = u'Form Line'
    field_information['GGDM 3.0']['SummaryDomainValues']['HQC'][5] = u'Depression Index Contour'
    field_information['GGDM 3.0']['SummaryDomainValues']['HQC'][6] = u'Depression Intermediate Contour'
    field_information['GGDM 3.0']['SummaryDomainValues']['HQC'][7] = u'Approximate Index Contour'
    field_information['GGDM 3.0']['SummaryDomainValues']['HQC'][8] = u'Mound Index Contour'
    field_information['GGDM 3.0']['SummaryDomainValues']['HQC'][9] = u'Mound Intermediate Contour'
    field_information['GGDM 3.0']['SummaryDomainValues']['HQC'][12] = u'Approximate Intermediate Contour'
    field_information['GGDM 3.0']['SummaryDomainValues']['HQC'][13] = u'Approximate Auxiliary Contour'
    field_information['GGDM 3.0']['SummaryDomainValues']['HQC'][14] = u'Quarter Auxiliary Contour'
    field_information['GGDM 3.0']['SummaryDomainValues']['HQC'][15] = u'Approximate Depression Index Contour'
    field_information['GGDM 3.0']['SummaryDomainValues']['HQC'][16] = u'Auxiliary Contour'
    field_information['GGDM 3.0']['SummaryDomainValues']['HQC'][18] = u'Approximate Depression Intermediate Contour'
    field_information['GGDM 3.0']['SummaryDomainValues']['HQC'][19] = u'Intermediate Carrying Contour'
    field_information['GGDM 3.0']['SummaryDomainValues']['HQC'][20] = u'Auxiliary Carrying Contour'
    field_information['GGDM 3.0']['SummaryDomainValues']['HQC'][21] = u'Index Carrying Contour'
    field_information['GGDM 3.0']['SummaryDomainValues']['HQC'][22] = u'Depression Auxiliary Contour'
    field_information['GGDM 3.0']['SummaryDomainValues']['HQC'][23] = u'Approximate Depression Auxiliary Contour'
    field_information['GGDM 3.0']['SummaryDomainValues']['HQC'][98] = u'Transition Line'
    field_information['GGDM 3.0']['SummaryDomainValues']['HQC'][99] = u'Connector Line'
    field_information['GGDM 3.0']['SummaryDomainValues']['HQC'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['HSS'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['HSS'][1] = u'Ancient'
    field_information['GGDM 3.0']['SummaryDomainValues']['HSS'][2] = u'Historic'
    field_information['GGDM 3.0']['SummaryDomainValues']['HSS'][3] = u'Not Significant'
    field_information['GGDM 3.0']['SummaryDomainValues']['HSS'][4] = u'Battlefield'
    field_information['GGDM 3.0']['SummaryDomainValues']['HSS'][5] = u'Military'
    field_information['GGDM 3.0']['SummaryDomainValues']['HSS'][6] = u'Political'
    field_information['GGDM 3.0']['SummaryDomainValues']['HSS'][7] = u'National'
    field_information['GGDM 3.0']['SummaryDomainValues']['HSS'][8] = u'Religious'
    field_information['GGDM 3.0']['SummaryDomainValues']['HSS'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['HST'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['HST'][1] = u'Bomb Shelter'
    field_information['GGDM 3.0']['SummaryDomainValues']['HST'][2] = u'Fallout Shelter'
    field_information['GGDM 3.0']['SummaryDomainValues']['HST'][3] = u'Storm Shelter'
    field_information['GGDM 3.0']['SummaryDomainValues']['HST'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['HST2'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['HST2'][1] = u'Bomb Shelter'
    field_information['GGDM 3.0']['SummaryDomainValues']['HST2'][2] = u'Fallout Shelter'
    field_information['GGDM 3.0']['SummaryDomainValues']['HST2'][3] = u'Storm Shelter'
    field_information['GGDM 3.0']['SummaryDomainValues']['HST2'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['HST3'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['HST3'][1] = u'Bomb Shelter'
    field_information['GGDM 3.0']['SummaryDomainValues']['HST3'][2] = u'Fallout Shelter'
    field_information['GGDM 3.0']['SummaryDomainValues']['HST3'][3] = u'Storm Shelter'
    field_information['GGDM 3.0']['SummaryDomainValues']['HST3'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['HTP'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['HTP'][1] = u'M - Multi-bay'
    field_information['GGDM 3.0']['SummaryDomainValues']['HTP'][2] = u'O - Open End'
    field_information['GGDM 3.0']['SummaryDomainValues']['HTP'][3] = u'N - Nose In'
    field_information['GGDM 3.0']['SummaryDomainValues']['HTP'][4] = u'G - Underground'
    field_information['GGDM 3.0']['SummaryDomainValues']['HTP'][5] = u'S - Single Bay'
    field_information['GGDM 3.0']['SummaryDomainValues']['HTP'][6] = u'D - Double Bay'
    field_information['GGDM 3.0']['SummaryDomainValues']['HTP'][7] = u'T - T-Shaped'
    field_information['GGDM 3.0']['SummaryDomainValues']['HTP'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][2] = u'Adindan (Ethiopia)'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][3] = u'Adindan (Sudan)'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][4] = u'Adindan (Mali)'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][5] = u'Adindan (Senegal)'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][6] = u'Adindan (Burkina Faso)'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][7] = u'Adindan (Cameroon)'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][8] = u'Adindan (mean value)'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][9] = u'Afgooye (Somalia)'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][10] = u'Antigua Island Astro 1943'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][12] = u'Ain el Abd 1970 (Bahrain Island)'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][13] = u'Ain el Abd 1970 (Saudi Arabia)'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][14] = u'American Samoa Datum 1962'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][15] = u'Amersfoort 1885/1903 (Netherlands)'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][16] = u'Anna 1 Astro 1965 (Cocos Islands)'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][17] = u'Approximate Luzon Datum (Philippines)'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][19] = u'Arc 1950 (Botswana)'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][20] = u'Arc 1950 (Lesotho)'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][21] = u'Arc 1950 (Malawi)'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][22] = u'Arc 1950 (Swaziland)'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][23] = u'Arc 1950 (Zaire)'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][24] = u'Arc 1950 (Zambia)'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][25] = u'Arc 1950 (Zimbabwe)'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][26] = u'Arc 1950 (Burundi)'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][27] = u'Arc 1950 (mean value)'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][29] = u'Arc 1960 (Kenya)'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][30] = u'Arc 1960 (Tanzania)'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][31] = u'Arc 1960 (mean value)'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][32] = u'Arc 1935 (Africa)'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][33] = u'Ascension Island 1958 (Ascension Island)'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][34] = u'Montserrat Island Astro 1958'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][35] = u'Astro Station 1952 (Marcus Island)'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][36] = u'Astro Beacon \'E\' (Iwo Jima Island)'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][37] = u'Average Terrestrial System 1977, New Brunswick'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][38] = u'Australian Geod. 1966 (Australia and Tasmania Island)'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][39] = u'Australian Geod. 1984 (Australia and Tasmania Island)'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][40] = u'Djakarta (Batavia) (Sumatra Island, Indonesia)'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][41] = u'Djakarta (Batavia) (Sumatra Island, Indonesia) with Zero Meridian Djakarta'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][42] = u'Bekaa Base South End (Lebanon)'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][43] = u'Belgium 1950 System (Lommel Signal, Belgium)'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][44] = u'Bermuda 1957 (Bermuda Islands)'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][45] = u'Bissau (Guinea-Bissau)'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][46] = u'Modified BJZ54 (China)'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][47] = u'BJZ54 (A954 Beijing Coordinates) (China)'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][48] = u'Bogota Observatory (Colombia)'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][49] = u'Bogota Observatory (Colombia) with Zero Meridian Bogota'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][50] = u'Bern 1898 (Switzerland)'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][51] = u'Bern 1898 (Switzerland) with Zero Meridian Bern'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][52] = u'Bukit Rimpah (Bangka and Belitung Islands, Indonesia)'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][53] = u'Cape Canaveral (mean value)'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][54] = u'Campo Inchauspe (Argentina)'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][55] = u'Camacupa Base SW End (Campo De Aviacao, Angola)'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][56] = u'Canton Astro 1966 (Phoenix Islands)'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][57] = u'Cape (South Africa)'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][58] = u'Camp Area Astro (Camp McMurdo Area, Antarctica)'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][59] = u'S-JTSK'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][60] = u'Carthage (Tunisia)'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][61] = u'Compensation Geodetique du Quebec 1977'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][62] = u'Chatham 1971 (Chatham Island, New Zealand)'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][63] = u'Chua Astro (Paraguay)'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][64] = u'Corrego Alegre (Brazil)'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][65] = u'Conakry Pyramid of the Service Geographique (Guinea)'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][66] = u'Guyana CSG67'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][67] = u'Dabola (Guinea)'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][68] = u'DCS-3 Lighthouse, Saint Lucia, Lesser Antilles'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][69] = u'Deception Island, Antarctica'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][70] = u'GUX 1 Astro (Guadacanal Island)'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][71] = u'Dominica Astro M-12, Dominica, Lesser Antilles'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][72] = u'Easter Island 1967 (Easter Island)'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][73] = u'Wake-Eniwetok 1960 (Marshall Islands)'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][75] = u'European 1950 (Western Europe)'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][76] = u'European 1950 (Greece)'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][77] = u'European 1950 (Norway and Finland)'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][78] = u'European 1950 (Portugal and Spain)'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][79] = u'European 1950 (Cyprus)'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][80] = u'European 1950 (Egypt)'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][81] = u'European 1950 (England, Channel Islands, Scotland, and Shetland Islands)'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][82] = u'European 1950 (Iran)'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][83] = u'European 1950 (Sardinia)'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][84] = u'European 1950 (Sicily)'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][85] = u'European 1950 (British Isles)'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][86] = u'European 1950 (Malta)'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][87] = u'European 1950 (mean value)'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][88] = u'European 1950 (Iraq, Israel, Jordan, Kuwait, Lebanon, Saudi Arabia, and Syria)'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][89] = u'European 1950 (Tunisia)'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][90] = u'European 1979 (mean value)'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][91] = u'European Terrestrial Reference System 1989 (ETRS89)'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][92] = u'Oman (Oman)'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][93] = u'Observatorio Meteorologico 1939 (Corvo and Flores Islands, Azores)'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][94] = u'Fort Thomas 1955 (Nevis, St Kitts, Leeward Islands)'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][95] = u'Gan 1970 (Addu Atoll, Republic of Maldives)'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][96] = u'Gandajika Base (Zaire)'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][97] = u'Geocentric Datum of Australia (GDA)'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][98] = u'GDZ80 (China)'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][99] = u'Geodetic Datum 1949 (New Zealand)'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][100] = u'DOS 1968 (Gizo Island, New Georgia Islands)'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][101] = u'Graciosa Base SW (Faial, Graciosa, Pico, Sao Jorge, and Terceira Island, Azores)'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][102] = u'Greek Datum, Greece'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][103] = u'Greek Geodetic Reference System 1987 (GGRS 87)'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][104] = u'Gunong Segara (Kalimantan Island, Indonesia)'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][105] = u'Gunong Serindung'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][106] = u'Guam 1963'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][107] = u'Herat North (Afganistan)'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][108] = u'Hermannskogel'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][109] = u'Provisional South Chilean 1963 (or Hito XVIII 1963) (S. Chile, 53 degrees South)'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][110] = u'Hjorsey 1955 (Iceland)'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][111] = u'Hong Kong 1963 (Hong Kong)'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][112] = u'Hong Kong 1929'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][113] = u'Hu-Tzu-Shan'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][114] = u'Hungarian 1972'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][115] = u'Bellevue (IGN) (Efate and Erromango Islands)'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][116] = u'Indonesian 1974'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][118] = u'Indian (Thailand and Vietnam)'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][119] = u'Indian (Bangladesh)'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][120] = u'Indian (India and Nepal)'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][121] = u'Indian (Pakistan)'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][123] = u'Indian 1954 (Thailand)'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][125] = u'Indian 1960 (Vietnam: near 16 degrees North)'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][126] = u'Indian 1960 (Con Son Island (Vietnam))'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][128] = u'Indian 1975 (Thailand)'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][129] = u'Ireland 1965 (Ireland and Northern Ireland)'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][130] = u'ISTS 061 Astro 1968 (South Georgia Islands)'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][131] = u'ISTS 073 Astro 1969 (Diego Garcia)'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][132] = u'Johnston Island 1961 (Johnston Island)'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][133] = u'Kalianpur (India)'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][134] = u'Kandawala (Sri Lanka)'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][135] = u'Kertau 1948 (or Revised Kertau) (West Malaysia and Singapore)'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][136] = u'KCS 2, Sierra Leone'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][137] = u'Kerguelen Island 1949 (Kerguelen Island)'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][138] = u'Korean Geodetic System 1995 (South Korea)'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][139] = u'KKJ (or Kartastokoordinaattijarjestelma), Finland'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][140] = u'Kusaie Astro 1951'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][141] = u'Kuwait Oil Company (K28)'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][142] = u'L.C. 5 Astro 1961 (Cayman Brac Island)'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][143] = u'Leigon (Ghana)'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][144] = u'Liberia 1964 (Liberia)'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][145] = u'Lisbon (Castelo di Sao Jorge), Portugal'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][146] = u'Local Astro'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][147] = u'Loma Quintana (Venezuela)'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][149] = u'Luzon (Philipines except Mindanao Island)'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][150] = u'Luzon (Mindanao Island)'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][151] = u'Marco Astro (Salvage Islands)'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][152] = u'Martinique Fort-Desaix'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][153] = u'Massawa (Eritrea, Ethiopia)'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][154] = u'Manokwari (West Irian)'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][155] = u'Mayotte Combani'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][156] = u'Mount Dillon, Tobago'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][157] = u'Merchich (Morocco)'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][158] = u'Midway Astro 1961 (Midway Island)'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][159] = u'Mahe 1971 (Mahe Island)'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][161] = u'Minna (Cameroon)'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][162] = u'Minna (Nigeria)'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][163] = u'Rome 1940 (or Monte Mario 1940), Italy'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][164] = u'Rome 1940 (or Monte Mario 1940), Italy, with Zero Meridian Rome'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][165] = u'Montjong Lowe'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][166] = u'M\'Poraloko (Gabon)'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][167] = u'Viti Levu 1916 (Viti Levu Island, Fiji Islands)'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][169] = u'Nahrwan (Masirah Island, Oman)'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][170] = u'Nahrwan (United Arab Emirates)'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][171] = u'Nahrwan (Saudi Arabia)'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][172] = u'Naparima (BWI, Trinidad and Tobago)'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][174] = u'North American 1983 (Alaska, excluding Aleutian Islands)'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][175] = u'North American 1983 (Canada)'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][176] = u'North American 1983 (CONUS)'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][177] = u'North American 1983 (Mexico and Central America))'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][178] = u'North American 1983 (Aleutian Islands)'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][179] = u'North American 1983 (Hawaii)'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][181] = u'North American 1927 (Eastern US)'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][182] = u'North American 1927 (Western US)'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][183] = u'North American 1927 (CONUS mean)'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][184] = u'North American 1927 (Alaska)'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][185] = u'North American 1927 (Canada mean)'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][186] = u'North American 1927 (Alberta and British Columbia)'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][187] = u'North American 1927 (Newfoundland, New Brunswick, Nova Scotia and Quebec)'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][188] = u'North American 1927 (Manitoba and Ontario)'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][189] = u'North American 1927 (Northwest Territories and Saskatchewan)'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][190] = u'North American 1927 (Yukon)'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][191] = u'North American 1927 (Mexico)'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][192] = u'North American 1927 (Central America)'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][193] = u'North American 1927 (Canal Zone)'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][194] = u'North American 1927 (Caribbean)'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][195] = u'North American 1927 (Bahamas, except San Salvador Island)'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][196] = u'North American 1927 (San Salvador Island)'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][197] = u'North American 1927 (Cuba)'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][198] = u'North American 1927 (Hayes Peninsula, Greenland)'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][199] = u'North American 1927 (Aleutian Islands East of 180 degrees West)'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][200] = u'North American 1927 (Aleutian Islands West of 180 degrees West)'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][201] = u'Revised Nahrwan'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][202] = u'New French or Nouvelle Triangulation Francaise (NTF) with Zero Meridian Paris'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][204] = u'North Sahara 1959'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][205] = u'Ocotopeque, Guatemala'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][206] = u'Belgium 1972 (Observatoire d\'Uccle)'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][207] = u'Old Egyptian (Egypt)'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][209] = u'Ordnance Survey G.B. 1936 (England)'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][210] = u'Ordnance Survey G.B. 1936 (England, Isle of Man, and Wales)'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][211] = u'Ordnance Survey G.B. 1936 (Scotland and Shetland Islands)'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][212] = u'Ordnance Survey G.B. 1936 (Wales)'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][213] = u'Ordnance Survey G.B. 1936 (mean value)'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][215] = u'Old Hawaiian (Hawaii)'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][216] = u'Old Hawaiian (Kauai)'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][217] = u'Old Hawaiian (Maui)'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][218] = u'Old Hawaiian (Oahu)'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][219] = u'Old Hawaiian (mean value)'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][220] = u'Oslo Observatory (Old), Norway'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][221] = u'Padang Base West End (Sumatra, Indonesia)'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][222] = u'Padang Base West End (Sumatra, Indonesia) with Zero Meridian Djakarta'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][223] = u'Palestine 1928 (Israel, Jordan)'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][224] = u'Potsdam or Helmertturm (Germany)'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][225] = u'Ayabelle Lighthouse (Djibouti)'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][226] = u'Pitcairn Astro 1967 (Pitcairn Island)'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][227] = u'Pico de las Nieves (Canary Islands)'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][228] = u'SE Base (Porto Santo) (Porto Santo and Madeira Islands)'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][230] = u'Prov. S. American 1956 (Bolivia)'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][231] = u'Prov. S. American 1956 (Northern Chile near 19 degrees South)'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][232] = u'Prov. S. American 1956 (Southern Chile near 43 degrees South)'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][233] = u'Prov. S. American 1956 (Columbia)'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][234] = u'Prov. S. American 1956 (Ecuador)'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][235] = u'Prov. S. American 1956 (Guyana)'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][236] = u'Prov. S. American 1956 (Peru)'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][237] = u'Prov. S. American 1956 (Venezuela)'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][238] = u'Prov. S. American 1956 (mean value)'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][239] = u'Point 58 Mean Solution (Burkina Faso and Niger)'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][240] = u'Pointe Noire 1948'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][241] = u'Pulkovo 1942 (Russia)'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][242] = u'Puerto Rico (Puerto Rico and Virgin Islands)'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][243] = u'Qatar National (Qatar)'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][244] = u'Qornoq (South Greenland)'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][245] = u'Rauenberg (Berlin, Germany)'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][246] = u'Reconnaissance Triangulation, Morocco'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][247] = u'Reunion 1947'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][248] = u'RT90, Stockholm, Sweden'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][249] = u'Santo (DOS) 1965 (Espirito Santo Island)'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][250] = u'South African (South Africa)'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][251] = u'Sainte Anne I 1984 (Guadeloupe)'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][253] = u'South American 1969 (Argentina)'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][254] = u'South American 1969 (Bolivia)'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][255] = u'South American 1969 (Brazil)'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][256] = u'South American 1969 (Chile)'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][257] = u'South American 1969 (Columbia)'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][258] = u'South American 1969 (Ecuador)'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][259] = u'South American 1969 (Guyana)'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][260] = u'South American 1969 (Paraguay)'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][261] = u'South American 1969 (Peru)'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][262] = u'South American 1969 (Baltra, Galapagos Islands)'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][263] = u'South American 1969 (Trinidad and Tobago)'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][264] = u'South American 1969 (Venezuela)'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][265] = u'South American 1969 (mean value)'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][266] = u'Sao Braz (Sao Miguel, Santa Maria Islands, Azores)'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][267] = u'Sapper Hill 1943 (East Falkland Islands)'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][268] = u'Schwarzeck (Namibia)'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][269] = u'Soviet Geodetic System 1985'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][270] = u'Soviet Geodetic System 1990'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][271] = u'Selvagem Grande 1938 (Salvage Islands)'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][272] = u'Astro DOS 71/4 (St. Helena Island)'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][273] = u'Sierra Leone 1960'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][274] = u'South Asia (Southeast Asia, Singapore)'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][276] = u'St. Pierre et Miquelon 1950'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][277] = u'Stockholm 1938 (Sweden)'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][278] = u'Sydney Observatory, New South Wales, Australia'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][279] = u'Tananarive Observatory 1925'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][280] = u'Tananarive Observatory 1925, with Zero Meridian Paris'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][281] = u'Tristan Astro 1968 (Tristan da Cunha)'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][282] = u'Timbalai 1948 (Brunei and East Malaysia - Sarawak and Sabah)'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][283] = u'Timbalai 1968'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][285] = u'Tokyo (Japan)'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][286] = u'Tokyo (Korea)'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][287] = u'Tokyo (Okinawa)'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][288] = u'Tokyo (mean value)'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][289] = u'Trinidad 1903'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][290] = u'Astro Tern Island 1961 (Tern Island, Hawaii)'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][292] = u'Voirol 1875'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][293] = u'Voirol 1875 with Zero Meridian Paris'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][294] = u'Voirol 1960, Algeria'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][295] = u'Voirol 1960, Algeria, with Zero Meridian Paris'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][296] = u'Wake Island Astro 1952'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][297] = u'World Geodetic System 1960'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][298] = u'World Geodetic System 1966'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][299] = u'World Geodetic System 1972'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][300] = u'World Geodetic System 1984'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][301] = u'Yacare (Uruguay)'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][302] = u'Zanderij (Surinam)'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][305] = u'Co-ordinate System 1937 of Estonia'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][306] = u'Indian 1975 (Thailand) - Cycle 1'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][307] = u'South American Geocentric Reference System (SIRGAS)'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][308] = u'Pulkovo 1942 (Hungary)'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][309] = u'Pulkovo 1942 (Poland)'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][310] = u'Pulkovo 1942 (Czechoslovakia)'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][311] = u'Pulkovo 1942 (Latvia)'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][312] = u'Pulkovo 1942 (Kazakhstan)'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][313] = u'Pulkovo 1942 (Albania)'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][314] = u'Pulkovo 1942 (Romania)'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][315] = u'Tokyo (Korea) - Cycle 1'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][998] = u'Not Applicable'
    field_information['GGDM 3.0']['SummaryDomainValues']['HZD'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['IAA'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['IAA'][1000] = u'False'
    field_information['GGDM 3.0']['SummaryDomainValues']['IAA'][1001] = u'True'
    field_information['GGDM 3.0']['SummaryDomainValues']['IAS'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['IAS'][1000] = u'False'
    field_information['GGDM 3.0']['SummaryDomainValues']['IAS'][1001] = u'True'
    field_information['GGDM 3.0']['SummaryDomainValues']['INU'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['INU'][1] = u'Controlled'
    field_information['GGDM 3.0']['SummaryDomainValues']['INU'][2] = u'Natural'
    field_information['GGDM 3.0']['SummaryDomainValues']['IWT'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['IWT'][1] = u'Lake'
    field_information['GGDM 3.0']['SummaryDomainValues']['IWT'][2] = u'Pond'
    field_information['GGDM 3.0']['SummaryDomainValues']['IWT'][3] = u'Undifferentiated Water Body'
    field_information['GGDM 3.0']['SummaryDomainValues']['IWT'][4] = u'Reservoir'
    field_information['GGDM 3.0']['SummaryDomainValues']['IWT'][5] = u'Basin'
    field_information['GGDM 3.0']['SummaryDomainValues']['IWT'][6] = u'Water-hole'
    field_information['GGDM 3.0']['SummaryDomainValues']['IWT'][7] = u'Landlocked Sea'
    field_information['GGDM 3.0']['SummaryDomainValues']['IWT'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['LAF'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['LAF'][1] = u'One other than Directional Light'
    field_information['GGDM 3.0']['SummaryDomainValues']['LAF'][2] = u'Directional Light'
    field_information['GGDM 3.0']['SummaryDomainValues']['LAF'][3] = u'Two Lights or more'
    field_information['GGDM 3.0']['SummaryDomainValues']['LAF'][4] = u'Two Beacons or more'
    field_information['GGDM 3.0']['SummaryDomainValues']['LAF'][5] = u'Two other than Two Lights or Beacons'
    field_information['GGDM 3.0']['SummaryDomainValues']['LAF'][6] = u'Measured Distance Markers'
    field_information['GGDM 3.0']['SummaryDomainValues']['LAF'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['LFC'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['LFC'][1] = u'Directional Function'
    field_information['GGDM 3.0']['SummaryDomainValues']['LFC'][4] = u'Leading Light'
    field_information['GGDM 3.0']['SummaryDomainValues']['LFC'][6] = u'Air Obstruction Light'
    field_information['GGDM 3.0']['SummaryDomainValues']['LFC'][7] = u'Fog Detector Light'
    field_information['GGDM 3.0']['SummaryDomainValues']['LFC'][8] = u'Flood Light'
    field_information['GGDM 3.0']['SummaryDomainValues']['LFC'][9] = u'Strip Light'
    field_information['GGDM 3.0']['SummaryDomainValues']['LFC'][10] = u'Subsidiary Light'
    field_information['GGDM 3.0']['SummaryDomainValues']['LFC'][11] = u'Spotlight'
    field_information['GGDM 3.0']['SummaryDomainValues']['LFC'][12] = u'Emergency Light'
    field_information['GGDM 3.0']['SummaryDomainValues']['LFC'][13] = u'Bearing Light'
    field_information['GGDM 3.0']['SummaryDomainValues']['LFC'][14] = u'Upper'
    field_information['GGDM 3.0']['SummaryDomainValues']['LFC'][16] = u'Lower'
    field_information['GGDM 3.0']['SummaryDomainValues']['LFC'][17] = u'Horizontally Disposed'
    field_information['GGDM 3.0']['SummaryDomainValues']['LFC'][18] = u'Vertically Disposed'
    field_information['GGDM 3.0']['SummaryDomainValues']['LFC'][19] = u'Front'
    field_information['GGDM 3.0']['SummaryDomainValues']['LFC'][20] = u'Rear'
    field_information['GGDM 3.0']['SummaryDomainValues']['LFC'][21] = u'Moire Effect Light'
    field_information['GGDM 3.0']['SummaryDomainValues']['LFC'][22] = u'Sectored Light'
    field_information['GGDM 3.0']['SummaryDomainValues']['LFC'][25] = u'Occasional Light'
    field_information['GGDM 3.0']['SummaryDomainValues']['LFC'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['LFC2'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['LFC2'][1] = u'Directional Function'
    field_information['GGDM 3.0']['SummaryDomainValues']['LFC2'][4] = u'Leading Light'
    field_information['GGDM 3.0']['SummaryDomainValues']['LFC2'][6] = u'Air Obstruction Light'
    field_information['GGDM 3.0']['SummaryDomainValues']['LFC2'][7] = u'Fog Detector Light'
    field_information['GGDM 3.0']['SummaryDomainValues']['LFC2'][8] = u'Flood Light'
    field_information['GGDM 3.0']['SummaryDomainValues']['LFC2'][9] = u'Strip Light'
    field_information['GGDM 3.0']['SummaryDomainValues']['LFC2'][10] = u'Subsidiary Light'
    field_information['GGDM 3.0']['SummaryDomainValues']['LFC2'][11] = u'Spotlight'
    field_information['GGDM 3.0']['SummaryDomainValues']['LFC2'][12] = u'Emergency Light'
    field_information['GGDM 3.0']['SummaryDomainValues']['LFC2'][13] = u'Bearing Light'
    field_information['GGDM 3.0']['SummaryDomainValues']['LFC2'][14] = u'Upper'
    field_information['GGDM 3.0']['SummaryDomainValues']['LFC2'][16] = u'Lower'
    field_information['GGDM 3.0']['SummaryDomainValues']['LFC2'][17] = u'Horizontally Disposed'
    field_information['GGDM 3.0']['SummaryDomainValues']['LFC2'][18] = u'Vertically Disposed'
    field_information['GGDM 3.0']['SummaryDomainValues']['LFC2'][19] = u'Front'
    field_information['GGDM 3.0']['SummaryDomainValues']['LFC2'][20] = u'Rear'
    field_information['GGDM 3.0']['SummaryDomainValues']['LFC2'][21] = u'Moire Effect Light'
    field_information['GGDM 3.0']['SummaryDomainValues']['LFC2'][22] = u'Sectored Light'
    field_information['GGDM 3.0']['SummaryDomainValues']['LFC2'][25] = u'Occasional Light'
    field_information['GGDM 3.0']['SummaryDomainValues']['LFC2'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['LFC3'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['LFC3'][1] = u'Directional Function'
    field_information['GGDM 3.0']['SummaryDomainValues']['LFC3'][4] = u'Leading Light'
    field_information['GGDM 3.0']['SummaryDomainValues']['LFC3'][6] = u'Air Obstruction Light'
    field_information['GGDM 3.0']['SummaryDomainValues']['LFC3'][7] = u'Fog Detector Light'
    field_information['GGDM 3.0']['SummaryDomainValues']['LFC3'][8] = u'Flood Light'
    field_information['GGDM 3.0']['SummaryDomainValues']['LFC3'][9] = u'Strip Light'
    field_information['GGDM 3.0']['SummaryDomainValues']['LFC3'][10] = u'Subsidiary Light'
    field_information['GGDM 3.0']['SummaryDomainValues']['LFC3'][11] = u'Spotlight'
    field_information['GGDM 3.0']['SummaryDomainValues']['LFC3'][12] = u'Emergency Light'
    field_information['GGDM 3.0']['SummaryDomainValues']['LFC3'][13] = u'Bearing Light'
    field_information['GGDM 3.0']['SummaryDomainValues']['LFC3'][14] = u'Upper'
    field_information['GGDM 3.0']['SummaryDomainValues']['LFC3'][16] = u'Lower'
    field_information['GGDM 3.0']['SummaryDomainValues']['LFC3'][17] = u'Horizontally Disposed'
    field_information['GGDM 3.0']['SummaryDomainValues']['LFC3'][18] = u'Vertically Disposed'
    field_information['GGDM 3.0']['SummaryDomainValues']['LFC3'][19] = u'Front'
    field_information['GGDM 3.0']['SummaryDomainValues']['LFC3'][20] = u'Rear'
    field_information['GGDM 3.0']['SummaryDomainValues']['LFC3'][21] = u'Moire Effect Light'
    field_information['GGDM 3.0']['SummaryDomainValues']['LFC3'][22] = u'Sectored Light'
    field_information['GGDM 3.0']['SummaryDomainValues']['LFC3'][25] = u'Occasional Light'
    field_information['GGDM 3.0']['SummaryDomainValues']['LFC3'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['LMC'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['LMC'][1000] = u'False'
    field_information['GGDM 3.0']['SummaryDomainValues']['LMC'][1001] = u'True'
    field_information['GGDM 3.0']['SummaryDomainValues']['LND'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['LND'][19] = u'Dome'
    field_information['GGDM 3.0']['SummaryDomainValues']['LND'][41] = u'Ridge'
    field_information['GGDM 3.0']['SummaryDomainValues']['LND'][56] = u'Depression'
    field_information['GGDM 3.0']['SummaryDomainValues']['LND'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['LOC'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['LOC'][17] = u'On Waterbody Bottom'
    field_information['GGDM 3.0']['SummaryDomainValues']['LOC'][23] = u'Below Waterbody Bottom'
    field_information['GGDM 3.0']['SummaryDomainValues']['LOC'][40] = u'Completely Below Ground Surface'
    field_information['GGDM 3.0']['SummaryDomainValues']['LOC'][44] = u'On Surface'
    field_information['GGDM 3.0']['SummaryDomainValues']['LOC'][45] = u'Above Surface'
    field_information['GGDM 3.0']['SummaryDomainValues']['LOC'][46] = u'Above Waterbody Bottom'
    field_information['GGDM 3.0']['SummaryDomainValues']['LOC'][47] = u'Below Waterbody Surface'
    field_information['GGDM 3.0']['SummaryDomainValues']['LOC'][48] = u'Portions Below Ground Surface'
    field_information['GGDM 3.0']['SummaryDomainValues']['LSP'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['LSP'][1] = u'Generic Administrative Boundary'
    field_information['GGDM 3.0']['SummaryDomainValues']['LSP'][2] = u'Provisional Administrative Line'
    field_information['GGDM 3.0']['SummaryDomainValues']['LSP'][3] = u'Armistice Line'
    field_information['GGDM 3.0']['SummaryDomainValues']['LSP'][4] = u'Line of Control'
    field_information['GGDM 3.0']['SummaryDomainValues']['LSP'][5] = u'Demarcation Line'
    field_information['GGDM 3.0']['SummaryDomainValues']['LSP'][6] = u'Line of Convenience'
    field_information['GGDM 3.0']['SummaryDomainValues']['LSP'][7] = u'Cease Fire Line'
    field_information['GGDM 3.0']['SummaryDomainValues']['LSP'][8] = u'Convention Line'
    field_information['GGDM 3.0']['SummaryDomainValues']['LSP'][9] = u'Claim Line'
    field_information['GGDM 3.0']['SummaryDomainValues']['LSP'][10] = u'Intercolonial Line'
    field_information['GGDM 3.0']['SummaryDomainValues']['LSP'][11] = u'Interentity Line'
    field_information['GGDM 3.0']['SummaryDomainValues']['LSP'][12] = u'Line of Adjacency'
    field_information['GGDM 3.0']['SummaryDomainValues']['LSP'][13] = u'Line of Withdrawal'
    field_information['GGDM 3.0']['SummaryDomainValues']['LSP'][14] = u'Military Disengagement Line'
    field_information['GGDM 3.0']['SummaryDomainValues']['LSP'][15] = u'Treaty Line'
    field_information['GGDM 3.0']['SummaryDomainValues']['LSP'][16] = u'UNCLOS Claim Boundary'
    field_information['GGDM 3.0']['SummaryDomainValues']['LSP'][17] = u'Generic International Boundary'
    field_information['GGDM 3.0']['SummaryDomainValues']['LSP'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['LUN'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['LUN'][1000] = u'False'
    field_information['GGDM 3.0']['SummaryDomainValues']['LUN'][1001] = u'True'
    field_information['GGDM 3.0']['SummaryDomainValues']['MAN'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['MAN'][1000] = u'False'
    field_information['GGDM 3.0']['SummaryDomainValues']['MAN'][1001] = u'True'
    field_information['GGDM 3.0']['SummaryDomainValues']['MAS'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['MAS'][1000] = u'False'
    field_information['GGDM 3.0']['SummaryDomainValues']['MAS'][1001] = u'True'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_MCC1'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_MCC1'][4] = u'Ash'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_MCC1'][7] = u'Bedrock'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_MCC1'][8] = u'Boulders'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_MCC1'][10] = u'Calcareous'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_MCC1'][12] = u'Chalk'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_MCC1'][14] = u'Cinders'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_MCC1'][15] = u'Cirripedia'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_MCC1'][16] = u'Clay'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_MCC1'][18] = u'Cobbles'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_MCC1'][22] = u'Conglomerate'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_MCC1'][24] = u'Coral'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_MCC1'][25] = u'Coral Head'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_MCC1'][28] = u'Diatomaceous Earth'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_MCC1'][36] = u'Foraminifera'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_MCC1'][37] = u'Fucus'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_MCC1'][45] = u'Plant Material'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_MCC1'][46] = u'Gravel'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_MCC1'][49] = u'Ground Shell'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_MCC1'][52] = u'Lava'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_MCC1'][55] = u'Loess'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_MCC1'][58] = u'Madrepore'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_MCC1'][59] = u'Manganese'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_MCC1'][61] = u'Marl'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_MCC1'][63] = u'Matte'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_MCC1'][65] = u'Mud'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_MCC1'][66] = u'Mussels'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_MCC1'][69] = u'Ooze'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_MCC1'][70] = u'Oysters'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_MCC1'][73] = u'Pebbles'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_MCC1'][75] = u'Sea Moss'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_MCC1'][79] = u'Pumice'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_MCC1'][80] = u'Quartz'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_MCC1'][81] = u'Radiolaria'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_MCC1'][84] = u'Rocks'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_MCC1'][88] = u'Sand'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_MCC1'][90] = u'Schist'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_MCC1'][92] = u'Scoria'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_MCC1'][96] = u'Shell'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_MCC1'][98] = u'Shingle'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_MCC1'][99] = u'Silt'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_MCC1'][103] = u'Frozen Water'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_MCC1'][104] = u'Soil'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_MCC1'][105] = u'Spicules'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_MCC1'][106] = u'Sponge'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_MCC1'][108] = u'Stone'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_MCC1'][111] = u'Tufa'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_MCC1'][115] = u'Volcanic Ash'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_MCC1'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_MCC2'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_MCC2'][4] = u'Ash'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_MCC2'][7] = u'Bedrock'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_MCC2'][8] = u'Boulders'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_MCC2'][10] = u'Calcareous'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_MCC2'][12] = u'Chalk'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_MCC2'][14] = u'Cinders'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_MCC2'][15] = u'Cirripedia'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_MCC2'][16] = u'Clay'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_MCC2'][18] = u'Cobbles'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_MCC2'][22] = u'Conglomerate'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_MCC2'][24] = u'Coral'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_MCC2'][25] = u'Coral Head'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_MCC2'][28] = u'Diatomaceous Earth'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_MCC2'][36] = u'Foraminifera'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_MCC2'][37] = u'Fucus'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_MCC2'][45] = u'Plant Material'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_MCC2'][46] = u'Gravel'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_MCC2'][49] = u'Ground Shell'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_MCC2'][52] = u'Lava'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_MCC2'][55] = u'Loess'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_MCC2'][58] = u'Madrepore'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_MCC2'][59] = u'Manganese'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_MCC2'][61] = u'Marl'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_MCC2'][63] = u'Matte'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_MCC2'][65] = u'Mud'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_MCC2'][66] = u'Mussels'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_MCC2'][69] = u'Ooze'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_MCC2'][70] = u'Oysters'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_MCC2'][73] = u'Pebbles'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_MCC2'][75] = u'Sea Moss'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_MCC2'][79] = u'Pumice'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_MCC2'][80] = u'Quartz'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_MCC2'][81] = u'Radiolaria'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_MCC2'][84] = u'Rocks'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_MCC2'][88] = u'Sand'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_MCC2'][90] = u'Schist'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_MCC2'][92] = u'Scoria'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_MCC2'][96] = u'Shell'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_MCC2'][98] = u'Shingle'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_MCC2'][99] = u'Silt'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_MCC2'][103] = u'Frozen Water'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_MCC2'][104] = u'Soil'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_MCC2'][105] = u'Spicules'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_MCC2'][106] = u'Sponge'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_MCC2'][108] = u'Stone'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_MCC2'][111] = u'Tufa'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_MCC2'][115] = u'Volcanic Ash'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_MCC2'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_PSC1'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_PSC1'][1] = u'Broken'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_PSC1'][2] = u'Coarse'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_PSC1'][3] = u'Decayed'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_PSC1'][4] = u'Fine'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_PSC1'][5] = u'Gritty'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_PSC1'][6] = u'Hard'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_PSC1'][7] = u'Rotten'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_PSC1'][8] = u'Soft'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_PSC1'][9] = u'Sticky'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_PSC1'][10] = u'Stiff'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_PSC1'][11] = u'Streaky'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_PSC1'][12] = u'Tenacious'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_PSC1'][13] = u'Irregular'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_PSC1'][14] = u'Bare'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_PSC1'][17] = u'Calcareous'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_PSC1'][18] = u'Flinty'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_PSC1'][19] = u'Glacial'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_PSC1'][20] = u'Ground'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_PSC1'][21] = u'Large'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_PSC1'][22] = u'Rocky'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_PSC1'][23] = u'Small'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_PSC1'][24] = u'Speckled'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_PSC1'][25] = u'Varied'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_PSC1'][26] = u'Volcanic'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_PSC1'][27] = u'Medium'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_PSC1'][29] = u'Mobile Bottom'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_PSC1'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_PSC2'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_PSC2'][1] = u'Broken'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_PSC2'][2] = u'Coarse'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_PSC2'][3] = u'Decayed'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_PSC2'][4] = u'Fine'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_PSC2'][5] = u'Gritty'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_PSC2'][6] = u'Hard'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_PSC2'][7] = u'Rotten'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_PSC2'][8] = u'Soft'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_PSC2'][9] = u'Sticky'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_PSC2'][10] = u'Stiff'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_PSC2'][11] = u'Streaky'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_PSC2'][12] = u'Tenacious'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_PSC2'][13] = u'Irregular'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_PSC2'][14] = u'Bare'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_PSC2'][17] = u'Calcareous'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_PSC2'][18] = u'Flinty'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_PSC2'][19] = u'Glacial'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_PSC2'][20] = u'Ground'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_PSC2'][21] = u'Large'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_PSC2'][22] = u'Rocky'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_PSC2'][23] = u'Small'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_PSC2'][24] = u'Speckled'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_PSC2'][25] = u'Varied'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_PSC2'][26] = u'Volcanic'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_PSC2'][27] = u'Medium'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_PSC2'][29] = u'Mobile Bottom'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_PSC2'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_SCO1'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_SCO1'][1] = u'Grayish Green'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_SCO1'][2] = u'Pale Grayish Green'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_SCO1'][3] = u'Very Pale Green'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_SCO1'][4] = u'Dusky Yellowish Green'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_SCO1'][5] = u'Dark Yellowish Green'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_SCO1'][6] = u'Grayish Yellowish Green'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_SCO1'][7] = u'Moderate Yellowish Green'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_SCO1'][8] = u'Pale Yellowish Green'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_SCO1'][9] = u'Very Dusky Red'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_SCO1'][10] = u'Dark Reddish Brown'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_SCO1'][11] = u'Grayish Red'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_SCO1'][12] = u'Moderate Reddish Brown'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_SCO1'][13] = u'Pale Reddish Brown'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_SCO1'][14] = u'Pale Red'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_SCO1'][15] = u'Moderate Reddish Orange'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_SCO1'][16] = u'Moderate Orange Pink'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_SCO1'][17] = u'Grayish Orange Pink'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_SCO1'][18] = u'Greenish Olive'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_SCO1'][19] = u'Light Olive'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_SCO1'][20] = u'Pale Olive'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_SCO1'][21] = u'Dark Greenish Yellow'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_SCO1'][22] = u'Moderate Greenish Yellow'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_SCO1'][23] = u'Pale Greenish Yellow'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_SCO1'][24] = u'Dusky Green'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_SCO1'][25] = u'Moderate Grayish Green'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_SCO1'][26] = u'Moderate Green'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_SCO1'][27] = u'Brilliant Green'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_SCO1'][28] = u'Pale Green'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_SCO1'][29] = u'Light Green'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_SCO1'][30] = u'Light Yellowish Green'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_SCO1'][31] = u'Very Dusky Purple'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_SCO1'][32] = u'Pale Purple'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_SCO1'][33] = u'Very Dark Red'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_SCO1'][34] = u'Dusky Red'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_SCO1'][35] = u'Moderate Red'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_SCO1'][36] = u'Light Red'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_SCO1'][37] = u'Moderate Pink'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_SCO1'][38] = u'Very Dusky Red Purple'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_SCO1'][39] = u'Pale Red Purple'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_SCO1'][40] = u'Pale Pink'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_SCO1'][41] = u'Moderate Olive Brown'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_SCO1'][42] = u'Light Olive Brown'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_SCO1'][43] = u'Dusky Yellow'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_SCO1'][44] = u'Moderate Yellow'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_SCO1'][45] = u'Grayish Yellow'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_SCO1'][46] = u'Dusky Blue Green'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_SCO1'][47] = u'Light Blue Green'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_SCO1'][48] = u'White'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_SCO1'][49] = u'Black'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_SCO1'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_SCO2'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_SCO2'][1] = u'Grayish Green'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_SCO2'][2] = u'Pale Grayish Green'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_SCO2'][3] = u'Very Pale Green'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_SCO2'][4] = u'Dusky Yellowish Green'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_SCO2'][5] = u'Dark Yellowish Green'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_SCO2'][6] = u'Grayish Yellowish Green'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_SCO2'][7] = u'Moderate Yellowish Green'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_SCO2'][8] = u'Pale Yellowish Green'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_SCO2'][9] = u'Very Dusky Red'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_SCO2'][10] = u'Dark Reddish Brown'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_SCO2'][11] = u'Grayish Red'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_SCO2'][12] = u'Moderate Reddish Brown'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_SCO2'][13] = u'Pale Reddish Brown'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_SCO2'][14] = u'Pale Red'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_SCO2'][15] = u'Moderate Reddish Orange'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_SCO2'][16] = u'Moderate Orange Pink'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_SCO2'][17] = u'Grayish Orange Pink'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_SCO2'][18] = u'Greenish Olive'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_SCO2'][19] = u'Light Olive'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_SCO2'][20] = u'Pale Olive'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_SCO2'][21] = u'Dark Greenish Yellow'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_SCO2'][22] = u'Moderate Greenish Yellow'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_SCO2'][23] = u'Pale Greenish Yellow'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_SCO2'][24] = u'Dusky Green'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_SCO2'][25] = u'Moderate Grayish Green'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_SCO2'][26] = u'Moderate Green'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_SCO2'][27] = u'Brilliant Green'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_SCO2'][28] = u'Pale Green'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_SCO2'][29] = u'Light Green'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_SCO2'][30] = u'Light Yellowish Green'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_SCO2'][31] = u'Very Dusky Purple'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_SCO2'][32] = u'Pale Purple'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_SCO2'][33] = u'Very Dark Red'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_SCO2'][34] = u'Dusky Red'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_SCO2'][35] = u'Moderate Red'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_SCO2'][36] = u'Light Red'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_SCO2'][37] = u'Moderate Pink'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_SCO2'][38] = u'Very Dusky Red Purple'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_SCO2'][39] = u'Pale Red Purple'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_SCO2'][40] = u'Pale Pink'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_SCO2'][41] = u'Moderate Olive Brown'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_SCO2'][42] = u'Light Olive Brown'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_SCO2'][43] = u'Dusky Yellow'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_SCO2'][44] = u'Moderate Yellow'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_SCO2'][45] = u'Grayish Yellow'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_SCO2'][46] = u'Dusky Blue Green'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_SCO2'][47] = u'Light Blue Green'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_SCO2'][48] = u'White'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_SCO2'][49] = u'Black'
    field_information['GGDM 3.0']['SummaryDomainValues']['MBC_SCO2'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['MCC'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['MCC'][2] = u'Aluminium'
    field_information['GGDM 3.0']['SummaryDomainValues']['MCC'][5] = u'Asphalt'
    field_information['GGDM 3.0']['SummaryDomainValues']['MCC'][7] = u'Bedrock'
    field_information['GGDM 3.0']['SummaryDomainValues']['MCC'][8] = u'Boulders'
    field_information['GGDM 3.0']['SummaryDomainValues']['MCC'][9] = u'Brick'
    field_information['GGDM 3.0']['SummaryDomainValues']['MCC'][21] = u'Concrete'
    field_information['GGDM 3.0']['SummaryDomainValues']['MCC'][23] = u'Copper'
    field_information['GGDM 3.0']['SummaryDomainValues']['MCC'][24] = u'Coral'
    field_information['GGDM 3.0']['SummaryDomainValues']['MCC'][25] = u'Coral Head'
    field_information['GGDM 3.0']['SummaryDomainValues']['MCC'][46] = u'Gravel'
    field_information['GGDM 3.0']['SummaryDomainValues']['MCC'][51] = u'Iron'
    field_information['GGDM 3.0']['SummaryDomainValues']['MCC'][52] = u'Lava'
    field_information['GGDM 3.0']['SummaryDomainValues']['MCC'][54] = u'Lead'
    field_information['GGDM 3.0']['SummaryDomainValues']['MCC'][55] = u'Loess'
    field_information['GGDM 3.0']['SummaryDomainValues']['MCC'][62] = u'Masonry'
    field_information['GGDM 3.0']['SummaryDomainValues']['MCC'][64] = u'Metal'
    field_information['GGDM 3.0']['SummaryDomainValues']['MCC'][65] = u'Mud'
    field_information['GGDM 3.0']['SummaryDomainValues']['MCC'][74] = u'Plastic'
    field_information['GGDM 3.0']['SummaryDomainValues']['MCC'][77] = u'Prestressed Concrete'
    field_information['GGDM 3.0']['SummaryDomainValues']['MCC'][83] = u'Reinforced Concrete'
    field_information['GGDM 3.0']['SummaryDomainValues']['MCC'][84] = u'Rocks'
    field_information['GGDM 3.0']['SummaryDomainValues']['MCC'][86] = u'Rubble'
    field_information['GGDM 3.0']['SummaryDomainValues']['MCC'][88] = u'Sand'
    field_information['GGDM 3.0']['SummaryDomainValues']['MCC'][103] = u'Frozen Water'
    field_information['GGDM 3.0']['SummaryDomainValues']['MCC'][104] = u'Soil'
    field_information['GGDM 3.0']['SummaryDomainValues']['MCC'][107] = u'Steel'
    field_information['GGDM 3.0']['SummaryDomainValues']['MCC'][108] = u'Stone'
    field_information['GGDM 3.0']['SummaryDomainValues']['MCC'][117] = u'Wood'
    field_information['GGDM 3.0']['SummaryDomainValues']['MCC'][119] = u'Evaporite'
    field_information['GGDM 3.0']['SummaryDomainValues']['MCC'][120] = u'Glass Reinforced Plastic (GRP)'
    field_information['GGDM 3.0']['SummaryDomainValues']['MCC'][131] = u'Ceramic'
    field_information['GGDM 3.0']['SummaryDomainValues']['MCC'][150] = u'Treated Timber'
    field_information['GGDM 3.0']['SummaryDomainValues']['MCC'][152] = u'Fibreglass'
    field_information['GGDM 3.0']['SummaryDomainValues']['MCC'][160] = u'Earthen'
    field_information['GGDM 3.0']['SummaryDomainValues']['MCC'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['MCC2'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['MCC2'][2] = u'Aluminium'
    field_information['GGDM 3.0']['SummaryDomainValues']['MCC2'][5] = u'Asphalt'
    field_information['GGDM 3.0']['SummaryDomainValues']['MCC2'][7] = u'Bedrock'
    field_information['GGDM 3.0']['SummaryDomainValues']['MCC2'][8] = u'Boulders'
    field_information['GGDM 3.0']['SummaryDomainValues']['MCC2'][9] = u'Brick'
    field_information['GGDM 3.0']['SummaryDomainValues']['MCC2'][21] = u'Concrete'
    field_information['GGDM 3.0']['SummaryDomainValues']['MCC2'][23] = u'Copper'
    field_information['GGDM 3.0']['SummaryDomainValues']['MCC2'][24] = u'Coral'
    field_information['GGDM 3.0']['SummaryDomainValues']['MCC2'][25] = u'Coral Head'
    field_information['GGDM 3.0']['SummaryDomainValues']['MCC2'][46] = u'Gravel'
    field_information['GGDM 3.0']['SummaryDomainValues']['MCC2'][51] = u'Iron'
    field_information['GGDM 3.0']['SummaryDomainValues']['MCC2'][52] = u'Lava'
    field_information['GGDM 3.0']['SummaryDomainValues']['MCC2'][54] = u'Lead'
    field_information['GGDM 3.0']['SummaryDomainValues']['MCC2'][55] = u'Loess'
    field_information['GGDM 3.0']['SummaryDomainValues']['MCC2'][62] = u'Masonry'
    field_information['GGDM 3.0']['SummaryDomainValues']['MCC2'][64] = u'Metal'
    field_information['GGDM 3.0']['SummaryDomainValues']['MCC2'][65] = u'Mud'
    field_information['GGDM 3.0']['SummaryDomainValues']['MCC2'][74] = u'Plastic'
    field_information['GGDM 3.0']['SummaryDomainValues']['MCC2'][77] = u'Prestressed Concrete'
    field_information['GGDM 3.0']['SummaryDomainValues']['MCC2'][83] = u'Reinforced Concrete'
    field_information['GGDM 3.0']['SummaryDomainValues']['MCC2'][84] = u'Rocks'
    field_information['GGDM 3.0']['SummaryDomainValues']['MCC2'][86] = u'Rubble'
    field_information['GGDM 3.0']['SummaryDomainValues']['MCC2'][88] = u'Sand'
    field_information['GGDM 3.0']['SummaryDomainValues']['MCC2'][103] = u'Frozen Water'
    field_information['GGDM 3.0']['SummaryDomainValues']['MCC2'][104] = u'Soil'
    field_information['GGDM 3.0']['SummaryDomainValues']['MCC2'][107] = u'Steel'
    field_information['GGDM 3.0']['SummaryDomainValues']['MCC2'][108] = u'Stone'
    field_information['GGDM 3.0']['SummaryDomainValues']['MCC2'][117] = u'Wood'
    field_information['GGDM 3.0']['SummaryDomainValues']['MCC2'][119] = u'Evaporite'
    field_information['GGDM 3.0']['SummaryDomainValues']['MCC2'][120] = u'Glass Reinforced Plastic (GRP)'
    field_information['GGDM 3.0']['SummaryDomainValues']['MCC2'][131] = u'Ceramic'
    field_information['GGDM 3.0']['SummaryDomainValues']['MCC2'][150] = u'Treated Timber'
    field_information['GGDM 3.0']['SummaryDomainValues']['MCC2'][152] = u'Fibreglass'
    field_information['GGDM 3.0']['SummaryDomainValues']['MCC2'][160] = u'Earthen'
    field_information['GGDM 3.0']['SummaryDomainValues']['MCC2'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['MCC3'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['MCC3'][2] = u'Aluminium'
    field_information['GGDM 3.0']['SummaryDomainValues']['MCC3'][5] = u'Asphalt'
    field_information['GGDM 3.0']['SummaryDomainValues']['MCC3'][7] = u'Bedrock'
    field_information['GGDM 3.0']['SummaryDomainValues']['MCC3'][8] = u'Boulders'
    field_information['GGDM 3.0']['SummaryDomainValues']['MCC3'][9] = u'Brick'
    field_information['GGDM 3.0']['SummaryDomainValues']['MCC3'][21] = u'Concrete'
    field_information['GGDM 3.0']['SummaryDomainValues']['MCC3'][23] = u'Copper'
    field_information['GGDM 3.0']['SummaryDomainValues']['MCC3'][24] = u'Coral'
    field_information['GGDM 3.0']['SummaryDomainValues']['MCC3'][25] = u'Coral Head'
    field_information['GGDM 3.0']['SummaryDomainValues']['MCC3'][46] = u'Gravel'
    field_information['GGDM 3.0']['SummaryDomainValues']['MCC3'][51] = u'Iron'
    field_information['GGDM 3.0']['SummaryDomainValues']['MCC3'][52] = u'Lava'
    field_information['GGDM 3.0']['SummaryDomainValues']['MCC3'][54] = u'Lead'
    field_information['GGDM 3.0']['SummaryDomainValues']['MCC3'][55] = u'Loess'
    field_information['GGDM 3.0']['SummaryDomainValues']['MCC3'][62] = u'Masonry'
    field_information['GGDM 3.0']['SummaryDomainValues']['MCC3'][64] = u'Metal'
    field_information['GGDM 3.0']['SummaryDomainValues']['MCC3'][65] = u'Mud'
    field_information['GGDM 3.0']['SummaryDomainValues']['MCC3'][74] = u'Plastic'
    field_information['GGDM 3.0']['SummaryDomainValues']['MCC3'][77] = u'Prestressed Concrete'
    field_information['GGDM 3.0']['SummaryDomainValues']['MCC3'][83] = u'Reinforced Concrete'
    field_information['GGDM 3.0']['SummaryDomainValues']['MCC3'][84] = u'Rocks'
    field_information['GGDM 3.0']['SummaryDomainValues']['MCC3'][86] = u'Rubble'
    field_information['GGDM 3.0']['SummaryDomainValues']['MCC3'][88] = u'Sand'
    field_information['GGDM 3.0']['SummaryDomainValues']['MCC3'][103] = u'Frozen Water'
    field_information['GGDM 3.0']['SummaryDomainValues']['MCC3'][104] = u'Soil'
    field_information['GGDM 3.0']['SummaryDomainValues']['MCC3'][107] = u'Steel'
    field_information['GGDM 3.0']['SummaryDomainValues']['MCC3'][108] = u'Stone'
    field_information['GGDM 3.0']['SummaryDomainValues']['MCC3'][117] = u'Wood'
    field_information['GGDM 3.0']['SummaryDomainValues']['MCC3'][119] = u'Evaporite'
    field_information['GGDM 3.0']['SummaryDomainValues']['MCC3'][120] = u'Glass Reinforced Plastic (GRP)'
    field_information['GGDM 3.0']['SummaryDomainValues']['MCC3'][131] = u'Ceramic'
    field_information['GGDM 3.0']['SummaryDomainValues']['MCC3'][150] = u'Treated Timber'
    field_information['GGDM 3.0']['SummaryDomainValues']['MCC3'][152] = u'Fibreglass'
    field_information['GGDM 3.0']['SummaryDomainValues']['MCC3'][160] = u'Earthen'
    field_information['GGDM 3.0']['SummaryDomainValues']['MCC3'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['MCX'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['MCX'][1000] = u'False'
    field_information['GGDM 3.0']['SummaryDomainValues']['MCX'][1001] = u'True'
    field_information['GGDM 3.0']['SummaryDomainValues']['MCY'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['MCY'][1] = u'Cargo Transshipment'
    field_information['GGDM 3.0']['SummaryDomainValues']['MCY'][2] = u'Ice Advisory'
    field_information['GGDM 3.0']['SummaryDomainValues']['MCY'][3] = u'Intake Area'
    field_information['GGDM 3.0']['SummaryDomainValues']['MCY'][4] = u'Outfall Area'
    field_information['GGDM 3.0']['SummaryDomainValues']['MCY'][5] = u'Pollution Zone'
    field_information['GGDM 3.0']['SummaryDomainValues']['MCY'][6] = u'Submarine Cable'
    field_information['GGDM 3.0']['SummaryDomainValues']['MCY'][7] = u'Submarine Pipeline'
    field_information['GGDM 3.0']['SummaryDomainValues']['MCY'][8] = u'Submarine Sewer'
    field_information['GGDM 3.0']['SummaryDomainValues']['MCY'][9] = u'Unexploded Ordnance'
    field_information['GGDM 3.0']['SummaryDomainValues']['MCY'][10] = u'Clearing Line'
    field_information['GGDM 3.0']['SummaryDomainValues']['MCY'][11] = u'COLREGS Demarcation Line'
    field_information['GGDM 3.0']['SummaryDomainValues']['MCY'][12] = u'Harbour Area'
    field_information['GGDM 3.0']['SummaryDomainValues']['MCY'][13] = u'Ocean Current Margin'
    field_information['GGDM 3.0']['SummaryDomainValues']['MCY'][14] = u'Works in Progress Area'
    field_information['GGDM 3.0']['SummaryDomainValues']['MCY'][15] = u'Unsurveyed Area'
    field_information['GGDM 3.0']['SummaryDomainValues']['MCY'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['MCY2'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['MCY2'][1] = u'Cargo Transshipment'
    field_information['GGDM 3.0']['SummaryDomainValues']['MCY2'][2] = u'Ice Advisory'
    field_information['GGDM 3.0']['SummaryDomainValues']['MCY2'][3] = u'Intake Area'
    field_information['GGDM 3.0']['SummaryDomainValues']['MCY2'][4] = u'Outfall Area'
    field_information['GGDM 3.0']['SummaryDomainValues']['MCY2'][5] = u'Pollution Zone'
    field_information['GGDM 3.0']['SummaryDomainValues']['MCY2'][6] = u'Submarine Cable'
    field_information['GGDM 3.0']['SummaryDomainValues']['MCY2'][7] = u'Submarine Pipeline'
    field_information['GGDM 3.0']['SummaryDomainValues']['MCY2'][8] = u'Submarine Sewer'
    field_information['GGDM 3.0']['SummaryDomainValues']['MCY2'][9] = u'Unexploded Ordnance'
    field_information['GGDM 3.0']['SummaryDomainValues']['MCY2'][10] = u'Clearing Line'
    field_information['GGDM 3.0']['SummaryDomainValues']['MCY2'][11] = u'COLREGS Demarcation Line'
    field_information['GGDM 3.0']['SummaryDomainValues']['MCY2'][12] = u'Harbour Area'
    field_information['GGDM 3.0']['SummaryDomainValues']['MCY2'][13] = u'Ocean Current Margin'
    field_information['GGDM 3.0']['SummaryDomainValues']['MCY2'][14] = u'Works in Progress Area'
    field_information['GGDM 3.0']['SummaryDomainValues']['MCY2'][15] = u'Unsurveyed Area'
    field_information['GGDM 3.0']['SummaryDomainValues']['MCY2'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['MCY3'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['MCY3'][1] = u'Cargo Transshipment'
    field_information['GGDM 3.0']['SummaryDomainValues']['MCY3'][2] = u'Ice Advisory'
    field_information['GGDM 3.0']['SummaryDomainValues']['MCY3'][3] = u'Intake Area'
    field_information['GGDM 3.0']['SummaryDomainValues']['MCY3'][4] = u'Outfall Area'
    field_information['GGDM 3.0']['SummaryDomainValues']['MCY3'][5] = u'Pollution Zone'
    field_information['GGDM 3.0']['SummaryDomainValues']['MCY3'][6] = u'Submarine Cable'
    field_information['GGDM 3.0']['SummaryDomainValues']['MCY3'][7] = u'Submarine Pipeline'
    field_information['GGDM 3.0']['SummaryDomainValues']['MCY3'][8] = u'Submarine Sewer'
    field_information['GGDM 3.0']['SummaryDomainValues']['MCY3'][9] = u'Unexploded Ordnance'
    field_information['GGDM 3.0']['SummaryDomainValues']['MCY3'][10] = u'Clearing Line'
    field_information['GGDM 3.0']['SummaryDomainValues']['MCY3'][11] = u'COLREGS Demarcation Line'
    field_information['GGDM 3.0']['SummaryDomainValues']['MCY3'][12] = u'Harbour Area'
    field_information['GGDM 3.0']['SummaryDomainValues']['MCY3'][13] = u'Ocean Current Margin'
    field_information['GGDM 3.0']['SummaryDomainValues']['MCY3'][14] = u'Works in Progress Area'
    field_information['GGDM 3.0']['SummaryDomainValues']['MCY3'][15] = u'Unsurveyed Area'
    field_information['GGDM 3.0']['SummaryDomainValues']['MCY3'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['MEL'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['MEL'][1] = u'Accident and Emergency'
    field_information['GGDM 3.0']['SummaryDomainValues']['MEL'][2] = u'Anaesthetics'
    field_information['GGDM 3.0']['SummaryDomainValues']['MEL'][3] = u'Cardiology'
    field_information['GGDM 3.0']['SummaryDomainValues']['MEL'][4] = u'Critical Care'
    field_information['GGDM 3.0']['SummaryDomainValues']['MEL'][5] = u'Diagnostic Imaging'
    field_information['GGDM 3.0']['SummaryDomainValues']['MEL'][6] = u'Ear, Nose and Throat'
    field_information['GGDM 3.0']['SummaryDomainValues']['MEL'][7] = u'General Surgery'
    field_information['GGDM 3.0']['SummaryDomainValues']['MEL'][8] = u'Gynaecology'
    field_information['GGDM 3.0']['SummaryDomainValues']['MEL'][9] = u'Maternity'
    field_information['GGDM 3.0']['SummaryDomainValues']['MEL'][10] = u'Neurology'
    field_information['GGDM 3.0']['SummaryDomainValues']['MEL'][11] = u'Oncology'
    field_information['GGDM 3.0']['SummaryDomainValues']['MEL'][12] = u'Ophthalmology'
    field_information['GGDM 3.0']['SummaryDomainValues']['MEL'][13] = u'Orthopaedics'
    field_information['GGDM 3.0']['SummaryDomainValues']['MEL'][14] = u'Pharmacy'
    field_information['GGDM 3.0']['SummaryDomainValues']['MEL'][15] = u'Urology'
    field_information['GGDM 3.0']['SummaryDomainValues']['MEL'][16] = u'Sexual Health'
    field_information['GGDM 3.0']['SummaryDomainValues']['MEL'][17] = u'Haematology'
    field_information['GGDM 3.0']['SummaryDomainValues']['MEL'][18] = u'Physiotherapy'
    field_information['GGDM 3.0']['SummaryDomainValues']['MEL'][19] = u'Dietetics'
    field_information['GGDM 3.0']['SummaryDomainValues']['MEL'][20] = u'Preventive Medicine'
    field_information['GGDM 3.0']['SummaryDomainValues']['MEL'][21] = u'Blood Bank'
    field_information['GGDM 3.0']['SummaryDomainValues']['MEL'][22] = u'Paediatrics'
    field_information['GGDM 3.0']['SummaryDomainValues']['MEL'][23] = u'Psychiatry'
    field_information['GGDM 3.0']['SummaryDomainValues']['MEL'][24] = u'Burns Unit'
    field_information['GGDM 3.0']['SummaryDomainValues']['MEL'][25] = u'General Practice'
    field_information['GGDM 3.0']['SummaryDomainValues']['MEL'][26] = u'Clinical Services'
    field_information['GGDM 3.0']['SummaryDomainValues']['MEL'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['MES'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['MES'][1000] = u'False'
    field_information['GGDM 3.0']['SummaryDomainValues']['MES'][1001] = u'True'
    field_information['GGDM 3.0']['SummaryDomainValues']['MFB'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['MFB'][1000] = u'False'
    field_information['GGDM 3.0']['SummaryDomainValues']['MFB'][1001] = u'True'
    field_information['GGDM 3.0']['SummaryDomainValues']['MFE'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['MFE'][1] = u'Fencing'
    field_information['GGDM 3.0']['SummaryDomainValues']['MFE'][2] = u'Fishing Stakes'
    field_information['GGDM 3.0']['SummaryDomainValues']['MFE'][3] = u'Nets'
    field_information['GGDM 3.0']['SummaryDomainValues']['MFE'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['MFY'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['MFY'][1] = u'General Medical and Surgical'
    field_information['GGDM 3.0']['SummaryDomainValues']['MFY'][2] = u'Long-term Acute Care'
    field_information['GGDM 3.0']['SummaryDomainValues']['MFY'][3] = u'Chemical Dependency'
    field_information['GGDM 3.0']['SummaryDomainValues']['MFY'][4] = u'Chronic Disease'
    field_information['GGDM 3.0']['SummaryDomainValues']['MFY'][5] = u'Eye, Ear, Nose and Throat'
    field_information['GGDM 3.0']['SummaryDomainValues']['MFY'][6] = u'Intellectual Disablement Care'
    field_information['GGDM 3.0']['SummaryDomainValues']['MFY'][7] = u'Obstetrics and Gynaecology'
    field_information['GGDM 3.0']['SummaryDomainValues']['MFY'][8] = u'Orthopaedics'
    field_information['GGDM 3.0']['SummaryDomainValues']['MFY'][9] = u'Psychiatric'
    field_information['GGDM 3.0']['SummaryDomainValues']['MFY'][10] = u'Rehabilitation'
    field_information['GGDM 3.0']['SummaryDomainValues']['MFY'][11] = u'Respiratory Disease'
    field_information['GGDM 3.0']['SummaryDomainValues']['MFY'][12] = u'Specialty Care'
    field_information['GGDM 3.0']['SummaryDomainValues']['MFY'][13] = u'Unit within Institution'
    field_information['GGDM 3.0']['SummaryDomainValues']['MFY'][14] = u'Unit within Institution for the Intellectually Disabled'
    field_information['GGDM 3.0']['SummaryDomainValues']['MFY'][15] = u'Pediatric Medical and Surgical'
    field_information['GGDM 3.0']['SummaryDomainValues']['MFY'][16] = u'Paediatric Chronic Disease'
    field_information['GGDM 3.0']['SummaryDomainValues']['MFY'][17] = u'Paediatric Eye, Ear, Nose and Throat'
    field_information['GGDM 3.0']['SummaryDomainValues']['MFY'][18] = u'Paediatric Orthopaedic'
    field_information['GGDM 3.0']['SummaryDomainValues']['MFY'][19] = u'Pediatric Psychiatric'
    field_information['GGDM 3.0']['SummaryDomainValues']['MFY'][20] = u'Paediatric Rehabilitation'
    field_information['GGDM 3.0']['SummaryDomainValues']['MFY'][21] = u'Paediatric Respiratory Disease'
    field_information['GGDM 3.0']['SummaryDomainValues']['MFY'][22] = u'Paediatric Specialty Care'
    field_information['GGDM 3.0']['SummaryDomainValues']['MFY'][23] = u'Paediatric Unit within Institution'
    field_information['GGDM 3.0']['SummaryDomainValues']['MFY'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['MGL'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['MGL'][1] = u'International Boundary'
    field_information['GGDM 3.0']['SummaryDomainValues']['MGL'][2] = u'Territorial Sea Baseline'
    field_information['GGDM 3.0']['SummaryDomainValues']['MGL'][3] = u'Three Nautical Mile Limit'
    field_information['GGDM 3.0']['SummaryDomainValues']['MGL'][4] = u'Territorial Waters Limit of Sovereignty'
    field_information['GGDM 3.0']['SummaryDomainValues']['MGL'][5] = u'Contiguous Zone Limit'
    field_information['GGDM 3.0']['SummaryDomainValues']['MGL'][6] = u'Continental Shelf Limit'
    field_information['GGDM 3.0']['SummaryDomainValues']['MGL'][7] = u'Extended Continental Shelf Limit'
    field_information['GGDM 3.0']['SummaryDomainValues']['MGL'][8] = u'Exclusive Economic Zone Limit'
    field_information['GGDM 3.0']['SummaryDomainValues']['MGL'][9] = u'Customs Boundary'
    field_information['GGDM 3.0']['SummaryDomainValues']['MGL'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['MGL2'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['MGL2'][1] = u'International Boundary'
    field_information['GGDM 3.0']['SummaryDomainValues']['MGL2'][2] = u'Territorial Sea Baseline'
    field_information['GGDM 3.0']['SummaryDomainValues']['MGL2'][3] = u'Three Nautical Mile Limit'
    field_information['GGDM 3.0']['SummaryDomainValues']['MGL2'][4] = u'Territorial Waters Limit of Sovereignty'
    field_information['GGDM 3.0']['SummaryDomainValues']['MGL2'][5] = u'Contiguous Zone Limit'
    field_information['GGDM 3.0']['SummaryDomainValues']['MGL2'][6] = u'Continental Shelf Limit'
    field_information['GGDM 3.0']['SummaryDomainValues']['MGL2'][7] = u'Extended Continental Shelf Limit'
    field_information['GGDM 3.0']['SummaryDomainValues']['MGL2'][8] = u'Exclusive Economic Zone Limit'
    field_information['GGDM 3.0']['SummaryDomainValues']['MGL2'][9] = u'Customs Boundary'
    field_information['GGDM 3.0']['SummaryDomainValues']['MGL2'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['MGL3'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['MGL3'][1] = u'International Boundary'
    field_information['GGDM 3.0']['SummaryDomainValues']['MGL3'][2] = u'Territorial Sea Baseline'
    field_information['GGDM 3.0']['SummaryDomainValues']['MGL3'][3] = u'Three Nautical Mile Limit'
    field_information['GGDM 3.0']['SummaryDomainValues']['MGL3'][4] = u'Territorial Waters Limit of Sovereignty'
    field_information['GGDM 3.0']['SummaryDomainValues']['MGL3'][5] = u'Contiguous Zone Limit'
    field_information['GGDM 3.0']['SummaryDomainValues']['MGL3'][6] = u'Continental Shelf Limit'
    field_information['GGDM 3.0']['SummaryDomainValues']['MGL3'][7] = u'Extended Continental Shelf Limit'
    field_information['GGDM 3.0']['SummaryDomainValues']['MGL3'][8] = u'Exclusive Economic Zone Limit'
    field_information['GGDM 3.0']['SummaryDomainValues']['MGL3'][9] = u'Customs Boundary'
    field_information['GGDM 3.0']['SummaryDomainValues']['MGL3'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['MKSZ'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['MKSZ'][1] = u'Small'
    field_information['GGDM 3.0']['SummaryDomainValues']['MKSZ'][2] = u'Medium'
    field_information['GGDM 3.0']['SummaryDomainValues']['MKSZ'][3] = u'Large'
    field_information['GGDM 3.0']['SummaryDomainValues']['MKSZ'][998] = u'Not Applicable'
    field_information['GGDM 3.0']['SummaryDomainValues']['MLO'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['MLO'][1000] = u'False'
    field_information['GGDM 3.0']['SummaryDomainValues']['MLO'][1001] = u'True'
    field_information['GGDM 3.0']['SummaryDomainValues']['MLOP'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['MLOP'][1] = u'Command Post'
    field_information['GGDM 3.0']['SummaryDomainValues']['MLOP'][2] = u'Command Outpost'
    field_information['GGDM 3.0']['SummaryDomainValues']['MLOP'][3] = u'Brigade Maintenance Area'
    field_information['GGDM 3.0']['SummaryDomainValues']['MLOP'][4] = u'Air Departure Point'
    field_information['GGDM 3.0']['SummaryDomainValues']['MLOP'][5] = u'Amphibious Departure Point'
    field_information['GGDM 3.0']['SummaryDomainValues']['MLOP'][6] = u'Evacuee Handling Centre'
    field_information['GGDM 3.0']['SummaryDomainValues']['MLOP'][7] = u'Evacuee Collection Point'
    field_information['GGDM 3.0']['SummaryDomainValues']['MLOP'][8] = u'Observation Post'
    field_information['GGDM 3.0']['SummaryDomainValues']['MLOP'][9] = u'Forward Operating Base'
    field_information['GGDM 3.0']['SummaryDomainValues']['MLOP'][10] = u'Patrol Base'
    field_information['GGDM 3.0']['SummaryDomainValues']['MLOP'][11] = u'Evacuation Point'
    field_information['GGDM 3.0']['SummaryDomainValues']['MLOP'][12] = u'Evacuee Assembly Area'
    field_information['GGDM 3.0']['SummaryDomainValues']['MLOP'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['MLUS'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['MLUS'][1] = u'Tactical Area of Responsibility'
    field_information['GGDM 3.0']['SummaryDomainValues']['MLUS'][2] = u'Named Area of Interest'
    field_information['GGDM 3.0']['SummaryDomainValues']['MLUS'][3] = u'Target Area of Interest'
    field_information['GGDM 3.0']['SummaryDomainValues']['MLUS'][4] = u'Area of Operations'
    field_information['GGDM 3.0']['SummaryDomainValues']['MLUS'][5] = u'Area of Interest'
    field_information['GGDM 3.0']['SummaryDomainValues']['MLUS'][6] = u'Out of Bounds'
    field_information['GGDM 3.0']['SummaryDomainValues']['MLUS'][7] = u'No Go Area'
    field_information['GGDM 3.0']['SummaryDomainValues']['MLUS'][8] = u'No Fly Zone'
    field_information['GGDM 3.0']['SummaryDomainValues']['MLUS'][9] = u'Restricted Operation Zone'
    field_information['GGDM 3.0']['SummaryDomainValues']['MLUS'][10] = u'Temporary Area of Operations'
    field_information['GGDM 3.0']['SummaryDomainValues']['MLUS'][11] = u'Report line'
    field_information['GGDM 3.0']['SummaryDomainValues']['MLUS'][12] = u'Supply Route, Main'
    field_information['GGDM 3.0']['SummaryDomainValues']['MLUS'][13] = u'Supply Route, Secondary'
    field_information['GGDM 3.0']['SummaryDomainValues']['MLUS'][14] = u'Supply Route, Alternate'
    field_information['GGDM 3.0']['SummaryDomainValues']['MLUS'][15] = u'Forward Edge of Battle Area'
    field_information['GGDM 3.0']['SummaryDomainValues']['MLUS'][16] = u'Bomb release line'
    field_information['GGDM 3.0']['SummaryDomainValues']['MLUS'][17] = u'Forward Line of Own Troops'
    field_information['GGDM 3.0']['SummaryDomainValues']['MLUS'][18] = u'Missile release line'
    field_information['GGDM 3.0']['SummaryDomainValues']['MLUS'][19] = u'Forward Line of Enemy Troops'
    field_information['GGDM 3.0']['SummaryDomainValues']['MLUS'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['MNR'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['MNR'][1] = u'Anchoring Prohibited'
    field_information['GGDM 3.0']['SummaryDomainValues']['MNR'][2] = u'Anchoring Restricted'
    field_information['GGDM 3.0']['SummaryDomainValues']['MNR'][3] = u'Fishing Prohibited'
    field_information['GGDM 3.0']['SummaryDomainValues']['MNR'][4] = u'Fishing Restricted'
    field_information['GGDM 3.0']['SummaryDomainValues']['MNR'][5] = u'Trawling Prohibited'
    field_information['GGDM 3.0']['SummaryDomainValues']['MNR'][6] = u'Trawling Restricted'
    field_information['GGDM 3.0']['SummaryDomainValues']['MNR'][7] = u'Entry Prohibited'
    field_information['GGDM 3.0']['SummaryDomainValues']['MNR'][8] = u'Entry Restricted'
    field_information['GGDM 3.0']['SummaryDomainValues']['MNR'][9] = u'Dredging Prohibited'
    field_information['GGDM 3.0']['SummaryDomainValues']['MNR'][10] = u'Dredging Restricted'
    field_information['GGDM 3.0']['SummaryDomainValues']['MNR'][11] = u'Diving Prohibited'
    field_information['GGDM 3.0']['SummaryDomainValues']['MNR'][12] = u'Diving Restricted'
    field_information['GGDM 3.0']['SummaryDomainValues']['MNR'][13] = u'Reduced Wake Area'
    field_information['GGDM 3.0']['SummaryDomainValues']['MNR'][14] = u'Avoidance Area'
    field_information['GGDM 3.0']['SummaryDomainValues']['MNR'][15] = u'Construction Prohibited'
    field_information['GGDM 3.0']['SummaryDomainValues']['MNR'][16] = u'Discharging Prohibited'
    field_information['GGDM 3.0']['SummaryDomainValues']['MNR'][17] = u'Discharging Restricted'
    field_information['GGDM 3.0']['SummaryDomainValues']['MNR'][18] = u'Exploration and/or Development Prohibited'
    field_information['GGDM 3.0']['SummaryDomainValues']['MNR'][19] = u'Exploration and/or Development Restricted'
    field_information['GGDM 3.0']['SummaryDomainValues']['MNR'][20] = u'Drilling Prohibited'
    field_information['GGDM 3.0']['SummaryDomainValues']['MNR'][21] = u'Drilling Restricted'
    field_information['GGDM 3.0']['SummaryDomainValues']['MNR'][22] = u'Artefact Removal Prohibited'
    field_information['GGDM 3.0']['SummaryDomainValues']['MNR'][23] = u'Cargo Transshipment Prohibited'
    field_information['GGDM 3.0']['SummaryDomainValues']['MNR'][24] = u'Dragging Prohibited'
    field_information['GGDM 3.0']['SummaryDomainValues']['MNR'][25] = u'Stopping Prohibited'
    field_information['GGDM 3.0']['SummaryDomainValues']['MNR'][26] = u'Landing Prohibited'
    field_information['GGDM 3.0']['SummaryDomainValues']['MNR'][27] = u'Limited Speed Area'
    field_information['GGDM 3.0']['SummaryDomainValues']['MNR'][28] = u'Navigational Aid Safety Zone'
    field_information['GGDM 3.0']['SummaryDomainValues']['MNR'][29] = u'Offshore Safety Zone'
    field_information['GGDM 3.0']['SummaryDomainValues']['MNR'][30] = u'Shipping Prohibited'
    field_information['GGDM 3.0']['SummaryDomainValues']['MNR'][31] = u'Swimming Prohibited'
    field_information['GGDM 3.0']['SummaryDomainValues']['MNR'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['MNR2'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['MNR2'][1] = u'Anchoring Prohibited'
    field_information['GGDM 3.0']['SummaryDomainValues']['MNR2'][2] = u'Anchoring Restricted'
    field_information['GGDM 3.0']['SummaryDomainValues']['MNR2'][3] = u'Fishing Prohibited'
    field_information['GGDM 3.0']['SummaryDomainValues']['MNR2'][4] = u'Fishing Restricted'
    field_information['GGDM 3.0']['SummaryDomainValues']['MNR2'][5] = u'Trawling Prohibited'
    field_information['GGDM 3.0']['SummaryDomainValues']['MNR2'][6] = u'Trawling Restricted'
    field_information['GGDM 3.0']['SummaryDomainValues']['MNR2'][7] = u'Entry Prohibited'
    field_information['GGDM 3.0']['SummaryDomainValues']['MNR2'][8] = u'Entry Restricted'
    field_information['GGDM 3.0']['SummaryDomainValues']['MNR2'][9] = u'Dredging Prohibited'
    field_information['GGDM 3.0']['SummaryDomainValues']['MNR2'][10] = u'Dredging Restricted'
    field_information['GGDM 3.0']['SummaryDomainValues']['MNR2'][11] = u'Diving Prohibited'
    field_information['GGDM 3.0']['SummaryDomainValues']['MNR2'][12] = u'Diving Restricted'
    field_information['GGDM 3.0']['SummaryDomainValues']['MNR2'][13] = u'Reduced Wake Area'
    field_information['GGDM 3.0']['SummaryDomainValues']['MNR2'][14] = u'Avoidance Area'
    field_information['GGDM 3.0']['SummaryDomainValues']['MNR2'][15] = u'Construction Prohibited'
    field_information['GGDM 3.0']['SummaryDomainValues']['MNR2'][16] = u'Discharging Prohibited'
    field_information['GGDM 3.0']['SummaryDomainValues']['MNR2'][17] = u'Discharging Restricted'
    field_information['GGDM 3.0']['SummaryDomainValues']['MNR2'][18] = u'Exploration and/or Development Prohibited'
    field_information['GGDM 3.0']['SummaryDomainValues']['MNR2'][19] = u'Exploration and/or Development Restricted'
    field_information['GGDM 3.0']['SummaryDomainValues']['MNR2'][20] = u'Drilling Prohibited'
    field_information['GGDM 3.0']['SummaryDomainValues']['MNR2'][21] = u'Drilling Restricted'
    field_information['GGDM 3.0']['SummaryDomainValues']['MNR2'][22] = u'Artefact Removal Prohibited'
    field_information['GGDM 3.0']['SummaryDomainValues']['MNR2'][23] = u'Cargo Transshipment Prohibited'
    field_information['GGDM 3.0']['SummaryDomainValues']['MNR2'][24] = u'Dragging Prohibited'
    field_information['GGDM 3.0']['SummaryDomainValues']['MNR2'][25] = u'Stopping Prohibited'
    field_information['GGDM 3.0']['SummaryDomainValues']['MNR2'][26] = u'Landing Prohibited'
    field_information['GGDM 3.0']['SummaryDomainValues']['MNR2'][27] = u'Limited Speed Area'
    field_information['GGDM 3.0']['SummaryDomainValues']['MNR2'][28] = u'Navigational Aid Safety Zone'
    field_information['GGDM 3.0']['SummaryDomainValues']['MNR2'][29] = u'Offshore Safety Zone'
    field_information['GGDM 3.0']['SummaryDomainValues']['MNR2'][30] = u'Shipping Prohibited'
    field_information['GGDM 3.0']['SummaryDomainValues']['MNR2'][31] = u'Swimming Prohibited'
    field_information['GGDM 3.0']['SummaryDomainValues']['MNR2'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['MNR3'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['MNR3'][1] = u'Anchoring Prohibited'
    field_information['GGDM 3.0']['SummaryDomainValues']['MNR3'][2] = u'Anchoring Restricted'
    field_information['GGDM 3.0']['SummaryDomainValues']['MNR3'][3] = u'Fishing Prohibited'
    field_information['GGDM 3.0']['SummaryDomainValues']['MNR3'][4] = u'Fishing Restricted'
    field_information['GGDM 3.0']['SummaryDomainValues']['MNR3'][5] = u'Trawling Prohibited'
    field_information['GGDM 3.0']['SummaryDomainValues']['MNR3'][6] = u'Trawling Restricted'
    field_information['GGDM 3.0']['SummaryDomainValues']['MNR3'][7] = u'Entry Prohibited'
    field_information['GGDM 3.0']['SummaryDomainValues']['MNR3'][8] = u'Entry Restricted'
    field_information['GGDM 3.0']['SummaryDomainValues']['MNR3'][9] = u'Dredging Prohibited'
    field_information['GGDM 3.0']['SummaryDomainValues']['MNR3'][10] = u'Dredging Restricted'
    field_information['GGDM 3.0']['SummaryDomainValues']['MNR3'][11] = u'Diving Prohibited'
    field_information['GGDM 3.0']['SummaryDomainValues']['MNR3'][12] = u'Diving Restricted'
    field_information['GGDM 3.0']['SummaryDomainValues']['MNR3'][13] = u'Reduced Wake Area'
    field_information['GGDM 3.0']['SummaryDomainValues']['MNR3'][14] = u'Avoidance Area'
    field_information['GGDM 3.0']['SummaryDomainValues']['MNR3'][15] = u'Construction Prohibited'
    field_information['GGDM 3.0']['SummaryDomainValues']['MNR3'][16] = u'Discharging Prohibited'
    field_information['GGDM 3.0']['SummaryDomainValues']['MNR3'][17] = u'Discharging Restricted'
    field_information['GGDM 3.0']['SummaryDomainValues']['MNR3'][18] = u'Exploration and/or Development Prohibited'
    field_information['GGDM 3.0']['SummaryDomainValues']['MNR3'][19] = u'Exploration and/or Development Restricted'
    field_information['GGDM 3.0']['SummaryDomainValues']['MNR3'][20] = u'Drilling Prohibited'
    field_information['GGDM 3.0']['SummaryDomainValues']['MNR3'][21] = u'Drilling Restricted'
    field_information['GGDM 3.0']['SummaryDomainValues']['MNR3'][22] = u'Artefact Removal Prohibited'
    field_information['GGDM 3.0']['SummaryDomainValues']['MNR3'][23] = u'Cargo Transshipment Prohibited'
    field_information['GGDM 3.0']['SummaryDomainValues']['MNR3'][24] = u'Dragging Prohibited'
    field_information['GGDM 3.0']['SummaryDomainValues']['MNR3'][25] = u'Stopping Prohibited'
    field_information['GGDM 3.0']['SummaryDomainValues']['MNR3'][26] = u'Landing Prohibited'
    field_information['GGDM 3.0']['SummaryDomainValues']['MNR3'][27] = u'Limited Speed Area'
    field_information['GGDM 3.0']['SummaryDomainValues']['MNR3'][28] = u'Navigational Aid Safety Zone'
    field_information['GGDM 3.0']['SummaryDomainValues']['MNR3'][29] = u'Offshore Safety Zone'
    field_information['GGDM 3.0']['SummaryDomainValues']['MNR3'][30] = u'Shipping Prohibited'
    field_information['GGDM 3.0']['SummaryDomainValues']['MNR3'][31] = u'Swimming Prohibited'
    field_information['GGDM 3.0']['SummaryDomainValues']['MNR3'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['MNS'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['MNS'][1000] = u'False'
    field_information['GGDM 3.0']['SummaryDomainValues']['MNS'][1001] = u'True'
    field_information['GGDM 3.0']['SummaryDomainValues']['MRP'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['MRP'][1000] = u'False'
    field_information['GGDM 3.0']['SummaryDomainValues']['MRP'][1001] = u'True'
    field_information['GGDM 3.0']['SummaryDomainValues']['MRR'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['MRR'][1] = u'Unrestricted Area'
    field_information['GGDM 3.0']['SummaryDomainValues']['MRR'][2] = u'Bird Sanctuary'
    field_information['GGDM 3.0']['SummaryDomainValues']['MRR'][3] = u'Conservation and Management Zone'
    field_information['GGDM 3.0']['SummaryDomainValues']['MRR'][4] = u'Ecological Reserve'
    field_information['GGDM 3.0']['SummaryDomainValues']['MRR'][5] = u'Fish Sanctuary'
    field_information['GGDM 3.0']['SummaryDomainValues']['MRR'][6] = u'Game Preserve'
    field_information['GGDM 3.0']['SummaryDomainValues']['MRR'][7] = u'Marine Nature Reserve'
    field_information['GGDM 3.0']['SummaryDomainValues']['MRR'][8] = u'Nature Reserve'
    field_information['GGDM 3.0']['SummaryDomainValues']['MRR'][9] = u'Seal Sanctuary'
    field_information['GGDM 3.0']['SummaryDomainValues']['MRR'][10] = u'Fishing Ground'
    field_information['GGDM 3.0']['SummaryDomainValues']['MRR'][11] = u'Fishery Zone'
    field_information['GGDM 3.0']['SummaryDomainValues']['MRR'][12] = u'Foreign Fishing Rights Zone'
    field_information['GGDM 3.0']['SummaryDomainValues']['MRR'][13] = u'Unilateral Fishing Zone'
    field_information['GGDM 3.0']['SummaryDomainValues']['MRR'][14] = u'International Council for the Seas (ICES) Fishery Zone'
    field_information['GGDM 3.0']['SummaryDomainValues']['MRR'][15] = u'Compass Adjustment'
    field_information['GGDM 3.0']['SummaryDomainValues']['MRR'][16] = u'Degaussing Range'
    field_information['GGDM 3.0']['SummaryDomainValues']['MRR'][17] = u'Dredging Area'
    field_information['GGDM 3.0']['SummaryDomainValues']['MRR'][18] = u'Fairway'
    field_information['GGDM 3.0']['SummaryDomainValues']['MRR'][19] = u'Historic Wreck Area'
    field_information['GGDM 3.0']['SummaryDomainValues']['MRR'][20] = u'Incineration Area'
    field_information['GGDM 3.0']['SummaryDomainValues']['MRR'][21] = u'Joint Economic Development Zone'
    field_information['GGDM 3.0']['SummaryDomainValues']['MRR'][22] = u'Maritime Mass Grave'
    field_information['GGDM 3.0']['SummaryDomainValues']['MRR'][23] = u'Maritime Pollution (MARPOL) Reporting Area'
    field_information['GGDM 3.0']['SummaryDomainValues']['MRR'][24] = u'Mine Danger Area'
    field_information['GGDM 3.0']['SummaryDomainValues']['MRR'][25] = u'Former Mine Danger Area'
    field_information['GGDM 3.0']['SummaryDomainValues']['MRR'][26] = u'Natural Gas Field'
    field_information['GGDM 3.0']['SummaryDomainValues']['MRR'][27] = u'Petroleum Field'
    field_information['GGDM 3.0']['SummaryDomainValues']['MRR'][28] = u'Reclamation Area'
    field_information['GGDM 3.0']['SummaryDomainValues']['MRR'][29] = u'Research Area'
    field_information['GGDM 3.0']['SummaryDomainValues']['MRR'][30] = u'Stranding Danger Area'
    field_information['GGDM 3.0']['SummaryDomainValues']['MRR'][31] = u'Swimming Area'
    field_information['GGDM 3.0']['SummaryDomainValues']['MRR'][32] = u'Swinging Area'
    field_information['GGDM 3.0']['SummaryDomainValues']['MRR'][33] = u'Waiting Area'
    field_information['GGDM 3.0']['SummaryDomainValues']['MRR'][34] = u'Water Skiing Area'
    field_information['GGDM 3.0']['SummaryDomainValues']['MRR'][35] = u'Exclusive Economic Zone'
    field_information['GGDM 3.0']['SummaryDomainValues']['MRR'][36] = u'Extended Continental Shelf Area'
    field_information['GGDM 3.0']['SummaryDomainValues']['MRR'][37] = u'Continental Shelf Area'
    field_information['GGDM 3.0']['SummaryDomainValues']['MRR'][38] = u'Contiguous Zone'
    field_information['GGDM 3.0']['SummaryDomainValues']['MRR'][39] = u'Territorial Sea Area'
    field_information['GGDM 3.0']['SummaryDomainValues']['MRR'][40] = u'Internal Waters'
    field_information['GGDM 3.0']['SummaryDomainValues']['MRR'][41] = u'No Wake Area'
    field_information['GGDM 3.0']['SummaryDomainValues']['MRR'][42] = u'Traffic Services Limit'
    field_information['GGDM 3.0']['SummaryDomainValues']['MRR'][45] = u'Environmentally Sensitive Sea Area'
    field_information['GGDM 3.0']['SummaryDomainValues']['MRR'][46] = u'Particularly Sensitive Sea Area'
    field_information['GGDM 3.0']['SummaryDomainValues']['MRR'][47] = u'Military Area'
    field_information['GGDM 3.0']['SummaryDomainValues']['MRR'][52] = u'Disengagement Area'
    field_information['GGDM 3.0']['SummaryDomainValues']['MRR'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['MRR2'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['MRR2'][1] = u'Unrestricted Area'
    field_information['GGDM 3.0']['SummaryDomainValues']['MRR2'][2] = u'Bird Sanctuary'
    field_information['GGDM 3.0']['SummaryDomainValues']['MRR2'][3] = u'Conservation and Management Zone'
    field_information['GGDM 3.0']['SummaryDomainValues']['MRR2'][4] = u'Ecological Reserve'
    field_information['GGDM 3.0']['SummaryDomainValues']['MRR2'][5] = u'Fish Sanctuary'
    field_information['GGDM 3.0']['SummaryDomainValues']['MRR2'][6] = u'Game Preserve'
    field_information['GGDM 3.0']['SummaryDomainValues']['MRR2'][7] = u'Marine Nature Reserve'
    field_information['GGDM 3.0']['SummaryDomainValues']['MRR2'][8] = u'Nature Reserve'
    field_information['GGDM 3.0']['SummaryDomainValues']['MRR2'][9] = u'Seal Sanctuary'
    field_information['GGDM 3.0']['SummaryDomainValues']['MRR2'][10] = u'Fishing Ground'
    field_information['GGDM 3.0']['SummaryDomainValues']['MRR2'][11] = u'Fishery Zone'
    field_information['GGDM 3.0']['SummaryDomainValues']['MRR2'][12] = u'Foreign Fishing Rights Zone'
    field_information['GGDM 3.0']['SummaryDomainValues']['MRR2'][13] = u'Unilateral Fishing Zone'
    field_information['GGDM 3.0']['SummaryDomainValues']['MRR2'][14] = u'International Council for the Seas (ICES) Fishery Zone'
    field_information['GGDM 3.0']['SummaryDomainValues']['MRR2'][15] = u'Compass Adjustment'
    field_information['GGDM 3.0']['SummaryDomainValues']['MRR2'][16] = u'Degaussing Range'
    field_information['GGDM 3.0']['SummaryDomainValues']['MRR2'][17] = u'Dredging Area'
    field_information['GGDM 3.0']['SummaryDomainValues']['MRR2'][18] = u'Fairway'
    field_information['GGDM 3.0']['SummaryDomainValues']['MRR2'][19] = u'Historic Wreck Area'
    field_information['GGDM 3.0']['SummaryDomainValues']['MRR2'][20] = u'Incineration Area'
    field_information['GGDM 3.0']['SummaryDomainValues']['MRR2'][21] = u'Joint Economic Development Zone'
    field_information['GGDM 3.0']['SummaryDomainValues']['MRR2'][22] = u'Maritime Mass Grave'
    field_information['GGDM 3.0']['SummaryDomainValues']['MRR2'][23] = u'Maritime Pollution (MARPOL) Reporting Area'
    field_information['GGDM 3.0']['SummaryDomainValues']['MRR2'][24] = u'Mine Danger Area'
    field_information['GGDM 3.0']['SummaryDomainValues']['MRR2'][25] = u'Former Mine Danger Area'
    field_information['GGDM 3.0']['SummaryDomainValues']['MRR2'][26] = u'Natural Gas Field'
    field_information['GGDM 3.0']['SummaryDomainValues']['MRR2'][27] = u'Petroleum Field'
    field_information['GGDM 3.0']['SummaryDomainValues']['MRR2'][28] = u'Reclamation Area'
    field_information['GGDM 3.0']['SummaryDomainValues']['MRR2'][29] = u'Research Area'
    field_information['GGDM 3.0']['SummaryDomainValues']['MRR2'][30] = u'Stranding Danger Area'
    field_information['GGDM 3.0']['SummaryDomainValues']['MRR2'][31] = u'Swimming Area'
    field_information['GGDM 3.0']['SummaryDomainValues']['MRR2'][32] = u'Swinging Area'
    field_information['GGDM 3.0']['SummaryDomainValues']['MRR2'][33] = u'Waiting Area'
    field_information['GGDM 3.0']['SummaryDomainValues']['MRR2'][34] = u'Water Skiing Area'
    field_information['GGDM 3.0']['SummaryDomainValues']['MRR2'][35] = u'Exclusive Economic Zone'
    field_information['GGDM 3.0']['SummaryDomainValues']['MRR2'][36] = u'Extended Continental Shelf Area'
    field_information['GGDM 3.0']['SummaryDomainValues']['MRR2'][37] = u'Continental Shelf Area'
    field_information['GGDM 3.0']['SummaryDomainValues']['MRR2'][38] = u'Contiguous Zone'
    field_information['GGDM 3.0']['SummaryDomainValues']['MRR2'][39] = u'Territorial Sea Area'
    field_information['GGDM 3.0']['SummaryDomainValues']['MRR2'][40] = u'Internal Waters'
    field_information['GGDM 3.0']['SummaryDomainValues']['MRR2'][41] = u'No Wake Area'
    field_information['GGDM 3.0']['SummaryDomainValues']['MRR2'][42] = u'Traffic Services Limit'
    field_information['GGDM 3.0']['SummaryDomainValues']['MRR2'][45] = u'Environmentally Sensitive Sea Area'
    field_information['GGDM 3.0']['SummaryDomainValues']['MRR2'][46] = u'Particularly Sensitive Sea Area'
    field_information['GGDM 3.0']['SummaryDomainValues']['MRR2'][47] = u'Military Area'
    field_information['GGDM 3.0']['SummaryDomainValues']['MRR2'][52] = u'Disengagement Area'
    field_information['GGDM 3.0']['SummaryDomainValues']['MRR2'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['MRR3'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['MRR3'][1] = u'Unrestricted Area'
    field_information['GGDM 3.0']['SummaryDomainValues']['MRR3'][2] = u'Bird Sanctuary'
    field_information['GGDM 3.0']['SummaryDomainValues']['MRR3'][3] = u'Conservation and Management Zone'
    field_information['GGDM 3.0']['SummaryDomainValues']['MRR3'][4] = u'Ecological Reserve'
    field_information['GGDM 3.0']['SummaryDomainValues']['MRR3'][5] = u'Fish Sanctuary'
    field_information['GGDM 3.0']['SummaryDomainValues']['MRR3'][6] = u'Game Preserve'
    field_information['GGDM 3.0']['SummaryDomainValues']['MRR3'][7] = u'Marine Nature Reserve'
    field_information['GGDM 3.0']['SummaryDomainValues']['MRR3'][8] = u'Nature Reserve'
    field_information['GGDM 3.0']['SummaryDomainValues']['MRR3'][9] = u'Seal Sanctuary'
    field_information['GGDM 3.0']['SummaryDomainValues']['MRR3'][10] = u'Fishing Ground'
    field_information['GGDM 3.0']['SummaryDomainValues']['MRR3'][11] = u'Fishery Zone'
    field_information['GGDM 3.0']['SummaryDomainValues']['MRR3'][12] = u'Foreign Fishing Rights Zone'
    field_information['GGDM 3.0']['SummaryDomainValues']['MRR3'][13] = u'Unilateral Fishing Zone'
    field_information['GGDM 3.0']['SummaryDomainValues']['MRR3'][14] = u'International Council for the Seas (ICES) Fishery Zone'
    field_information['GGDM 3.0']['SummaryDomainValues']['MRR3'][15] = u'Compass Adjustment'
    field_information['GGDM 3.0']['SummaryDomainValues']['MRR3'][16] = u'Degaussing Range'
    field_information['GGDM 3.0']['SummaryDomainValues']['MRR3'][17] = u'Dredging Area'
    field_information['GGDM 3.0']['SummaryDomainValues']['MRR3'][18] = u'Fairway'
    field_information['GGDM 3.0']['SummaryDomainValues']['MRR3'][19] = u'Historic Wreck Area'
    field_information['GGDM 3.0']['SummaryDomainValues']['MRR3'][20] = u'Incineration Area'
    field_information['GGDM 3.0']['SummaryDomainValues']['MRR3'][21] = u'Joint Economic Development Zone'
    field_information['GGDM 3.0']['SummaryDomainValues']['MRR3'][22] = u'Maritime Mass Grave'
    field_information['GGDM 3.0']['SummaryDomainValues']['MRR3'][23] = u'Maritime Pollution (MARPOL) Reporting Area'
    field_information['GGDM 3.0']['SummaryDomainValues']['MRR3'][24] = u'Mine Danger Area'
    field_information['GGDM 3.0']['SummaryDomainValues']['MRR3'][25] = u'Former Mine Danger Area'
    field_information['GGDM 3.0']['SummaryDomainValues']['MRR3'][26] = u'Natural Gas Field'
    field_information['GGDM 3.0']['SummaryDomainValues']['MRR3'][27] = u'Petroleum Field'
    field_information['GGDM 3.0']['SummaryDomainValues']['MRR3'][28] = u'Reclamation Area'
    field_information['GGDM 3.0']['SummaryDomainValues']['MRR3'][29] = u'Research Area'
    field_information['GGDM 3.0']['SummaryDomainValues']['MRR3'][30] = u'Stranding Danger Area'
    field_information['GGDM 3.0']['SummaryDomainValues']['MRR3'][31] = u'Swimming Area'
    field_information['GGDM 3.0']['SummaryDomainValues']['MRR3'][32] = u'Swinging Area'
    field_information['GGDM 3.0']['SummaryDomainValues']['MRR3'][33] = u'Waiting Area'
    field_information['GGDM 3.0']['SummaryDomainValues']['MRR3'][34] = u'Water Skiing Area'
    field_information['GGDM 3.0']['SummaryDomainValues']['MRR3'][35] = u'Exclusive Economic Zone'
    field_information['GGDM 3.0']['SummaryDomainValues']['MRR3'][36] = u'Extended Continental Shelf Area'
    field_information['GGDM 3.0']['SummaryDomainValues']['MRR3'][37] = u'Continental Shelf Area'
    field_information['GGDM 3.0']['SummaryDomainValues']['MRR3'][38] = u'Contiguous Zone'
    field_information['GGDM 3.0']['SummaryDomainValues']['MRR3'][39] = u'Territorial Sea Area'
    field_information['GGDM 3.0']['SummaryDomainValues']['MRR3'][40] = u'Internal Waters'
    field_information['GGDM 3.0']['SummaryDomainValues']['MRR3'][41] = u'No Wake Area'
    field_information['GGDM 3.0']['SummaryDomainValues']['MRR3'][42] = u'Traffic Services Limit'
    field_information['GGDM 3.0']['SummaryDomainValues']['MRR3'][45] = u'Environmentally Sensitive Sea Area'
    field_information['GGDM 3.0']['SummaryDomainValues']['MRR3'][46] = u'Particularly Sensitive Sea Area'
    field_information['GGDM 3.0']['SummaryDomainValues']['MRR3'][47] = u'Military Area'
    field_information['GGDM 3.0']['SummaryDomainValues']['MRR3'][52] = u'Disengagement Area'
    field_information['GGDM 3.0']['SummaryDomainValues']['MRR3'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['MRT'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['MRT'][1] = u'Automated Identification System (AIS)'
    field_information['GGDM 3.0']['SummaryDomainValues']['MRT'][2] = u'Circular Radiobeacon'
    field_information['GGDM 3.0']['SummaryDomainValues']['MRT'][3] = u'Directional Radiobeacon'
    field_information['GGDM 3.0']['SummaryDomainValues']['MRT'][4] = u'Long Range Air Navigation System (LORAN) C'
    field_information['GGDM 3.0']['SummaryDomainValues']['MRT'][5] = u'QTG Station'
    field_information['GGDM 3.0']['SummaryDomainValues']['MRT'][6] = u'Radar Marker (RAMARK)'
    field_information['GGDM 3.0']['SummaryDomainValues']['MRT'][7] = u'Radar Responder Beacon (RACON)'
    field_information['GGDM 3.0']['SummaryDomainValues']['MRT'][8] = u'Radio Direction Finding Station'
    field_information['GGDM 3.0']['SummaryDomainValues']['MRT'][9] = u'Rotating Pattern Radiobeacon'
    field_information['GGDM 3.0']['SummaryDomainValues']['MRT'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['MST'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['MST'][1] = u'Anti-ballistic Missile (ABM)'
    field_information['GGDM 3.0']['SummaryDomainValues']['MST'][2] = u'Intercontinental Ballistic Missile (ICBM)'
    field_information['GGDM 3.0']['SummaryDomainValues']['MST'][3] = u'Intermediate-range Ballistic Missile (IRBM)'
    field_information['GGDM 3.0']['SummaryDomainValues']['MST'][4] = u'SA-1 Guild'
    field_information['GGDM 3.0']['SummaryDomainValues']['MST'][5] = u'SA-2 Guideline'
    field_information['GGDM 3.0']['SummaryDomainValues']['MST'][6] = u'SA-3 Goa'
    field_information['GGDM 3.0']['SummaryDomainValues']['MST'][7] = u'SA-4 Ganef'
    field_information['GGDM 3.0']['SummaryDomainValues']['MST'][8] = u'SA-5 Gammon'
    field_information['GGDM 3.0']['SummaryDomainValues']['MST'][9] = u'SA-6 Gainful'
    field_information['GGDM 3.0']['SummaryDomainValues']['MST'][10] = u'SA-7 Grail'
    field_information['GGDM 3.0']['SummaryDomainValues']['MST'][11] = u'SA-8 Gecko'
    field_information['GGDM 3.0']['SummaryDomainValues']['MST'][12] = u'SA-9 Gaskin'
    field_information['GGDM 3.0']['SummaryDomainValues']['MST'][13] = u'Medium-range Ballistic Missile (MRBM)'
    field_information['GGDM 3.0']['SummaryDomainValues']['MST'][14] = u'Surface-to-surface Missile (SSM)'
    field_information['GGDM 3.0']['SummaryDomainValues']['MST'][15] = u'Surface-to-air Missile (SAM)'
    field_information['GGDM 3.0']['SummaryDomainValues']['MST'][17] = u'SA-10 Grumble'
    field_information['GGDM 3.0']['SummaryDomainValues']['MST'][18] = u'SA-11 Gadfly'
    field_information['GGDM 3.0']['SummaryDomainValues']['MST'][19] = u'SA-12 Gladiator/Giant'
    field_information['GGDM 3.0']['SummaryDomainValues']['MST'][20] = u'SA-13 Gopher'
    field_information['GGDM 3.0']['SummaryDomainValues']['MST'][21] = u'SA-14 Gremlin'
    field_information['GGDM 3.0']['SummaryDomainValues']['MST'][22] = u'SA-15 Gauntlet'
    field_information['GGDM 3.0']['SummaryDomainValues']['MST'][23] = u'SA-16 Gimlet'
    field_information['GGDM 3.0']['SummaryDomainValues']['MST'][24] = u'SA-17 Grizzly'
    field_information['GGDM 3.0']['SummaryDomainValues']['MST'][25] = u'SA-18 Grouse'
    field_information['GGDM 3.0']['SummaryDomainValues']['MST'][26] = u'SA-19 Grisom'
    field_information['GGDM 3.0']['SummaryDomainValues']['MST'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['MST2'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['MST2'][1] = u'Anti-ballistic Missile (ABM)'
    field_information['GGDM 3.0']['SummaryDomainValues']['MST2'][2] = u'Intercontinental Ballistic Missile (ICBM)'
    field_information['GGDM 3.0']['SummaryDomainValues']['MST2'][3] = u'Intermediate-range Ballistic Missile (IRBM)'
    field_information['GGDM 3.0']['SummaryDomainValues']['MST2'][4] = u'SA-1 Guild'
    field_information['GGDM 3.0']['SummaryDomainValues']['MST2'][5] = u'SA-2 Guideline'
    field_information['GGDM 3.0']['SummaryDomainValues']['MST2'][6] = u'SA-3 Goa'
    field_information['GGDM 3.0']['SummaryDomainValues']['MST2'][7] = u'SA-4 Ganef'
    field_information['GGDM 3.0']['SummaryDomainValues']['MST2'][8] = u'SA-5 Gammon'
    field_information['GGDM 3.0']['SummaryDomainValues']['MST2'][9] = u'SA-6 Gainful'
    field_information['GGDM 3.0']['SummaryDomainValues']['MST2'][10] = u'SA-7 Grail'
    field_information['GGDM 3.0']['SummaryDomainValues']['MST2'][11] = u'SA-8 Gecko'
    field_information['GGDM 3.0']['SummaryDomainValues']['MST2'][12] = u'SA-9 Gaskin'
    field_information['GGDM 3.0']['SummaryDomainValues']['MST2'][13] = u'Medium-range Ballistic Missile (MRBM)'
    field_information['GGDM 3.0']['SummaryDomainValues']['MST2'][14] = u'Surface-to-surface Missile (SSM)'
    field_information['GGDM 3.0']['SummaryDomainValues']['MST2'][15] = u'Surface-to-air Missile (SAM)'
    field_information['GGDM 3.0']['SummaryDomainValues']['MST2'][17] = u'SA-10 Grumble'
    field_information['GGDM 3.0']['SummaryDomainValues']['MST2'][18] = u'SA-11 Gadfly'
    field_information['GGDM 3.0']['SummaryDomainValues']['MST2'][19] = u'SA-12 Gladiator/Giant'
    field_information['GGDM 3.0']['SummaryDomainValues']['MST2'][20] = u'SA-13 Gopher'
    field_information['GGDM 3.0']['SummaryDomainValues']['MST2'][21] = u'SA-14 Gremlin'
    field_information['GGDM 3.0']['SummaryDomainValues']['MST2'][22] = u'SA-15 Gauntlet'
    field_information['GGDM 3.0']['SummaryDomainValues']['MST2'][23] = u'SA-16 Gimlet'
    field_information['GGDM 3.0']['SummaryDomainValues']['MST2'][24] = u'SA-17 Grizzly'
    field_information['GGDM 3.0']['SummaryDomainValues']['MST2'][25] = u'SA-18 Grouse'
    field_information['GGDM 3.0']['SummaryDomainValues']['MST2'][26] = u'SA-19 Grisom'
    field_information['GGDM 3.0']['SummaryDomainValues']['MST2'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['MST3'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['MST3'][1] = u'Anti-ballistic Missile (ABM)'
    field_information['GGDM 3.0']['SummaryDomainValues']['MST3'][2] = u'Intercontinental Ballistic Missile (ICBM)'
    field_information['GGDM 3.0']['SummaryDomainValues']['MST3'][3] = u'Intermediate-range Ballistic Missile (IRBM)'
    field_information['GGDM 3.0']['SummaryDomainValues']['MST3'][4] = u'SA-1 Guild'
    field_information['GGDM 3.0']['SummaryDomainValues']['MST3'][5] = u'SA-2 Guideline'
    field_information['GGDM 3.0']['SummaryDomainValues']['MST3'][6] = u'SA-3 Goa'
    field_information['GGDM 3.0']['SummaryDomainValues']['MST3'][7] = u'SA-4 Ganef'
    field_information['GGDM 3.0']['SummaryDomainValues']['MST3'][8] = u'SA-5 Gammon'
    field_information['GGDM 3.0']['SummaryDomainValues']['MST3'][9] = u'SA-6 Gainful'
    field_information['GGDM 3.0']['SummaryDomainValues']['MST3'][10] = u'SA-7 Grail'
    field_information['GGDM 3.0']['SummaryDomainValues']['MST3'][11] = u'SA-8 Gecko'
    field_information['GGDM 3.0']['SummaryDomainValues']['MST3'][12] = u'SA-9 Gaskin'
    field_information['GGDM 3.0']['SummaryDomainValues']['MST3'][13] = u'Medium-range Ballistic Missile (MRBM)'
    field_information['GGDM 3.0']['SummaryDomainValues']['MST3'][14] = u'Surface-to-surface Missile (SSM)'
    field_information['GGDM 3.0']['SummaryDomainValues']['MST3'][15] = u'Surface-to-air Missile (SAM)'
    field_information['GGDM 3.0']['SummaryDomainValues']['MST3'][17] = u'SA-10 Grumble'
    field_information['GGDM 3.0']['SummaryDomainValues']['MST3'][18] = u'SA-11 Gadfly'
    field_information['GGDM 3.0']['SummaryDomainValues']['MST3'][19] = u'SA-12 Gladiator/Giant'
    field_information['GGDM 3.0']['SummaryDomainValues']['MST3'][20] = u'SA-13 Gopher'
    field_information['GGDM 3.0']['SummaryDomainValues']['MST3'][21] = u'SA-14 Gremlin'
    field_information['GGDM 3.0']['SummaryDomainValues']['MST3'][22] = u'SA-15 Gauntlet'
    field_information['GGDM 3.0']['SummaryDomainValues']['MST3'][23] = u'SA-16 Gimlet'
    field_information['GGDM 3.0']['SummaryDomainValues']['MST3'][24] = u'SA-17 Grizzly'
    field_information['GGDM 3.0']['SummaryDomainValues']['MST3'][25] = u'SA-18 Grouse'
    field_information['GGDM 3.0']['SummaryDomainValues']['MST3'][26] = u'SA-19 Grisom'
    field_information['GGDM 3.0']['SummaryDomainValues']['MST3'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['MUB'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['MUB'][1000] = u'False'
    field_information['GGDM 3.0']['SummaryDomainValues']['MUB'][1001] = u'True'
    field_information['GGDM 3.0']['SummaryDomainValues']['MZN'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['MZN'][1] = u'Borrow-pit'
    field_information['GGDM 3.0']['SummaryDomainValues']['MZN'][3] = u'Opencast'
    field_information['GGDM 3.0']['SummaryDomainValues']['MZN'][4] = u'Placer'
    field_information['GGDM 3.0']['SummaryDomainValues']['MZN'][5] = u'Prospect'
    field_information['GGDM 3.0']['SummaryDomainValues']['MZN'][6] = u'Area Strip-mine'
    field_information['GGDM 3.0']['SummaryDomainValues']['MZN'][8] = u'Peatery'
    field_information['GGDM 3.0']['SummaryDomainValues']['MZN'][9] = u'Below Surface'
    field_information['GGDM 3.0']['SummaryDomainValues']['MZN'][10] = u'Quarry'
    field_information['GGDM 3.0']['SummaryDomainValues']['MZN'][11] = u'Contour Strip-mine'
    field_information['GGDM 3.0']['SummaryDomainValues']['MZN'][13] = u'Dredge'
    field_information['GGDM 3.0']['SummaryDomainValues']['MZN'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['NDX'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['NDX'][1] = u'Economic Activity'
    field_information['GGDM 3.0']['SummaryDomainValues']['NDX'][2] = u'Ethnicity'
    field_information['GGDM 3.0']['SummaryDomainValues']['NDX'][3] = u'Historical'
    field_information['GGDM 3.0']['SummaryDomainValues']['NDX'][4] = u'Linguistics'
    field_information['GGDM 3.0']['SummaryDomainValues']['NDX'][5] = u'Physical Structure'
    field_information['GGDM 3.0']['SummaryDomainValues']['NDX'][6] = u'Religion'
    field_information['GGDM 3.0']['SummaryDomainValues']['NDX'][7] = u'Socioeconomics'
    field_information['GGDM 3.0']['SummaryDomainValues']['NDX'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['NDX2'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['NDX2'][1] = u'Economic Activity'
    field_information['GGDM 3.0']['SummaryDomainValues']['NDX2'][2] = u'Ethnicity'
    field_information['GGDM 3.0']['SummaryDomainValues']['NDX2'][3] = u'Historical'
    field_information['GGDM 3.0']['SummaryDomainValues']['NDX2'][4] = u'Linguistics'
    field_information['GGDM 3.0']['SummaryDomainValues']['NDX2'][5] = u'Physical Structure'
    field_information['GGDM 3.0']['SummaryDomainValues']['NDX2'][6] = u'Religion'
    field_information['GGDM 3.0']['SummaryDomainValues']['NDX2'][7] = u'Socioeconomics'
    field_information['GGDM 3.0']['SummaryDomainValues']['NDX2'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['NDX3'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['NDX3'][1] = u'Economic Activity'
    field_information['GGDM 3.0']['SummaryDomainValues']['NDX3'][2] = u'Ethnicity'
    field_information['GGDM 3.0']['SummaryDomainValues']['NDX3'][3] = u'Historical'
    field_information['GGDM 3.0']['SummaryDomainValues']['NDX3'][4] = u'Linguistics'
    field_information['GGDM 3.0']['SummaryDomainValues']['NDX3'][5] = u'Physical Structure'
    field_information['GGDM 3.0']['SummaryDomainValues']['NDX3'][6] = u'Religion'
    field_information['GGDM 3.0']['SummaryDomainValues']['NDX3'][7] = u'Socioeconomics'
    field_information['GGDM 3.0']['SummaryDomainValues']['NDX3'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['NFP'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['NFP'][4] = u'Firing Danger Area'
    field_information['GGDM 3.0']['SummaryDomainValues']['NFP'][6] = u'Mine Laying Practice Area'
    field_information['GGDM 3.0']['SummaryDomainValues']['NFP'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['NFP2'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['NFP2'][4] = u'Firing Danger Area'
    field_information['GGDM 3.0']['SummaryDomainValues']['NFP2'][6] = u'Mine Laying Practice Area'
    field_information['GGDM 3.0']['SummaryDomainValues']['NFP2'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['NFP3'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['NFP3'][4] = u'Firing Danger Area'
    field_information['GGDM 3.0']['SummaryDomainValues']['NFP3'][6] = u'Mine Laying Practice Area'
    field_information['GGDM 3.0']['SummaryDomainValues']['NFP3'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['NLT'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['NLT'][1] = u'Area'
    field_information['GGDM 3.0']['SummaryDomainValues']['NLT'][2] = u'Locality'
    field_information['GGDM 3.0']['SummaryDomainValues']['NLT'][3] = u'Region'
    field_information['GGDM 3.0']['SummaryDomainValues']['NLT'][4] = u'Arctic Land'
    field_information['GGDM 3.0']['SummaryDomainValues']['NLT'][5] = u'Populated Locality'
    field_information['GGDM 3.0']['SummaryDomainValues']['NLT'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['NMC'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['NMC'][1] = u'White'
    field_information['GGDM 3.0']['SummaryDomainValues']['NMC'][2] = u'Black'
    field_information['GGDM 3.0']['SummaryDomainValues']['NMC'][3] = u'Red'
    field_information['GGDM 3.0']['SummaryDomainValues']['NMC'][4] = u'Green'
    field_information['GGDM 3.0']['SummaryDomainValues']['NMC'][5] = u'Blue'
    field_information['GGDM 3.0']['SummaryDomainValues']['NMC'][6] = u'Yellow'
    field_information['GGDM 3.0']['SummaryDomainValues']['NMC'][7] = u'Grey'
    field_information['GGDM 3.0']['SummaryDomainValues']['NMC'][8] = u'Brown'
    field_information['GGDM 3.0']['SummaryDomainValues']['NMC'][9] = u'Amber'
    field_information['GGDM 3.0']['SummaryDomainValues']['NMC'][10] = u'Violet'
    field_information['GGDM 3.0']['SummaryDomainValues']['NMC'][11] = u'Orange'
    field_information['GGDM 3.0']['SummaryDomainValues']['NMC'][12] = u'Magenta'
    field_information['GGDM 3.0']['SummaryDomainValues']['NMC'][13] = u'Pink'
    field_information['GGDM 3.0']['SummaryDomainValues']['NMC'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['NMC2'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['NMC2'][1] = u'White'
    field_information['GGDM 3.0']['SummaryDomainValues']['NMC2'][2] = u'Black'
    field_information['GGDM 3.0']['SummaryDomainValues']['NMC2'][3] = u'Red'
    field_information['GGDM 3.0']['SummaryDomainValues']['NMC2'][4] = u'Green'
    field_information['GGDM 3.0']['SummaryDomainValues']['NMC2'][5] = u'Blue'
    field_information['GGDM 3.0']['SummaryDomainValues']['NMC2'][6] = u'Yellow'
    field_information['GGDM 3.0']['SummaryDomainValues']['NMC2'][7] = u'Grey'
    field_information['GGDM 3.0']['SummaryDomainValues']['NMC2'][8] = u'Brown'
    field_information['GGDM 3.0']['SummaryDomainValues']['NMC2'][9] = u'Amber'
    field_information['GGDM 3.0']['SummaryDomainValues']['NMC2'][10] = u'Violet'
    field_information['GGDM 3.0']['SummaryDomainValues']['NMC2'][11] = u'Orange'
    field_information['GGDM 3.0']['SummaryDomainValues']['NMC2'][12] = u'Magenta'
    field_information['GGDM 3.0']['SummaryDomainValues']['NMC2'][13] = u'Pink'
    field_information['GGDM 3.0']['SummaryDomainValues']['NMC2'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['NMC3'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['NMC3'][1] = u'White'
    field_information['GGDM 3.0']['SummaryDomainValues']['NMC3'][2] = u'Black'
    field_information['GGDM 3.0']['SummaryDomainValues']['NMC3'][3] = u'Red'
    field_information['GGDM 3.0']['SummaryDomainValues']['NMC3'][4] = u'Green'
    field_information['GGDM 3.0']['SummaryDomainValues']['NMC3'][5] = u'Blue'
    field_information['GGDM 3.0']['SummaryDomainValues']['NMC3'][6] = u'Yellow'
    field_information['GGDM 3.0']['SummaryDomainValues']['NMC3'][7] = u'Grey'
    field_information['GGDM 3.0']['SummaryDomainValues']['NMC3'][8] = u'Brown'
    field_information['GGDM 3.0']['SummaryDomainValues']['NMC3'][9] = u'Amber'
    field_information['GGDM 3.0']['SummaryDomainValues']['NMC3'][10] = u'Violet'
    field_information['GGDM 3.0']['SummaryDomainValues']['NMC3'][11] = u'Orange'
    field_information['GGDM 3.0']['SummaryDomainValues']['NMC3'][12] = u'Magenta'
    field_information['GGDM 3.0']['SummaryDomainValues']['NMC3'][13] = u'Pink'
    field_information['GGDM 3.0']['SummaryDomainValues']['NMC3'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['NOA'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['NOA'][14] = u'Submarine Exercise Area'
    field_information['GGDM 3.0']['SummaryDomainValues']['NOA'][27] = u'FORACS V Limit'
    field_information['GGDM 3.0']['SummaryDomainValues']['NOA'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['NOA2'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['NOA2'][14] = u'Submarine Exercise Area'
    field_information['GGDM 3.0']['SummaryDomainValues']['NOA2'][27] = u'FORACS V Limit'
    field_information['GGDM 3.0']['SummaryDomainValues']['NOA2'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['NOA3'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['NOA3'][14] = u'Submarine Exercise Area'
    field_information['GGDM 3.0']['SummaryDomainValues']['NOA3'][27] = u'FORACS V Limit'
    field_information['GGDM 3.0']['SummaryDomainValues']['NOA3'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['NSC'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['NSC'][2] = u'IALA Region A'
    field_information['GGDM 3.0']['SummaryDomainValues']['NSC'][3] = u'IALA Region B'
    field_information['GGDM 3.0']['SummaryDomainValues']['NSC'][6] = u'SIGNI'
    field_information['GGDM 3.0']['SummaryDomainValues']['NSC'][7] = u'US Intracoastal Waterway'
    field_information['GGDM 3.0']['SummaryDomainValues']['NSC'][8] = u'US Uniform State'
    field_information['GGDM 3.0']['SummaryDomainValues']['NSC'][9] = u'US Western Rivers'
    field_information['GGDM 3.0']['SummaryDomainValues']['NSC'][10] = u'No System'
    field_information['GGDM 3.0']['SummaryDomainValues']['NVS'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['NVS'][1] = u'Navigable and Operational'
    field_information['GGDM 3.0']['SummaryDomainValues']['NVS'][2] = u'Navigable but Abandoned'
    field_information['GGDM 3.0']['SummaryDomainValues']['NVS'][3] = u'Navigable'
    field_information['GGDM 3.0']['SummaryDomainValues']['NVS'][4] = u'Navigable with Periodic Restrictions'
    field_information['GGDM 3.0']['SummaryDomainValues']['NVS'][5] = u'Not Navigable'
    field_information['GGDM 3.0']['SummaryDomainValues']['NVS'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['OCS'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['OCS'][1] = u'Platform'
    field_information['GGDM 3.0']['SummaryDomainValues']['OCS'][2] = u'Terminal Buoy'
    field_information['GGDM 3.0']['SummaryDomainValues']['OCS'][3] = u'Catenary Turntable'
    field_information['GGDM 3.0']['SummaryDomainValues']['OCS'][4] = u'Submerged Turret'
    field_information['GGDM 3.0']['SummaryDomainValues']['OCS'][5] = u'Vessel'
    field_information['GGDM 3.0']['SummaryDomainValues']['OCS'][6] = u'Barge'
    field_information['GGDM 3.0']['SummaryDomainValues']['OCS'][7] = u'Submerged Platform'
    field_information['GGDM 3.0']['SummaryDomainValues']['OCS'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['ONE'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['ONE'][1000] = u'False'
    field_information['GGDM 3.0']['SummaryDomainValues']['ONE'][1001] = u'True'
    field_information['GGDM 3.0']['SummaryDomainValues']['OOC'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['OOC'][1] = u'Frame Bridge Span'
    field_information['GGDM 3.0']['SummaryDomainValues']['OOC'][2] = u'Arch Bridge Span'
    field_information['GGDM 3.0']['SummaryDomainValues']['OOC'][3] = u'Roof'
    field_information['GGDM 3.0']['SummaryDomainValues']['OOC'][4] = u'Railway Power Line'
    field_information['GGDM 3.0']['SummaryDomainValues']['OOC'][6] = u'Bridge Superstructure'
    field_information['GGDM 3.0']['SummaryDomainValues']['OOC'][7] = u'Building'
    field_information['GGDM 3.0']['SummaryDomainValues']['OOC'][8] = u'Bridge Span'
    field_information['GGDM 3.0']['SummaryDomainValues']['OOC'][9] = u'Gantry'
    field_information['GGDM 3.0']['SummaryDomainValues']['OOC'][10] = u'Scaffold'
    field_information['GGDM 3.0']['SummaryDomainValues']['OOC'][11] = u'Arcade'
    field_information['GGDM 3.0']['SummaryDomainValues']['OOC'][12] = u'Building Overhang'
    field_information['GGDM 3.0']['SummaryDomainValues']['OOC'][13] = u'Cable'
    field_information['GGDM 3.0']['SummaryDomainValues']['OOC'][14] = u'Cableway'
    field_information['GGDM 3.0']['SummaryDomainValues']['OOC'][15] = u'Conveyor'
    field_information['GGDM 3.0']['SummaryDomainValues']['OOC'][16] = u'Entrance and/or Exit'
    field_information['GGDM 3.0']['SummaryDomainValues']['OOC'][17] = u'Memorial Monument'
    field_information['GGDM 3.0']['SummaryDomainValues']['OOC'][18] = u'Non-building Structure'
    field_information['GGDM 3.0']['SummaryDomainValues']['OOC'][19] = u'Overhead Walkway'
    field_information['GGDM 3.0']['SummaryDomainValues']['OOC'][20] = u'Parking Garage'
    field_information['GGDM 3.0']['SummaryDomainValues']['OOC'][21] = u'Pipeline'
    field_information['GGDM 3.0']['SummaryDomainValues']['OOC'][22] = u'Pipeline Crossing Point'
    field_information['GGDM 3.0']['SummaryDomainValues']['OOC'][23] = u'Route-related Structure'
    field_information['GGDM 3.0']['SummaryDomainValues']['OOC'][24] = u'Transportation Block'
    field_information['GGDM 3.0']['SummaryDomainValues']['OOC'][25] = u'Transportation Route Protection Structure'
    field_information['GGDM 3.0']['SummaryDomainValues']['OOC'][26] = u'Tunnel'
    field_information['GGDM 3.0']['SummaryDomainValues']['OOC'][27] = u'Traffic Sign'
    field_information['GGDM 3.0']['SummaryDomainValues']['OOC'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['OPT'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['OPT'][1] = u'Daytime'
    field_information['GGDM 3.0']['SummaryDomainValues']['OPT'][2] = u'Night-time'
    field_information['GGDM 3.0']['SummaryDomainValues']['OPT'][3] = u'Continuously Operating'
    field_information['GGDM 3.0']['SummaryDomainValues']['OPT'][4] = u'Summer Season'
    field_information['GGDM 3.0']['SummaryDomainValues']['OPT'][5] = u'Winter Season'
    field_information['GGDM 3.0']['SummaryDomainValues']['OPT'][6] = u'Restricted'
    field_information['GGDM 3.0']['SummaryDomainValues']['OPT'][7] = u'Never Operating'
    field_information['GGDM 3.0']['SummaryDomainValues']['OPT'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['ORS'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['ORS'][3] = u'No Restriction'
    field_information['GGDM 3.0']['SummaryDomainValues']['ORS'][4] = u'Snow'
    field_information['GGDM 3.0']['SummaryDomainValues']['ORS'][5] = u'Icing'
    field_information['GGDM 3.0']['SummaryDomainValues']['ORS'][6] = u'Flooding'
    field_information['GGDM 3.0']['SummaryDomainValues']['ORS'][7] = u'Special Restriction'
    field_information['GGDM 3.0']['SummaryDomainValues']['ORS'][8] = u'Wind'
    field_information['GGDM 3.0']['SummaryDomainValues']['ORS'][9] = u'Reduced Visibility'
    field_information['GGDM 3.0']['SummaryDomainValues']['ORS'][10] = u'Time'
    field_information['GGDM 3.0']['SummaryDomainValues']['ORS'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['ORS2'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['ORS2'][3] = u'No Restriction'
    field_information['GGDM 3.0']['SummaryDomainValues']['ORS2'][4] = u'Snow'
    field_information['GGDM 3.0']['SummaryDomainValues']['ORS2'][5] = u'Icing'
    field_information['GGDM 3.0']['SummaryDomainValues']['ORS2'][6] = u'Flooding'
    field_information['GGDM 3.0']['SummaryDomainValues']['ORS2'][7] = u'Special Restriction'
    field_information['GGDM 3.0']['SummaryDomainValues']['ORS2'][8] = u'Wind'
    field_information['GGDM 3.0']['SummaryDomainValues']['ORS2'][9] = u'Reduced Visibility'
    field_information['GGDM 3.0']['SummaryDomainValues']['ORS2'][10] = u'Time'
    field_information['GGDM 3.0']['SummaryDomainValues']['ORS2'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['ORS3'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['ORS3'][3] = u'No Restriction'
    field_information['GGDM 3.0']['SummaryDomainValues']['ORS3'][4] = u'Snow'
    field_information['GGDM 3.0']['SummaryDomainValues']['ORS3'][5] = u'Icing'
    field_information['GGDM 3.0']['SummaryDomainValues']['ORS3'][6] = u'Flooding'
    field_information['GGDM 3.0']['SummaryDomainValues']['ORS3'][7] = u'Special Restriction'
    field_information['GGDM 3.0']['SummaryDomainValues']['ORS3'][8] = u'Wind'
    field_information['GGDM 3.0']['SummaryDomainValues']['ORS3'][9] = u'Reduced Visibility'
    field_information['GGDM 3.0']['SummaryDomainValues']['ORS3'][10] = u'Time'
    field_information['GGDM 3.0']['SummaryDomainValues']['ORS3'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['OTH'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['OWO'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['OWO'][1000] = u'False'
    field_information['GGDM 3.0']['SummaryDomainValues']['OWO'][1001] = u'True'
    field_information['GGDM 3.0']['SummaryDomainValues']['PBY'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['PBY'][8] = u'Refuse'
    field_information['GGDM 3.0']['SummaryDomainValues']['PBY'][15] = u'Slag'
    field_information['GGDM 3.0']['SummaryDomainValues']['PBY'][16] = u'Sludge'
    field_information['GGDM 3.0']['SummaryDomainValues']['PBY'][17] = u'Spoil'
    field_information['GGDM 3.0']['SummaryDomainValues']['PBY'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['PBY2'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['PBY2'][8] = u'Refuse'
    field_information['GGDM 3.0']['SummaryDomainValues']['PBY2'][15] = u'Slag'
    field_information['GGDM 3.0']['SummaryDomainValues']['PBY2'][16] = u'Sludge'
    field_information['GGDM 3.0']['SummaryDomainValues']['PBY2'][17] = u'Spoil'
    field_information['GGDM 3.0']['SummaryDomainValues']['PBY2'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['PBY3'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['PBY3'][8] = u'Refuse'
    field_information['GGDM 3.0']['SummaryDomainValues']['PBY3'][15] = u'Slag'
    field_information['GGDM 3.0']['SummaryDomainValues']['PBY3'][16] = u'Sludge'
    field_information['GGDM 3.0']['SummaryDomainValues']['PBY3'][17] = u'Spoil'
    field_information['GGDM 3.0']['SummaryDomainValues']['PBY3'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['PCF'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['PCF'][1] = u'Construction'
    field_information['GGDM 3.0']['SummaryDomainValues']['PCF'][2] = u'Intact'
    field_information['GGDM 3.0']['SummaryDomainValues']['PCF'][3] = u'Unmaintained'
    field_information['GGDM 3.0']['SummaryDomainValues']['PCF'][4] = u'Damaged'
    field_information['GGDM 3.0']['SummaryDomainValues']['PCF'][5] = u'Dismantled'
    field_information['GGDM 3.0']['SummaryDomainValues']['PCF'][6] = u'Destroyed'
    field_information['GGDM 3.0']['SummaryDomainValues']['PEC'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['PEC'][1000] = u'False'
    field_information['GGDM 3.0']['SummaryDomainValues']['PEC'][1001] = u'True'
    field_information['GGDM 3.0']['SummaryDomainValues']['PFHC'][2] = u'Open Interval'
    field_information['GGDM 3.0']['SummaryDomainValues']['PFHC'][3] = u'Greater-than-or-equal to Less-than Interval'
    field_information['GGDM 3.0']['SummaryDomainValues']['PFHC'][4] = u'Greater-than to Less-than-or-equal Interval'
    field_information['GGDM 3.0']['SummaryDomainValues']['PFHC'][5] = u'Closed Interval'
    field_information['GGDM 3.0']['SummaryDomainValues']['PFHC'][6] = u'Greater-than Semi-interval'
    field_information['GGDM 3.0']['SummaryDomainValues']['PFHC'][7] = u'Greater-than or Equal Semi-interval'
    field_information['GGDM 3.0']['SummaryDomainValues']['PFHC'][8] = u'Less-than Semi-interval'
    field_information['GGDM 3.0']['SummaryDomainValues']['PFHC'][9] = u'Less-than or Equal Semi-interval'
    field_information['GGDM 3.0']['SummaryDomainValues']['PLC'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['PLC'][1] = u'Stake'
    field_information['GGDM 3.0']['SummaryDomainValues']['PLC'][3] = u'Post'
    field_information['GGDM 3.0']['SummaryDomainValues']['PLC'][4] = u'Tripodal'
    field_information['GGDM 3.0']['SummaryDomainValues']['PLC'][5] = u'Linear'
    field_information['GGDM 3.0']['SummaryDomainValues']['PLC'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['PLT'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['PLT'][1] = u'Transport Pipe'
    field_information['GGDM 3.0']['SummaryDomainValues']['PLT'][2] = u'Outfall Pipe'
    field_information['GGDM 3.0']['SummaryDomainValues']['PLT'][3] = u'Intake Pipe'
    field_information['GGDM 3.0']['SummaryDomainValues']['PLT'][4] = u'Sewer'
    field_information['GGDM 3.0']['SummaryDomainValues']['PLT'][5] = u'Pipeline Valve'
    field_information['GGDM 3.0']['SummaryDomainValues']['PLT'][7] = u'Bubbler System'
    field_information['GGDM 3.0']['SummaryDomainValues']['PLT'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['PLT2'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['PLT2'][1] = u'Transport Pipe'
    field_information['GGDM 3.0']['SummaryDomainValues']['PLT2'][2] = u'Outfall Pipe'
    field_information['GGDM 3.0']['SummaryDomainValues']['PLT2'][3] = u'Intake Pipe'
    field_information['GGDM 3.0']['SummaryDomainValues']['PLT2'][4] = u'Sewer'
    field_information['GGDM 3.0']['SummaryDomainValues']['PLT2'][5] = u'Pipeline Valve'
    field_information['GGDM 3.0']['SummaryDomainValues']['PLT2'][7] = u'Bubbler System'
    field_information['GGDM 3.0']['SummaryDomainValues']['PLT2'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['PLT3'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['PLT3'][1] = u'Transport Pipe'
    field_information['GGDM 3.0']['SummaryDomainValues']['PLT3'][2] = u'Outfall Pipe'
    field_information['GGDM 3.0']['SummaryDomainValues']['PLT3'][3] = u'Intake Pipe'
    field_information['GGDM 3.0']['SummaryDomainValues']['PLT3'][4] = u'Sewer'
    field_information['GGDM 3.0']['SummaryDomainValues']['PLT3'][5] = u'Pipeline Valve'
    field_information['GGDM 3.0']['SummaryDomainValues']['PLT3'][7] = u'Bubbler System'
    field_information['GGDM 3.0']['SummaryDomainValues']['PLT3'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['PMPR'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['PMPR'][1000] = u'False'
    field_information['GGDM 3.0']['SummaryDomainValues']['PMPR'][1001] = u'True'
    field_information['GGDM 3.0']['SummaryDomainValues']['POS'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['POS'][1] = u'Geothermal'
    field_information['GGDM 3.0']['SummaryDomainValues']['POS'][2] = u'Hydro-electric'
    field_information['GGDM 3.0']['SummaryDomainValues']['POS'][3] = u'Nuclear'
    field_information['GGDM 3.0']['SummaryDomainValues']['POS'][4] = u'Thermal'
    field_information['GGDM 3.0']['SummaryDomainValues']['POS'][5] = u'Tidal'
    field_information['GGDM 3.0']['SummaryDomainValues']['POS'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['POS2'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['POS2'][1] = u'Geothermal'
    field_information['GGDM 3.0']['SummaryDomainValues']['POS2'][2] = u'Hydro-electric'
    field_information['GGDM 3.0']['SummaryDomainValues']['POS2'][3] = u'Nuclear'
    field_information['GGDM 3.0']['SummaryDomainValues']['POS2'][4] = u'Thermal'
    field_information['GGDM 3.0']['SummaryDomainValues']['POS2'][5] = u'Tidal'
    field_information['GGDM 3.0']['SummaryDomainValues']['POS2'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['POS3'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['POS3'][1] = u'Geothermal'
    field_information['GGDM 3.0']['SummaryDomainValues']['POS3'][2] = u'Hydro-electric'
    field_information['GGDM 3.0']['SummaryDomainValues']['POS3'][3] = u'Nuclear'
    field_information['GGDM 3.0']['SummaryDomainValues']['POS3'][4] = u'Thermal'
    field_information['GGDM 3.0']['SummaryDomainValues']['POS3'][5] = u'Tidal'
    field_information['GGDM 3.0']['SummaryDomainValues']['POS3'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['PPO'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['PPO'][1] = u'Aircraft'
    field_information['GGDM 3.0']['SummaryDomainValues']['PPO'][3] = u'Ammunition'
    field_information['GGDM 3.0']['SummaryDomainValues']['PPO'][8] = u'Basalt'
    field_information['GGDM 3.0']['SummaryDomainValues']['PPO'][9] = u'Bauxite'
    field_information['GGDM 3.0']['SummaryDomainValues']['PPO'][11] = u'Bivalve Mollusc'
    field_information['GGDM 3.0']['SummaryDomainValues']['PPO'][13] = u'Brick'
    field_information['GGDM 3.0']['SummaryDomainValues']['PPO'][15] = u'Cement'
    field_information['GGDM 3.0']['SummaryDomainValues']['PPO'][16] = u'Chemical'
    field_information['GGDM 3.0']['SummaryDomainValues']['PPO'][17] = u'Clay'
    field_information['GGDM 3.0']['SummaryDomainValues']['PPO'][18] = u'Coal'
    field_information['GGDM 3.0']['SummaryDomainValues']['PPO'][19] = u'Cobbles'
    field_information['GGDM 3.0']['SummaryDomainValues']['PPO'][21] = u'Coke'
    field_information['GGDM 3.0']['SummaryDomainValues']['PPO'][26] = u'Copper'
    field_information['GGDM 3.0']['SummaryDomainValues']['PPO'][29] = u'Crustacean'
    field_information['GGDM 3.0']['SummaryDomainValues']['PPO'][30] = u'Cultivated Shellfish'
    field_information['GGDM 3.0']['SummaryDomainValues']['PPO'][33] = u'Diamond'
    field_information['GGDM 3.0']['SummaryDomainValues']['PPO'][34] = u'Diatomaceous Earth'
    field_information['GGDM 3.0']['SummaryDomainValues']['PPO'][35] = u'Dolomite'
    field_information['GGDM 3.0']['SummaryDomainValues']['PPO'][37] = u'Electric Power'
    field_information['GGDM 3.0']['SummaryDomainValues']['PPO'][38] = u'Explosive'
    field_information['GGDM 3.0']['SummaryDomainValues']['PPO'][39] = u'Fish'
    field_information['GGDM 3.0']['SummaryDomainValues']['PPO'][45] = u'Gas'
    field_information['GGDM 3.0']['SummaryDomainValues']['PPO'][46] = u'Petrol'
    field_information['GGDM 3.0']['SummaryDomainValues']['PPO'][48] = u'Gold'
    field_information['GGDM 3.0']['SummaryDomainValues']['PPO'][49] = u'Grain'
    field_information['GGDM 3.0']['SummaryDomainValues']['PPO'][50] = u'Granite'
    field_information['GGDM 3.0']['SummaryDomainValues']['PPO'][53] = u'Gravel'
    field_information['GGDM 3.0']['SummaryDomainValues']['PPO'][58] = u'Iron'
    field_information['GGDM 3.0']['SummaryDomainValues']['PPO'][59] = u'Lead'
    field_information['GGDM 3.0']['SummaryDomainValues']['PPO'][60] = u'Lime'
    field_information['GGDM 3.0']['SummaryDomainValues']['PPO'][61] = u'Liquefied Natural Gas (LNG)'
    field_information['GGDM 3.0']['SummaryDomainValues']['PPO'][62] = u'Liquefied Petroleum Gas (LPG)'
    field_information['GGDM 3.0']['SummaryDomainValues']['PPO'][63] = u'Lumber'
    field_information['GGDM 3.0']['SummaryDomainValues']['PPO'][65] = u'Manganese'
    field_information['GGDM 3.0']['SummaryDomainValues']['PPO'][66] = u'Marble'
    field_information['GGDM 3.0']['SummaryDomainValues']['PPO'][70] = u'Milk'
    field_information['GGDM 3.0']['SummaryDomainValues']['PPO'][72] = u'Mussels'
    field_information['GGDM 3.0']['SummaryDomainValues']['PPO'][77] = u'Oysters'
    field_information['GGDM 3.0']['SummaryDomainValues']['PPO'][83] = u'Petroleum'
    field_information['GGDM 3.0']['SummaryDomainValues']['PPO'][85] = u'Porphyry'
    field_information['GGDM 3.0']['SummaryDomainValues']['PPO'][88] = u'Pumice'
    field_information['GGDM 3.0']['SummaryDomainValues']['PPO'][89] = u'Quartz'
    field_information['GGDM 3.0']['SummaryDomainValues']['PPO'][90] = u'Radioactive Material'
    field_information['GGDM 3.0']['SummaryDomainValues']['PPO'][93] = u'Rocks'
    field_information['GGDM 3.0']['SummaryDomainValues']['PPO'][95] = u'Salt'
    field_information['GGDM 3.0']['SummaryDomainValues']['PPO'][96] = u'Sand'
    field_information['GGDM 3.0']['SummaryDomainValues']['PPO'][97] = u'Sandstone'
    field_information['GGDM 3.0']['SummaryDomainValues']['PPO'][101] = u'Sewage'
    field_information['GGDM 3.0']['SummaryDomainValues']['PPO'][105] = u'Silver'
    field_information['GGDM 3.0']['SummaryDomainValues']['PPO'][110] = u'Stone'
    field_information['GGDM 3.0']['SummaryDomainValues']['PPO'][116] = u'Timber'
    field_information['GGDM 3.0']['SummaryDomainValues']['PPO'][117] = u'Tobacco'
    field_information['GGDM 3.0']['SummaryDomainValues']['PPO'][118] = u'Travertine'
    field_information['GGDM 3.0']['SummaryDomainValues']['PPO'][120] = u'Uranium'
    field_information['GGDM 3.0']['SummaryDomainValues']['PPO'][122] = u'Water'
    field_information['GGDM 3.0']['SummaryDomainValues']['PPO'][123] = u'Wine'
    field_information['GGDM 3.0']['SummaryDomainValues']['PPO'][126] = u'Zinc'
    field_information['GGDM 3.0']['SummaryDomainValues']['PPO'][130] = u'Chalk'
    field_information['GGDM 3.0']['SummaryDomainValues']['PPO'][146] = u'Heating Steam and/or Water'
    field_information['GGDM 3.0']['SummaryDomainValues']['PPO'][149] = u'Brine'
    field_information['GGDM 3.0']['SummaryDomainValues']['PPO'][151] = u'Chromium'
    field_information['GGDM 3.0']['SummaryDomainValues']['PPO'][152] = u'Nickel'
    field_information['GGDM 3.0']['SummaryDomainValues']['PPO'][153] = u'Tin'
    field_information['GGDM 3.0']['SummaryDomainValues']['PPO'][158] = u'Pottery'
    field_information['GGDM 3.0']['SummaryDomainValues']['PPO'][159] = u'Charcoal'
    field_information['GGDM 3.0']['SummaryDomainValues']['PPO'][160] = u'Milled Grain'
    field_information['GGDM 3.0']['SummaryDomainValues']['PPO'][161] = u'Coalbed Methane'
    field_information['GGDM 3.0']['SummaryDomainValues']['PPO'][162] = u'Natural Gas Condensate'
    field_information['GGDM 3.0']['SummaryDomainValues']['PPO'][163] = u'Helium'
    field_information['GGDM 3.0']['SummaryDomainValues']['PPO'][164] = u'Hydrothermal Fluid'
    field_information['GGDM 3.0']['SummaryDomainValues']['PPO'][170] = u'Beverage'
    field_information['GGDM 3.0']['SummaryDomainValues']['PPO'][173] = u'Fluorite'
    field_information['GGDM 3.0']['SummaryDomainValues']['PPO'][204] = u'Phosphate'
    field_information['GGDM 3.0']['SummaryDomainValues']['PPO'][214] = u'Biodiesel'
    field_information['GGDM 3.0']['SummaryDomainValues']['PPO'][224] = u'Vanadium'
    field_information['GGDM 3.0']['SummaryDomainValues']['PPO'][283] = u'Mica'
    field_information['GGDM 3.0']['SummaryDomainValues']['PPO'][339] = u'Selenium'
    field_information['GGDM 3.0']['SummaryDomainValues']['PPO'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['PPO2'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['PPO2'][1] = u'Aircraft'
    field_information['GGDM 3.0']['SummaryDomainValues']['PPO2'][3] = u'Ammunition'
    field_information['GGDM 3.0']['SummaryDomainValues']['PPO2'][8] = u'Basalt'
    field_information['GGDM 3.0']['SummaryDomainValues']['PPO2'][9] = u'Bauxite'
    field_information['GGDM 3.0']['SummaryDomainValues']['PPO2'][11] = u'Bivalve Mollusc'
    field_information['GGDM 3.0']['SummaryDomainValues']['PPO2'][13] = u'Brick'
    field_information['GGDM 3.0']['SummaryDomainValues']['PPO2'][15] = u'Cement'
    field_information['GGDM 3.0']['SummaryDomainValues']['PPO2'][16] = u'Chemical'
    field_information['GGDM 3.0']['SummaryDomainValues']['PPO2'][17] = u'Clay'
    field_information['GGDM 3.0']['SummaryDomainValues']['PPO2'][18] = u'Coal'
    field_information['GGDM 3.0']['SummaryDomainValues']['PPO2'][19] = u'Cobbles'
    field_information['GGDM 3.0']['SummaryDomainValues']['PPO2'][21] = u'Coke'
    field_information['GGDM 3.0']['SummaryDomainValues']['PPO2'][26] = u'Copper'
    field_information['GGDM 3.0']['SummaryDomainValues']['PPO2'][29] = u'Crustacean'
    field_information['GGDM 3.0']['SummaryDomainValues']['PPO2'][30] = u'Cultivated Shellfish'
    field_information['GGDM 3.0']['SummaryDomainValues']['PPO2'][33] = u'Diamond'
    field_information['GGDM 3.0']['SummaryDomainValues']['PPO2'][34] = u'Diatomaceous Earth'
    field_information['GGDM 3.0']['SummaryDomainValues']['PPO2'][35] = u'Dolomite'
    field_information['GGDM 3.0']['SummaryDomainValues']['PPO2'][37] = u'Electric Power'
    field_information['GGDM 3.0']['SummaryDomainValues']['PPO2'][38] = u'Explosive'
    field_information['GGDM 3.0']['SummaryDomainValues']['PPO2'][39] = u'Fish'
    field_information['GGDM 3.0']['SummaryDomainValues']['PPO2'][45] = u'Gas'
    field_information['GGDM 3.0']['SummaryDomainValues']['PPO2'][46] = u'Petrol'
    field_information['GGDM 3.0']['SummaryDomainValues']['PPO2'][48] = u'Gold'
    field_information['GGDM 3.0']['SummaryDomainValues']['PPO2'][49] = u'Grain'
    field_information['GGDM 3.0']['SummaryDomainValues']['PPO2'][50] = u'Granite'
    field_information['GGDM 3.0']['SummaryDomainValues']['PPO2'][53] = u'Gravel'
    field_information['GGDM 3.0']['SummaryDomainValues']['PPO2'][58] = u'Iron'
    field_information['GGDM 3.0']['SummaryDomainValues']['PPO2'][59] = u'Lead'
    field_information['GGDM 3.0']['SummaryDomainValues']['PPO2'][60] = u'Lime'
    field_information['GGDM 3.0']['SummaryDomainValues']['PPO2'][61] = u'Liquefied Natural Gas (LNG)'
    field_information['GGDM 3.0']['SummaryDomainValues']['PPO2'][62] = u'Liquefied Petroleum Gas (LPG)'
    field_information['GGDM 3.0']['SummaryDomainValues']['PPO2'][63] = u'Lumber'
    field_information['GGDM 3.0']['SummaryDomainValues']['PPO2'][65] = u'Manganese'
    field_information['GGDM 3.0']['SummaryDomainValues']['PPO2'][66] = u'Marble'
    field_information['GGDM 3.0']['SummaryDomainValues']['PPO2'][70] = u'Milk'
    field_information['GGDM 3.0']['SummaryDomainValues']['PPO2'][72] = u'Mussels'
    field_information['GGDM 3.0']['SummaryDomainValues']['PPO2'][77] = u'Oysters'
    field_information['GGDM 3.0']['SummaryDomainValues']['PPO2'][83] = u'Petroleum'
    field_information['GGDM 3.0']['SummaryDomainValues']['PPO2'][85] = u'Porphyry'
    field_information['GGDM 3.0']['SummaryDomainValues']['PPO2'][88] = u'Pumice'
    field_information['GGDM 3.0']['SummaryDomainValues']['PPO2'][89] = u'Quartz'
    field_information['GGDM 3.0']['SummaryDomainValues']['PPO2'][90] = u'Radioactive Material'
    field_information['GGDM 3.0']['SummaryDomainValues']['PPO2'][93] = u'Rocks'
    field_information['GGDM 3.0']['SummaryDomainValues']['PPO2'][95] = u'Salt'
    field_information['GGDM 3.0']['SummaryDomainValues']['PPO2'][96] = u'Sand'
    field_information['GGDM 3.0']['SummaryDomainValues']['PPO2'][97] = u'Sandstone'
    field_information['GGDM 3.0']['SummaryDomainValues']['PPO2'][101] = u'Sewage'
    field_information['GGDM 3.0']['SummaryDomainValues']['PPO2'][105] = u'Silver'
    field_information['GGDM 3.0']['SummaryDomainValues']['PPO2'][110] = u'Stone'
    field_information['GGDM 3.0']['SummaryDomainValues']['PPO2'][116] = u'Timber'
    field_information['GGDM 3.0']['SummaryDomainValues']['PPO2'][117] = u'Tobacco'
    field_information['GGDM 3.0']['SummaryDomainValues']['PPO2'][118] = u'Travertine'
    field_information['GGDM 3.0']['SummaryDomainValues']['PPO2'][120] = u'Uranium'
    field_information['GGDM 3.0']['SummaryDomainValues']['PPO2'][122] = u'Water'
    field_information['GGDM 3.0']['SummaryDomainValues']['PPO2'][123] = u'Wine'
    field_information['GGDM 3.0']['SummaryDomainValues']['PPO2'][126] = u'Zinc'
    field_information['GGDM 3.0']['SummaryDomainValues']['PPO2'][130] = u'Chalk'
    field_information['GGDM 3.0']['SummaryDomainValues']['PPO2'][146] = u'Heating Steam and/or Water'
    field_information['GGDM 3.0']['SummaryDomainValues']['PPO2'][149] = u'Brine'
    field_information['GGDM 3.0']['SummaryDomainValues']['PPO2'][151] = u'Chromium'
    field_information['GGDM 3.0']['SummaryDomainValues']['PPO2'][152] = u'Nickel'
    field_information['GGDM 3.0']['SummaryDomainValues']['PPO2'][153] = u'Tin'
    field_information['GGDM 3.0']['SummaryDomainValues']['PPO2'][158] = u'Pottery'
    field_information['GGDM 3.0']['SummaryDomainValues']['PPO2'][159] = u'Charcoal'
    field_information['GGDM 3.0']['SummaryDomainValues']['PPO2'][160] = u'Milled Grain'
    field_information['GGDM 3.0']['SummaryDomainValues']['PPO2'][161] = u'Coalbed Methane'
    field_information['GGDM 3.0']['SummaryDomainValues']['PPO2'][162] = u'Natural Gas Condensate'
    field_information['GGDM 3.0']['SummaryDomainValues']['PPO2'][163] = u'Helium'
    field_information['GGDM 3.0']['SummaryDomainValues']['PPO2'][164] = u'Hydrothermal Fluid'
    field_information['GGDM 3.0']['SummaryDomainValues']['PPO2'][170] = u'Beverage'
    field_information['GGDM 3.0']['SummaryDomainValues']['PPO2'][173] = u'Fluorite'
    field_information['GGDM 3.0']['SummaryDomainValues']['PPO2'][204] = u'Phosphate'
    field_information['GGDM 3.0']['SummaryDomainValues']['PPO2'][214] = u'Biodiesel'
    field_information['GGDM 3.0']['SummaryDomainValues']['PPO2'][224] = u'Vanadium'
    field_information['GGDM 3.0']['SummaryDomainValues']['PPO2'][283] = u'Mica'
    field_information['GGDM 3.0']['SummaryDomainValues']['PPO2'][339] = u'Selenium'
    field_information['GGDM 3.0']['SummaryDomainValues']['PPO2'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['PPO3'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['PPO3'][1] = u'Aircraft'
    field_information['GGDM 3.0']['SummaryDomainValues']['PPO3'][3] = u'Ammunition'
    field_information['GGDM 3.0']['SummaryDomainValues']['PPO3'][8] = u'Basalt'
    field_information['GGDM 3.0']['SummaryDomainValues']['PPO3'][9] = u'Bauxite'
    field_information['GGDM 3.0']['SummaryDomainValues']['PPO3'][11] = u'Bivalve Mollusc'
    field_information['GGDM 3.0']['SummaryDomainValues']['PPO3'][13] = u'Brick'
    field_information['GGDM 3.0']['SummaryDomainValues']['PPO3'][15] = u'Cement'
    field_information['GGDM 3.0']['SummaryDomainValues']['PPO3'][16] = u'Chemical'
    field_information['GGDM 3.0']['SummaryDomainValues']['PPO3'][17] = u'Clay'
    field_information['GGDM 3.0']['SummaryDomainValues']['PPO3'][18] = u'Coal'
    field_information['GGDM 3.0']['SummaryDomainValues']['PPO3'][19] = u'Cobbles'
    field_information['GGDM 3.0']['SummaryDomainValues']['PPO3'][21] = u'Coke'
    field_information['GGDM 3.0']['SummaryDomainValues']['PPO3'][26] = u'Copper'
    field_information['GGDM 3.0']['SummaryDomainValues']['PPO3'][29] = u'Crustacean'
    field_information['GGDM 3.0']['SummaryDomainValues']['PPO3'][30] = u'Cultivated Shellfish'
    field_information['GGDM 3.0']['SummaryDomainValues']['PPO3'][33] = u'Diamond'
    field_information['GGDM 3.0']['SummaryDomainValues']['PPO3'][34] = u'Diatomaceous Earth'
    field_information['GGDM 3.0']['SummaryDomainValues']['PPO3'][35] = u'Dolomite'
    field_information['GGDM 3.0']['SummaryDomainValues']['PPO3'][37] = u'Electric Power'
    field_information['GGDM 3.0']['SummaryDomainValues']['PPO3'][38] = u'Explosive'
    field_information['GGDM 3.0']['SummaryDomainValues']['PPO3'][39] = u'Fish'
    field_information['GGDM 3.0']['SummaryDomainValues']['PPO3'][45] = u'Gas'
    field_information['GGDM 3.0']['SummaryDomainValues']['PPO3'][46] = u'Petrol'
    field_information['GGDM 3.0']['SummaryDomainValues']['PPO3'][48] = u'Gold'
    field_information['GGDM 3.0']['SummaryDomainValues']['PPO3'][49] = u'Grain'
    field_information['GGDM 3.0']['SummaryDomainValues']['PPO3'][50] = u'Granite'
    field_information['GGDM 3.0']['SummaryDomainValues']['PPO3'][53] = u'Gravel'
    field_information['GGDM 3.0']['SummaryDomainValues']['PPO3'][58] = u'Iron'
    field_information['GGDM 3.0']['SummaryDomainValues']['PPO3'][59] = u'Lead'
    field_information['GGDM 3.0']['SummaryDomainValues']['PPO3'][60] = u'Lime'
    field_information['GGDM 3.0']['SummaryDomainValues']['PPO3'][61] = u'Liquefied Natural Gas (LNG)'
    field_information['GGDM 3.0']['SummaryDomainValues']['PPO3'][62] = u'Liquefied Petroleum Gas (LPG)'
    field_information['GGDM 3.0']['SummaryDomainValues']['PPO3'][63] = u'Lumber'
    field_information['GGDM 3.0']['SummaryDomainValues']['PPO3'][65] = u'Manganese'
    field_information['GGDM 3.0']['SummaryDomainValues']['PPO3'][66] = u'Marble'
    field_information['GGDM 3.0']['SummaryDomainValues']['PPO3'][70] = u'Milk'
    field_information['GGDM 3.0']['SummaryDomainValues']['PPO3'][72] = u'Mussels'
    field_information['GGDM 3.0']['SummaryDomainValues']['PPO3'][77] = u'Oysters'
    field_information['GGDM 3.0']['SummaryDomainValues']['PPO3'][83] = u'Petroleum'
    field_information['GGDM 3.0']['SummaryDomainValues']['PPO3'][85] = u'Porphyry'
    field_information['GGDM 3.0']['SummaryDomainValues']['PPO3'][88] = u'Pumice'
    field_information['GGDM 3.0']['SummaryDomainValues']['PPO3'][89] = u'Quartz'
    field_information['GGDM 3.0']['SummaryDomainValues']['PPO3'][90] = u'Radioactive Material'
    field_information['GGDM 3.0']['SummaryDomainValues']['PPO3'][93] = u'Rocks'
    field_information['GGDM 3.0']['SummaryDomainValues']['PPO3'][95] = u'Salt'
    field_information['GGDM 3.0']['SummaryDomainValues']['PPO3'][96] = u'Sand'
    field_information['GGDM 3.0']['SummaryDomainValues']['PPO3'][97] = u'Sandstone'
    field_information['GGDM 3.0']['SummaryDomainValues']['PPO3'][101] = u'Sewage'
    field_information['GGDM 3.0']['SummaryDomainValues']['PPO3'][105] = u'Silver'
    field_information['GGDM 3.0']['SummaryDomainValues']['PPO3'][110] = u'Stone'
    field_information['GGDM 3.0']['SummaryDomainValues']['PPO3'][116] = u'Timber'
    field_information['GGDM 3.0']['SummaryDomainValues']['PPO3'][117] = u'Tobacco'
    field_information['GGDM 3.0']['SummaryDomainValues']['PPO3'][118] = u'Travertine'
    field_information['GGDM 3.0']['SummaryDomainValues']['PPO3'][120] = u'Uranium'
    field_information['GGDM 3.0']['SummaryDomainValues']['PPO3'][122] = u'Water'
    field_information['GGDM 3.0']['SummaryDomainValues']['PPO3'][123] = u'Wine'
    field_information['GGDM 3.0']['SummaryDomainValues']['PPO3'][126] = u'Zinc'
    field_information['GGDM 3.0']['SummaryDomainValues']['PPO3'][130] = u'Chalk'
    field_information['GGDM 3.0']['SummaryDomainValues']['PPO3'][146] = u'Heating Steam and/or Water'
    field_information['GGDM 3.0']['SummaryDomainValues']['PPO3'][149] = u'Brine'
    field_information['GGDM 3.0']['SummaryDomainValues']['PPO3'][151] = u'Chromium'
    field_information['GGDM 3.0']['SummaryDomainValues']['PPO3'][152] = u'Nickel'
    field_information['GGDM 3.0']['SummaryDomainValues']['PPO3'][153] = u'Tin'
    field_information['GGDM 3.0']['SummaryDomainValues']['PPO3'][158] = u'Pottery'
    field_information['GGDM 3.0']['SummaryDomainValues']['PPO3'][159] = u'Charcoal'
    field_information['GGDM 3.0']['SummaryDomainValues']['PPO3'][160] = u'Milled Grain'
    field_information['GGDM 3.0']['SummaryDomainValues']['PPO3'][161] = u'Coalbed Methane'
    field_information['GGDM 3.0']['SummaryDomainValues']['PPO3'][162] = u'Natural Gas Condensate'
    field_information['GGDM 3.0']['SummaryDomainValues']['PPO3'][163] = u'Helium'
    field_information['GGDM 3.0']['SummaryDomainValues']['PPO3'][164] = u'Hydrothermal Fluid'
    field_information['GGDM 3.0']['SummaryDomainValues']['PPO3'][170] = u'Beverage'
    field_information['GGDM 3.0']['SummaryDomainValues']['PPO3'][173] = u'Fluorite'
    field_information['GGDM 3.0']['SummaryDomainValues']['PPO3'][204] = u'Phosphate'
    field_information['GGDM 3.0']['SummaryDomainValues']['PPO3'][214] = u'Biodiesel'
    field_information['GGDM 3.0']['SummaryDomainValues']['PPO3'][224] = u'Vanadium'
    field_information['GGDM 3.0']['SummaryDomainValues']['PPO3'][283] = u'Mica'
    field_information['GGDM 3.0']['SummaryDomainValues']['PPO3'][339] = u'Selenium'
    field_information['GGDM 3.0']['SummaryDomainValues']['PPO3'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['PRM'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['PRM'][1000] = u'False'
    field_information['GGDM 3.0']['SummaryDomainValues']['PRM'][1001] = u'True'
    field_information['GGDM 3.0']['SummaryDomainValues']['PRW'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['PRW'][12] = u'Coal'
    field_information['GGDM 3.0']['SummaryDomainValues']['PRW'][14] = u'Coke'
    field_information['GGDM 3.0']['SummaryDomainValues']['PRW'][34] = u'Gravel'
    field_information['GGDM 3.0']['SummaryDomainValues']['PRW'][54] = u'Ore'
    field_information['GGDM 3.0']['SummaryDomainValues']['PRW'][67] = u'Salt'
    field_information['GGDM 3.0']['SummaryDomainValues']['PRW'][68] = u'Sand'
    field_information['GGDM 3.0']['SummaryDomainValues']['PRW'][84] = u'Stone'
    field_information['GGDM 3.0']['SummaryDomainValues']['PRW'][154] = u'Sulphur'
    field_information['GGDM 3.0']['SummaryDomainValues']['PRW'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['PRW2'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['PRW2'][12] = u'Coal'
    field_information['GGDM 3.0']['SummaryDomainValues']['PRW2'][14] = u'Coke'
    field_information['GGDM 3.0']['SummaryDomainValues']['PRW2'][34] = u'Gravel'
    field_information['GGDM 3.0']['SummaryDomainValues']['PRW2'][54] = u'Ore'
    field_information['GGDM 3.0']['SummaryDomainValues']['PRW2'][67] = u'Salt'
    field_information['GGDM 3.0']['SummaryDomainValues']['PRW2'][68] = u'Sand'
    field_information['GGDM 3.0']['SummaryDomainValues']['PRW2'][84] = u'Stone'
    field_information['GGDM 3.0']['SummaryDomainValues']['PRW2'][154] = u'Sulphur'
    field_information['GGDM 3.0']['SummaryDomainValues']['PRW2'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['PRW3'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['PRW3'][12] = u'Coal'
    field_information['GGDM 3.0']['SummaryDomainValues']['PRW3'][14] = u'Coke'
    field_information['GGDM 3.0']['SummaryDomainValues']['PRW3'][34] = u'Gravel'
    field_information['GGDM 3.0']['SummaryDomainValues']['PRW3'][54] = u'Ore'
    field_information['GGDM 3.0']['SummaryDomainValues']['PRW3'][67] = u'Salt'
    field_information['GGDM 3.0']['SummaryDomainValues']['PRW3'][68] = u'Sand'
    field_information['GGDM 3.0']['SummaryDomainValues']['PRW3'][84] = u'Stone'
    field_information['GGDM 3.0']['SummaryDomainValues']['PRW3'][154] = u'Sulphur'
    field_information['GGDM 3.0']['SummaryDomainValues']['PRW3'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['PTG'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['PTG'][1000] = u'False'
    field_information['GGDM 3.0']['SummaryDomainValues']['PTG'][1001] = u'True'
    field_information['GGDM 3.0']['SummaryDomainValues']['PWAC'][2] = u'Open Interval'
    field_information['GGDM 3.0']['SummaryDomainValues']['PWAC'][3] = u'Greater-than-or-equal to Less-than Interval'
    field_information['GGDM 3.0']['SummaryDomainValues']['PWAC'][4] = u'Greater-than to Less-than-or-equal Interval'
    field_information['GGDM 3.0']['SummaryDomainValues']['PWAC'][5] = u'Closed Interval'
    field_information['GGDM 3.0']['SummaryDomainValues']['PWAC'][6] = u'Greater-than Semi-interval'
    field_information['GGDM 3.0']['SummaryDomainValues']['PWAC'][7] = u'Greater-than or Equal Semi-interval'
    field_information['GGDM 3.0']['SummaryDomainValues']['PWAC'][8] = u'Less-than Semi-interval'
    field_information['GGDM 3.0']['SummaryDomainValues']['PWAC'][9] = u'Less-than or Equal Semi-interval'
    field_information['GGDM 3.0']['SummaryDomainValues']['PWC'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['PWC'][1] = u'Pier'
    field_information['GGDM 3.0']['SummaryDomainValues']['PWC'][2] = u'Wharf'
    field_information['GGDM 3.0']['SummaryDomainValues']['PWC'][3] = u'Quay'
    field_information['GGDM 3.0']['SummaryDomainValues']['PWC'][4] = u'Breakwater'
    field_information['GGDM 3.0']['SummaryDomainValues']['PWC'][5] = u'Groin'
    field_information['GGDM 3.0']['SummaryDomainValues']['PWC'][6] = u'Mole'
    field_information['GGDM 3.0']['SummaryDomainValues']['PWC'][7] = u'Recreational Pier'
    field_information['GGDM 3.0']['SummaryDomainValues']['PWC'][8] = u'Training Wall'
    field_information['GGDM 3.0']['SummaryDomainValues']['PWC'][9] = u'Riprap'
    field_information['GGDM 3.0']['SummaryDomainValues']['PWC'][10] = u'Revetment (Marine)'
    field_information['GGDM 3.0']['SummaryDomainValues']['PWC'][11] = u'Seawall'
    field_information['GGDM 3.0']['SummaryDomainValues']['PWC'][18] = u'Promenade'
    field_information['GGDM 3.0']['SummaryDomainValues']['PWC'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['PYC'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['PYC'][1] = u'A\''
    field_information['GGDM 3.0']['SummaryDomainValues']['PYC'][2] = u'H\''
    field_information['GGDM 3.0']['SummaryDomainValues']['PYC'][3] = u'I\''
    field_information['GGDM 3.0']['SummaryDomainValues']['PYC'][4] = u'Y\''
    field_information['GGDM 3.0']['SummaryDomainValues']['PYC'][5] = u'T\''
    field_information['GGDM 3.0']['SummaryDomainValues']['PYC'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['PYM'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['PYM'][1] = u'Aluminium'
    field_information['GGDM 3.0']['SummaryDomainValues']['PYM'][3] = u'Concrete'
    field_information['GGDM 3.0']['SummaryDomainValues']['PYM'][4] = u'Masonry'
    field_information['GGDM 3.0']['SummaryDomainValues']['PYM'][5] = u'Metal'
    field_information['GGDM 3.0']['SummaryDomainValues']['PYM'][7] = u'Wood'
    field_information['GGDM 3.0']['SummaryDomainValues']['PYM'][8] = u'Steel'
    field_information['GGDM 3.0']['SummaryDomainValues']['PYM'][9] = u'Fibreglass'
    field_information['GGDM 3.0']['SummaryDomainValues']['PYM'][10] = u'Iron'
    field_information['GGDM 3.0']['SummaryDomainValues']['PYM'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['RAC'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['RAC'][1] = u'Dome Enclosed'
    field_information['GGDM 3.0']['SummaryDomainValues']['RAC'][2] = u'Mast Mounted'
    field_information['GGDM 3.0']['SummaryDomainValues']['RAC'][3] = u'Radome'
    field_information['GGDM 3.0']['SummaryDomainValues']['RAC'][4] = u'    Radome on Tower'
    field_information['GGDM 3.0']['SummaryDomainValues']['RAC'][5] = u'Scanner'
    field_information['GGDM 3.0']['SummaryDomainValues']['RAC'][6] = u'Tower Mounted'
    field_information['GGDM 3.0']['SummaryDomainValues']['RAC'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['RAS'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['RAS'][1] = u'General Surveillance'
    field_information['GGDM 3.0']['SummaryDomainValues']['RAS'][2] = u'Coastal Radar'
    field_information['GGDM 3.0']['SummaryDomainValues']['RAS'][5] = u'Early Warning'
    field_information['GGDM 3.0']['SummaryDomainValues']['RAS'][6] = u'Weather'
    field_information['GGDM 3.0']['SummaryDomainValues']['RAS'][7] = u'Satellite Tracking'
    field_information['GGDM 3.0']['SummaryDomainValues']['RAS'][8] = u'Aircraft Flight Tracking'
    field_information['GGDM 3.0']['SummaryDomainValues']['RAS'][9] = u'Fire Control Tracking'
    field_information['GGDM 3.0']['SummaryDomainValues']['RAS'][10] = u'Launch Control Tracking'
    field_information['GGDM 3.0']['SummaryDomainValues']['RAS'][11] = u'Aerodrome Ground Surveillance'
    field_information['GGDM 3.0']['SummaryDomainValues']['RAS'][12] = u'Precision Approach'
    field_information['GGDM 3.0']['SummaryDomainValues']['RAS'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['RAY'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['RAY'][1] = u'Bicycle'
    field_information['GGDM 3.0']['SummaryDomainValues']['RAY'][2] = u'Camel'
    field_information['GGDM 3.0']['SummaryDomainValues']['RAY'][3] = u'Greyhound'
    field_information['GGDM 3.0']['SummaryDomainValues']['RAY'][4] = u'Harness'
    field_information['GGDM 3.0']['SummaryDomainValues']['RAY'][5] = u'Horse'
    field_information['GGDM 3.0']['SummaryDomainValues']['RAY'][6] = u'Ice Skate'
    field_information['GGDM 3.0']['SummaryDomainValues']['RAY'][7] = u'Motor Vehicle'
    field_information['GGDM 3.0']['SummaryDomainValues']['RAY'][8] = u'Roller Skate'
    field_information['GGDM 3.0']['SummaryDomainValues']['RAY'][9] = u'Track and Field'
    field_information['GGDM 3.0']['SummaryDomainValues']['RAY'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['RCG'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['RCG'][1] = u'U.S. Army'
    field_information['GGDM 3.0']['SummaryDomainValues']['RCG'][2] = u'U.S. Navy'
    field_information['GGDM 3.0']['SummaryDomainValues']['RCG'][3] = u'U.S. Air Force'
    field_information['GGDM 3.0']['SummaryDomainValues']['RCG'][4] = u'U.S. Marine Corps'
    field_information['GGDM 3.0']['SummaryDomainValues']['RCG'][5] = u'U.S. Coast Guard'
    field_information['GGDM 3.0']['SummaryDomainValues']['RCG'][6] = u'U.S. Africa Command (USAFRICOM)'
    field_information['GGDM 3.0']['SummaryDomainValues']['RCG'][7] = u'U.S. Central Command (USCENTCOM)'
    field_information['GGDM 3.0']['SummaryDomainValues']['RCG'][8] = u'U.S. European Command (USEUCOM)'
    field_information['GGDM 3.0']['SummaryDomainValues']['RCG'][9] = u'U.S. Joint Forces Command (USJFCOM)'
    field_information['GGDM 3.0']['SummaryDomainValues']['RCG'][10] = u'U.S. Northern Command (USNORTHCOM)'
    field_information['GGDM 3.0']['SummaryDomainValues']['RCG'][11] = u'U.S. Pacific Command (PACOM)'
    field_information['GGDM 3.0']['SummaryDomainValues']['RCG'][12] = u'U.S. Special Operations Command (USSOCOM)'
    field_information['GGDM 3.0']['SummaryDomainValues']['RCG'][13] = u'U.S. Southern Command (USSOUTHCOM)'
    field_information['GGDM 3.0']['SummaryDomainValues']['RCG'][14] = u'U.S. Strategic Command (USSTRATCOM)'
    field_information['GGDM 3.0']['SummaryDomainValues']['RCG'][15] = u'U.S. Transportation Command (USTRANSCOM)'
    field_information['GGDM 3.0']['SummaryDomainValues']['RCG'][16] = u'U.S. Central Intelligence Agency (CIA)'
    field_information['GGDM 3.0']['SummaryDomainValues']['RCG'][17] = u'U.S. Defense Intelligence Agency (DIA)'
    field_information['GGDM 3.0']['SummaryDomainValues']['RCG'][18] = u'U.S. National Security Agency (NSA)'
    field_information['GGDM 3.0']['SummaryDomainValues']['RCG'][19] = u'U.S. National Geospatial-Intelligence Agency (NGA)'
    field_information['GGDM 3.0']['SummaryDomainValues']['RCG'][20] = u'U.S. National Reconnaissance Office (NRO)'
    field_information['GGDM 3.0']['SummaryDomainValues']['RCG'][21] = u'U.S. Department of State'
    field_information['GGDM 3.0']['SummaryDomainValues']['RCG'][22] = u'U.S. Department of Homeland Security (DHS)'
    field_information['GGDM 3.0']['SummaryDomainValues']['RCG'][23] = u'U.S. Department of Energy (DOE)'
    field_information['GGDM 3.0']['SummaryDomainValues']['RCG'][24] = u'U.S. Federal Bureau of Investigation (FBI)'
    field_information['GGDM 3.0']['SummaryDomainValues']['RCG'][25] = u'U.S. Geological Survey (USGS)'
    field_information['GGDM 3.0']['SummaryDomainValues']['RCG'][26] = u'U.S. National Civil Applications Program (NCAP)'
    field_information['GGDM 3.0']['SummaryDomainValues']['RCG'][27] = u'U.S. National Oceanic and Atmospheric Administration'
    field_information['GGDM 3.0']['SummaryDomainValues']['RCG'][28] = u'Defence Imagery and Geospatial Organisation (Australia)'
    field_information['GGDM 3.0']['SummaryDomainValues']['RCG'][29] = u'Geographic Service (Belgium)'
    field_information['GGDM 3.0']['SummaryDomainValues']['RCG'][30] = u'Military Topographic Service (Bulgaria)'
    field_information['GGDM 3.0']['SummaryDomainValues']['RCG'][31] = u'Mapping and Charting Establishment (Canada)'
    field_information['GGDM 3.0']['SummaryDomainValues']['RCG'][32] = u'Geographic Service of the Czech Armed Forces (Czech Republic)'
    field_information['GGDM 3.0']['SummaryDomainValues']['RCG'][33] = u'Defence Acquisition and Logistics Organization (Denmark)'
    field_information['GGDM 3.0']['SummaryDomainValues']['RCG'][34] = u'Military Geographic Group (Estonia)'
    field_information['GGDM 3.0']['SummaryDomainValues']['RCG'][35] = u'Topographic Service (Finland)'
    field_information['GGDM 3.0']['SummaryDomainValues']['RCG'][36] = u'Joint Geography Bureau (France)'
    field_information['GGDM 3.0']['SummaryDomainValues']['RCG'][37] = u'Bundeswehr Geoinformation Office (Germany)'
    field_information['GGDM 3.0']['SummaryDomainValues']['RCG'][38] = u'Hellenic Military Geographic Service (Greece)'
    field_information['GGDM 3.0']['SummaryDomainValues']['RCG'][39] = u'Mapping Service (Hungary)'
    field_information['GGDM 3.0']['SummaryDomainValues']['RCG'][40] = u'Defense Information Security (Italy)'
    field_information['GGDM 3.0']['SummaryDomainValues']['RCG'][41] = u'Geospatial Information Agency (Latvia)'
    field_information['GGDM 3.0']['SummaryDomainValues']['RCG'][42] = u'Military Mapping Centre (Lithuania)'
    field_information['GGDM 3.0']['SummaryDomainValues']['RCG'][43] = u'National Army Topographic Service (Moldova)'
    field_information['GGDM 3.0']['SummaryDomainValues']['RCG'][44] = u'Army Geographic Agency (Netherlands)'
    field_information['GGDM 3.0']['SummaryDomainValues']['RCG'][45] = u'Geospatial Intelligence Organisation (New Zealand)'
    field_information['GGDM 3.0']['SummaryDomainValues']['RCG'][46] = u'Military Geographic Service (Norway)'
    field_information['GGDM 3.0']['SummaryDomainValues']['RCG'][47] = u'Military Geography Division (Poland)'
    field_information['GGDM 3.0']['SummaryDomainValues']['RCG'][48] = u'Army Geographic Institute (Portugal)'
    field_information['GGDM 3.0']['SummaryDomainValues']['RCG'][49] = u'Military Topographic Directorate (Romania)'
    field_information['GGDM 3.0']['SummaryDomainValues']['RCG'][50] = u'Topographic Institute (Slovakia)'
    field_information['GGDM 3.0']['SummaryDomainValues']['RCG'][51] = u'Army Geographic Centre (Spain)'
    field_information['GGDM 3.0']['SummaryDomainValues']['RCG'][52] = u'Swedish Armed Forces (Sweden)'
    field_information['GGDM 3.0']['SummaryDomainValues']['RCG'][53] = u'General Command of Mapping (Turkey)'
    field_information['GGDM 3.0']['SummaryDomainValues']['RCG'][54] = u'Defence Geographic Centre Intelligence Collection Group (United Kingdom)'
    field_information['GGDM 3.0']['SummaryDomainValues']['RCG'][55] = u'U.S. Army Geospatial Center (AGC)'
    field_information['GGDM 3.0']['SummaryDomainValues']['RCG'][56] = u'Army (Australia)'
    field_information['GGDM 3.0']['SummaryDomainValues']['RCG'][57] = u'Military Geographic Division (Croatia)'
    field_information['GGDM 3.0']['SummaryDomainValues']['RCG'][58] = u'Directorate Geospatial Information (South Africa)'
    field_information['GGDM 3.0']['SummaryDomainValues']['RCG'][59] = u'Korean Defense Intelligence Agency (South Korea)'
    field_information['GGDM 3.0']['SummaryDomainValues']['RCG'][60] = u'National Intelligence Service (South Korea)'
    field_information['GGDM 3.0']['SummaryDomainValues']['RCG'][61] = u'Imagery Support Group (Singapore)'
    field_information['GGDM 3.0']['SummaryDomainValues']['RCG'][62] = u'National Security Bureau (Taiwan)'
    field_information['GGDM 3.0']['SummaryDomainValues']['RCG'][63] = u'Materiel Production Center (Taiwan)'
    field_information['GGDM 3.0']['SummaryDomainValues']['RCG'][64] = u'Ministry of Defense of Japan (Japan)'
    field_information['GGDM 3.0']['SummaryDomainValues']['RCG'][65] = u'Ministry of Construction and Urban Development (Mongolia)'
    field_information['GGDM 3.0']['SummaryDomainValues']['RCG'][66] = u'National Mapping and Resource Information Authority (Philippines)'
    field_information['GGDM 3.0']['SummaryDomainValues']['RCG'][67] = u'Royal Jordanian Geographic Centre (Jordan)'
    field_information['GGDM 3.0']['SummaryDomainValues']['RCG'][68] = u'National Survey Authority (Oman)'
    field_information['GGDM 3.0']['SummaryDomainValues']['RCG'][69] = u'Armed Forces General Headquarters (Qatar)'
    field_information['GGDM 3.0']['SummaryDomainValues']['RCG'][70] = u'Ministry of Defense of Saudi Arabia (Saudi Arabia)'
    field_information['GGDM 3.0']['SummaryDomainValues']['RCG'][71] = u'Directorate of Survey (Kuwait)'
    field_information['GGDM 3.0']['SummaryDomainValues']['RCG'][72] = u'Military Survey Department (United Arab Emirates)'
    field_information['GGDM 3.0']['SummaryDomainValues']['RCG'][73] = u'Information Network Security Agency (Ethiopia)'
    field_information['GGDM 3.0']['SummaryDomainValues']['RCG'][74] = u'Ministry of State for Defense (Kenya)'
    field_information['GGDM 3.0']['SummaryDomainValues']['RCG'][75] = u'El Instituto Nacional de Estadistica y Geografia (Mexico)'
    field_information['GGDM 3.0']['SummaryDomainValues']['RCG'][76] = u'Instituto Geográfico Militar (Chile)'
    field_information['GGDM 3.0']['SummaryDomainValues']['RCG'][77] = u'Servicio Geográfico Militar (Uruguay)'
    field_information['GGDM 3.0']['SummaryDomainValues']['RCG'][78] = u'Dirección del Servicio Geográfico Military (Paraguay)'
    field_information['GGDM 3.0']['SummaryDomainValues']['RCG'][79] = u'Instituto Geográfico Nacional (Peru)'
    field_information['GGDM 3.0']['SummaryDomainValues']['RCG'][80] = u'Instituto Geográfico Agustín Codazzi (Colombia)'
    field_information['GGDM 3.0']['SummaryDomainValues']['RCG'][81] = u'Instituto Geográfico y del Catastro Nacional (El Salvador)'
    field_information['GGDM 3.0']['SummaryDomainValues']['RCG'][82] = u'Instituto Geográfico Nacional (Guatemala)'
    field_information['GGDM 3.0']['SummaryDomainValues']['RCG'][83] = u'Servicio Geográfico Militar (Guatemala)'
    field_information['GGDM 3.0']['SummaryDomainValues']['RCG'][84] = u'Instituto Cartográfico Militar (Dominican Republic)'
    field_information['GGDM 3.0']['SummaryDomainValues']['RCG'][85] = u'Instituto Nicaragüense de Estudios Terretoriales (Nicaragua)'
    field_information['GGDM 3.0']['SummaryDomainValues']['RCG'][86] = u'Dirección General de Registros, Catastro, y Geografía (Honduras)'
    field_information['GGDM 3.0']['SummaryDomainValues']['RCG'][87] = u'Instituto Geográfico Militar (Ecuador)'
    field_information['GGDM 3.0']['SummaryDomainValues']['RCG'][88] = u'Instituto Geográfico Nacional "Tommy Guardia" (Panama)'
    field_information['GGDM 3.0']['SummaryDomainValues']['RCG'][89] = u'Instituto Geográfico Nacional (Argentina)'
    field_information['GGDM 3.0']['SummaryDomainValues']['RCG'][90] = u'Diretoria de Serviço Geográfico (Brazil)'
    field_information['GGDM 3.0']['SummaryDomainValues']['RCG'][998] = u'Not Applicable'
    field_information['GGDM 3.0']['SummaryDomainValues']['RCG'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['REF'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['REF'][1000] = u'False'
    field_information['GGDM 3.0']['SummaryDomainValues']['REF'][1001] = u'True'
    field_information['GGDM 3.0']['SummaryDomainValues']['REW'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['REW'][1] = u'High Tide'
    field_information['GGDM 3.0']['SummaryDomainValues']['REW'][2] = u'Low Tide'
    field_information['GGDM 3.0']['SummaryDomainValues']['RFD'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['RFD'][1000] = u'False'
    field_information['GGDM 3.0']['SummaryDomainValues']['RFD'][1001] = u'True'
    field_information['GGDM 3.0']['SummaryDomainValues']['RIN_ROI'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['RIN_ROI'][1] = u'International'
    field_information['GGDM 3.0']['SummaryDomainValues']['RIN_ROI'][2] = u'National Motorway'
    field_information['GGDM 3.0']['SummaryDomainValues']['RIN_ROI'][3] = u'National'
    field_information['GGDM 3.0']['SummaryDomainValues']['RIN_ROI'][4] = u'Secondary'
    field_information['GGDM 3.0']['SummaryDomainValues']['RIN_ROI'][5] = u'Local'
    field_information['GGDM 3.0']['SummaryDomainValues']['RIN_ROI'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['RIN_ROI2'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['RIN_ROI2'][1] = u'International'
    field_information['GGDM 3.0']['SummaryDomainValues']['RIN_ROI2'][2] = u'National Motorway'
    field_information['GGDM 3.0']['SummaryDomainValues']['RIN_ROI2'][3] = u'National'
    field_information['GGDM 3.0']['SummaryDomainValues']['RIN_ROI2'][4] = u'Secondary'
    field_information['GGDM 3.0']['SummaryDomainValues']['RIN_ROI2'][5] = u'Local'
    field_information['GGDM 3.0']['SummaryDomainValues']['RIN_ROI2'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['RIN_ROI3'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['RIN_ROI3'][1] = u'International'
    field_information['GGDM 3.0']['SummaryDomainValues']['RIN_ROI3'][2] = u'National Motorway'
    field_information['GGDM 3.0']['SummaryDomainValues']['RIN_ROI3'][3] = u'National'
    field_information['GGDM 3.0']['SummaryDomainValues']['RIN_ROI3'][4] = u'Secondary'
    field_information['GGDM 3.0']['SummaryDomainValues']['RIN_ROI3'][5] = u'Local'
    field_information['GGDM 3.0']['SummaryDomainValues']['RIN_ROI3'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['RIP'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['RIP'][1000] = u'False'
    field_information['GGDM 3.0']['SummaryDomainValues']['RIP'][1001] = u'True'
    field_information['GGDM 3.0']['SummaryDomainValues']['RIT'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['RIT'][1] = u'Cloverleaf'
    field_information['GGDM 3.0']['SummaryDomainValues']['RIT'][2] = u'Diamond'
    field_information['GGDM 3.0']['SummaryDomainValues']['RIT'][3] = u'Fork'
    field_information['GGDM 3.0']['SummaryDomainValues']['RIT'][4] = u'Rotary'
    field_information['GGDM 3.0']['SummaryDomainValues']['RIT'][5] = u'Staggered Ramps'
    field_information['GGDM 3.0']['SummaryDomainValues']['RIT'][6] = u'Standard Ramps'
    field_information['GGDM 3.0']['SummaryDomainValues']['RIT'][7] = u'Symmetrical Ramps'
    field_information['GGDM 3.0']['SummaryDomainValues']['RIT'][8] = u'Trumpet'
    field_information['GGDM 3.0']['SummaryDomainValues']['RIT'][9] = u'Turban'
    field_information['GGDM 3.0']['SummaryDomainValues']['RIT'][10] = u'Wye'
    field_information['GGDM 3.0']['SummaryDomainValues']['RIT'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['RKF'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['RKF'][1] = u'Columnar'
    field_information['GGDM 3.0']['SummaryDomainValues']['RKF'][2] = u'Needle'
    field_information['GGDM 3.0']['SummaryDomainValues']['RKF'][3] = u'Pinnacle'
    field_information['GGDM 3.0']['SummaryDomainValues']['RKF'][4] = u'Fossilized Forest'
    field_information['GGDM 3.0']['SummaryDomainValues']['RKF'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['RLE'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['RLE'][1] = u'Raised'
    field_information['GGDM 3.0']['SummaryDomainValues']['RLE'][2] = u'Level'
    field_information['GGDM 3.0']['SummaryDomainValues']['RLE'][3] = u'Depressed'
    field_information['GGDM 3.0']['SummaryDomainValues']['RLE'][998] = u'Not Applicable'
    field_information['GGDM 3.0']['SummaryDomainValues']['RMWC'][2] = u'Open Interval'
    field_information['GGDM 3.0']['SummaryDomainValues']['RMWC'][3] = u'Greater-than-or-equal to Less-than Interval'
    field_information['GGDM 3.0']['SummaryDomainValues']['RMWC'][4] = u'Greater-than to Less-than-or-equal Interval'
    field_information['GGDM 3.0']['SummaryDomainValues']['RMWC'][5] = u'Closed Interval'
    field_information['GGDM 3.0']['SummaryDomainValues']['RMWC'][6] = u'Greater-than Semi-interval'
    field_information['GGDM 3.0']['SummaryDomainValues']['RMWC'][7] = u'Greater-than or Equal Semi-interval'
    field_information['GGDM 3.0']['SummaryDomainValues']['RMWC'][8] = u'Less-than Semi-interval'
    field_information['GGDM 3.0']['SummaryDomainValues']['RMWC'][9] = u'Less-than or Equal Semi-interval'
    field_information['GGDM 3.0']['SummaryDomainValues']['ROR'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['ROR'][1000] = u'False'
    field_information['GGDM 3.0']['SummaryDomainValues']['ROR'][1001] = u'True'
    field_information['GGDM 3.0']['SummaryDomainValues']['RPC'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['RPC'][1] = u'Show No Line'
    field_information['GGDM 3.0']['SummaryDomainValues']['RPC'][2] = u'Definite'
    field_information['GGDM 3.0']['SummaryDomainValues']['RPC'][3] = u'Indefinite'
    field_information['GGDM 3.0']['SummaryDomainValues']['RPC'][4] = u'In Dispute'
    field_information['GGDM 3.0']['SummaryDomainValues']['RPC'][5] = u'Administrative as International'
    field_information['GGDM 3.0']['SummaryDomainValues']['RPC'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['RRC'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['RRC'][2] = u'Carline'
    field_information['GGDM 3.0']['SummaryDomainValues']['RRC'][6] = u'Underground Railway'
    field_information['GGDM 3.0']['SummaryDomainValues']['RRC'][8] = u'Logging'
    field_information['GGDM 3.0']['SummaryDomainValues']['RRC'][11] = u'Rail Rapid Transit'
    field_information['GGDM 3.0']['SummaryDomainValues']['RRC'][13] = u'Marine Railway'
    field_information['GGDM 3.0']['SummaryDomainValues']['RRC'][14] = u'Tramway'
    field_information['GGDM 3.0']['SummaryDomainValues']['RRC'][15] = u'Funicular'
    field_information['GGDM 3.0']['SummaryDomainValues']['RRC'][24] = u'Museum'
    field_information['GGDM 3.0']['SummaryDomainValues']['RRC'][32] = u'Automated Transit System'
    field_information['GGDM 3.0']['SummaryDomainValues']['RRC'][33] = u'Long-haul'
    field_information['GGDM 3.0']['SummaryDomainValues']['RRC'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['RRC2'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['RRC2'][2] = u'Carline'
    field_information['GGDM 3.0']['SummaryDomainValues']['RRC2'][6] = u'Underground Railway'
    field_information['GGDM 3.0']['SummaryDomainValues']['RRC2'][8] = u'Logging'
    field_information['GGDM 3.0']['SummaryDomainValues']['RRC2'][11] = u'Rail Rapid Transit'
    field_information['GGDM 3.0']['SummaryDomainValues']['RRC2'][13] = u'Marine Railway'
    field_information['GGDM 3.0']['SummaryDomainValues']['RRC2'][14] = u'Tramway'
    field_information['GGDM 3.0']['SummaryDomainValues']['RRC2'][15] = u'Funicular'
    field_information['GGDM 3.0']['SummaryDomainValues']['RRC2'][24] = u'Museum'
    field_information['GGDM 3.0']['SummaryDomainValues']['RRC2'][32] = u'Automated Transit System'
    field_information['GGDM 3.0']['SummaryDomainValues']['RRC2'][33] = u'Long-haul'
    field_information['GGDM 3.0']['SummaryDomainValues']['RRC2'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['RRC3'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['RRC3'][2] = u'Carline'
    field_information['GGDM 3.0']['SummaryDomainValues']['RRC3'][6] = u'Underground Railway'
    field_information['GGDM 3.0']['SummaryDomainValues']['RRC3'][8] = u'Logging'
    field_information['GGDM 3.0']['SummaryDomainValues']['RRC3'][11] = u'Rail Rapid Transit'
    field_information['GGDM 3.0']['SummaryDomainValues']['RRC3'][13] = u'Marine Railway'
    field_information['GGDM 3.0']['SummaryDomainValues']['RRC3'][14] = u'Tramway'
    field_information['GGDM 3.0']['SummaryDomainValues']['RRC3'][15] = u'Funicular'
    field_information['GGDM 3.0']['SummaryDomainValues']['RRC3'][24] = u'Museum'
    field_information['GGDM 3.0']['SummaryDomainValues']['RRC3'][32] = u'Automated Transit System'
    field_information['GGDM 3.0']['SummaryDomainValues']['RRC3'][33] = u'Long-haul'
    field_information['GGDM 3.0']['SummaryDomainValues']['RRC3'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['RSA'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['RSA'][1] = u'Spur'
    field_information['GGDM 3.0']['SummaryDomainValues']['RSA'][2] = u'Siding'
    field_information['GGDM 3.0']['SummaryDomainValues']['RSA'][3] = u'Passing'
    field_information['GGDM 3.0']['SummaryDomainValues']['RSA'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['RSI'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['RSI'][1] = u'Metal'
    field_information['GGDM 3.0']['SummaryDomainValues']['RSI'][2] = u'Part Metal'
    field_information['GGDM 3.0']['SummaryDomainValues']['RSI'][3] = u'Masonry'
    field_information['GGDM 3.0']['SummaryDomainValues']['RSI'][4] = u'Composition'
    field_information['GGDM 3.0']['SummaryDomainValues']['RSI'][5] = u'Earthen'
    field_information['GGDM 3.0']['SummaryDomainValues']['RSI'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['RTA'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['RTA'][1] = u'Single Arrangement'
    field_information['GGDM 3.0']['SummaryDomainValues']['RTA'][2] = u'Double Arrangement'
    field_information['GGDM 3.0']['SummaryDomainValues']['RTA'][3] = u'Multiple Arrangements'
    field_information['GGDM 3.0']['SummaryDomainValues']['RTA'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['RTT'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['RTT'][2] = u'Recommended Track for Other Than Deep Draft Vessels'
    field_information['GGDM 3.0']['SummaryDomainValues']['RTT'][3] = u'Recommended Track for Deep Draft Vessels'
    field_information['GGDM 3.0']['SummaryDomainValues']['RTT'][4] = u'Deep Water Route'
    field_information['GGDM 3.0']['SummaryDomainValues']['RTT'][5] = u'Transit Route'
    field_information['GGDM 3.0']['SummaryDomainValues']['RTT'][11] = u'Two-way Route'
    field_information['GGDM 3.0']['SummaryDomainValues']['RTT'][13] = u'Recommended Direction of Traffic Flow'
    field_information['GGDM 3.0']['SummaryDomainValues']['RTT'][17] = u'Q-Route'
    field_information['GGDM 3.0']['SummaryDomainValues']['RTT'][18] = u'Recommended Route'
    field_information['GGDM 3.0']['SummaryDomainValues']['RTT'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['RTY'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['RTY'][1] = u'Motorway'
    field_information['GGDM 3.0']['SummaryDomainValues']['RTY'][2] = u'    Limited Access Motorway'
    field_information['GGDM 3.0']['SummaryDomainValues']['RTY'][3] = u'Road'
    field_information['GGDM 3.0']['SummaryDomainValues']['RTY'][4] = u'Street'
    field_information['GGDM 3.0']['SummaryDomainValues']['RTY'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['RWC'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['RWC'][1] = u'High Speed Rail'
    field_information['GGDM 3.0']['SummaryDomainValues']['RWC'][2] = u'Main Line'
    field_information['GGDM 3.0']['SummaryDomainValues']['RWC'][3] = u'Branch-line'
    field_information['GGDM 3.0']['SummaryDomainValues']['RWC'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['SAD'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['SAD'][1000] = u'False'
    field_information['GGDM 3.0']['SummaryDomainValues']['SAD'][1001] = u'True'
    field_information['GGDM 3.0']['SummaryDomainValues']['SBB'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['SBB'][1000] = u'False'
    field_information['GGDM 3.0']['SummaryDomainValues']['SBB'][1001] = u'True'
    field_information['GGDM 3.0']['SummaryDomainValues']['SBC'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['SBC'][1000] = u'False'
    field_information['GGDM 3.0']['SummaryDomainValues']['SBC'][1001] = u'True'
    field_information['GGDM 3.0']['SummaryDomainValues']['SBT'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['SBT'][1] = u'Switched Substation'
    field_information['GGDM 3.0']['SummaryDomainValues']['SBT'][2] = u'Transformer Substation'
    field_information['GGDM 3.0']['SummaryDomainValues']['SBT'][3] = u'Converter Substation'
    field_information['GGDM 3.0']['SummaryDomainValues']['SBT'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['SBT2'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['SBT2'][1] = u'Switched Substation'
    field_information['GGDM 3.0']['SummaryDomainValues']['SBT2'][2] = u'Transformer Substation'
    field_information['GGDM 3.0']['SummaryDomainValues']['SBT2'][3] = u'Converter Substation'
    field_information['GGDM 3.0']['SummaryDomainValues']['SBT2'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['SBT3'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['SBT3'][1] = u'Switched Substation'
    field_information['GGDM 3.0']['SummaryDomainValues']['SBT3'][2] = u'Transformer Substation'
    field_information['GGDM 3.0']['SummaryDomainValues']['SBT3'][3] = u'Converter Substation'
    field_information['GGDM 3.0']['SummaryDomainValues']['SBT3'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['SCOG'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['SCOG'][1] = u'Government Official'
    field_information['GGDM 3.0']['SummaryDomainValues']['SCOG'][2] = u'Non Government'
    field_information['GGDM 3.0']['SummaryDomainValues']['SCOG'][3] = u'Military'
    field_information['GGDM 3.0']['SummaryDomainValues']['SCOG'][4] = u'Educational'
    field_information['GGDM 3.0']['SummaryDomainValues']['SCOG'][998] = u'Not Applicable'
    field_information['GGDM 3.0']['SummaryDomainValues']['SCOG'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['SDCC'][2] = u'Open Interval'
    field_information['GGDM 3.0']['SummaryDomainValues']['SDCC'][3] = u'Greater-than-or-equal to Less-than Interval'
    field_information['GGDM 3.0']['SummaryDomainValues']['SDCC'][4] = u'Greater-than to Less-than-or-equal Interval'
    field_information['GGDM 3.0']['SummaryDomainValues']['SDCC'][5] = u'Closed Interval'
    field_information['GGDM 3.0']['SummaryDomainValues']['SDCC'][6] = u'Greater-than Semi-interval'
    field_information['GGDM 3.0']['SummaryDomainValues']['SDCC'][7] = u'Greater-than or Equal Semi-interval'
    field_information['GGDM 3.0']['SummaryDomainValues']['SDCC'][8] = u'Less-than Semi-interval'
    field_information['GGDM 3.0']['SummaryDomainValues']['SDCC'][9] = u'Less-than or Equal Semi-interval'
    field_information['GGDM 3.0']['SummaryDomainValues']['SDQ'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['SDQ'][1000] = u'False'
    field_information['GGDM 3.0']['SummaryDomainValues']['SDQ'][1001] = u'True'
    field_information['GGDM 3.0']['SummaryDomainValues']['SDSC'][2] = u'Open Interval'
    field_information['GGDM 3.0']['SummaryDomainValues']['SDSC'][3] = u'Greater-than-or-equal to Less-than Interval'
    field_information['GGDM 3.0']['SummaryDomainValues']['SDSC'][4] = u'Greater-than to Less-than-or-equal Interval'
    field_information['GGDM 3.0']['SummaryDomainValues']['SDSC'][5] = u'Closed Interval'
    field_information['GGDM 3.0']['SummaryDomainValues']['SDSC'][6] = u'Greater-than Semi-interval'
    field_information['GGDM 3.0']['SummaryDomainValues']['SDSC'][7] = u'Greater-than or Equal Semi-interval'
    field_information['GGDM 3.0']['SummaryDomainValues']['SDSC'][8] = u'Less-than Semi-interval'
    field_information['GGDM 3.0']['SummaryDomainValues']['SDSC'][9] = u'Less-than or Equal Semi-interval'
    field_information['GGDM 3.0']['SummaryDomainValues']['SDT'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['SDT'][1] = u'Crescent'
    field_information['GGDM 3.0']['SummaryDomainValues']['SDT'][2] = u'Dome'
    field_information['GGDM 3.0']['SummaryDomainValues']['SDT'][3] = u'Transverse'
    field_information['GGDM 3.0']['SummaryDomainValues']['SDT'][4] = u'Linear'
    field_information['GGDM 3.0']['SummaryDomainValues']['SDT'][5] = u'Parabolic'
    field_information['GGDM 3.0']['SummaryDomainValues']['SDT'][6] = u'Ripple'
    field_information['GGDM 3.0']['SummaryDomainValues']['SDT'][7] = u'Star'
    field_information['GGDM 3.0']['SummaryDomainValues']['SDT'][8] = u'Dome and Transverse'
    field_information['GGDM 3.0']['SummaryDomainValues']['SDT'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['SEP'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['SEP'][1000] = u'False'
    field_information['GGDM 3.0']['SummaryDomainValues']['SEP'][1001] = u'True'
    field_information['GGDM 3.0']['SummaryDomainValues']['SERP'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['SERP'][6] = u'Natural'
    field_information['GGDM 3.0']['SummaryDomainValues']['SERP'][7] = u'Permanent'
    field_information['GGDM 3.0']['SummaryDomainValues']['SERP'][8] = u'Temporary'
    field_information['GGDM 3.0']['SummaryDomainValues']['SGCC'][2] = u'Open Interval'
    field_information['GGDM 3.0']['SummaryDomainValues']['SGCC'][3] = u'Greater-than-or-equal to Less-than Interval'
    field_information['GGDM 3.0']['SummaryDomainValues']['SGCC'][4] = u'Greater-than to Less-than-or-equal Interval'
    field_information['GGDM 3.0']['SummaryDomainValues']['SGCC'][5] = u'Closed Interval'
    field_information['GGDM 3.0']['SummaryDomainValues']['SGCC'][6] = u'Greater-than Semi-interval'
    field_information['GGDM 3.0']['SummaryDomainValues']['SGCC'][7] = u'Greater-than or Equal Semi-interval'
    field_information['GGDM 3.0']['SummaryDomainValues']['SGCC'][8] = u'Less-than Semi-interval'
    field_information['GGDM 3.0']['SummaryDomainValues']['SGCC'][9] = u'Less-than or Equal Semi-interval'
    field_information['GGDM 3.0']['SummaryDomainValues']['SHD'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['SHD'][1000] = u'False'
    field_information['GGDM 3.0']['SummaryDomainValues']['SHD'][1001] = u'True'
    field_information['GGDM 3.0']['SummaryDomainValues']['SHO'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['SHO'][1] = u'Hillocks'
    field_information['GGDM 3.0']['SummaryDomainValues']['SHO'][2] = u'Flat Coast'
    field_information['GGDM 3.0']['SummaryDomainValues']['SHO'][7] = u'Glacier'
    field_information['GGDM 3.0']['SummaryDomainValues']['SHO'][8] = u'Ice Coast'
    field_information['GGDM 3.0']['SummaryDomainValues']['SHO'][9] = u'Steep Coast'
    field_information['GGDM 3.0']['SummaryDomainValues']['SHO'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['SHT'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['SHT'][1] = u'Deliverable Container'
    field_information['GGDM 3.0']['SummaryDomainValues']['SHT'][2] = u'Dumpster'
    field_information['GGDM 3.0']['SummaryDomainValues']['SHT'][3] = u'ISO Container'
    field_information['GGDM 3.0']['SummaryDomainValues']['SHT'][4] = u'Roll-off Dumpster'
    field_information['GGDM 3.0']['SummaryDomainValues']['SHT'][5] = u'Tank Container'
    field_information['GGDM 3.0']['SummaryDomainValues']['SHT'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['SIC'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['SIC'][1] = u'Snowfield'
    field_information['GGDM 3.0']['SummaryDomainValues']['SIC'][2] = u'Ice-field'
    field_information['GGDM 3.0']['SummaryDomainValues']['SLR'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['SLR'][1] = u'Log Ramp'
    field_information['GGDM 3.0']['SummaryDomainValues']['SLR'][2] = u'Marine Ramp'
    field_information['GGDM 3.0']['SummaryDomainValues']['SLR'][3] = u'Slipway'
    field_information['GGDM 3.0']['SummaryDomainValues']['SLR'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['SLT'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['SLT'][6] = u'Mangrove'
    field_information['GGDM 3.0']['SummaryDomainValues']['SLT'][8] = u'Marshy'
    field_information['GGDM 3.0']['SummaryDomainValues']['SLT'][10] = u'Stony'
    field_information['GGDM 3.0']['SummaryDomainValues']['SLT'][11] = u'Building Rubble'
    field_information['GGDM 3.0']['SummaryDomainValues']['SLT'][12] = u'Erosion Rubble'
    field_information['GGDM 3.0']['SummaryDomainValues']['SLT'][13] = u'Sandy'
    field_information['GGDM 3.0']['SummaryDomainValues']['SLT'][14] = u'Shingly'
    field_information['GGDM 3.0']['SummaryDomainValues']['SLT'][16] = u'Coral'
    field_information['GGDM 3.0']['SummaryDomainValues']['SLT'][17] = u'Ice'
    field_information['GGDM 3.0']['SummaryDomainValues']['SLT'][18] = u'Mud'
    field_information['GGDM 3.0']['SummaryDomainValues']['SLT'][998] = u'Not Applicable'
    field_information['GGDM 3.0']['SummaryDomainValues']['SLT'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['SNDC'][2] = u'Open Interval'
    field_information['GGDM 3.0']['SummaryDomainValues']['SNDC'][3] = u'Greater-than-or-equal to Less-than Interval'
    field_information['GGDM 3.0']['SummaryDomainValues']['SNDC'][4] = u'Greater-than to Less-than-or-equal Interval'
    field_information['GGDM 3.0']['SummaryDomainValues']['SNDC'][5] = u'Closed Interval'
    field_information['GGDM 3.0']['SummaryDomainValues']['SNDC'][6] = u'Greater-than Semi-interval'
    field_information['GGDM 3.0']['SummaryDomainValues']['SNDC'][7] = u'Greater-than or Equal Semi-interval'
    field_information['GGDM 3.0']['SummaryDomainValues']['SNDC'][8] = u'Less-than Semi-interval'
    field_information['GGDM 3.0']['SummaryDomainValues']['SNDC'][9] = u'Less-than or Equal Semi-interval'
    field_information['GGDM 3.0']['SummaryDomainValues']['SPT'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['SPT'][1000] = u'False'
    field_information['GGDM 3.0']['SummaryDomainValues']['SPT'][1001] = u'True'
    field_information['GGDM 3.0']['SummaryDomainValues']['SRD'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['SRD'][1] = u'No Effect'
    field_information['GGDM 3.0']['SummaryDomainValues']['SRD'][2] = u'Landslide Potential'
    field_information['GGDM 3.0']['SummaryDomainValues']['SRD'][11] = u'Numerous Cobbles and Boulders'
    field_information['GGDM 3.0']['SummaryDomainValues']['SRD'][12] = u'Stony Areas'
    field_information['GGDM 3.0']['SummaryDomainValues']['SRD'][13] = u'Stony Soil with Surface Rock'
    field_information['GGDM 3.0']['SummaryDomainValues']['SRD'][14] = u'Stony Soil with scattered Boulders'
    field_information['GGDM 3.0']['SummaryDomainValues']['SRD'][15] = u'Stony Soil with numerous Boulders'
    field_information['GGDM 3.0']['SummaryDomainValues']['SRD'][16] = u'Numerous Boulders'
    field_information['GGDM 3.0']['SummaryDomainValues']['SRD'][17] = u'Numerous Rock Outcrops'
    field_information['GGDM 3.0']['SummaryDomainValues']['SRD'][18] = u'Scattered Boulders'
    field_information['GGDM 3.0']['SummaryDomainValues']['SRD'][19] = u'Talus'
    field_information['GGDM 3.0']['SummaryDomainValues']['SRD'][20] = u'Boulder Field'
    field_information['GGDM 3.0']['SummaryDomainValues']['SRD'][31] = u'Highly Fractured Rock'
    field_information['GGDM 3.0']['SummaryDomainValues']['SRD'][32] = u'Weathered Lava'
    field_information['GGDM 3.0']['SummaryDomainValues']['SRD'][33] = u'Unweathered Lava'
    field_information['GGDM 3.0']['SummaryDomainValues']['SRD'][34] = u'Stony Soil with numerous Rock Outcrops'
    field_information['GGDM 3.0']['SummaryDomainValues']['SRD'][35] = u'Irregular with deep Foliation Fractures'
    field_information['GGDM 3.0']['SummaryDomainValues']['SRD'][36] = u'Rugged with numerous Rock Outcrops'
    field_information['GGDM 3.0']['SummaryDomainValues']['SRD'][37] = u'Rugged Bedrock'
    field_information['GGDM 3.0']['SummaryDomainValues']['SRD'][43] = u'Highly Distorted with sharp Rocky Ridges'
    field_information['GGDM 3.0']['SummaryDomainValues']['SRD'][51] = u'Stony Soil with numerous Gullies'
    field_information['GGDM 3.0']['SummaryDomainValues']['SRD'][52] = u'Moderately Dissected'
    field_information['GGDM 3.0']['SummaryDomainValues']['SRD'][53] = u'Moderately Dissected with scattered Rock Outcrops'
    field_information['GGDM 3.0']['SummaryDomainValues']['SRD'][54] = u'Dissected Floodplain'
    field_information['GGDM 3.0']['SummaryDomainValues']['SRD'][55] = u'Highly Dissected'
    field_information['GGDM 3.0']['SummaryDomainValues']['SRD'][56] = u'Deep Erosional Gullies'
    field_information['GGDM 3.0']['SummaryDomainValues']['SRD'][57] = u'Steep Rugged Dissected with narrow Gullies'
    field_information['GGDM 3.0']['SummaryDomainValues']['SRD'][58] = u'Karst with numerous Sinkholes and Solution Valleys'
    field_information['GGDM 3.0']['SummaryDomainValues']['SRD'][59] = u'Karst with numerous Sinkholes'
    field_information['GGDM 3.0']['SummaryDomainValues']['SRD'][60] = u'Hummocky Karst with Large Hills'
    field_information['GGDM 3.0']['SummaryDomainValues']['SRD'][61] = u'Hummocky Karst with Low Mounds'
    field_information['GGDM 3.0']['SummaryDomainValues']['SRD'][63] = u'Playa'
    field_information['GGDM 3.0']['SummaryDomainValues']['SRD'][64] = u'Meander Scars and Lakes'
    field_information['GGDM 3.0']['SummaryDomainValues']['SRD'][65] = u'Solifluction Lobes and Frost Scars'
    field_information['GGDM 3.0']['SummaryDomainValues']['SRD'][66] = u'Hummocky with Frost Heaves'
    field_information['GGDM 3.0']['SummaryDomainValues']['SRD'][67] = u'Frost Polygons'
    field_information['GGDM 3.0']['SummaryDomainValues']['SRD'][69] = u'Numerous Small Lakes and Ponds'
    field_information['GGDM 3.0']['SummaryDomainValues']['SRD'][70] = u'Numerous Crevasses'
    field_information['GGDM 3.0']['SummaryDomainValues']['SRD'][81] = u'Numerous Terraces'
    field_information['GGDM 3.0']['SummaryDomainValues']['SRD'][86] = u'Mine Tailing(s)'
    field_information['GGDM 3.0']['SummaryDomainValues']['SRD'][88] = u'Numerous Dykes'
    field_information['GGDM 3.0']['SummaryDomainValues']['SRD'][89] = u'Numerous Dyked Fields'
    field_information['GGDM 3.0']['SummaryDomainValues']['SRD'][90] = u'Numerous Fences'
    field_information['GGDM 3.0']['SummaryDomainValues']['SRD'][91] = u'Numerous Stone Walls'
    field_information['GGDM 3.0']['SummaryDomainValues']['SRD'][92] = u'Numerous Man-made Drainage'
    field_information['GGDM 3.0']['SummaryDomainValues']['SRD'][93] = u'Numerous Terraced Fields'
    field_information['GGDM 3.0']['SummaryDomainValues']['SRD'][94] = u'Parallel Earthen Rows'
    field_information['GGDM 3.0']['SummaryDomainValues']['SRD'][95] = u'Numerous Hedgerows'
    field_information['GGDM 3.0']['SummaryDomainValues']['SRD'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['SRE'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['SRE'][1] = u'Railway Switch'
    field_information['GGDM 3.0']['SummaryDomainValues']['SRE'][2] = u'Reduced Track or Lane Count'
    field_information['GGDM 3.0']['SummaryDomainValues']['SRE'][3] = u'Road Interchange'
    field_information['GGDM 3.0']['SummaryDomainValues']['SRE'][8] = u'Sharp Curves'
    field_information['GGDM 3.0']['SummaryDomainValues']['SRE'][9] = u'Steep Grades'
    field_information['GGDM 3.0']['SummaryDomainValues']['SRE'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['SRL'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['SRL'][1] = u'Offshore'
    field_information['GGDM 3.0']['SummaryDomainValues']['SRL'][2] = u'Inland'
    field_information['GGDM 3.0']['SummaryDomainValues']['SRL'][3] = u'At Shoreline'
    field_information['GGDM 3.0']['SummaryDomainValues']['SSC'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['SSC'][2] = u'Horizontal Capped Cylindrical'
    field_information['GGDM 3.0']['SummaryDomainValues']['SSC'][4] = u'Vertical Capped Cylindrical'
    field_information['GGDM 3.0']['SummaryDomainValues']['SSC'][12] = u'Pyramidal'
    field_information['GGDM 3.0']['SummaryDomainValues']['SSC'][17] = u'Spherical'
    field_information['GGDM 3.0']['SummaryDomainValues']['SSC'][59] = u'Cylindrical with Framework'
    field_information['GGDM 3.0']['SummaryDomainValues']['SSC'][65] = u'Cylindrical with Flat Top'
    field_information['GGDM 3.0']['SummaryDomainValues']['SSC'][66] = u'Cylindrical with Domed Top'
    field_information['GGDM 3.0']['SummaryDomainValues']['SSC'][71] = u'Cylindrical with Conical Top'
    field_information['GGDM 3.0']['SummaryDomainValues']['SSC'][77] = u'Arched'
    field_information['GGDM 3.0']['SummaryDomainValues']['SSC'][78] = u'Multiple Arched'
    field_information['GGDM 3.0']['SummaryDomainValues']['SSC'][87] = u'Domed'
    field_information['GGDM 3.0']['SummaryDomainValues']['SSC'][88] = u'Spherical on Column'
    field_information['GGDM 3.0']['SummaryDomainValues']['SSC'][89] = u'Cylindrical on Tower'
    field_information['GGDM 3.0']['SummaryDomainValues']['SSC'][91] = u'Vertical Cylindrical'
    field_information['GGDM 3.0']['SummaryDomainValues']['SSC'][92] = u'Cubic'
    field_information['GGDM 3.0']['SummaryDomainValues']['SSC'][94] = u'Board-like Prism'
    field_information['GGDM 3.0']['SummaryDomainValues']['SSC'][95] = u'Columnar'
    field_information['GGDM 3.0']['SummaryDomainValues']['SSC'][96] = u'Plaque'
    field_information['GGDM 3.0']['SummaryDomainValues']['SSC'][97] = u'Statue'
    field_information['GGDM 3.0']['SummaryDomainValues']['SSC'][98] = u'Cross'
    field_information['GGDM 3.0']['SummaryDomainValues']['SSC'][99] = u'Horizontal Cylindrical'
    field_information['GGDM 3.0']['SummaryDomainValues']['SSC'][100] = u'Rectangular Prism'
    field_information['GGDM 3.0']['SummaryDomainValues']['SSC'][101] = u'Square Prism'
    field_information['GGDM 3.0']['SummaryDomainValues']['SSC'][109] = u'Obelisk'
    field_information['GGDM 3.0']['SummaryDomainValues']['SSC'][112] = u'Statue on Pedestal'
    field_information['GGDM 3.0']['SummaryDomainValues']['SSC'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['SSG'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['SSG'][1] = u'Direction'
    field_information['GGDM 3.0']['SummaryDomainValues']['SSG'][2] = u'Electronic Message'
    field_information['GGDM 3.0']['SummaryDomainValues']['SSG'][3] = u'General Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['SSG'][4] = u'Mandatory Regulation'
    field_information['GGDM 3.0']['SummaryDomainValues']['SSG'][5] = u'Place Identification'
    field_information['GGDM 3.0']['SummaryDomainValues']['SSG'][6] = u'Prohibited or Restricted Activity'
    field_information['GGDM 3.0']['SummaryDomainValues']['SSG'][7] = u'Road Identification'
    field_information['GGDM 3.0']['SummaryDomainValues']['SSG'][8] = u'Route Marker'
    field_information['GGDM 3.0']['SummaryDomainValues']['SSG'][9] = u'Traffic Control'
    field_information['GGDM 3.0']['SummaryDomainValues']['SSG'][10] = u'Warning'
    field_information['GGDM 3.0']['SummaryDomainValues']['SSG'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['SSR'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['SSR'][6] = u'Conical'
    field_information['GGDM 3.0']['SummaryDomainValues']['SSR'][7] = u'Pyramidal'
    field_information['GGDM 3.0']['SummaryDomainValues']['SSR'][38] = u'Semi-cylindrical'
    field_information['GGDM 3.0']['SummaryDomainValues']['SSR'][40] = u'Domed'
    field_information['GGDM 3.0']['SummaryDomainValues']['SSR'][41] = u'Flat'
    field_information['GGDM 3.0']['SummaryDomainValues']['SSR'][42] = u'Pitched'
    field_information['GGDM 3.0']['SummaryDomainValues']['SSR'][47] = u'Sawtoothed'
    field_information['GGDM 3.0']['SummaryDomainValues']['SSR'][50] = u'With Clerestory'
    field_information['GGDM 3.0']['SummaryDomainValues']['SSR'][55] = u'Flat with Clerestory'
    field_information['GGDM 3.0']['SummaryDomainValues']['SSR'][64] = u'Pitched with Clerestory'
    field_information['GGDM 3.0']['SummaryDomainValues']['SSR'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['SSR2'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['SSR2'][6] = u'Conical'
    field_information['GGDM 3.0']['SummaryDomainValues']['SSR2'][7] = u'Pyramidal'
    field_information['GGDM 3.0']['SummaryDomainValues']['SSR2'][38] = u'Semi-cylindrical'
    field_information['GGDM 3.0']['SummaryDomainValues']['SSR2'][40] = u'Domed'
    field_information['GGDM 3.0']['SummaryDomainValues']['SSR2'][41] = u'Flat'
    field_information['GGDM 3.0']['SummaryDomainValues']['SSR2'][42] = u'Pitched'
    field_information['GGDM 3.0']['SummaryDomainValues']['SSR2'][47] = u'Sawtoothed'
    field_information['GGDM 3.0']['SummaryDomainValues']['SSR2'][50] = u'With Clerestory'
    field_information['GGDM 3.0']['SummaryDomainValues']['SSR2'][55] = u'Flat with Clerestory'
    field_information['GGDM 3.0']['SummaryDomainValues']['SSR2'][64] = u'Pitched with Clerestory'
    field_information['GGDM 3.0']['SummaryDomainValues']['SSR2'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['SSR3'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['SSR3'][6] = u'Conical'
    field_information['GGDM 3.0']['SummaryDomainValues']['SSR3'][7] = u'Pyramidal'
    field_information['GGDM 3.0']['SummaryDomainValues']['SSR3'][38] = u'Semi-cylindrical'
    field_information['GGDM 3.0']['SummaryDomainValues']['SSR3'][40] = u'Domed'
    field_information['GGDM 3.0']['SummaryDomainValues']['SSR3'][41] = u'Flat'
    field_information['GGDM 3.0']['SummaryDomainValues']['SSR3'][42] = u'Pitched'
    field_information['GGDM 3.0']['SummaryDomainValues']['SSR3'][47] = u'Sawtoothed'
    field_information['GGDM 3.0']['SummaryDomainValues']['SSR3'][50] = u'With Clerestory'
    field_information['GGDM 3.0']['SummaryDomainValues']['SSR3'][55] = u'Flat with Clerestory'
    field_information['GGDM 3.0']['SummaryDomainValues']['SSR3'][64] = u'Pitched with Clerestory'
    field_information['GGDM 3.0']['SummaryDomainValues']['SSR3'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['STA'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['STA'][1] = u'Coast Guard Station'
    field_information['GGDM 3.0']['SummaryDomainValues']['STA'][2] = u'Fireboat Station'
    field_information['GGDM 3.0']['SummaryDomainValues']['STA'][3] = u'Water-police Station'
    field_information['GGDM 3.0']['SummaryDomainValues']['STA'][4] = u'Ice Signal Station'
    field_information['GGDM 3.0']['SummaryDomainValues']['STA'][5] = u'Rescue Station'
    field_information['GGDM 3.0']['SummaryDomainValues']['STA'][6] = u'Port Control Station'
    field_information['GGDM 3.0']['SummaryDomainValues']['STA'][11] = u'Pilot Station'
    field_information['GGDM 3.0']['SummaryDomainValues']['STA'][13] = u'Signal Station'
    field_information['GGDM 3.0']['SummaryDomainValues']['STA'][14] = u'Signal Mast'
    field_information['GGDM 3.0']['SummaryDomainValues']['STA'][15] = u'Storm Signal Station'
    field_information['GGDM 3.0']['SummaryDomainValues']['STA'][17] = u'Tide Station'
    field_information['GGDM 3.0']['SummaryDomainValues']['STA'][18] = u'Time Ball Station'
    field_information['GGDM 3.0']['SummaryDomainValues']['STA'][19] = u'Time Signal Station'
    field_information['GGDM 3.0']['SummaryDomainValues']['STA'][20] = u'Unmanned Oceanographic Station'
    field_information['GGDM 3.0']['SummaryDomainValues']['STA'][21] = u'Weather Signal Station'
    field_information['GGDM 3.0']['SummaryDomainValues']['STA'][22] = u'Fog Signal'
    field_information['GGDM 3.0']['SummaryDomainValues']['STA'][27] = u'Tidal Stream Station'
    field_information['GGDM 3.0']['SummaryDomainValues']['STA'][28] = u'Traffic Signal Station'
    field_information['GGDM 3.0']['SummaryDomainValues']['STA'][29] = u'Bridge Signal Station'
    field_information['GGDM 3.0']['SummaryDomainValues']['STA'][30] = u'Lock Signal Station'
    field_information['GGDM 3.0']['SummaryDomainValues']['STA'][32] = u'International Port Signals Station'
    field_information['GGDM 3.0']['SummaryDomainValues']['STA'][33] = u'Military Practice Signal Station'
    field_information['GGDM 3.0']['SummaryDomainValues']['STA'][35] = u'Warning Signal Station'
    field_information['GGDM 3.0']['SummaryDomainValues']['STA'][36] = u'Radar Surveillance Station'
    field_information['GGDM 3.0']['SummaryDomainValues']['STA'][37] = u'Pilot Lookout Station'
    field_information['GGDM 3.0']['SummaryDomainValues']['STA'][48] = u'Semaphore Station'
    field_information['GGDM 3.0']['SummaryDomainValues']['STA'][49] = u'Berthing Control Station'
    field_information['GGDM 3.0']['SummaryDomainValues']['STA'][50] = u'Cable Warning Station'
    field_information['GGDM 3.0']['SummaryDomainValues']['STA'][51] = u'Clock Station'
    field_information['GGDM 3.0']['SummaryDomainValues']['STA'][52] = u'Danger Warning Station'
    field_information['GGDM 3.0']['SummaryDomainValues']['STA'][53] = u'Distress Warning Station'
    field_information['GGDM 3.0']['SummaryDomainValues']['STA'][54] = u'Diving Warning Station'
    field_information['GGDM 3.0']['SummaryDomainValues']['STA'][55] = u'Dock Control Station'
    field_information['GGDM 3.0']['SummaryDomainValues']['STA'][56] = u'Dredging Operations Station'
    field_information['GGDM 3.0']['SummaryDomainValues']['STA'][57] = u'Flood Barrage Control Station'
    field_information['GGDM 3.0']['SummaryDomainValues']['STA'][58] = u'Maritime Obstruction Warning Station'
    field_information['GGDM 3.0']['SummaryDomainValues']['STA'][59] = u'Port Entry and Departure Control Station'
    field_information['GGDM 3.0']['SummaryDomainValues']['STA'][60] = u'Tide Scale Station'
    field_information['GGDM 3.0']['SummaryDomainValues']['STA'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['STA2'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['STA2'][1] = u'Coast Guard Station'
    field_information['GGDM 3.0']['SummaryDomainValues']['STA2'][2] = u'Fireboat Station'
    field_information['GGDM 3.0']['SummaryDomainValues']['STA2'][3] = u'Water-police Station'
    field_information['GGDM 3.0']['SummaryDomainValues']['STA2'][4] = u'Ice Signal Station'
    field_information['GGDM 3.0']['SummaryDomainValues']['STA2'][5] = u'Rescue Station'
    field_information['GGDM 3.0']['SummaryDomainValues']['STA2'][6] = u'Port Control Station'
    field_information['GGDM 3.0']['SummaryDomainValues']['STA2'][11] = u'Pilot Station'
    field_information['GGDM 3.0']['SummaryDomainValues']['STA2'][13] = u'Signal Station'
    field_information['GGDM 3.0']['SummaryDomainValues']['STA2'][14] = u'Signal Mast'
    field_information['GGDM 3.0']['SummaryDomainValues']['STA2'][15] = u'Storm Signal Station'
    field_information['GGDM 3.0']['SummaryDomainValues']['STA2'][17] = u'Tide Station'
    field_information['GGDM 3.0']['SummaryDomainValues']['STA2'][18] = u'Time Ball Station'
    field_information['GGDM 3.0']['SummaryDomainValues']['STA2'][19] = u'Time Signal Station'
    field_information['GGDM 3.0']['SummaryDomainValues']['STA2'][20] = u'Unmanned Oceanographic Station'
    field_information['GGDM 3.0']['SummaryDomainValues']['STA2'][21] = u'Weather Signal Station'
    field_information['GGDM 3.0']['SummaryDomainValues']['STA2'][22] = u'Fog Signal'
    field_information['GGDM 3.0']['SummaryDomainValues']['STA2'][27] = u'Tidal Stream Station'
    field_information['GGDM 3.0']['SummaryDomainValues']['STA2'][28] = u'Traffic Signal Station'
    field_information['GGDM 3.0']['SummaryDomainValues']['STA2'][29] = u'Bridge Signal Station'
    field_information['GGDM 3.0']['SummaryDomainValues']['STA2'][30] = u'Lock Signal Station'
    field_information['GGDM 3.0']['SummaryDomainValues']['STA2'][32] = u'International Port Signals Station'
    field_information['GGDM 3.0']['SummaryDomainValues']['STA2'][33] = u'Military Practice Signal Station'
    field_information['GGDM 3.0']['SummaryDomainValues']['STA2'][35] = u'Warning Signal Station'
    field_information['GGDM 3.0']['SummaryDomainValues']['STA2'][36] = u'Radar Surveillance Station'
    field_information['GGDM 3.0']['SummaryDomainValues']['STA2'][37] = u'Pilot Lookout Station'
    field_information['GGDM 3.0']['SummaryDomainValues']['STA2'][48] = u'Semaphore Station'
    field_information['GGDM 3.0']['SummaryDomainValues']['STA2'][49] = u'Berthing Control Station'
    field_information['GGDM 3.0']['SummaryDomainValues']['STA2'][50] = u'Cable Warning Station'
    field_information['GGDM 3.0']['SummaryDomainValues']['STA2'][51] = u'Clock Station'
    field_information['GGDM 3.0']['SummaryDomainValues']['STA2'][52] = u'Danger Warning Station'
    field_information['GGDM 3.0']['SummaryDomainValues']['STA2'][53] = u'Distress Warning Station'
    field_information['GGDM 3.0']['SummaryDomainValues']['STA2'][54] = u'Diving Warning Station'
    field_information['GGDM 3.0']['SummaryDomainValues']['STA2'][55] = u'Dock Control Station'
    field_information['GGDM 3.0']['SummaryDomainValues']['STA2'][56] = u'Dredging Operations Station'
    field_information['GGDM 3.0']['SummaryDomainValues']['STA2'][57] = u'Flood Barrage Control Station'
    field_information['GGDM 3.0']['SummaryDomainValues']['STA2'][58] = u'Maritime Obstruction Warning Station'
    field_information['GGDM 3.0']['SummaryDomainValues']['STA2'][59] = u'Port Entry and Departure Control Station'
    field_information['GGDM 3.0']['SummaryDomainValues']['STA2'][60] = u'Tide Scale Station'
    field_information['GGDM 3.0']['SummaryDomainValues']['STA2'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['STA3'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['STA3'][1] = u'Coast Guard Station'
    field_information['GGDM 3.0']['SummaryDomainValues']['STA3'][2] = u'Fireboat Station'
    field_information['GGDM 3.0']['SummaryDomainValues']['STA3'][3] = u'Water-police Station'
    field_information['GGDM 3.0']['SummaryDomainValues']['STA3'][4] = u'Ice Signal Station'
    field_information['GGDM 3.0']['SummaryDomainValues']['STA3'][5] = u'Rescue Station'
    field_information['GGDM 3.0']['SummaryDomainValues']['STA3'][6] = u'Port Control Station'
    field_information['GGDM 3.0']['SummaryDomainValues']['STA3'][11] = u'Pilot Station'
    field_information['GGDM 3.0']['SummaryDomainValues']['STA3'][13] = u'Signal Station'
    field_information['GGDM 3.0']['SummaryDomainValues']['STA3'][14] = u'Signal Mast'
    field_information['GGDM 3.0']['SummaryDomainValues']['STA3'][15] = u'Storm Signal Station'
    field_information['GGDM 3.0']['SummaryDomainValues']['STA3'][17] = u'Tide Station'
    field_information['GGDM 3.0']['SummaryDomainValues']['STA3'][18] = u'Time Ball Station'
    field_information['GGDM 3.0']['SummaryDomainValues']['STA3'][19] = u'Time Signal Station'
    field_information['GGDM 3.0']['SummaryDomainValues']['STA3'][20] = u'Unmanned Oceanographic Station'
    field_information['GGDM 3.0']['SummaryDomainValues']['STA3'][21] = u'Weather Signal Station'
    field_information['GGDM 3.0']['SummaryDomainValues']['STA3'][22] = u'Fog Signal'
    field_information['GGDM 3.0']['SummaryDomainValues']['STA3'][27] = u'Tidal Stream Station'
    field_information['GGDM 3.0']['SummaryDomainValues']['STA3'][28] = u'Traffic Signal Station'
    field_information['GGDM 3.0']['SummaryDomainValues']['STA3'][29] = u'Bridge Signal Station'
    field_information['GGDM 3.0']['SummaryDomainValues']['STA3'][30] = u'Lock Signal Station'
    field_information['GGDM 3.0']['SummaryDomainValues']['STA3'][32] = u'International Port Signals Station'
    field_information['GGDM 3.0']['SummaryDomainValues']['STA3'][33] = u'Military Practice Signal Station'
    field_information['GGDM 3.0']['SummaryDomainValues']['STA3'][35] = u'Warning Signal Station'
    field_information['GGDM 3.0']['SummaryDomainValues']['STA3'][36] = u'Radar Surveillance Station'
    field_information['GGDM 3.0']['SummaryDomainValues']['STA3'][37] = u'Pilot Lookout Station'
    field_information['GGDM 3.0']['SummaryDomainValues']['STA3'][48] = u'Semaphore Station'
    field_information['GGDM 3.0']['SummaryDomainValues']['STA3'][49] = u'Berthing Control Station'
    field_information['GGDM 3.0']['SummaryDomainValues']['STA3'][50] = u'Cable Warning Station'
    field_information['GGDM 3.0']['SummaryDomainValues']['STA3'][51] = u'Clock Station'
    field_information['GGDM 3.0']['SummaryDomainValues']['STA3'][52] = u'Danger Warning Station'
    field_information['GGDM 3.0']['SummaryDomainValues']['STA3'][53] = u'Distress Warning Station'
    field_information['GGDM 3.0']['SummaryDomainValues']['STA3'][54] = u'Diving Warning Station'
    field_information['GGDM 3.0']['SummaryDomainValues']['STA3'][55] = u'Dock Control Station'
    field_information['GGDM 3.0']['SummaryDomainValues']['STA3'][56] = u'Dredging Operations Station'
    field_information['GGDM 3.0']['SummaryDomainValues']['STA3'][57] = u'Flood Barrage Control Station'
    field_information['GGDM 3.0']['SummaryDomainValues']['STA3'][58] = u'Maritime Obstruction Warning Station'
    field_information['GGDM 3.0']['SummaryDomainValues']['STA3'][59] = u'Port Entry and Departure Control Station'
    field_information['GGDM 3.0']['SummaryDomainValues']['STA3'][60] = u'Tide Scale Station'
    field_information['GGDM 3.0']['SummaryDomainValues']['STA3'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['STL'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['STL'][1] = u'Winter'
    field_information['GGDM 3.0']['SummaryDomainValues']['STL'][2] = u'Summer'
    field_information['GGDM 3.0']['SummaryDomainValues']['STL'][3] = u'Spring'
    field_information['GGDM 3.0']['SummaryDomainValues']['STL'][4] = u'Autumn'
    field_information['GGDM 3.0']['SummaryDomainValues']['STL'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['STL2'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['STL2'][1] = u'Winter'
    field_information['GGDM 3.0']['SummaryDomainValues']['STL2'][2] = u'Summer'
    field_information['GGDM 3.0']['SummaryDomainValues']['STL2'][3] = u'Spring'
    field_information['GGDM 3.0']['SummaryDomainValues']['STL2'][4] = u'Autumn'
    field_information['GGDM 3.0']['SummaryDomainValues']['STL2'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['STL3'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['STL3'][1] = u'Winter'
    field_information['GGDM 3.0']['SummaryDomainValues']['STL3'][2] = u'Summer'
    field_information['GGDM 3.0']['SummaryDomainValues']['STL3'][3] = u'Spring'
    field_information['GGDM 3.0']['SummaryDomainValues']['STL3'][4] = u'Autumn'
    field_information['GGDM 3.0']['SummaryDomainValues']['STL3'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['STP'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['STP'][1] = u'GW: Well-graded Gravel'
    field_information['GGDM 3.0']['SummaryDomainValues']['STP'][2] = u'GP: Poorly-graded Gravel'
    field_information['GGDM 3.0']['SummaryDomainValues']['STP'][3] = u'GM: Silty Gravel Sand'
    field_information['GGDM 3.0']['SummaryDomainValues']['STP'][4] = u'GC: Clayey Gravel'
    field_information['GGDM 3.0']['SummaryDomainValues']['STP'][5] = u'SW: Well-graded Sand'
    field_information['GGDM 3.0']['SummaryDomainValues']['STP'][6] = u'SP: Poorly-graded Sand'
    field_information['GGDM 3.0']['SummaryDomainValues']['STP'][7] = u'SM: Silty Sand'
    field_information['GGDM 3.0']['SummaryDomainValues']['STP'][8] = u'SC: Clayey Sand'
    field_information['GGDM 3.0']['SummaryDomainValues']['STP'][9] = u'ML: Silt and Fine Sand'
    field_information['GGDM 3.0']['SummaryDomainValues']['STP'][10] = u'CL: Lean Clay'
    field_information['GGDM 3.0']['SummaryDomainValues']['STP'][11] = u'OL: Organic Silt and Clay'
    field_information['GGDM 3.0']['SummaryDomainValues']['STP'][12] = u'CH: Fat Clay'
    field_information['GGDM 3.0']['SummaryDomainValues']['STP'][13] = u'MH: Micraceous'
    field_information['GGDM 3.0']['SummaryDomainValues']['STP'][14] = u'OH: Organic Clay'
    field_information['GGDM 3.0']['SummaryDomainValues']['STP'][15] = u'PT: Peat'
    field_information['GGDM 3.0']['SummaryDomainValues']['STP'][17] = u'ML-CL: Silt, Fine Sand and Lean Clay'
    field_information['GGDM 3.0']['SummaryDomainValues']['STP'][18] = u'Evaporite'
    field_information['GGDM 3.0']['SummaryDomainValues']['STP'][99] = u'Not Evaluated'
    field_information['GGDM 3.0']['SummaryDomainValues']['STP'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['SUY'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['SUY'][1] = u'Astronomic Position'
    field_information['GGDM 3.0']['SummaryDomainValues']['SUY'][2] = u'Benchmark'
    field_information['GGDM 3.0']['SummaryDomainValues']['SUY'][3] = u'Cadastral Control Point'
    field_information['GGDM 3.0']['SummaryDomainValues']['SUY'][4] = u'Camera Station'
    field_information['GGDM 3.0']['SummaryDomainValues']['SUY'][5] = u'Geodetic Point'
    field_information['GGDM 3.0']['SummaryDomainValues']['SUY'][6] = u'Gravity Point'
    field_information['GGDM 3.0']['SummaryDomainValues']['SUY'][7] = u'Magnetic Station'
    field_information['GGDM 3.0']['SummaryDomainValues']['SUY'][8] = u'Theodolite Station'
    field_information['GGDM 3.0']['SummaryDomainValues']['SUY'][9] = u'Tidal Benchmark'
    field_information['GGDM 3.0']['SummaryDomainValues']['SUY'][10] = u'Transit Station'
    field_information['GGDM 3.0']['SummaryDomainValues']['SUY'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['SWC'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['SWC'][1] = u'Normally Dry'
    field_information['GGDM 3.0']['SummaryDomainValues']['SWC'][2] = u'Normally Moist'
    field_information['GGDM 3.0']['SummaryDomainValues']['SWC'][3] = u'Normally Wet'
    field_information['GGDM 3.0']['SummaryDomainValues']['SWC'][4] = u'Normally Frozen'
    field_information['GGDM 3.0']['SummaryDomainValues']['SWT'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['SWT'][4] = u'Spring'
    field_information['GGDM 3.0']['SummaryDomainValues']['SWT'][6] = u'Walled-in Spring'
    field_information['GGDM 3.0']['SummaryDomainValues']['SWT'][7] = u'Resurgence'
    field_information['GGDM 3.0']['SummaryDomainValues']['SWT'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['TCS'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['TCS'][1] = u'Arch'
    field_information['GGDM 3.0']['SummaryDomainValues']['TCS'][2] = u'Box'
    field_information['GGDM 3.0']['SummaryDomainValues']['TCS'][3] = u'Semicircular'
    field_information['GGDM 3.0']['SummaryDomainValues']['TCS'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['TEL'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['TEL'][1] = u'Optical'
    field_information['GGDM 3.0']['SummaryDomainValues']['TEL'][2] = u'Parabolic Radio Aerial'
    field_information['GGDM 3.0']['SummaryDomainValues']['TEL'][3] = u'Radio Aerial Array'
    field_information['GGDM 3.0']['SummaryDomainValues']['TEL'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['THR'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['THR'][1000] = u'False'
    field_information['GGDM 3.0']['SummaryDomainValues']['THR'][1001] = u'True'
    field_information['GGDM 3.0']['SummaryDomainValues']['TID'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['TID'][1000] = u'False'
    field_information['GGDM 3.0']['SummaryDomainValues']['TID'][1001] = u'True'
    field_information['GGDM 3.0']['SummaryDomainValues']['TOS'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['TOS'][1] = u'A\' Frame'
    field_information['GGDM 3.0']['SummaryDomainValues']['TOS'][2] = u'H\' Frame'
    field_information['GGDM 3.0']['SummaryDomainValues']['TOS'][3] = u'I\' Frame'
    field_information['GGDM 3.0']['SummaryDomainValues']['TOS'][5] = u'Y\' Frame'
    field_information['GGDM 3.0']['SummaryDomainValues']['TOS'][6] = u'Mast'
    field_information['GGDM 3.0']['SummaryDomainValues']['TOS'][8] = u'Pole'
    field_information['GGDM 3.0']['SummaryDomainValues']['TOS'][11] = u'Tripod'
    field_information['GGDM 3.0']['SummaryDomainValues']['TOS'][12] = u'Truss'
    field_information['GGDM 3.0']['SummaryDomainValues']['TOS'][13] = u'Tubular'
    field_information['GGDM 3.0']['SummaryDomainValues']['TOS'][14] = u'Tower Mill'
    field_information['GGDM 3.0']['SummaryDomainValues']['TOS'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['TRA'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['TRA'][1000] = u'False'
    field_information['GGDM 3.0']['SummaryDomainValues']['TRA'][1001] = u'True'
    field_information['GGDM 3.0']['SummaryDomainValues']['TRE'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['TRE'][1] = u'Deciduous'
    field_information['GGDM 3.0']['SummaryDomainValues']['TRE'][2] = u'Evergreen'
    field_information['GGDM 3.0']['SummaryDomainValues']['TRE'][3] = u'Mixed'
    field_information['GGDM 3.0']['SummaryDomainValues']['TRE'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['TRP'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['TRP'][1] = u'Gallery'
    field_information['GGDM 3.0']['SummaryDomainValues']['TRP'][2] = u'Rock Protection Shed'
    field_information['GGDM 3.0']['SummaryDomainValues']['TRP'][3] = u'Snow Protection Shed'
    field_information['GGDM 3.0']['SummaryDomainValues']['TRP'][4] = u'Protection Shed'
    field_information['GGDM 3.0']['SummaryDomainValues']['TRP'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['TRS'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['TRS'][1] = u'Aeronautical'
    field_information['GGDM 3.0']['SummaryDomainValues']['TRS'][2] = u'Aqueduct'
    field_information['GGDM 3.0']['SummaryDomainValues']['TRS'][3] = u'Automotive'
    field_information['GGDM 3.0']['SummaryDomainValues']['TRS'][4] = u'Bus'
    field_information['GGDM 3.0']['SummaryDomainValues']['TRS'][5] = u'Canal'
    field_information['GGDM 3.0']['SummaryDomainValues']['TRS'][6] = u'Caravan Route'
    field_information['GGDM 3.0']['SummaryDomainValues']['TRS'][7] = u'Maritime'
    field_information['GGDM 3.0']['SummaryDomainValues']['TRS'][8] = u'No Transportation System'
    field_information['GGDM 3.0']['SummaryDomainValues']['TRS'][9] = u'Pedestrian'
    field_information['GGDM 3.0']['SummaryDomainValues']['TRS'][10] = u'Pipeline'
    field_information['GGDM 3.0']['SummaryDomainValues']['TRS'][11] = u'Portage'
    field_information['GGDM 3.0']['SummaryDomainValues']['TRS'][12] = u'Railway'
    field_information['GGDM 3.0']['SummaryDomainValues']['TRS'][13] = u'Road'
    field_information['GGDM 3.0']['SummaryDomainValues']['TRS'][16] = u'Underground Railway'
    field_information['GGDM 3.0']['SummaryDomainValues']['TRS'][17] = u'Inland Waterway'
    field_information['GGDM 3.0']['SummaryDomainValues']['TRS'][18] = u'Pack-road'
    field_information['GGDM 3.0']['SummaryDomainValues']['TRS'][20] = u'Taxiway'
    field_information['GGDM 3.0']['SummaryDomainValues']['TRS'][23] = u'Drove'
    field_information['GGDM 3.0']['SummaryDomainValues']['TRS'][25] = u'Runway'
    field_information['GGDM 3.0']['SummaryDomainValues']['TRS'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['TRS2'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['TRS2'][1] = u'Aeronautical'
    field_information['GGDM 3.0']['SummaryDomainValues']['TRS2'][2] = u'Aqueduct'
    field_information['GGDM 3.0']['SummaryDomainValues']['TRS2'][3] = u'Automotive'
    field_information['GGDM 3.0']['SummaryDomainValues']['TRS2'][4] = u'Bus'
    field_information['GGDM 3.0']['SummaryDomainValues']['TRS2'][5] = u'Canal'
    field_information['GGDM 3.0']['SummaryDomainValues']['TRS2'][6] = u'Caravan Route'
    field_information['GGDM 3.0']['SummaryDomainValues']['TRS2'][7] = u'Maritime'
    field_information['GGDM 3.0']['SummaryDomainValues']['TRS2'][8] = u'No Transportation System'
    field_information['GGDM 3.0']['SummaryDomainValues']['TRS2'][9] = u'Pedestrian'
    field_information['GGDM 3.0']['SummaryDomainValues']['TRS2'][10] = u'Pipeline'
    field_information['GGDM 3.0']['SummaryDomainValues']['TRS2'][11] = u'Portage'
    field_information['GGDM 3.0']['SummaryDomainValues']['TRS2'][12] = u'Railway'
    field_information['GGDM 3.0']['SummaryDomainValues']['TRS2'][13] = u'Road'
    field_information['GGDM 3.0']['SummaryDomainValues']['TRS2'][16] = u'Underground Railway'
    field_information['GGDM 3.0']['SummaryDomainValues']['TRS2'][17] = u'Inland Waterway'
    field_information['GGDM 3.0']['SummaryDomainValues']['TRS2'][18] = u'Pack-road'
    field_information['GGDM 3.0']['SummaryDomainValues']['TRS2'][20] = u'Taxiway'
    field_information['GGDM 3.0']['SummaryDomainValues']['TRS2'][23] = u'Drove'
    field_information['GGDM 3.0']['SummaryDomainValues']['TRS2'][25] = u'Runway'
    field_information['GGDM 3.0']['SummaryDomainValues']['TRS2'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['TRS3'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['TRS3'][1] = u'Aeronautical'
    field_information['GGDM 3.0']['SummaryDomainValues']['TRS3'][2] = u'Aqueduct'
    field_information['GGDM 3.0']['SummaryDomainValues']['TRS3'][3] = u'Automotive'
    field_information['GGDM 3.0']['SummaryDomainValues']['TRS3'][4] = u'Bus'
    field_information['GGDM 3.0']['SummaryDomainValues']['TRS3'][5] = u'Canal'
    field_information['GGDM 3.0']['SummaryDomainValues']['TRS3'][6] = u'Caravan Route'
    field_information['GGDM 3.0']['SummaryDomainValues']['TRS3'][7] = u'Maritime'
    field_information['GGDM 3.0']['SummaryDomainValues']['TRS3'][8] = u'No Transportation System'
    field_information['GGDM 3.0']['SummaryDomainValues']['TRS3'][9] = u'Pedestrian'
    field_information['GGDM 3.0']['SummaryDomainValues']['TRS3'][10] = u'Pipeline'
    field_information['GGDM 3.0']['SummaryDomainValues']['TRS3'][11] = u'Portage'
    field_information['GGDM 3.0']['SummaryDomainValues']['TRS3'][12] = u'Railway'
    field_information['GGDM 3.0']['SummaryDomainValues']['TRS3'][13] = u'Road'
    field_information['GGDM 3.0']['SummaryDomainValues']['TRS3'][16] = u'Underground Railway'
    field_information['GGDM 3.0']['SummaryDomainValues']['TRS3'][17] = u'Inland Waterway'
    field_information['GGDM 3.0']['SummaryDomainValues']['TRS3'][18] = u'Pack-road'
    field_information['GGDM 3.0']['SummaryDomainValues']['TRS3'][20] = u'Taxiway'
    field_information['GGDM 3.0']['SummaryDomainValues']['TRS3'][23] = u'Drove'
    field_information['GGDM 3.0']['SummaryDomainValues']['TRS3'][25] = u'Runway'
    field_information['GGDM 3.0']['SummaryDomainValues']['TRS3'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['TSCC'][2] = u'Open Interval'
    field_information['GGDM 3.0']['SummaryDomainValues']['TSCC'][3] = u'Greater-than-or-equal to Less-than Interval'
    field_information['GGDM 3.0']['SummaryDomainValues']['TSCC'][4] = u'Greater-than to Less-than-or-equal Interval'
    field_information['GGDM 3.0']['SummaryDomainValues']['TSCC'][5] = u'Closed Interval'
    field_information['GGDM 3.0']['SummaryDomainValues']['TSCC'][6] = u'Greater-than Semi-interval'
    field_information['GGDM 3.0']['SummaryDomainValues']['TSCC'][7] = u'Greater-than or Equal Semi-interval'
    field_information['GGDM 3.0']['SummaryDomainValues']['TSCC'][8] = u'Less-than Semi-interval'
    field_information['GGDM 3.0']['SummaryDomainValues']['TSCC'][9] = u'Less-than or Equal Semi-interval'
    field_information['GGDM 3.0']['SummaryDomainValues']['TSM'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['TSM'][1] = u'Asphalt'
    field_information['GGDM 3.0']['SummaryDomainValues']['TSM'][2] = u'Bedrock'
    field_information['GGDM 3.0']['SummaryDomainValues']['TSM'][3] = u'Boulders'
    field_information['GGDM 3.0']['SummaryDomainValues']['TSM'][4] = u'Concrete'
    field_information['GGDM 3.0']['SummaryDomainValues']['TSM'][5] = u'Evaporite'
    field_information['GGDM 3.0']['SummaryDomainValues']['TSM'][6] = u'Frozen Water'
    field_information['GGDM 3.0']['SummaryDomainValues']['TSM'][7] = u'Gravel'
    field_information['GGDM 3.0']['SummaryDomainValues']['TSM'][8] = u'Lava Flow'
    field_information['GGDM 3.0']['SummaryDomainValues']['TSM'][9] = u'Loess'
    field_information['GGDM 3.0']['SummaryDomainValues']['TSM'][10] = u'Mud'
    field_information['GGDM 3.0']['SummaryDomainValues']['TSM'][11] = u'Paved'
    field_information['GGDM 3.0']['SummaryDomainValues']['TSM'][12] = u'Rocks'
    field_information['GGDM 3.0']['SummaryDomainValues']['TSM'][13] = u'Sand'
    field_information['GGDM 3.0']['SummaryDomainValues']['TSM'][14] = u'Soil'
    field_information['GGDM 3.0']['SummaryDomainValues']['TSM'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['TSM2'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['TSM2'][1] = u'Asphalt'
    field_information['GGDM 3.0']['SummaryDomainValues']['TSM2'][2] = u'Bedrock'
    field_information['GGDM 3.0']['SummaryDomainValues']['TSM2'][3] = u'Boulders'
    field_information['GGDM 3.0']['SummaryDomainValues']['TSM2'][4] = u'Concrete'
    field_information['GGDM 3.0']['SummaryDomainValues']['TSM2'][5] = u'Evaporite'
    field_information['GGDM 3.0']['SummaryDomainValues']['TSM2'][6] = u'Frozen Water'
    field_information['GGDM 3.0']['SummaryDomainValues']['TSM2'][7] = u'Gravel'
    field_information['GGDM 3.0']['SummaryDomainValues']['TSM2'][8] = u'Lava Flow'
    field_information['GGDM 3.0']['SummaryDomainValues']['TSM2'][9] = u'Loess'
    field_information['GGDM 3.0']['SummaryDomainValues']['TSM2'][10] = u'Mud'
    field_information['GGDM 3.0']['SummaryDomainValues']['TSM2'][11] = u'Paved'
    field_information['GGDM 3.0']['SummaryDomainValues']['TSM2'][12] = u'Rocks'
    field_information['GGDM 3.0']['SummaryDomainValues']['TSM2'][13] = u'Sand'
    field_information['GGDM 3.0']['SummaryDomainValues']['TSM2'][14] = u'Soil'
    field_information['GGDM 3.0']['SummaryDomainValues']['TSM2'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['TSM3'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['TSM3'][1] = u'Asphalt'
    field_information['GGDM 3.0']['SummaryDomainValues']['TSM3'][2] = u'Bedrock'
    field_information['GGDM 3.0']['SummaryDomainValues']['TSM3'][3] = u'Boulders'
    field_information['GGDM 3.0']['SummaryDomainValues']['TSM3'][4] = u'Concrete'
    field_information['GGDM 3.0']['SummaryDomainValues']['TSM3'][5] = u'Evaporite'
    field_information['GGDM 3.0']['SummaryDomainValues']['TSM3'][6] = u'Frozen Water'
    field_information['GGDM 3.0']['SummaryDomainValues']['TSM3'][7] = u'Gravel'
    field_information['GGDM 3.0']['SummaryDomainValues']['TSM3'][8] = u'Lava Flow'
    field_information['GGDM 3.0']['SummaryDomainValues']['TSM3'][9] = u'Loess'
    field_information['GGDM 3.0']['SummaryDomainValues']['TSM3'][10] = u'Mud'
    field_information['GGDM 3.0']['SummaryDomainValues']['TSM3'][11] = u'Paved'
    field_information['GGDM 3.0']['SummaryDomainValues']['TSM3'][12] = u'Rocks'
    field_information['GGDM 3.0']['SummaryDomainValues']['TSM3'][13] = u'Sand'
    field_information['GGDM 3.0']['SummaryDomainValues']['TSM3'][14] = u'Soil'
    field_information['GGDM 3.0']['SummaryDomainValues']['TSM3'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['TSP'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['TSP'][2] = u'Boundary'
    field_information['GGDM 3.0']['SummaryDomainValues']['TSP'][3] = u'Separation Zone'
    field_information['GGDM 3.0']['SummaryDomainValues']['TSP'][4] = u'Line'
    field_information['GGDM 3.0']['SummaryDomainValues']['TSP'][5] = u'Point'
    field_information['GGDM 3.0']['SummaryDomainValues']['TSP'][6] = u'Inbound Lane'
    field_information['GGDM 3.0']['SummaryDomainValues']['TSP'][7] = u'Outbound Lane'
    field_information['GGDM 3.0']['SummaryDomainValues']['TSP'][8] = u'Lane Part'
    field_information['GGDM 3.0']['SummaryDomainValues']['TSP'][9] = u'Roundabout'
    field_information['GGDM 3.0']['SummaryDomainValues']['TSP'][10] = u'Crossing'
    field_information['GGDM 3.0']['SummaryDomainValues']['TSP'][11] = u'Precautionary Area'
    field_information['GGDM 3.0']['SummaryDomainValues']['TSP'][12] = u'Inshore Traffic Zone'
    field_information['GGDM 3.0']['SummaryDomainValues']['TSP'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['TSSM'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['TSSM'][1] = u'Basalt'
    field_information['GGDM 3.0']['SummaryDomainValues']['TSSM'][2] = u'Boulders'
    field_information['GGDM 3.0']['SummaryDomainValues']['TSSM'][3] = u'Clay'
    field_information['GGDM 3.0']['SummaryDomainValues']['TSSM'][4] = u'Conglomerate'
    field_information['GGDM 3.0']['SummaryDomainValues']['TSSM'][5] = u'Dolomite'
    field_information['GGDM 3.0']['SummaryDomainValues']['TSSM'][6] = u'Granite'
    field_information['GGDM 3.0']['SummaryDomainValues']['TSSM'][7] = u'Gravel'
    field_information['GGDM 3.0']['SummaryDomainValues']['TSSM'][8] = u'Igneous Rock'
    field_information['GGDM 3.0']['SummaryDomainValues']['TSSM'][9] = u'Karst'
    field_information['GGDM 3.0']['SummaryDomainValues']['TSSM'][10] = u'Limestone'
    field_information['GGDM 3.0']['SummaryDomainValues']['TSSM'][11] = u'Marl'
    field_information['GGDM 3.0']['SummaryDomainValues']['TSSM'][12] = u'Metamorphic Rock'
    field_information['GGDM 3.0']['SummaryDomainValues']['TSSM'][13] = u'Mud'
    field_information['GGDM 3.0']['SummaryDomainValues']['TSSM'][14] = u'Sand'
    field_information['GGDM 3.0']['SummaryDomainValues']['TSSM'][15] = u'Schist'
    field_information['GGDM 3.0']['SummaryDomainValues']['TSSM'][16] = u'Unconsolidated'
    field_information['GGDM 3.0']['SummaryDomainValues']['TSSM'][17] = u'Semi-consolidated and Consolidated Volcanic Ash'
    field_information['GGDM 3.0']['SummaryDomainValues']['TSSM'][18] = u'Volcanic Rock'
    field_information['GGDM 3.0']['SummaryDomainValues']['TSSM'][19] = u'Sandstone'
    field_information['GGDM 3.0']['SummaryDomainValues']['TSSM'][20] = u'Shale'
    field_information['GGDM 3.0']['SummaryDomainValues']['TSSM'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['TSSM2'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['TSSM2'][1] = u'Basalt'
    field_information['GGDM 3.0']['SummaryDomainValues']['TSSM2'][2] = u'Boulders'
    field_information['GGDM 3.0']['SummaryDomainValues']['TSSM2'][3] = u'Clay'
    field_information['GGDM 3.0']['SummaryDomainValues']['TSSM2'][4] = u'Conglomerate'
    field_information['GGDM 3.0']['SummaryDomainValues']['TSSM2'][5] = u'Dolomite'
    field_information['GGDM 3.0']['SummaryDomainValues']['TSSM2'][6] = u'Granite'
    field_information['GGDM 3.0']['SummaryDomainValues']['TSSM2'][7] = u'Gravel'
    field_information['GGDM 3.0']['SummaryDomainValues']['TSSM2'][8] = u'Igneous Rock'
    field_information['GGDM 3.0']['SummaryDomainValues']['TSSM2'][9] = u'Karst'
    field_information['GGDM 3.0']['SummaryDomainValues']['TSSM2'][10] = u'Limestone'
    field_information['GGDM 3.0']['SummaryDomainValues']['TSSM2'][11] = u'Marl'
    field_information['GGDM 3.0']['SummaryDomainValues']['TSSM2'][12] = u'Metamorphic Rock'
    field_information['GGDM 3.0']['SummaryDomainValues']['TSSM2'][13] = u'Mud'
    field_information['GGDM 3.0']['SummaryDomainValues']['TSSM2'][14] = u'Sand'
    field_information['GGDM 3.0']['SummaryDomainValues']['TSSM2'][15] = u'Schist'
    field_information['GGDM 3.0']['SummaryDomainValues']['TSSM2'][16] = u'Unconsolidated'
    field_information['GGDM 3.0']['SummaryDomainValues']['TSSM2'][17] = u'Semi-consolidated and Consolidated Volcanic Ash'
    field_information['GGDM 3.0']['SummaryDomainValues']['TSSM2'][18] = u'Volcanic Rock'
    field_information['GGDM 3.0']['SummaryDomainValues']['TSSM2'][19] = u'Sandstone'
    field_information['GGDM 3.0']['SummaryDomainValues']['TSSM2'][20] = u'Shale'
    field_information['GGDM 3.0']['SummaryDomainValues']['TSSM2'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['TSSM3'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['TSSM3'][1] = u'Basalt'
    field_information['GGDM 3.0']['SummaryDomainValues']['TSSM3'][2] = u'Boulders'
    field_information['GGDM 3.0']['SummaryDomainValues']['TSSM3'][3] = u'Clay'
    field_information['GGDM 3.0']['SummaryDomainValues']['TSSM3'][4] = u'Conglomerate'
    field_information['GGDM 3.0']['SummaryDomainValues']['TSSM3'][5] = u'Dolomite'
    field_information['GGDM 3.0']['SummaryDomainValues']['TSSM3'][6] = u'Granite'
    field_information['GGDM 3.0']['SummaryDomainValues']['TSSM3'][7] = u'Gravel'
    field_information['GGDM 3.0']['SummaryDomainValues']['TSSM3'][8] = u'Igneous Rock'
    field_information['GGDM 3.0']['SummaryDomainValues']['TSSM3'][9] = u'Karst'
    field_information['GGDM 3.0']['SummaryDomainValues']['TSSM3'][10] = u'Limestone'
    field_information['GGDM 3.0']['SummaryDomainValues']['TSSM3'][11] = u'Marl'
    field_information['GGDM 3.0']['SummaryDomainValues']['TSSM3'][12] = u'Metamorphic Rock'
    field_information['GGDM 3.0']['SummaryDomainValues']['TSSM3'][13] = u'Mud'
    field_information['GGDM 3.0']['SummaryDomainValues']['TSSM3'][14] = u'Sand'
    field_information['GGDM 3.0']['SummaryDomainValues']['TSSM3'][15] = u'Schist'
    field_information['GGDM 3.0']['SummaryDomainValues']['TSSM3'][16] = u'Unconsolidated'
    field_information['GGDM 3.0']['SummaryDomainValues']['TSSM3'][17] = u'Semi-consolidated and Consolidated Volcanic Ash'
    field_information['GGDM 3.0']['SummaryDomainValues']['TSSM3'][18] = u'Volcanic Rock'
    field_information['GGDM 3.0']['SummaryDomainValues']['TSSM3'][19] = u'Sandstone'
    field_information['GGDM 3.0']['SummaryDomainValues']['TSSM3'][20] = u'Shale'
    field_information['GGDM 3.0']['SummaryDomainValues']['TSSM3'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['TST'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['TST'][1] = u'Symmetric Catenary'
    field_information['GGDM 3.0']['SummaryDomainValues']['TST'][2] = u'Mountain Catenary'
    field_information['GGDM 3.0']['SummaryDomainValues']['TST'][3] = u'Overwater Catenary'
    field_information['GGDM 3.0']['SummaryDomainValues']['TST'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['TSTE'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['TSTE'][1] = u'Salty or brackish'
    field_information['GGDM 3.0']['SummaryDomainValues']['TSTE'][2] = u'Alkali or Soapy'
    field_information['GGDM 3.0']['SummaryDomainValues']['TSTE'][3] = u'Metallic'
    field_information['GGDM 3.0']['SummaryDomainValues']['TSTE'][4] = u'Chemical'
    field_information['GGDM 3.0']['SummaryDomainValues']['TSTE'][998] = u'Not Applicable'
    field_information['GGDM 3.0']['SummaryDomainValues']['TSTE'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['TTC'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['TTC'][2] = u'Observation Tower'
    field_information['GGDM 3.0']['SummaryDomainValues']['TTC'][10] = u'Lookout Tower'
    field_information['GGDM 3.0']['SummaryDomainValues']['TTC'][12] = u'Fire Tower'
    field_information['GGDM 3.0']['SummaryDomainValues']['TTC'][20] = u'Telecommunication Tower'
    field_information['GGDM 3.0']['SummaryDomainValues']['TTC'][21] = u'Guard Tower'
    field_information['GGDM 3.0']['SummaryDomainValues']['TTC'][22] = u'Industrial Tower'
    field_information['GGDM 3.0']['SummaryDomainValues']['TTC'][23] = u'Drop Tower'
    field_information['GGDM 3.0']['SummaryDomainValues']['TTC'][24] = u'Solar Power Tower'
    field_information['GGDM 3.0']['SummaryDomainValues']['TTC'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['TTC2'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['TTC2'][2] = u'Observation Tower'
    field_information['GGDM 3.0']['SummaryDomainValues']['TTC2'][10] = u'Lookout Tower'
    field_information['GGDM 3.0']['SummaryDomainValues']['TTC2'][12] = u'Fire Tower'
    field_information['GGDM 3.0']['SummaryDomainValues']['TTC2'][20] = u'Telecommunication Tower'
    field_information['GGDM 3.0']['SummaryDomainValues']['TTC2'][21] = u'Guard Tower'
    field_information['GGDM 3.0']['SummaryDomainValues']['TTC2'][22] = u'Industrial Tower'
    field_information['GGDM 3.0']['SummaryDomainValues']['TTC2'][23] = u'Drop Tower'
    field_information['GGDM 3.0']['SummaryDomainValues']['TTC2'][24] = u'Solar Power Tower'
    field_information['GGDM 3.0']['SummaryDomainValues']['TTC2'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['TTC3'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['TTC3'][2] = u'Observation Tower'
    field_information['GGDM 3.0']['SummaryDomainValues']['TTC3'][10] = u'Lookout Tower'
    field_information['GGDM 3.0']['SummaryDomainValues']['TTC3'][12] = u'Fire Tower'
    field_information['GGDM 3.0']['SummaryDomainValues']['TTC3'][20] = u'Telecommunication Tower'
    field_information['GGDM 3.0']['SummaryDomainValues']['TTC3'][21] = u'Guard Tower'
    field_information['GGDM 3.0']['SummaryDomainValues']['TTC3'][22] = u'Industrial Tower'
    field_information['GGDM 3.0']['SummaryDomainValues']['TTC3'][23] = u'Drop Tower'
    field_information['GGDM 3.0']['SummaryDomainValues']['TTC3'][24] = u'Solar Power Tower'
    field_information['GGDM 3.0']['SummaryDomainValues']['TTC3'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['TTY'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['TTY'][1] = u'Cave'
    field_information['GGDM 3.0']['SummaryDomainValues']['TTY'][2] = u'Catacomb'
    field_information['GGDM 3.0']['SummaryDomainValues']['TTY'][3] = u'Crypt'
    field_information['GGDM 3.0']['SummaryDomainValues']['TTY'][4] = u'Surface Vault'
    field_information['GGDM 3.0']['SummaryDomainValues']['TTY'][5] = u'Mausoleum'
    field_information['GGDM 3.0']['SummaryDomainValues']['TTY'][6] = u'Burial Mound'
    field_information['GGDM 3.0']['SummaryDomainValues']['TTY'][7] = u'Columbarium'
    field_information['GGDM 3.0']['SummaryDomainValues']['TTY'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['TWS'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['TWS'][1000] = u'False'
    field_information['GGDM 3.0']['SummaryDomainValues']['TWS'][1001] = u'True'
    field_information['GGDM 3.0']['SummaryDomainValues']['TXP'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['TXP'][1] = u'Parallel Taxiway'
    field_information['GGDM 3.0']['SummaryDomainValues']['TXP'][2] = u'Stub Taxiway'
    field_information['GGDM 3.0']['SummaryDomainValues']['TXP'][3] = u'Rapid Exit and/or Turnoff Taxiway'
    field_information['GGDM 3.0']['SummaryDomainValues']['TXP'][4] = u'Turnaround Taxiway'
    field_information['GGDM 3.0']['SummaryDomainValues']['TXP'][5] = u'Dispersal'
    field_information['GGDM 3.0']['SummaryDomainValues']['TXP'][6] = u'Loop'
    field_information['GGDM 3.0']['SummaryDomainValues']['TXP'][7] = u'Perimeter'
    field_information['GGDM 3.0']['SummaryDomainValues']['TXP'][8] = u'Apron Taxiway'
    field_information['GGDM 3.0']['SummaryDomainValues']['TXP'][9] = u'Aircraft Stand Taxilane'
    field_information['GGDM 3.0']['SummaryDomainValues']['TXP'][10] = u'Lead-in Taxilane'
    field_information['GGDM 3.0']['SummaryDomainValues']['TXP'][11] = u'Lead-out Taxilane'
    field_information['GGDM 3.0']['SummaryDomainValues']['TXP'][12] = u'Air Taxiway'
    field_information['GGDM 3.0']['SummaryDomainValues']['TXP'][13] = u'Helicopter Ground Taxiway'
    field_information['GGDM 3.0']['SummaryDomainValues']['TXP'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['TZP'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['TZP'][1] = u'Cone Point Upward'
    field_information['GGDM 3.0']['SummaryDomainValues']['TZP'][2] = u'Cone Point Downward'
    field_information['GGDM 3.0']['SummaryDomainValues']['TZP'][3] = u'Sphere'
    field_information['GGDM 3.0']['SummaryDomainValues']['TZP'][4] = u'2 Spheres One over Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['TZP'][5] = u'Cylinder'
    field_information['GGDM 3.0']['SummaryDomainValues']['TZP'][6] = u'Board'
    field_information['GGDM 3.0']['SummaryDomainValues']['TZP'][7] = u'X-shaped'
    field_information['GGDM 3.0']['SummaryDomainValues']['TZP'][8] = u'Upright Cross'
    field_information['GGDM 3.0']['SummaryDomainValues']['TZP'][9] = u'Cube Point Upward'
    field_information['GGDM 3.0']['SummaryDomainValues']['TZP'][10] = u'2 Cones Point to Point'
    field_information['GGDM 3.0']['SummaryDomainValues']['TZP'][11] = u'2 Cones Base to Base'
    field_information['GGDM 3.0']['SummaryDomainValues']['TZP'][12] = u'Diamond'
    field_information['GGDM 3.0']['SummaryDomainValues']['TZP'][13] = u'2 Cones Points Upward'
    field_information['GGDM 3.0']['SummaryDomainValues']['TZP'][14] = u'2 Cones Points Downward'
    field_information['GGDM 3.0']['SummaryDomainValues']['TZP'][15] = u'Besom Point Upward'
    field_information['GGDM 3.0']['SummaryDomainValues']['TZP'][16] = u'Besom Point Downward'
    field_information['GGDM 3.0']['SummaryDomainValues']['TZP'][17] = u'Flag'
    field_information['GGDM 3.0']['SummaryDomainValues']['TZP'][18] = u'Sphere over Diamond'
    field_information['GGDM 3.0']['SummaryDomainValues']['TZP'][19] = u'Square'
    field_information['GGDM 3.0']['SummaryDomainValues']['TZP'][20] = u'Horizontal Rectangle'
    field_information['GGDM 3.0']['SummaryDomainValues']['TZP'][21] = u'Vertical Rectangle'
    field_information['GGDM 3.0']['SummaryDomainValues']['TZP'][22] = u'Trapezium Short Upward'
    field_information['GGDM 3.0']['SummaryDomainValues']['TZP'][23] = u'Trapezium Short Downward'
    field_information['GGDM 3.0']['SummaryDomainValues']['TZP'][24] = u'Triangle Point Upward'
    field_information['GGDM 3.0']['SummaryDomainValues']['TZP'][25] = u'Triangle Point Downward'
    field_information['GGDM 3.0']['SummaryDomainValues']['TZP'][26] = u'Circle'
    field_information['GGDM 3.0']['SummaryDomainValues']['TZP'][27] = u'2 Upright Crosses'
    field_information['GGDM 3.0']['SummaryDomainValues']['TZP'][28] = u'T-shaped'
    field_information['GGDM 3.0']['SummaryDomainValues']['TZP'][29] = u'Triangle Point Upward over Circle'
    field_information['GGDM 3.0']['SummaryDomainValues']['TZP'][30] = u'Upright Cross over Circle'
    field_information['GGDM 3.0']['SummaryDomainValues']['TZP'][31] = u'Diamond over Circle'
    field_information['GGDM 3.0']['SummaryDomainValues']['TZP'][32] = u'Circle over Triangle Point Upward'
    field_information['GGDM 3.0']['SummaryDomainValues']['TZP'][33] = u'Ball over Cone'
    field_information['GGDM 3.0']['SummaryDomainValues']['TZP'][34] = u'Can over Ball'
    field_information['GGDM 3.0']['SummaryDomainValues']['TZP'][35] = u'Cone over Ball'
    field_information['GGDM 3.0']['SummaryDomainValues']['TZP'][36] = u'Cross over Ball'
    field_information['GGDM 3.0']['SummaryDomainValues']['TZP'][37] = u'Diamond over Ball'
    field_information['GGDM 3.0']['SummaryDomainValues']['TZP'][998] = u'Not Applicable'
    field_information['GGDM 3.0']['SummaryDomainValues']['TZP'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['UMA'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['UMA'][1] = u'Drift'
    field_information['GGDM 3.0']['SummaryDomainValues']['UMA'][2] = u'Slope'
    field_information['GGDM 3.0']['SummaryDomainValues']['UMA'][3] = u'Shaft'
    field_information['GGDM 3.0']['SummaryDomainValues']['UMA'][998] = u'Not Applicable'
    field_information['GGDM 3.0']['SummaryDomainValues']['UTY'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['UTY'][1] = u'Cable Television'
    field_information['GGDM 3.0']['SummaryDomainValues']['UTY'][2] = u'Cooling Fluid Circulation'
    field_information['GGDM 3.0']['SummaryDomainValues']['UTY'][3] = u'Digital Fibre-optic System'
    field_information['GGDM 3.0']['SummaryDomainValues']['UTY'][4] = u'Electric Power Distribution'
    field_information['GGDM 3.0']['SummaryDomainValues']['UTY'][5] = u'Heating Fluid Circulation'
    field_information['GGDM 3.0']['SummaryDomainValues']['UTY'][6] = u'Natural Gas Distribution'
    field_information['GGDM 3.0']['SummaryDomainValues']['UTY'][7] = u'Sewage'
    field_information['GGDM 3.0']['SummaryDomainValues']['UTY'][8] = u'Storm Sewer'
    field_information['GGDM 3.0']['SummaryDomainValues']['UTY'][9] = u'Street Light'
    field_information['GGDM 3.0']['SummaryDomainValues']['UTY'][10] = u'Telegraph'
    field_information['GGDM 3.0']['SummaryDomainValues']['UTY'][11] = u'Telephone'
    field_information['GGDM 3.0']['SummaryDomainValues']['UTY'][12] = u'Traffic Light'
    field_information['GGDM 3.0']['SummaryDomainValues']['UTY'][13] = u'Water Distribution'
    field_information['GGDM 3.0']['SummaryDomainValues']['UTY'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['UTY2'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['UTY2'][1] = u'Cable Television'
    field_information['GGDM 3.0']['SummaryDomainValues']['UTY2'][2] = u'Cooling Fluid Circulation'
    field_information['GGDM 3.0']['SummaryDomainValues']['UTY2'][3] = u'Digital Fibre-optic System'
    field_information['GGDM 3.0']['SummaryDomainValues']['UTY2'][4] = u'Electric Power Distribution'
    field_information['GGDM 3.0']['SummaryDomainValues']['UTY2'][5] = u'Heating Fluid Circulation'
    field_information['GGDM 3.0']['SummaryDomainValues']['UTY2'][6] = u'Natural Gas Distribution'
    field_information['GGDM 3.0']['SummaryDomainValues']['UTY2'][7] = u'Sewage'
    field_information['GGDM 3.0']['SummaryDomainValues']['UTY2'][8] = u'Storm Sewer'
    field_information['GGDM 3.0']['SummaryDomainValues']['UTY2'][9] = u'Street Light'
    field_information['GGDM 3.0']['SummaryDomainValues']['UTY2'][10] = u'Telegraph'
    field_information['GGDM 3.0']['SummaryDomainValues']['UTY2'][11] = u'Telephone'
    field_information['GGDM 3.0']['SummaryDomainValues']['UTY2'][12] = u'Traffic Light'
    field_information['GGDM 3.0']['SummaryDomainValues']['UTY2'][13] = u'Water Distribution'
    field_information['GGDM 3.0']['SummaryDomainValues']['UTY2'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['UTY3'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['UTY3'][1] = u'Cable Television'
    field_information['GGDM 3.0']['SummaryDomainValues']['UTY3'][2] = u'Cooling Fluid Circulation'
    field_information['GGDM 3.0']['SummaryDomainValues']['UTY3'][3] = u'Digital Fibre-optic System'
    field_information['GGDM 3.0']['SummaryDomainValues']['UTY3'][4] = u'Electric Power Distribution'
    field_information['GGDM 3.0']['SummaryDomainValues']['UTY3'][5] = u'Heating Fluid Circulation'
    field_information['GGDM 3.0']['SummaryDomainValues']['UTY3'][6] = u'Natural Gas Distribution'
    field_information['GGDM 3.0']['SummaryDomainValues']['UTY3'][7] = u'Sewage'
    field_information['GGDM 3.0']['SummaryDomainValues']['UTY3'][8] = u'Storm Sewer'
    field_information['GGDM 3.0']['SummaryDomainValues']['UTY3'][9] = u'Street Light'
    field_information['GGDM 3.0']['SummaryDomainValues']['UTY3'][10] = u'Telegraph'
    field_information['GGDM 3.0']['SummaryDomainValues']['UTY3'][11] = u'Telephone'
    field_information['GGDM 3.0']['SummaryDomainValues']['UTY3'][12] = u'Traffic Light'
    field_information['GGDM 3.0']['SummaryDomainValues']['UTY3'][13] = u'Water Distribution'
    field_information['GGDM 3.0']['SummaryDomainValues']['UTY3'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['VAVC'][2] = u'Open Interval'
    field_information['GGDM 3.0']['SummaryDomainValues']['VAVC'][3] = u'Greater-than-or-equal to Less-than Interval'
    field_information['GGDM 3.0']['SummaryDomainValues']['VAVC'][4] = u'Greater-than to Less-than-or-equal Interval'
    field_information['GGDM 3.0']['SummaryDomainValues']['VAVC'][5] = u'Closed Interval'
    field_information['GGDM 3.0']['SummaryDomainValues']['VAVC'][6] = u'Greater-than Semi-interval'
    field_information['GGDM 3.0']['SummaryDomainValues']['VAVC'][7] = u'Greater-than or Equal Semi-interval'
    field_information['GGDM 3.0']['SummaryDomainValues']['VAVC'][8] = u'Less-than Semi-interval'
    field_information['GGDM 3.0']['SummaryDomainValues']['VAVC'][9] = u'Less-than or Equal Semi-interval'
    field_information['GGDM 3.0']['SummaryDomainValues']['VCA'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['VCA'][1] = u'Not Requested'
    field_information['GGDM 3.0']['SummaryDomainValues']['VCA'][2] = u'Inaccessible'
    field_information['GGDM 3.0']['SummaryDomainValues']['VCA'][3] = u'No Available Imagery'
    field_information['GGDM 3.0']['SummaryDomainValues']['VCA'][6] = u'No Available Map Source'
    field_information['GGDM 3.0']['SummaryDomainValues']['VCA'][7] = u'No Suitable Imagery'
    field_information['GGDM 3.0']['SummaryDomainValues']['VCA'][8] = u'Not Required'
    field_information['GGDM 3.0']['SummaryDomainValues']['VCA'][9] = u'Cloud Cover'
    field_information['GGDM 3.0']['SummaryDomainValues']['VCA'][10] = u'Snow Cover'
    field_information['GGDM 3.0']['SummaryDomainValues']['VCA'][11] = u'Dark Shade'
    field_information['GGDM 3.0']['SummaryDomainValues']['VCA'][12] = u'Vegetation Cover'
    field_information['GGDM 3.0']['SummaryDomainValues']['VCA'][13] = u'Flooded'
    field_information['GGDM 3.0']['SummaryDomainValues']['VCA'][16] = u'No Available Survey'
    field_information['GGDM 3.0']['SummaryDomainValues']['VCA'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['VCA2'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['VCA2'][1] = u'Not Requested'
    field_information['GGDM 3.0']['SummaryDomainValues']['VCA2'][2] = u'Inaccessible'
    field_information['GGDM 3.0']['SummaryDomainValues']['VCA2'][3] = u'No Available Imagery'
    field_information['GGDM 3.0']['SummaryDomainValues']['VCA2'][6] = u'No Available Map Source'
    field_information['GGDM 3.0']['SummaryDomainValues']['VCA2'][7] = u'No Suitable Imagery'
    field_information['GGDM 3.0']['SummaryDomainValues']['VCA2'][8] = u'Not Required'
    field_information['GGDM 3.0']['SummaryDomainValues']['VCA2'][9] = u'Cloud Cover'
    field_information['GGDM 3.0']['SummaryDomainValues']['VCA2'][10] = u'Snow Cover'
    field_information['GGDM 3.0']['SummaryDomainValues']['VCA2'][11] = u'Dark Shade'
    field_information['GGDM 3.0']['SummaryDomainValues']['VCA2'][12] = u'Vegetation Cover'
    field_information['GGDM 3.0']['SummaryDomainValues']['VCA2'][13] = u'Flooded'
    field_information['GGDM 3.0']['SummaryDomainValues']['VCA2'][16] = u'No Available Survey'
    field_information['GGDM 3.0']['SummaryDomainValues']['VCA2'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['VCA3'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['VCA3'][1] = u'Not Requested'
    field_information['GGDM 3.0']['SummaryDomainValues']['VCA3'][2] = u'Inaccessible'
    field_information['GGDM 3.0']['SummaryDomainValues']['VCA3'][3] = u'No Available Imagery'
    field_information['GGDM 3.0']['SummaryDomainValues']['VCA3'][6] = u'No Available Map Source'
    field_information['GGDM 3.0']['SummaryDomainValues']['VCA3'][7] = u'No Suitable Imagery'
    field_information['GGDM 3.0']['SummaryDomainValues']['VCA3'][8] = u'Not Required'
    field_information['GGDM 3.0']['SummaryDomainValues']['VCA3'][9] = u'Cloud Cover'
    field_information['GGDM 3.0']['SummaryDomainValues']['VCA3'][10] = u'Snow Cover'
    field_information['GGDM 3.0']['SummaryDomainValues']['VCA3'][11] = u'Dark Shade'
    field_information['GGDM 3.0']['SummaryDomainValues']['VCA3'][12] = u'Vegetation Cover'
    field_information['GGDM 3.0']['SummaryDomainValues']['VCA3'][13] = u'Flooded'
    field_information['GGDM 3.0']['SummaryDomainValues']['VCA3'][16] = u'No Available Survey'
    field_information['GGDM 3.0']['SummaryDomainValues']['VCA3'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['VCM'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['VCM'][1] = u'Adobe Brick'
    field_information['GGDM 3.0']['SummaryDomainValues']['VCM'][2] = u'Aluminium'
    field_information['GGDM 3.0']['SummaryDomainValues']['VCM'][3] = u'Brick'
    field_information['GGDM 3.0']['SummaryDomainValues']['VCM'][4] = u'Concrete'
    field_information['GGDM 3.0']['SummaryDomainValues']['VCM'][5] = u'Fibreglass'
    field_information['GGDM 3.0']['SummaryDomainValues']['VCM'][6] = u'Glass'
    field_information['GGDM 3.0']['SummaryDomainValues']['VCM'][7] = u'Iron'
    field_information['GGDM 3.0']['SummaryDomainValues']['VCM'][8] = u'Masonry'
    field_information['GGDM 3.0']['SummaryDomainValues']['VCM'][9] = u'Metal'
    field_information['GGDM 3.0']['SummaryDomainValues']['VCM'][10] = u'Mud-based Construction'
    field_information['GGDM 3.0']['SummaryDomainValues']['VCM'][11] = u'Plant Material'
    field_information['GGDM 3.0']['SummaryDomainValues']['VCM'][12] = u'Prestressed Concrete'
    field_information['GGDM 3.0']['SummaryDomainValues']['VCM'][13] = u'Reinforced Concrete'
    field_information['GGDM 3.0']['SummaryDomainValues']['VCM'][14] = u'Sod'
    field_information['GGDM 3.0']['SummaryDomainValues']['VCM'][15] = u'Steel'
    field_information['GGDM 3.0']['SummaryDomainValues']['VCM'][16] = u'Stone'
    field_information['GGDM 3.0']['SummaryDomainValues']['VCM'][17] = u'Treated Timber'
    field_information['GGDM 3.0']['SummaryDomainValues']['VCM'][18] = u'Wood'
    field_information['GGDM 3.0']['SummaryDomainValues']['VCM'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['VCM2'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['VCM2'][1] = u'Adobe Brick'
    field_information['GGDM 3.0']['SummaryDomainValues']['VCM2'][2] = u'Aluminium'
    field_information['GGDM 3.0']['SummaryDomainValues']['VCM2'][3] = u'Brick'
    field_information['GGDM 3.0']['SummaryDomainValues']['VCM2'][4] = u'Concrete'
    field_information['GGDM 3.0']['SummaryDomainValues']['VCM2'][5] = u'Fibreglass'
    field_information['GGDM 3.0']['SummaryDomainValues']['VCM2'][6] = u'Glass'
    field_information['GGDM 3.0']['SummaryDomainValues']['VCM2'][7] = u'Iron'
    field_information['GGDM 3.0']['SummaryDomainValues']['VCM2'][8] = u'Masonry'
    field_information['GGDM 3.0']['SummaryDomainValues']['VCM2'][9] = u'Metal'
    field_information['GGDM 3.0']['SummaryDomainValues']['VCM2'][10] = u'Mud-based Construction'
    field_information['GGDM 3.0']['SummaryDomainValues']['VCM2'][11] = u'Plant Material'
    field_information['GGDM 3.0']['SummaryDomainValues']['VCM2'][12] = u'Prestressed Concrete'
    field_information['GGDM 3.0']['SummaryDomainValues']['VCM2'][13] = u'Reinforced Concrete'
    field_information['GGDM 3.0']['SummaryDomainValues']['VCM2'][14] = u'Sod'
    field_information['GGDM 3.0']['SummaryDomainValues']['VCM2'][15] = u'Steel'
    field_information['GGDM 3.0']['SummaryDomainValues']['VCM2'][16] = u'Stone'
    field_information['GGDM 3.0']['SummaryDomainValues']['VCM2'][17] = u'Treated Timber'
    field_information['GGDM 3.0']['SummaryDomainValues']['VCM2'][18] = u'Wood'
    field_information['GGDM 3.0']['SummaryDomainValues']['VCM2'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['VCM3'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['VCM3'][1] = u'Adobe Brick'
    field_information['GGDM 3.0']['SummaryDomainValues']['VCM3'][2] = u'Aluminium'
    field_information['GGDM 3.0']['SummaryDomainValues']['VCM3'][3] = u'Brick'
    field_information['GGDM 3.0']['SummaryDomainValues']['VCM3'][4] = u'Concrete'
    field_information['GGDM 3.0']['SummaryDomainValues']['VCM3'][5] = u'Fibreglass'
    field_information['GGDM 3.0']['SummaryDomainValues']['VCM3'][6] = u'Glass'
    field_information['GGDM 3.0']['SummaryDomainValues']['VCM3'][7] = u'Iron'
    field_information['GGDM 3.0']['SummaryDomainValues']['VCM3'][8] = u'Masonry'
    field_information['GGDM 3.0']['SummaryDomainValues']['VCM3'][9] = u'Metal'
    field_information['GGDM 3.0']['SummaryDomainValues']['VCM3'][10] = u'Mud-based Construction'
    field_information['GGDM 3.0']['SummaryDomainValues']['VCM3'][11] = u'Plant Material'
    field_information['GGDM 3.0']['SummaryDomainValues']['VCM3'][12] = u'Prestressed Concrete'
    field_information['GGDM 3.0']['SummaryDomainValues']['VCM3'][13] = u'Reinforced Concrete'
    field_information['GGDM 3.0']['SummaryDomainValues']['VCM3'][14] = u'Sod'
    field_information['GGDM 3.0']['SummaryDomainValues']['VCM3'][15] = u'Steel'
    field_information['GGDM 3.0']['SummaryDomainValues']['VCM3'][16] = u'Stone'
    field_information['GGDM 3.0']['SummaryDomainValues']['VCM3'][17] = u'Treated Timber'
    field_information['GGDM 3.0']['SummaryDomainValues']['VCM3'][18] = u'Wood'
    field_information['GGDM 3.0']['SummaryDomainValues']['VCM3'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['VCS_VCD'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['VCS_VCD'][7] = u'Mean High Water'
    field_information['GGDM 3.0']['SummaryDomainValues']['VCS_VCD'][9] = u'Mean High Water Springs'
    field_information['GGDM 3.0']['SummaryDomainValues']['VCS_VCD'][10] = u'Mean Higher High Water'
    field_information['GGDM 3.0']['SummaryDomainValues']['VCS_VCD'][15] = u'Mean Sea Level'
    field_information['GGDM 3.0']['SummaryDomainValues']['VCS_VCD'][24] = u'Mean Higher High Water Springs'
    field_information['GGDM 3.0']['SummaryDomainValues']['VCS_VCD'][28] = u'Highest High Water'
    field_information['GGDM 3.0']['SummaryDomainValues']['VCS_VCD'][30] = u'Indian Spring High Water'
    field_information['GGDM 3.0']['SummaryDomainValues']['VCS_VCD'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['VCT'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['VCT'][1] = u'Hypsography'
    field_information['GGDM 3.0']['SummaryDomainValues']['VCT'][3] = u'Bathymetry'
    field_information['GGDM 3.0']['SummaryDomainValues']['VCT'][4] = u'Waterbody Bottom Composition'
    field_information['GGDM 3.0']['SummaryDomainValues']['VCT'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['VCT2'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['VCT2'][1] = u'Hypsography'
    field_information['GGDM 3.0']['SummaryDomainValues']['VCT2'][3] = u'Bathymetry'
    field_information['GGDM 3.0']['SummaryDomainValues']['VCT2'][4] = u'Waterbody Bottom Composition'
    field_information['GGDM 3.0']['SummaryDomainValues']['VCT2'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['VCT3'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['VCT3'][1] = u'Hypsography'
    field_information['GGDM 3.0']['SummaryDomainValues']['VCT3'][3] = u'Bathymetry'
    field_information['GGDM 3.0']['SummaryDomainValues']['VCT3'][4] = u'Waterbody Bottom Composition'
    field_information['GGDM 3.0']['SummaryDomainValues']['VCT3'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['VDT'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['VDT'][1] = u'WGS 84 Ellipsoid'
    field_information['GGDM 3.0']['SummaryDomainValues']['VDT'][2] = u'WGS 84 EGM96 Geoid'
    field_information['GGDM 3.0']['SummaryDomainValues']['VDT'][3] = u'Mean Sea Level (MSL)'
    field_information['GGDM 3.0']['SummaryDomainValues']['VDT'][4] = u'North American Vertical Datum (NAVD) 1988'
    field_information['GGDM 3.0']['SummaryDomainValues']['VDT'][5] = u'National Geodetic Vertical Datum (NGVD) 1929'
    field_information['GGDM 3.0']['SummaryDomainValues']['VDT'][6] = u'Ground Level'
    field_information['GGDM 3.0']['SummaryDomainValues']['VDT'][7] = u'WGS 84 EGM08 Geoid'
    field_information['GGDM 3.0']['SummaryDomainValues']['VDT'][998] = u'Not Applicable'
    field_information['GGDM 3.0']['SummaryDomainValues']['VDT'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['VEG'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['VEG'][8] = u'Grassland'
    field_information['GGDM 3.0']['SummaryDomainValues']['VEG'][10] = u'Tropical Grass'
    field_information['GGDM 3.0']['SummaryDomainValues']['VEG'][61] = u'Algae'
    field_information['GGDM 3.0']['SummaryDomainValues']['VEG'][62] = u'Sea Grass'
    field_information['GGDM 3.0']['SummaryDomainValues']['VEG'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['VET'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['VET'][1] = u'Aircraft'
    field_information['GGDM 3.0']['SummaryDomainValues']['VET'][2] = u'Automobile'
    field_information['GGDM 3.0']['SummaryDomainValues']['VET'][3] = u'Barge'
    field_information['GGDM 3.0']['SummaryDomainValues']['VET'][4] = u'Bicycle'
    field_information['GGDM 3.0']['SummaryDomainValues']['VET'][5] = u'Boat'
    field_information['GGDM 3.0']['SummaryDomainValues']['VET'][6] = u'Bus'
    field_information['GGDM 3.0']['SummaryDomainValues']['VET'][7] = u'Caravanette'
    field_information['GGDM 3.0']['SummaryDomainValues']['VET'][8] = u'Caravan'
    field_information['GGDM 3.0']['SummaryDomainValues']['VET'][9] = u'Motorcycle'
    field_information['GGDM 3.0']['SummaryDomainValues']['VET'][10] = u'Ship'
    field_information['GGDM 3.0']['SummaryDomainValues']['VET'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['VGT'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['VGT'][1] = u'Cone'
    field_information['GGDM 3.0']['SummaryDomainValues']['VGT'][2] = u'Cinder Cone'
    field_information['GGDM 3.0']['SummaryDomainValues']['VGT'][3] = u'Shield'
    field_information['GGDM 3.0']['SummaryDomainValues']['VGT'][4] = u'Caldera'
    field_information['GGDM 3.0']['SummaryDomainValues']['VGT'][5] = u'Composite'
    field_information['GGDM 3.0']['SummaryDomainValues']['VIS'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['VIS'][1] = u'High Intensity'
    field_information['GGDM 3.0']['SummaryDomainValues']['VIS'][2] = u'Low Intensity'
    field_information['GGDM 3.0']['SummaryDomainValues']['VIS'][3] = u'Faint'
    field_information['GGDM 3.0']['SummaryDomainValues']['VIS'][4] = u'Intensified'
    field_information['GGDM 3.0']['SummaryDomainValues']['VIS'][5] = u'Unintensified'
    field_information['GGDM 3.0']['SummaryDomainValues']['VIS'][6] = u'Visibility Deliberately Restricted'
    field_information['GGDM 3.0']['SummaryDomainValues']['VIS'][7] = u'Obscured'
    field_information['GGDM 3.0']['SummaryDomainValues']['VIS'][8] = u'Partially Obscured'
    field_information['GGDM 3.0']['SummaryDomainValues']['VIS'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['VIS2'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['VIS2'][1] = u'High Intensity'
    field_information['GGDM 3.0']['SummaryDomainValues']['VIS2'][2] = u'Low Intensity'
    field_information['GGDM 3.0']['SummaryDomainValues']['VIS2'][3] = u'Faint'
    field_information['GGDM 3.0']['SummaryDomainValues']['VIS2'][4] = u'Intensified'
    field_information['GGDM 3.0']['SummaryDomainValues']['VIS2'][5] = u'Unintensified'
    field_information['GGDM 3.0']['SummaryDomainValues']['VIS2'][6] = u'Visibility Deliberately Restricted'
    field_information['GGDM 3.0']['SummaryDomainValues']['VIS2'][7] = u'Obscured'
    field_information['GGDM 3.0']['SummaryDomainValues']['VIS2'][8] = u'Partially Obscured'
    field_information['GGDM 3.0']['SummaryDomainValues']['VIS2'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['VIS3'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['VIS3'][1] = u'High Intensity'
    field_information['GGDM 3.0']['SummaryDomainValues']['VIS3'][2] = u'Low Intensity'
    field_information['GGDM 3.0']['SummaryDomainValues']['VIS3'][3] = u'Faint'
    field_information['GGDM 3.0']['SummaryDomainValues']['VIS3'][4] = u'Intensified'
    field_information['GGDM 3.0']['SummaryDomainValues']['VIS3'][5] = u'Unintensified'
    field_information['GGDM 3.0']['SummaryDomainValues']['VIS3'][6] = u'Visibility Deliberately Restricted'
    field_information['GGDM 3.0']['SummaryDomainValues']['VIS3'][7] = u'Obscured'
    field_information['GGDM 3.0']['SummaryDomainValues']['VIS3'][8] = u'Partially Obscured'
    field_information['GGDM 3.0']['SummaryDomainValues']['VIS3'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['VOA'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['VOA'][1] = u'Active'
    field_information['GGDM 3.0']['SummaryDomainValues']['VOA'][2] = u'Dormant'
    field_information['GGDM 3.0']['SummaryDomainValues']['VOA'][3] = u'Inactive or Extinct'
    field_information['GGDM 3.0']['SummaryDomainValues']['VSP'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['VSP'][8] = u'Cypress'
    field_information['GGDM 3.0']['SummaryDomainValues']['VSP'][17] = u'Kelp'
    field_information['GGDM 3.0']['SummaryDomainValues']['VSP'][19] = u'Mangrove'
    field_information['GGDM 3.0']['SummaryDomainValues']['VSP'][22] = u'Nipa'
    field_information['GGDM 3.0']['SummaryDomainValues']['VSP'][25] = u'Palm'
    field_information['GGDM 3.0']['SummaryDomainValues']['VSP'][28] = u'Posidonia'
    field_information['GGDM 3.0']['SummaryDomainValues']['VSP'][29] = u'Reed'
    field_information['GGDM 3.0']['SummaryDomainValues']['VSP'][30] = u'Sargassum'
    field_information['GGDM 3.0']['SummaryDomainValues']['VSP'][31] = u'Sea-tangle'
    field_information['GGDM 3.0']['SummaryDomainValues']['VSP'][34] = u'Bamboo'
    field_information['GGDM 3.0']['SummaryDomainValues']['VSP'][35] = u'Water Hyacinth'
    field_information['GGDM 3.0']['SummaryDomainValues']['VSP'][36] = u'Algae'
    field_information['GGDM 3.0']['SummaryDomainValues']['VSP'][64] = u'Swamp Cypress'
    field_information['GGDM 3.0']['SummaryDomainValues']['VSP'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['VSP2'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['VSP2'][8] = u'Cypress'
    field_information['GGDM 3.0']['SummaryDomainValues']['VSP2'][17] = u'Kelp'
    field_information['GGDM 3.0']['SummaryDomainValues']['VSP2'][19] = u'Mangrove'
    field_information['GGDM 3.0']['SummaryDomainValues']['VSP2'][22] = u'Nipa'
    field_information['GGDM 3.0']['SummaryDomainValues']['VSP2'][25] = u'Palm'
    field_information['GGDM 3.0']['SummaryDomainValues']['VSP2'][28] = u'Posidonia'
    field_information['GGDM 3.0']['SummaryDomainValues']['VSP2'][29] = u'Reed'
    field_information['GGDM 3.0']['SummaryDomainValues']['VSP2'][30] = u'Sargassum'
    field_information['GGDM 3.0']['SummaryDomainValues']['VSP2'][31] = u'Sea-tangle'
    field_information['GGDM 3.0']['SummaryDomainValues']['VSP2'][34] = u'Bamboo'
    field_information['GGDM 3.0']['SummaryDomainValues']['VSP2'][35] = u'Water Hyacinth'
    field_information['GGDM 3.0']['SummaryDomainValues']['VSP2'][36] = u'Algae'
    field_information['GGDM 3.0']['SummaryDomainValues']['VSP2'][64] = u'Swamp Cypress'
    field_information['GGDM 3.0']['SummaryDomainValues']['VSP2'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['VSP3'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['VSP3'][8] = u'Cypress'
    field_information['GGDM 3.0']['SummaryDomainValues']['VSP3'][17] = u'Kelp'
    field_information['GGDM 3.0']['SummaryDomainValues']['VSP3'][19] = u'Mangrove'
    field_information['GGDM 3.0']['SummaryDomainValues']['VSP3'][22] = u'Nipa'
    field_information['GGDM 3.0']['SummaryDomainValues']['VSP3'][25] = u'Palm'
    field_information['GGDM 3.0']['SummaryDomainValues']['VSP3'][28] = u'Posidonia'
    field_information['GGDM 3.0']['SummaryDomainValues']['VSP3'][29] = u'Reed'
    field_information['GGDM 3.0']['SummaryDomainValues']['VSP3'][30] = u'Sargassum'
    field_information['GGDM 3.0']['SummaryDomainValues']['VSP3'][31] = u'Sea-tangle'
    field_information['GGDM 3.0']['SummaryDomainValues']['VSP3'][34] = u'Bamboo'
    field_information['GGDM 3.0']['SummaryDomainValues']['VSP3'][35] = u'Water Hyacinth'
    field_information['GGDM 3.0']['SummaryDomainValues']['VSP3'][36] = u'Algae'
    field_information['GGDM 3.0']['SummaryDomainValues']['VSP3'][64] = u'Swamp Cypress'
    field_information['GGDM 3.0']['SummaryDomainValues']['VSP3'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['WCC'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['WCC'][1] = u'Channelized Stream'
    field_information['GGDM 3.0']['SummaryDomainValues']['WCC'][2] = u'Braided Stream'
    field_information['GGDM 3.0']['SummaryDomainValues']['WCC'][3] = u'Gorge'
    field_information['GGDM 3.0']['SummaryDomainValues']['WCC'][4] = u'Wadi'
    field_information['GGDM 3.0']['SummaryDomainValues']['WCC'][7] = u'Normal Channel'
    field_information['GGDM 3.0']['SummaryDomainValues']['WCC'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['WDAC'][2] = u'Open Interval'
    field_information['GGDM 3.0']['SummaryDomainValues']['WDAC'][3] = u'Greater-than-or-equal to Less-than Interval'
    field_information['GGDM 3.0']['SummaryDomainValues']['WDAC'][4] = u'Greater-than to Less-than-or-equal Interval'
    field_information['GGDM 3.0']['SummaryDomainValues']['WDAC'][5] = u'Closed Interval'
    field_information['GGDM 3.0']['SummaryDomainValues']['WDAC'][6] = u'Greater-than Semi-interval'
    field_information['GGDM 3.0']['SummaryDomainValues']['WDAC'][7] = u'Greater-than or Equal Semi-interval'
    field_information['GGDM 3.0']['SummaryDomainValues']['WDAC'][8] = u'Less-than Semi-interval'
    field_information['GGDM 3.0']['SummaryDomainValues']['WDAC'][9] = u'Less-than or Equal Semi-interval'
    field_information['GGDM 3.0']['SummaryDomainValues']['WDST'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['WDST'][1] = u'None'
    field_information['GGDM 3.0']['SummaryDomainValues']['WDST'][2] = u'No Current System but Nearby System'
    field_information['GGDM 3.0']['SummaryDomainValues']['WDST'][3] = u'Manual Labor-Transported'
    field_information['GGDM 3.0']['SummaryDomainValues']['WDST'][4] = u'Water Storage Tanks/Trucks'
    field_information['GGDM 3.0']['SummaryDomainValues']['WDST'][5] = u'Simple Gravity'
    field_information['GGDM 3.0']['SummaryDomainValues']['WDST'][6] = u'Complex Gravity'
    field_information['GGDM 3.0']['SummaryDomainValues']['WDST'][7] = u'Small Pumped and Piped'
    field_information['GGDM 3.0']['SummaryDomainValues']['WDST'][8] = u'Large Urban System'
    field_information['GGDM 3.0']['SummaryDomainValues']['WDST'][998] = u'Not Applicable'
    field_information['GGDM 3.0']['SummaryDomainValues']['WDST'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['WEQ'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['WEQ'][1] = u'Wellhead'
    field_information['GGDM 3.0']['SummaryDomainValues']['WEQ'][2] = u'Christmas Tree'
    field_information['GGDM 3.0']['SummaryDomainValues']['WEQ'][3] = u'Manifold'
    field_information['GGDM 3.0']['SummaryDomainValues']['WEQ'][4] = u'Protective Structure'
    field_information['GGDM 3.0']['SummaryDomainValues']['WEQ'][5] = u'Pump'
    field_information['GGDM 3.0']['SummaryDomainValues']['WEQ'][6] = u'Rod Pump'
    field_information['GGDM 3.0']['SummaryDomainValues']['WEQ'][7] = u'Separator'
    field_information['GGDM 3.0']['SummaryDomainValues']['WEQ'][8] = u'Stock Tank'
    field_information['GGDM 3.0']['SummaryDomainValues']['WEQ'][9] = u'Treater'
    field_information['GGDM 3.0']['SummaryDomainValues']['WEQ'][10] = u'Capped'
    field_information['GGDM 3.0']['SummaryDomainValues']['WEQ'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['WEQ2'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['WEQ2'][1] = u'Wellhead'
    field_information['GGDM 3.0']['SummaryDomainValues']['WEQ2'][2] = u'Christmas Tree'
    field_information['GGDM 3.0']['SummaryDomainValues']['WEQ2'][3] = u'Manifold'
    field_information['GGDM 3.0']['SummaryDomainValues']['WEQ2'][4] = u'Protective Structure'
    field_information['GGDM 3.0']['SummaryDomainValues']['WEQ2'][5] = u'Pump'
    field_information['GGDM 3.0']['SummaryDomainValues']['WEQ2'][6] = u'Rod Pump'
    field_information['GGDM 3.0']['SummaryDomainValues']['WEQ2'][7] = u'Separator'
    field_information['GGDM 3.0']['SummaryDomainValues']['WEQ2'][8] = u'Stock Tank'
    field_information['GGDM 3.0']['SummaryDomainValues']['WEQ2'][9] = u'Treater'
    field_information['GGDM 3.0']['SummaryDomainValues']['WEQ2'][10] = u'Capped'
    field_information['GGDM 3.0']['SummaryDomainValues']['WEQ2'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['WEQ3'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['WEQ3'][1] = u'Wellhead'
    field_information['GGDM 3.0']['SummaryDomainValues']['WEQ3'][2] = u'Christmas Tree'
    field_information['GGDM 3.0']['SummaryDomainValues']['WEQ3'][3] = u'Manifold'
    field_information['GGDM 3.0']['SummaryDomainValues']['WEQ3'][4] = u'Protective Structure'
    field_information['GGDM 3.0']['SummaryDomainValues']['WEQ3'][5] = u'Pump'
    field_information['GGDM 3.0']['SummaryDomainValues']['WEQ3'][6] = u'Rod Pump'
    field_information['GGDM 3.0']['SummaryDomainValues']['WEQ3'][7] = u'Separator'
    field_information['GGDM 3.0']['SummaryDomainValues']['WEQ3'][8] = u'Stock Tank'
    field_information['GGDM 3.0']['SummaryDomainValues']['WEQ3'][9] = u'Treater'
    field_information['GGDM 3.0']['SummaryDomainValues']['WEQ3'][10] = u'Capped'
    field_information['GGDM 3.0']['SummaryDomainValues']['WEQ3'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['WFT'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['WFT'][2] = u'Walled-in'
    field_information['GGDM 3.0']['SummaryDomainValues']['WFT'][3] = u'Artesian'
    field_information['GGDM 3.0']['SummaryDomainValues']['WFT'][5] = u'Dug or Drilled'
    field_information['GGDM 3.0']['SummaryDomainValues']['WFT'][6] = u'Dug'
    field_information['GGDM 3.0']['SummaryDomainValues']['WFT'][7] = u'Drilled'
    field_information['GGDM 3.0']['SummaryDomainValues']['WFT'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['WLE'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['WLE'][1] = u'Partly Submerged'
    field_information['GGDM 3.0']['SummaryDomainValues']['WLE'][2] = u'Always Dry'
    field_information['GGDM 3.0']['SummaryDomainValues']['WLE'][3] = u'Always Submerged'
    field_information['GGDM 3.0']['SummaryDomainValues']['WLE'][4] = u'Covers and Uncovers'
    field_information['GGDM 3.0']['SummaryDomainValues']['WLE'][5] = u'Awash at Low Water'
    field_information['GGDM 3.0']['SummaryDomainValues']['WLE'][9] = u'Awash at Chart Datum'
    field_information['GGDM 3.0']['SummaryDomainValues']['WLE'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['WLO'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['WLO'][1] = u'Hull Showing'
    field_information['GGDM 3.0']['SummaryDomainValues']['WLO'][2] = u'Masts Showing'
    field_information['GGDM 3.0']['SummaryDomainValues']['WLO'][3] = u'Funnel Showing'
    field_information['GGDM 3.0']['SummaryDomainValues']['WLO'][4] = u'Superstructure Showing'
    field_information['GGDM 3.0']['SummaryDomainValues']['WLO'][5] = u'Masts and Funnel Showing'
    field_information['GGDM 3.0']['SummaryDomainValues']['WLO'][6] = u'Not Exposed'
    field_information['GGDM 3.0']['SummaryDomainValues']['WLO'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['WMT'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['WMT'][1] = u'Mouth'
    field_information['GGDM 3.0']['SummaryDomainValues']['WMT'][2] = u'Pool'
    field_information['GGDM 3.0']['SummaryDomainValues']['WMT'][3] = u'Bend'
    field_information['GGDM 3.0']['SummaryDomainValues']['WMT'][4] = u'Confluence'
    field_information['GGDM 3.0']['SummaryDomainValues']['WMT'][5] = u'Cut-off'
    field_information['GGDM 3.0']['SummaryDomainValues']['WMT'][6] = u'Reach'
    field_information['GGDM 3.0']['SummaryDomainValues']['WMT'][7] = u'Anabranch'
    field_information['GGDM 3.0']['SummaryDomainValues']['WMT'][8] = u'Canalized'
    field_information['GGDM 3.0']['SummaryDomainValues']['WMT'][9] = u'Distributary'
    field_information['GGDM 3.0']['SummaryDomainValues']['WMT'][10] = u'Headwaters'
    field_information['GGDM 3.0']['SummaryDomainValues']['WMT'][11] = u'Abandoned'
    field_information['GGDM 3.0']['SummaryDomainValues']['WMT'][12] = u'Meander'
    field_information['GGDM 3.0']['SummaryDomainValues']['WMT'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['WODR'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['WODR'][1] = u'None'
    field_information['GGDM 3.0']['SummaryDomainValues']['WODR'][2] = u'Sulphur/Rotten Egg'
    field_information['GGDM 3.0']['SummaryDomainValues']['WODR'][3] = u'Detergent'
    field_information['GGDM 3.0']['SummaryDomainValues']['WODR'][4] = u'Gasoline/Oil'
    field_information['GGDM 3.0']['SummaryDomainValues']['WODR'][5] = u'Chlorine'
    field_information['GGDM 3.0']['SummaryDomainValues']['WODR'][6] = u'Methane Gas/Earthy'
    field_information['GGDM 3.0']['SummaryDomainValues']['WODR'][7] = u'Phenolic or Chemical'
    field_information['GGDM 3.0']['SummaryDomainValues']['WODR'][998] = u'Not Applicable'
    field_information['GGDM 3.0']['SummaryDomainValues']['WODR'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['WPC'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['WPC'][1] = u'Land Reclamation'
    field_information['GGDM 3.0']['SummaryDomainValues']['WPC'][2] = u'Construction of Structures'
    field_information['GGDM 3.0']['SummaryDomainValues']['WPC'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['WPC2'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['WPC2'][1] = u'Land Reclamation'
    field_information['GGDM 3.0']['SummaryDomainValues']['WPC2'][2] = u'Construction of Structures'
    field_information['GGDM 3.0']['SummaryDomainValues']['WPC2'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['WPC3'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['WPC3'][1] = u'Land Reclamation'
    field_information['GGDM 3.0']['SummaryDomainValues']['WPC3'][2] = u'Construction of Structures'
    field_information['GGDM 3.0']['SummaryDomainValues']['WPC3'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['WRCC'][2] = u'Open Interval'
    field_information['GGDM 3.0']['SummaryDomainValues']['WRCC'][3] = u'Greater-than-or-equal to Less-than Interval'
    field_information['GGDM 3.0']['SummaryDomainValues']['WRCC'][4] = u'Greater-than to Less-than-or-equal Interval'
    field_information['GGDM 3.0']['SummaryDomainValues']['WRCC'][5] = u'Closed Interval'
    field_information['GGDM 3.0']['SummaryDomainValues']['WRCC'][6] = u'Greater-than Semi-interval'
    field_information['GGDM 3.0']['SummaryDomainValues']['WRCC'][7] = u'Greater-than or Equal Semi-interval'
    field_information['GGDM 3.0']['SummaryDomainValues']['WRCC'][8] = u'Less-than Semi-interval'
    field_information['GGDM 3.0']['SummaryDomainValues']['WRCC'][9] = u'Less-than or Equal Semi-interval'
    field_information['GGDM 3.0']['SummaryDomainValues']['WRT'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['WRT'][1] = u'Sluice'
    field_information['GGDM 3.0']['SummaryDomainValues']['WRT'][2] = u'Flume'
    field_information['GGDM 3.0']['SummaryDomainValues']['WRT'][3] = u'Headrace'
    field_information['GGDM 3.0']['SummaryDomainValues']['WRT'][4] = u'Tailrace'
    field_information['GGDM 3.0']['SummaryDomainValues']['WSRC'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['WSRC'][1] = u'Well/Ground Water'
    field_information['GGDM 3.0']['SummaryDomainValues']['WSRC'][2] = u'Surface Water'
    field_information['GGDM 3.0']['SummaryDomainValues']['WSRC'][3] = u'Piped Water Supply'
    field_information['GGDM 3.0']['SummaryDomainValues']['WSRC'][4] = u'Delivered Water Supply'
    field_information['GGDM 3.0']['SummaryDomainValues']['WSRC'][5] = u'Rain fed/Cistern'
    field_information['GGDM 3.0']['SummaryDomainValues']['WSRC'][998] = u'Not Applicable'
    field_information['GGDM 3.0']['SummaryDomainValues']['WSRC'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['WST'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['WST'][1] = u'Dissipating'
    field_information['GGDM 3.0']['SummaryDomainValues']['WST'][2] = u'Disappearing'
    field_information['GGDM 3.0']['SummaryDomainValues']['WST'][3] = u'Sinkhole'
    field_information['GGDM 3.0']['SummaryDomainValues']['WST'][4] = u'Hole'
    field_information['GGDM 3.0']['SummaryDomainValues']['WST'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['WTI'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['WTI'][1] = u'Free-standing'
    field_information['GGDM 3.0']['SummaryDomainValues']['WTI'][2] = u'Retaining'
    field_information['GGDM 3.0']['SummaryDomainValues']['WTI'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['WTST'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['WTST'][1] = u'Quick Field Test'
    field_information['GGDM 3.0']['SummaryDomainValues']['WTST'][2] = u'Complex Lab Test'
    field_information['GGDM 3.0']['SummaryDomainValues']['WTST'][998] = u'Not Applicable'
    field_information['GGDM 3.0']['SummaryDomainValues']['WTST'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['WTT'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['WTT'][1] = u'    Spilling Breakers'
    field_information['GGDM 3.0']['SummaryDomainValues']['WTT'][2] = u'    Plunging Breakers'
    field_information['GGDM 3.0']['SummaryDomainValues']['WTT'][3] = u'    Surging Breakers'
    field_information['GGDM 3.0']['SummaryDomainValues']['WTT'][4] = u'Eddies'
    field_information['GGDM 3.0']['SummaryDomainValues']['WTT'][5] = u'Overfalls'
    field_information['GGDM 3.0']['SummaryDomainValues']['WTT'][6] = u'Tide Rips'
    field_information['GGDM 3.0']['SummaryDomainValues']['WTT'][7] = u'Whirlpool'
    field_information['GGDM 3.0']['SummaryDomainValues']['WTT'][8] = u'Breakers'
    field_information['GGDM 3.0']['SummaryDomainValues']['WTT'][9] = u'Confused Seas'
    field_information['GGDM 3.0']['SummaryDomainValues']['WTT'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['WTYP'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['WTYP'][1] = u'Open with Bars'
    field_information['GGDM 3.0']['SummaryDomainValues']['WTYP'][2] = u'Open without Bars'
    field_information['GGDM 3.0']['SummaryDomainValues']['WTYP'][3] = u'Plastic with Bars'
    field_information['GGDM 3.0']['SummaryDomainValues']['WTYP'][4] = u'Plastic without Bars'
    field_information['GGDM 3.0']['SummaryDomainValues']['WTYP'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['WWM'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['WWM'][1] = u'Basalt'
    field_information['GGDM 3.0']['SummaryDomainValues']['WWM'][2] = u'Boulders'
    field_information['GGDM 3.0']['SummaryDomainValues']['WWM'][3] = u'Clay'
    field_information['GGDM 3.0']['SummaryDomainValues']['WWM'][4] = u'Conglomerate'
    field_information['GGDM 3.0']['SummaryDomainValues']['WWM'][5] = u'Dolomite'
    field_information['GGDM 3.0']['SummaryDomainValues']['WWM'][6] = u'Granite'
    field_information['GGDM 3.0']['SummaryDomainValues']['WWM'][7] = u'Gravel'
    field_information['GGDM 3.0']['SummaryDomainValues']['WWM'][8] = u'Igneous Rock'
    field_information['GGDM 3.0']['SummaryDomainValues']['WWM'][9] = u'Karst'
    field_information['GGDM 3.0']['SummaryDomainValues']['WWM'][10] = u'Limestone'
    field_information['GGDM 3.0']['SummaryDomainValues']['WWM'][11] = u'Marl'
    field_information['GGDM 3.0']['SummaryDomainValues']['WWM'][12] = u'Metamorphic Rock'
    field_information['GGDM 3.0']['SummaryDomainValues']['WWM'][13] = u'Mud'
    field_information['GGDM 3.0']['SummaryDomainValues']['WWM'][14] = u'Sand'
    field_information['GGDM 3.0']['SummaryDomainValues']['WWM'][15] = u'Schist'
    field_information['GGDM 3.0']['SummaryDomainValues']['WWM'][16] = u'Unconsolidated'
    field_information['GGDM 3.0']['SummaryDomainValues']['WWM'][17] = u'Semi-consolidated and Consolidated Volcanic Ash'
    field_information['GGDM 3.0']['SummaryDomainValues']['WWM'][18] = u'Volcanic Rock'
    field_information['GGDM 3.0']['SummaryDomainValues']['WWM'][19] = u'Sandstone'
    field_information['GGDM 3.0']['SummaryDomainValues']['WWM'][20] = u'Shale'
    field_information['GGDM 3.0']['SummaryDomainValues']['WWM'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['WWM2'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['WWM2'][1] = u'Basalt'
    field_information['GGDM 3.0']['SummaryDomainValues']['WWM2'][2] = u'Boulders'
    field_information['GGDM 3.0']['SummaryDomainValues']['WWM2'][3] = u'Clay'
    field_information['GGDM 3.0']['SummaryDomainValues']['WWM2'][4] = u'Conglomerate'
    field_information['GGDM 3.0']['SummaryDomainValues']['WWM2'][5] = u'Dolomite'
    field_information['GGDM 3.0']['SummaryDomainValues']['WWM2'][6] = u'Granite'
    field_information['GGDM 3.0']['SummaryDomainValues']['WWM2'][7] = u'Gravel'
    field_information['GGDM 3.0']['SummaryDomainValues']['WWM2'][8] = u'Igneous Rock'
    field_information['GGDM 3.0']['SummaryDomainValues']['WWM2'][9] = u'Karst'
    field_information['GGDM 3.0']['SummaryDomainValues']['WWM2'][10] = u'Limestone'
    field_information['GGDM 3.0']['SummaryDomainValues']['WWM2'][11] = u'Marl'
    field_information['GGDM 3.0']['SummaryDomainValues']['WWM2'][12] = u'Metamorphic Rock'
    field_information['GGDM 3.0']['SummaryDomainValues']['WWM2'][13] = u'Mud'
    field_information['GGDM 3.0']['SummaryDomainValues']['WWM2'][14] = u'Sand'
    field_information['GGDM 3.0']['SummaryDomainValues']['WWM2'][15] = u'Schist'
    field_information['GGDM 3.0']['SummaryDomainValues']['WWM2'][16] = u'Unconsolidated'
    field_information['GGDM 3.0']['SummaryDomainValues']['WWM2'][17] = u'Semi-consolidated and Consolidated Volcanic Ash'
    field_information['GGDM 3.0']['SummaryDomainValues']['WWM2'][18] = u'Volcanic Rock'
    field_information['GGDM 3.0']['SummaryDomainValues']['WWM2'][19] = u'Sandstone'
    field_information['GGDM 3.0']['SummaryDomainValues']['WWM2'][20] = u'Shale'
    field_information['GGDM 3.0']['SummaryDomainValues']['WWM2'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['WWM3'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['WWM3'][1] = u'Basalt'
    field_information['GGDM 3.0']['SummaryDomainValues']['WWM3'][2] = u'Boulders'
    field_information['GGDM 3.0']['SummaryDomainValues']['WWM3'][3] = u'Clay'
    field_information['GGDM 3.0']['SummaryDomainValues']['WWM3'][4] = u'Conglomerate'
    field_information['GGDM 3.0']['SummaryDomainValues']['WWM3'][5] = u'Dolomite'
    field_information['GGDM 3.0']['SummaryDomainValues']['WWM3'][6] = u'Granite'
    field_information['GGDM 3.0']['SummaryDomainValues']['WWM3'][7] = u'Gravel'
    field_information['GGDM 3.0']['SummaryDomainValues']['WWM3'][8] = u'Igneous Rock'
    field_information['GGDM 3.0']['SummaryDomainValues']['WWM3'][9] = u'Karst'
    field_information['GGDM 3.0']['SummaryDomainValues']['WWM3'][10] = u'Limestone'
    field_information['GGDM 3.0']['SummaryDomainValues']['WWM3'][11] = u'Marl'
    field_information['GGDM 3.0']['SummaryDomainValues']['WWM3'][12] = u'Metamorphic Rock'
    field_information['GGDM 3.0']['SummaryDomainValues']['WWM3'][13] = u'Mud'
    field_information['GGDM 3.0']['SummaryDomainValues']['WWM3'][14] = u'Sand'
    field_information['GGDM 3.0']['SummaryDomainValues']['WWM3'][15] = u'Schist'
    field_information['GGDM 3.0']['SummaryDomainValues']['WWM3'][16] = u'Unconsolidated'
    field_information['GGDM 3.0']['SummaryDomainValues']['WWM3'][17] = u'Semi-consolidated and Consolidated Volcanic Ash'
    field_information['GGDM 3.0']['SummaryDomainValues']['WWM3'][18] = u'Volcanic Rock'
    field_information['GGDM 3.0']['SummaryDomainValues']['WWM3'][19] = u'Sandstone'
    field_information['GGDM 3.0']['SummaryDomainValues']['WWM3'][20] = u'Shale'
    field_information['GGDM 3.0']['SummaryDomainValues']['WWM3'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['WWRC'][2] = u'Open Interval'
    field_information['GGDM 3.0']['SummaryDomainValues']['WWRC'][3] = u'Greater-than-or-equal to Less-than Interval'
    field_information['GGDM 3.0']['SummaryDomainValues']['WWRC'][4] = u'Greater-than to Less-than-or-equal Interval'
    field_information['GGDM 3.0']['SummaryDomainValues']['WWRC'][5] = u'Closed Interval'
    field_information['GGDM 3.0']['SummaryDomainValues']['WWRC'][6] = u'Greater-than Semi-interval'
    field_information['GGDM 3.0']['SummaryDomainValues']['WWRC'][7] = u'Greater-than or Equal Semi-interval'
    field_information['GGDM 3.0']['SummaryDomainValues']['WWRC'][8] = u'Less-than Semi-interval'
    field_information['GGDM 3.0']['SummaryDomainValues']['WWRC'][9] = u'Less-than or Equal Semi-interval'
    field_information['GGDM 3.0']['SummaryDomainValues']['YSU'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['YSU'][1] = u'Air Force'
    field_information['GGDM 3.0']['SummaryDomainValues']['YSU'][2] = u'Army'
    field_information['GGDM 3.0']['SummaryDomainValues']['YSU'][3] = u'Coastguard'
    field_information['GGDM 3.0']['SummaryDomainValues']['YSU'][4] = u'Marines'
    field_information['GGDM 3.0']['SummaryDomainValues']['YSU'][5] = u'Navy'
    field_information['GGDM 3.0']['SummaryDomainValues']['YSU'][7] = u'Joint'
    field_information['GGDM 3.0']['SummaryDomainValues']['YSU'][8] = u'Air National Guard'
    field_information['GGDM 3.0']['SummaryDomainValues']['YSU'][9] = u'Army National Guard'
    field_information['GGDM 3.0']['SummaryDomainValues']['YSU'][998] = u'Not Applicable'
    field_information['GGDM 3.0']['SummaryDomainValues']['YSU'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['YWQ'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['YWQ'][1] = u'Potable'
    field_information['GGDM 3.0']['SummaryDomainValues']['YWQ'][2] = u'Treatable'
    field_information['GGDM 3.0']['SummaryDomainValues']['YWQ'][3] = u'Contaminated'
    field_information['GGDM 3.0']['SummaryDomainValues']['YWQ'][4] = u'Nonpotable'
    field_information['GGDM 3.0']['SummaryDomainValues']['YWQ'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHBH_DCR'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHBH_DCR'][1000] = u'False'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHBH_DCR'][1001] = u'True'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHBH_DKC'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHBH_DKC'][1] = u'Depth Known'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHBH_DKC'][3] = u'Safe Clearance Known'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHBH_DKC'][4] = u'Depth Unknown'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHBH_DKC'][5] = u'Depth Doubtful'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHBH_DKC'][6] = u'Depth Unreliable'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHBH_DKC'][7] = u'No Bottom'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHBH_DKC'][8] = u'Least Depth'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHBH_DKC'][9] = u'Reported Depth'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHBH_DKC'][10] = u'Unconfirmed Depth'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHBH_DKC'][11] = u'Maintained Depth'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHBH_DKC'][12] = u'Unmaintained Depth'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHBH_DKC'][998] = u'Not Applicable'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHBH_DKC'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHBH_DKC2'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHBH_DKC2'][1] = u'Depth Known'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHBH_DKC2'][3] = u'Safe Clearance Known'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHBH_DKC2'][4] = u'Depth Unknown'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHBH_DKC2'][5] = u'Depth Doubtful'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHBH_DKC2'][6] = u'Depth Unreliable'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHBH_DKC2'][7] = u'No Bottom'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHBH_DKC2'][8] = u'Least Depth'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHBH_DKC2'][9] = u'Reported Depth'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHBH_DKC2'][10] = u'Unconfirmed Depth'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHBH_DKC2'][11] = u'Maintained Depth'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHBH_DKC2'][12] = u'Unmaintained Depth'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHBH_DKC2'][998] = u'Not Applicable'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHBH_DKC2'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHBH_DKC3'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHBH_DKC3'][1] = u'Depth Known'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHBH_DKC3'][3] = u'Safe Clearance Known'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHBH_DKC3'][4] = u'Depth Unknown'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHBH_DKC3'][5] = u'Depth Doubtful'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHBH_DKC3'][6] = u'Depth Unreliable'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHBH_DKC3'][7] = u'No Bottom'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHBH_DKC3'][8] = u'Least Depth'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHBH_DKC3'][9] = u'Reported Depth'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHBH_DKC3'][10] = u'Unconfirmed Depth'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHBH_DKC3'][11] = u'Maintained Depth'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHBH_DKC3'][12] = u'Unmaintained Depth'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHBH_DKC3'][998] = u'Not Applicable'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHBH_DKC3'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHBH_SVC'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHBH_SVC'][1] = u'Sounder 4800 Calibrated'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHBH_SVC'][2] = u'Sounder 1500 Calibrated'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHBH_SVC'][3] = u'Mathews Tables'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHBH_SVC'][4] = u'Sound Velocity Meter'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHBH_SVC'][5] = u'Sounder Other Calibrated'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHBH_SVC'][998] = u'Not Applicable'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHBH_SVC'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHBH_TEC'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHBH_TEC'][1] = u'Echo Sounder'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHBH_TEC'][2] = u'Side-scan Sonar'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHBH_TEC'][3] = u'Multi-beam Echo Sounder'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHBH_TEC'][4] = u'Diver'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHBH_TEC'][5] = u'Lead-line'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHBH_TEC'][6] = u'Area Swept by Wire-drag'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHBH_TEC'][8] = u'Area Swept by Vertical Acoustic System'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHBH_TEC'][9] = u'Electromagnetic Sensor'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHBH_TEC'][10] = u'Photogrammetry'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHBH_TEC'][11] = u'Satellite Imagery'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHBH_TEC'][12] = u'Levelling'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHBH_TEC'][13] = u'Computer Generated'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHBH_TEC'][14] = u'Area Swept by Side-scan Sonar'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHBH_TEC'][15] = u'Bathymetric LiDAR'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHBH_TEC'][17] = u'Singlebeam'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHBH_TEC'][18] = u'Underwater Utility Vehicle'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHBH_TEC'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHBH_TEC2'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHBH_TEC2'][1] = u'Echo Sounder'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHBH_TEC2'][2] = u'Side-scan Sonar'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHBH_TEC2'][3] = u'Multi-beam Echo Sounder'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHBH_TEC2'][4] = u'Diver'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHBH_TEC2'][5] = u'Lead-line'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHBH_TEC2'][6] = u'Area Swept by Wire-drag'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHBH_TEC2'][8] = u'Area Swept by Vertical Acoustic System'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHBH_TEC2'][9] = u'Electromagnetic Sensor'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHBH_TEC2'][10] = u'Photogrammetry'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHBH_TEC2'][11] = u'Satellite Imagery'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHBH_TEC2'][12] = u'Levelling'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHBH_TEC2'][13] = u'Computer Generated'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHBH_TEC2'][14] = u'Area Swept by Side-scan Sonar'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHBH_TEC2'][15] = u'Bathymetric LiDAR'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHBH_TEC2'][17] = u'Singlebeam'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHBH_TEC2'][18] = u'Underwater Utility Vehicle'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHBH_TEC2'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHBH_TEC3'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHBH_TEC3'][1] = u'Echo Sounder'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHBH_TEC3'][2] = u'Side-scan Sonar'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHBH_TEC3'][3] = u'Multi-beam Echo Sounder'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHBH_TEC3'][4] = u'Diver'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHBH_TEC3'][5] = u'Lead-line'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHBH_TEC3'][6] = u'Area Swept by Wire-drag'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHBH_TEC3'][8] = u'Area Swept by Vertical Acoustic System'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHBH_TEC3'][9] = u'Electromagnetic Sensor'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHBH_TEC3'][10] = u'Photogrammetry'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHBH_TEC3'][11] = u'Satellite Imagery'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHBH_TEC3'][12] = u'Levelling'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHBH_TEC3'][13] = u'Computer Generated'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHBH_TEC3'][14] = u'Area Swept by Side-scan Sonar'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHBH_TEC3'][15] = u'Bathymetric LiDAR'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHBH_TEC3'][17] = u'Singlebeam'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHBH_TEC3'][18] = u'Underwater Utility Vehicle'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHBH_TEC3'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHBH_VDC'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHBH_VDC'][2] = u'High Water'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHBH_VDC'][3] = u'Higher High Water'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHBH_VDC'][4] = u'Indian Spring Low Water'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHBH_VDC'][5] = u'Low Water'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHBH_VDC'][6] = u'Lower Low Water'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHBH_VDC'][7] = u'Mean High Water'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHBH_VDC'][8] = u'Mean High Water Neaps'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHBH_VDC'][9] = u'Mean High Water Springs'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHBH_VDC'][10] = u'Mean Higher High Water'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHBH_VDC'][11] = u'Mean Low Water'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHBH_VDC'][12] = u'Mean Low Water Neaps'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHBH_VDC'][13] = u'Mean Low Water Springs'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHBH_VDC'][14] = u'Mean Lower Low Water'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHBH_VDC'][15] = u'Mean Sea Level'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHBH_VDC'][16] = u'Mean Tide Level'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHBH_VDC'][17] = u'Neap Tide'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHBH_VDC'][18] = u'Spring Tide'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHBH_VDC'][19] = u'Mean Lower Low Water Springs'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHBH_VDC'][20] = u'Lowest Astronomical Tide'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHBH_VDC'][21] = u'Chart Datum (Unspecified)'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHBH_VDC'][22] = u'Highest Astronomical Tide'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHBH_VDC'][24] = u'Mean Higher High Water Springs'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHBH_VDC'][28] = u'Highest High Water'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHBH_VDC'][30] = u'Indian Spring High Water'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHBH_VDC'][90] = u'Lowest Low Water'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHBH_VDC'][91] = u'Lowest Low Water Springs'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHBH_VDC'][92] = u'Approximate Mean Low Water Springs'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHBH_VDC'][93] = u'Low Water Springs'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHBH_VDC'][94] = u'Approximate Lowest Astronomical Tide'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHBH_VDC'][95] = u'Nearly Lowest Low Water'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHBH_VDC'][96] = u'Approximate Mean Low Water'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHBH_VDC'][97] = u'Approximate Mean Lower Low Water'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHBH_VDC'][98] = u'Approximate Mean Sea Level'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHBH_VDC'][99] = u'High Water Springs'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHBH_VDC'][100] = u'Equinoctial Spring Low Water'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHBH_VDC'][101] = u'Local Datum'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHBH_VDC'][102] = u'International Great Lakes Datum 1985'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHBH_VDC'][103] = u'Mean Water Level'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHBH_VDC'][104] = u'Lower Low Water Large Tide'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHBH_VDC'][105] = u'Higher High Water Large Tide'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHBH_VDC'][107] = u'Nearly Highest High Water'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHBH_VDC'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHDP_DCR'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHDP_DCR'][1000] = u'False'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHDP_DCR'][1001] = u'True'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHDP_DKC'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHDP_DKC'][1] = u'Depth Known'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHDP_DKC'][3] = u'Safe Clearance Known'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHDP_DKC'][4] = u'Depth Unknown'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHDP_DKC'][5] = u'Depth Doubtful'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHDP_DKC'][6] = u'Depth Unreliable'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHDP_DKC'][7] = u'No Bottom'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHDP_DKC'][8] = u'Least Depth'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHDP_DKC'][9] = u'Reported Depth'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHDP_DKC'][10] = u'Unconfirmed Depth'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHDP_DKC'][11] = u'Maintained Depth'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHDP_DKC'][12] = u'Unmaintained Depth'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHDP_DKC'][998] = u'Not Applicable'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHDP_DKC'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHDP_DKC2'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHDP_DKC2'][1] = u'Depth Known'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHDP_DKC2'][3] = u'Safe Clearance Known'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHDP_DKC2'][4] = u'Depth Unknown'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHDP_DKC2'][5] = u'Depth Doubtful'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHDP_DKC2'][6] = u'Depth Unreliable'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHDP_DKC2'][7] = u'No Bottom'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHDP_DKC2'][8] = u'Least Depth'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHDP_DKC2'][9] = u'Reported Depth'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHDP_DKC2'][10] = u'Unconfirmed Depth'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHDP_DKC2'][11] = u'Maintained Depth'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHDP_DKC2'][12] = u'Unmaintained Depth'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHDP_DKC2'][998] = u'Not Applicable'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHDP_DKC2'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHDP_DKC3'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHDP_DKC3'][1] = u'Depth Known'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHDP_DKC3'][3] = u'Safe Clearance Known'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHDP_DKC3'][4] = u'Depth Unknown'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHDP_DKC3'][5] = u'Depth Doubtful'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHDP_DKC3'][6] = u'Depth Unreliable'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHDP_DKC3'][7] = u'No Bottom'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHDP_DKC3'][8] = u'Least Depth'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHDP_DKC3'][9] = u'Reported Depth'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHDP_DKC3'][10] = u'Unconfirmed Depth'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHDP_DKC3'][11] = u'Maintained Depth'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHDP_DKC3'][12] = u'Unmaintained Depth'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHDP_DKC3'][998] = u'Not Applicable'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHDP_DKC3'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHDP_SVC'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHDP_SVC'][1] = u'Sounder 4800 Calibrated'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHDP_SVC'][2] = u'Sounder 1500 Calibrated'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHDP_SVC'][3] = u'Mathews Tables'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHDP_SVC'][4] = u'Sound Velocity Meter'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHDP_SVC'][5] = u'Sounder Other Calibrated'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHDP_SVC'][998] = u'Not Applicable'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHDP_SVC'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHDP_TEC'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHDP_TEC'][1] = u'Echo Sounder'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHDP_TEC'][2] = u'Side-scan Sonar'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHDP_TEC'][3] = u'Multi-beam Echo Sounder'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHDP_TEC'][4] = u'Diver'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHDP_TEC'][5] = u'Lead-line'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHDP_TEC'][6] = u'Area Swept by Wire-drag'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHDP_TEC'][8] = u'Area Swept by Vertical Acoustic System'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHDP_TEC'][9] = u'Electromagnetic Sensor'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHDP_TEC'][10] = u'Photogrammetry'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHDP_TEC'][11] = u'Satellite Imagery'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHDP_TEC'][12] = u'Levelling'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHDP_TEC'][13] = u'Computer Generated'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHDP_TEC'][14] = u'Area Swept by Side-scan Sonar'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHDP_TEC'][15] = u'Bathymetric LiDAR'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHDP_TEC'][17] = u'Singlebeam'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHDP_TEC'][18] = u'Underwater Utility Vehicle'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHDP_TEC'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHDP_TEC2'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHDP_TEC2'][1] = u'Echo Sounder'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHDP_TEC2'][2] = u'Side-scan Sonar'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHDP_TEC2'][3] = u'Multi-beam Echo Sounder'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHDP_TEC2'][4] = u'Diver'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHDP_TEC2'][5] = u'Lead-line'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHDP_TEC2'][6] = u'Area Swept by Wire-drag'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHDP_TEC2'][8] = u'Area Swept by Vertical Acoustic System'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHDP_TEC2'][9] = u'Electromagnetic Sensor'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHDP_TEC2'][10] = u'Photogrammetry'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHDP_TEC2'][11] = u'Satellite Imagery'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHDP_TEC2'][12] = u'Levelling'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHDP_TEC2'][13] = u'Computer Generated'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHDP_TEC2'][14] = u'Area Swept by Side-scan Sonar'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHDP_TEC2'][15] = u'Bathymetric LiDAR'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHDP_TEC2'][17] = u'Singlebeam'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHDP_TEC2'][18] = u'Underwater Utility Vehicle'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHDP_TEC2'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHDP_TEC3'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHDP_TEC3'][1] = u'Echo Sounder'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHDP_TEC3'][2] = u'Side-scan Sonar'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHDP_TEC3'][3] = u'Multi-beam Echo Sounder'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHDP_TEC3'][4] = u'Diver'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHDP_TEC3'][5] = u'Lead-line'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHDP_TEC3'][6] = u'Area Swept by Wire-drag'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHDP_TEC3'][8] = u'Area Swept by Vertical Acoustic System'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHDP_TEC3'][9] = u'Electromagnetic Sensor'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHDP_TEC3'][10] = u'Photogrammetry'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHDP_TEC3'][11] = u'Satellite Imagery'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHDP_TEC3'][12] = u'Levelling'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHDP_TEC3'][13] = u'Computer Generated'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHDP_TEC3'][14] = u'Area Swept by Side-scan Sonar'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHDP_TEC3'][15] = u'Bathymetric LiDAR'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHDP_TEC3'][17] = u'Singlebeam'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHDP_TEC3'][18] = u'Underwater Utility Vehicle'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHDP_TEC3'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHDP_VDC'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHDP_VDC'][2] = u'High Water'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHDP_VDC'][3] = u'Higher High Water'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHDP_VDC'][4] = u'Indian Spring Low Water'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHDP_VDC'][5] = u'Low Water'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHDP_VDC'][6] = u'Lower Low Water'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHDP_VDC'][7] = u'Mean High Water'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHDP_VDC'][8] = u'Mean High Water Neaps'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHDP_VDC'][9] = u'Mean High Water Springs'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHDP_VDC'][10] = u'Mean Higher High Water'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHDP_VDC'][11] = u'Mean Low Water'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHDP_VDC'][12] = u'Mean Low Water Neaps'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHDP_VDC'][13] = u'Mean Low Water Springs'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHDP_VDC'][14] = u'Mean Lower Low Water'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHDP_VDC'][15] = u'Mean Sea Level'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHDP_VDC'][16] = u'Mean Tide Level'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHDP_VDC'][17] = u'Neap Tide'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHDP_VDC'][18] = u'Spring Tide'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHDP_VDC'][19] = u'Mean Lower Low Water Springs'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHDP_VDC'][20] = u'Lowest Astronomical Tide'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHDP_VDC'][21] = u'Chart Datum (Unspecified)'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHDP_VDC'][22] = u'Highest Astronomical Tide'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHDP_VDC'][24] = u'Mean Higher High Water Springs'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHDP_VDC'][28] = u'Highest High Water'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHDP_VDC'][30] = u'Indian Spring High Water'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHDP_VDC'][90] = u'Lowest Low Water'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHDP_VDC'][91] = u'Lowest Low Water Springs'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHDP_VDC'][92] = u'Approximate Mean Low Water Springs'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHDP_VDC'][93] = u'Low Water Springs'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHDP_VDC'][94] = u'Approximate Lowest Astronomical Tide'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHDP_VDC'][95] = u'Nearly Lowest Low Water'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHDP_VDC'][96] = u'Approximate Mean Low Water'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHDP_VDC'][97] = u'Approximate Mean Lower Low Water'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHDP_VDC'][98] = u'Approximate Mean Sea Level'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHDP_VDC'][99] = u'High Water Springs'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHDP_VDC'][100] = u'Equinoctial Spring Low Water'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHDP_VDC'][101] = u'Local Datum'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHDP_VDC'][102] = u'International Great Lakes Datum 1985'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHDP_VDC'][103] = u'Mean Water Level'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHDP_VDC'][104] = u'Lower Low Water Large Tide'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHDP_VDC'][105] = u'Higher High Water Large Tide'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHDP_VDC'][107] = u'Nearly Highest High Water'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZHDP_VDC'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI001_SPS'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI001_SPS'][1000] = u'False'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI001_SPS'][1001] = u'True'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI001_SRT'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI001_SRT'][2] = u'AAFIF'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI001_SRT'][7] = u'CIB1'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI001_SRT'][9] = u'QuickBird Imagery'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI001_SRT'][10] = u'DNC'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI001_SRT'][21] = u'DVOF'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI001_SRT'][22] = u'FFD'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI001_SRT'][25] = u'GeoNames'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI001_SRT'][26] = u'GPS'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI001_SRT'][28] = u'Ikonos Imagery'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI001_SRT'][29] = u'NTM Imagery'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI001_SRT'][30] = u'Imagery'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI001_SRT'][31] = u'ITD'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI001_SRT'][32] = u'IVD'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI001_SRT'][43] = u'MIDB'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI001_SRT'][60] = u'UVMap'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI001_SRT'][61] = u'VITD'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI001_SRT'][64] = u'VMap 2'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI001_SRT'][108] = u'NAVTEQ Data'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI001_SRT'][159] = u'Commercial Data'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI001_SRT'][160] = u'Open Source Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI001_SRT'][165] = u'DAFIF'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI001_SRT'][166] = u'DeLorme Digital Atlas of the Earth (DAE) '
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI001_SRT'][167] = u'Military Map Data'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI001_SRT'][168] = u'Non-military Map'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI001_SRT'][169] = u'Operations Data'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI001_SRT'][170] = u'SAC'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI001_SRT'][171] = u'TomTom Data'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI001_SRT'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI001_VSC'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI001_VSC'][1] = u'DTED 1'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI001_VSC'][2] = u'DTED 2'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI001_VSC'][3] = u'No Elevations'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI001_VSC'][4] = u'Reflective Surface'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI001_VSC'][5] = u'Stereoscopic Imagery'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI001_VSC'][6] = u'TIN Data'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI001_VSC'][998] = u'Not Applicable'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI001_VSC'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI004_RCG'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI004_RCG'][1] = u'U.S. Army'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI004_RCG'][2] = u'U.S. Navy'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI004_RCG'][3] = u'U.S. Air Force'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI004_RCG'][4] = u'U.S. Marine Corps'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI004_RCG'][5] = u'U.S. Coast Guard'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI004_RCG'][6] = u'U.S. Africa Command (USAFRICOM)'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI004_RCG'][7] = u'U.S. Central Command (USCENTCOM)'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI004_RCG'][8] = u'U.S. European Command (USEUCOM)'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI004_RCG'][9] = u'U.S. Joint Forces Command (USJFCOM)'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI004_RCG'][10] = u'U.S. Northern Command (USNORTHCOM)'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI004_RCG'][11] = u'U.S. Pacific Command (PACOM)'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI004_RCG'][12] = u'U.S. Special Operations Command (USSOCOM)'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI004_RCG'][13] = u'U.S. Southern Command (USSOUTHCOM)'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI004_RCG'][14] = u'U.S. Strategic Command (USSTRATCOM)'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI004_RCG'][15] = u'U.S. Transportation Command (USTRANSCOM)'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI004_RCG'][16] = u'U.S. Central Intelligence Agency (CIA)'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI004_RCG'][17] = u'U.S. Defense Intelligence Agency (DIA)'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI004_RCG'][18] = u'U.S. National Security Agency (NSA)'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI004_RCG'][19] = u'U.S. National Geospatial-Intelligence Agency (NGA)'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI004_RCG'][20] = u'U.S. National Reconnaissance Office (NRO)'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI004_RCG'][21] = u'U.S. Department of State'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI004_RCG'][22] = u'U.S. Department of Homeland Security (DHS)'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI004_RCG'][23] = u'U.S. Department of Energy (DOE)'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI004_RCG'][24] = u'U.S. Federal Bureau of Investigation (FBI)'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI004_RCG'][25] = u'U.S. Geological Survey (USGS)'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI004_RCG'][26] = u'U.S. National Civil Applications Program (NCAP)'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI004_RCG'][27] = u'U.S. National Oceanic and Atmospheric Administration'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI004_RCG'][28] = u'Defence Imagery and Geospatial Organisation (Australia)'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI004_RCG'][29] = u'Geographic Service (Belgium)'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI004_RCG'][30] = u'Military Topographic Service (Bulgaria)'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI004_RCG'][31] = u'Mapping and Charting Establishment (Canada)'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI004_RCG'][32] = u'Geographic Service of the Czech Armed Forces (Czech Republic)'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI004_RCG'][33] = u'Defence Acquisition and Logistics Organization (Denmark)'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI004_RCG'][34] = u'Military Geographic Group (Estonia)'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI004_RCG'][35] = u'Topographic Service (Finland)'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI004_RCG'][36] = u'Joint Geography Bureau (France)'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI004_RCG'][37] = u'Bundeswehr Geoinformation Office (Germany)'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI004_RCG'][38] = u'Hellenic Military Geographic Service (Greece)'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI004_RCG'][39] = u'Mapping Service (Hungary)'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI004_RCG'][40] = u'Defense Information Security (Italy)'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI004_RCG'][41] = u'Geospatial Information Agency (Latvia)'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI004_RCG'][42] = u'Military Mapping Centre (Lithuania)'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI004_RCG'][43] = u'National Army Topographic Service (Moldova)'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI004_RCG'][44] = u'Army Geographic Agency (Netherlands)'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI004_RCG'][45] = u'Geospatial Intelligence Organisation (New Zealand)'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI004_RCG'][46] = u'Military Geographic Service (Norway)'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI004_RCG'][47] = u'Military Geography Division (Poland)'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI004_RCG'][48] = u'Army Geographic Institute (Portugal)'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI004_RCG'][49] = u'Military Topographic Directorate (Romania)'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI004_RCG'][50] = u'Topographic Institute (Slovakia)'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI004_RCG'][51] = u'Army Geographic Centre (Spain)'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI004_RCG'][52] = u'Swedish Armed Forces (Sweden)'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI004_RCG'][53] = u'General Command of Mapping (Turkey)'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI004_RCG'][54] = u'Defence Geographic Centre Intelligence Collection Group (United Kingdom)'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI004_RCG'][55] = u'U.S. Army Geospatial Center (AGC)'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI004_RCG'][56] = u'Army (Australia)'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI004_RCG'][57] = u'Military Geographic Division (Croatia)'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI004_RCG'][58] = u'Directorate Geospatial Information (South Africa)'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI004_RCG'][59] = u'Korean Defense Intelligence Agency (South Korea)'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI004_RCG'][60] = u'National Intelligence Service (South Korea)'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI004_RCG'][61] = u'Imagery Support Group (Singapore)'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI004_RCG'][62] = u'National Security Bureau (Taiwan)'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI004_RCG'][63] = u'Materiel Production Center (Taiwan)'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI004_RCG'][64] = u'Ministry of Defense of Japan (Japan)'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI004_RCG'][65] = u'Ministry of Construction and Urban Development (Mongolia)'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI004_RCG'][66] = u'National Mapping and Resource Information Authority (Philippines)'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI004_RCG'][67] = u'Royal Jordanian Geographic Centre (Jordan)'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI004_RCG'][68] = u'National Survey Authority (Oman)'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI004_RCG'][69] = u'Armed Forces General Headquarters (Qatar)'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI004_RCG'][70] = u'Ministry of Defense of Saudi Arabia (Saudi Arabia)'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI004_RCG'][71] = u'Directorate of Survey (Kuwait)'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI004_RCG'][72] = u'Military Survey Department (United Arab Emirates)'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI004_RCG'][73] = u'Information Network Security Agency (Ethiopia)'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI004_RCG'][74] = u'Ministry of State for Defense (Kenya)'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI004_RCG'][75] = u'El Instituto Nacional de Estadistica y Geografia (Mexico)'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI004_RCG'][76] = u'Instituto Geográfico Militar (Chile)'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI004_RCG'][77] = u'Servicio Geográfico Militar (Uruguay)'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI004_RCG'][78] = u'Dirección del Servicio Geográfico Military (Paraguay)'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI004_RCG'][79] = u'Instituto Geográfico Nacional (Peru)'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI004_RCG'][80] = u'Instituto Geográfico Agustín Codazzi (Colombia)'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI004_RCG'][81] = u'Instituto Geográfico y del Catastro Nacional (El Salvador)'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI004_RCG'][82] = u'Instituto Geográfico Nacional (Guatemala)'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI004_RCG'][83] = u'Servicio Geográfico Militar (Guatemala)'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI004_RCG'][84] = u'Instituto Cartográfico Militar (Dominican Republic)'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI004_RCG'][85] = u'Instituto Nicaragüense de Estudios Terretoriales (Nicaragua)'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI004_RCG'][86] = u'Dirección General de Registros, Catastro, y Geografía (Honduras)'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI004_RCG'][87] = u'Instituto Geográfico Militar (Ecuador)'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI004_RCG'][88] = u'Instituto Geográfico Nacional "Tommy Guardia" (Panama)'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI004_RCG'][89] = u'Instituto Geográfico Nacional (Argentina)'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI004_RCG'][90] = u'Diretoria de Serviço Geográfico (Brazil)'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI004_RCG'][998] = u'Not Applicable'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI004_RCG'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI005_GNT'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI005_GNT'][1] = u'Conventional'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI005_GNT'][2] = u'Native Transliterated'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI005_GNT'][3] = u'Variant Transliterated'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI005_GNT'][4] = u'Unverified Transliterated'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI005_GNT'][5] = u'Native Original'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI005_GNT'][6] = u'Variant Original'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI005_GNT'][7] = u'Unverified Original'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI005_GNT'][8] = u'Historical Transliterated'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI005_GNT'][9] = u'Historical Original'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI005_GNT'][10] = u'Provisional'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI005_GNT'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI005_GNT2'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI005_GNT2'][1] = u'Conventional'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI005_GNT2'][2] = u'Native Transliterated'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI005_GNT2'][3] = u'Variant Transliterated'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI005_GNT2'][4] = u'Unverified Transliterated'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI005_GNT2'][5] = u'Native Original'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI005_GNT2'][6] = u'Variant Original'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI005_GNT2'][7] = u'Unverified Original'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI005_GNT2'][8] = u'Historical Transliterated'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI005_GNT2'][9] = u'Historical Original'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI005_GNT2'][10] = u'Provisional'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI005_GNT2'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI005_GNT3'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI005_GNT3'][1] = u'Conventional'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI005_GNT3'][2] = u'Native Transliterated'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI005_GNT3'][3] = u'Variant Transliterated'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI005_GNT3'][4] = u'Unverified Transliterated'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI005_GNT3'][5] = u'Native Original'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI005_GNT3'][6] = u'Variant Original'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI005_GNT3'][7] = u'Unverified Original'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI005_GNT3'][8] = u'Historical Transliterated'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI005_GNT3'][9] = u'Historical Original'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI005_GNT3'][10] = u'Provisional'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI005_GNT3'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI005_GNTA'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI005_GNTA'][1] = u'Conventional'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI005_GNTA'][2] = u'Native Transliterated'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI005_GNTA'][3] = u'Variant Transliterated'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI005_GNTA'][4] = u'Unverified Transliterated'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI005_GNTA'][5] = u'Native Original'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI005_GNTA'][6] = u'Variant Original'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI005_GNTA'][7] = u'Unverified Original'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI005_GNTA'][8] = u'Historical Transliterated'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI005_GNTA'][9] = u'Historical Original'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI005_GNTA'][10] = u'Provisional'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI005_GNTA'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI005_GNTB'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI005_GNTB'][1] = u'Conventional'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI005_GNTB'][2] = u'Native Transliterated'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI005_GNTB'][3] = u'Variant Transliterated'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI005_GNTB'][4] = u'Unverified Transliterated'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI005_GNTB'][5] = u'Native Original'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI005_GNTB'][6] = u'Variant Original'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI005_GNTB'][7] = u'Unverified Original'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI005_GNTB'][8] = u'Historical Transliterated'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI005_GNTB'][9] = u'Historical Original'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI005_GNTB'][10] = u'Provisional'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI005_GNTB'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI006_MEM'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI012_DCR'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI012_DCR'][1000] = u'False'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI012_DCR'][1001] = u'True'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI012_DKC'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI012_DKC'][1] = u'Depth Known'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI012_DKC'][3] = u'Safe Clearance Known'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI012_DKC'][4] = u'Depth Unknown'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI012_DKC'][5] = u'Depth Doubtful'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI012_DKC'][6] = u'Depth Unreliable'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI012_DKC'][7] = u'No Bottom'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI012_DKC'][8] = u'Least Depth'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI012_DKC'][9] = u'Reported Depth'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI012_DKC'][10] = u'Unconfirmed Depth'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI012_DKC'][11] = u'Maintained Depth'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI012_DKC'][12] = u'Unmaintained Depth'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI012_DKC'][998] = u'Not Applicable'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI012_DKC'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI012_DKC2'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI012_DKC2'][1] = u'Depth Known'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI012_DKC2'][3] = u'Safe Clearance Known'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI012_DKC2'][4] = u'Depth Unknown'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI012_DKC2'][5] = u'Depth Doubtful'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI012_DKC2'][6] = u'Depth Unreliable'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI012_DKC2'][7] = u'No Bottom'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI012_DKC2'][8] = u'Least Depth'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI012_DKC2'][9] = u'Reported Depth'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI012_DKC2'][10] = u'Unconfirmed Depth'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI012_DKC2'][11] = u'Maintained Depth'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI012_DKC2'][12] = u'Unmaintained Depth'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI012_DKC2'][998] = u'Not Applicable'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI012_DKC2'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI012_DKC3'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI012_DKC3'][1] = u'Depth Known'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI012_DKC3'][3] = u'Safe Clearance Known'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI012_DKC3'][4] = u'Depth Unknown'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI012_DKC3'][5] = u'Depth Doubtful'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI012_DKC3'][6] = u'Depth Unreliable'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI012_DKC3'][7] = u'No Bottom'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI012_DKC3'][8] = u'Least Depth'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI012_DKC3'][9] = u'Reported Depth'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI012_DKC3'][10] = u'Unconfirmed Depth'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI012_DKC3'][11] = u'Maintained Depth'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI012_DKC3'][12] = u'Unmaintained Depth'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI012_DKC3'][998] = u'Not Applicable'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI012_DKC3'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI012_SVC'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI012_SVC'][1] = u'Sounder 4800 Calibrated'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI012_SVC'][2] = u'Sounder 1500 Calibrated'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI012_SVC'][3] = u'Mathews Tables'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI012_SVC'][4] = u'Sound Velocity Meter'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI012_SVC'][5] = u'Sounder Other Calibrated'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI012_SVC'][998] = u'Not Applicable'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI012_SVC'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI012_TEC'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI012_TEC'][1] = u'Echo Sounder'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI012_TEC'][2] = u'Side-scan Sonar'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI012_TEC'][3] = u'Multi-beam Echo Sounder'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI012_TEC'][4] = u'Diver'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI012_TEC'][5] = u'Lead-line'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI012_TEC'][6] = u'Area Swept by Wire-drag'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI012_TEC'][8] = u'Area Swept by Vertical Acoustic System'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI012_TEC'][9] = u'Electromagnetic Sensor'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI012_TEC'][10] = u'Photogrammetry'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI012_TEC'][11] = u'Satellite Imagery'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI012_TEC'][12] = u'Levelling'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI012_TEC'][13] = u'Computer Generated'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI012_TEC'][14] = u'Area Swept by Side-scan Sonar'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI012_TEC'][15] = u'Bathymetric LiDAR'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI012_TEC'][17] = u'Singlebeam'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI012_TEC'][18] = u'Underwater Utility Vehicle'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI012_TEC'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI012_TEC2'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI012_TEC2'][1] = u'Echo Sounder'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI012_TEC2'][2] = u'Side-scan Sonar'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI012_TEC2'][3] = u'Multi-beam Echo Sounder'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI012_TEC2'][4] = u'Diver'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI012_TEC2'][5] = u'Lead-line'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI012_TEC2'][6] = u'Area Swept by Wire-drag'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI012_TEC2'][8] = u'Area Swept by Vertical Acoustic System'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI012_TEC2'][9] = u'Electromagnetic Sensor'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI012_TEC2'][10] = u'Photogrammetry'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI012_TEC2'][11] = u'Satellite Imagery'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI012_TEC2'][12] = u'Levelling'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI012_TEC2'][13] = u'Computer Generated'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI012_TEC2'][14] = u'Area Swept by Side-scan Sonar'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI012_TEC2'][15] = u'Bathymetric LiDAR'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI012_TEC2'][17] = u'Singlebeam'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI012_TEC2'][18] = u'Underwater Utility Vehicle'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI012_TEC2'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI012_TEC3'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI012_TEC3'][1] = u'Echo Sounder'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI012_TEC3'][2] = u'Side-scan Sonar'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI012_TEC3'][3] = u'Multi-beam Echo Sounder'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI012_TEC3'][4] = u'Diver'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI012_TEC3'][5] = u'Lead-line'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI012_TEC3'][6] = u'Area Swept by Wire-drag'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI012_TEC3'][8] = u'Area Swept by Vertical Acoustic System'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI012_TEC3'][9] = u'Electromagnetic Sensor'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI012_TEC3'][10] = u'Photogrammetry'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI012_TEC3'][11] = u'Satellite Imagery'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI012_TEC3'][12] = u'Levelling'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI012_TEC3'][13] = u'Computer Generated'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI012_TEC3'][14] = u'Area Swept by Side-scan Sonar'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI012_TEC3'][15] = u'Bathymetric LiDAR'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI012_TEC3'][17] = u'Singlebeam'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI012_TEC3'][18] = u'Underwater Utility Vehicle'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI012_TEC3'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI012_VDC'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI012_VDC'][2] = u'High Water'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI012_VDC'][3] = u'Higher High Water'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI012_VDC'][4] = u'Indian Spring Low Water'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI012_VDC'][5] = u'Low Water'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI012_VDC'][6] = u'Lower Low Water'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI012_VDC'][7] = u'Mean High Water'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI012_VDC'][8] = u'Mean High Water Neaps'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI012_VDC'][9] = u'Mean High Water Springs'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI012_VDC'][10] = u'Mean Higher High Water'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI012_VDC'][11] = u'Mean Low Water'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI012_VDC'][12] = u'Mean Low Water Neaps'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI012_VDC'][13] = u'Mean Low Water Springs'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI012_VDC'][14] = u'Mean Lower Low Water'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI012_VDC'][15] = u'Mean Sea Level'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI012_VDC'][16] = u'Mean Tide Level'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI012_VDC'][17] = u'Neap Tide'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI012_VDC'][18] = u'Spring Tide'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI012_VDC'][19] = u'Mean Lower Low Water Springs'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI012_VDC'][20] = u'Lowest Astronomical Tide'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI012_VDC'][21] = u'Chart Datum (Unspecified)'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI012_VDC'][22] = u'Highest Astronomical Tide'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI012_VDC'][24] = u'Mean Higher High Water Springs'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI012_VDC'][28] = u'Highest High Water'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI012_VDC'][30] = u'Indian Spring High Water'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI012_VDC'][90] = u'Lowest Low Water'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI012_VDC'][91] = u'Lowest Low Water Springs'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI012_VDC'][92] = u'Approximate Mean Low Water Springs'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI012_VDC'][93] = u'Low Water Springs'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI012_VDC'][94] = u'Approximate Lowest Astronomical Tide'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI012_VDC'][95] = u'Nearly Lowest Low Water'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI012_VDC'][96] = u'Approximate Mean Low Water'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI012_VDC'][97] = u'Approximate Mean Lower Low Water'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI012_VDC'][98] = u'Approximate Mean Sea Level'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI012_VDC'][99] = u'High Water Springs'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI012_VDC'][100] = u'Equinoctial Spring Low Water'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI012_VDC'][101] = u'Local Datum'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI012_VDC'][102] = u'International Great Lakes Datum 1985'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI012_VDC'][103] = u'Mean Water Level'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI012_VDC'][104] = u'Lower Low Water Large Tide'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI012_VDC'][105] = u'Higher High Water Large Tide'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI012_VDC'][107] = u'Nearly Highest High Water'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI012_VDC'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI013_CSP'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI013_CSP'][1] = u'Almond'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI013_CSP'][2] = u'Apple'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI013_CSP'][3] = u'Barley'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI013_CSP'][4] = u'Berry'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI013_CSP'][5] = u'Carob'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI013_CSP'][6] = u'Chestnut'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI013_CSP'][7] = u'Citrus'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI013_CSP'][8] = u'Cork-Oak'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI013_CSP'][9] = u'Cacao'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI013_CSP'][10] = u'Coffee'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI013_CSP'][11] = u'Maize'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI013_CSP'][13] = u'Dry Crop'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI013_CSP'][14] = u'Fibre Crop'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI013_CSP'][15] = u'Fruit Tree'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI013_CSP'][16] = u'Grape'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI013_CSP'][17] = u'Hazelnut'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI013_CSP'][18] = u'Hop'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI013_CSP'][19] = u'Maple'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI013_CSP'][20] = u'Millet'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI013_CSP'][21] = u'Oat'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI013_CSP'][22] = u'Oil Crop'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI013_CSP'][23] = u'Olive'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI013_CSP'][24] = u'Peach'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI013_CSP'][25] = u'Peanut'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI013_CSP'][26] = u'Potato'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI013_CSP'][27] = u'Pulse'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI013_CSP'][28] = u'Rice'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI013_CSP'][29] = u'Rubber'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI013_CSP'][30] = u'Rye'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI013_CSP'][31] = u'Sisal'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI013_CSP'][32] = u'Sorghum'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI013_CSP'][33] = u'Sugar Crop'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI013_CSP'][34] = u'Tea'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI013_CSP'][35] = u'Tobacco'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI013_CSP'][36] = u'Tuber'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI013_CSP'][37] = u'Vegetable Crop'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI013_CSP'][38] = u'Walnut'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI013_CSP'][39] = u'Wheat'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI013_CSP'][40] = u'Date'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI013_CSP'][41] = u'Banana'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI013_CSP'][42] = u'Oil Palm'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI013_CSP'][43] = u'Coconut'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI013_CSP'][44] = u'Sugar Cane'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI013_CSP'][45] = u'Cotton'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI013_CSP'][46] = u'Bamboo'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI013_CSP'][47] = u'Palmetto'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI013_CSP'][48] = u'Timber'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI013_CSP'][117] = u'Opium Poppy'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI013_CSP'][152] = u'Cannabis'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI013_CSP'][159] = u'Ornamental Crop'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI013_CSP'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI013_CSP2'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI013_CSP2'][1] = u'Almond'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI013_CSP2'][2] = u'Apple'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI013_CSP2'][3] = u'Barley'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI013_CSP2'][4] = u'Berry'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI013_CSP2'][5] = u'Carob'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI013_CSP2'][6] = u'Chestnut'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI013_CSP2'][7] = u'Citrus'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI013_CSP2'][8] = u'Cork-Oak'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI013_CSP2'][9] = u'Cacao'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI013_CSP2'][10] = u'Coffee'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI013_CSP2'][11] = u'Maize'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI013_CSP2'][13] = u'Dry Crop'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI013_CSP2'][14] = u'Fibre Crop'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI013_CSP2'][15] = u'Fruit Tree'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI013_CSP2'][17] = u'Hazelnut'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI013_CSP2'][19] = u'Maple'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI013_CSP2'][20] = u'Millet'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI013_CSP2'][21] = u'Oat'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI013_CSP2'][22] = u'Oil Crop'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI013_CSP2'][23] = u'Olive'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI013_CSP2'][24] = u'Peach'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI013_CSP2'][25] = u'Peanut'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI013_CSP2'][26] = u'Potato'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI013_CSP2'][27] = u'Pulse'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI013_CSP2'][29] = u'Rubber'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI013_CSP2'][30] = u'Rye'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI013_CSP2'][31] = u'Sisal'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI013_CSP2'][32] = u'Sorghum'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI013_CSP2'][33] = u'Sugar Crop'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI013_CSP2'][34] = u'Tea'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI013_CSP2'][35] = u'Tobacco'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI013_CSP2'][36] = u'Tuber'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI013_CSP2'][37] = u'Vegetable Crop'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI013_CSP2'][38] = u'Walnut'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI013_CSP2'][39] = u'Wheat'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI013_CSP2'][40] = u'Date'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI013_CSP2'][41] = u'Banana'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI013_CSP2'][42] = u'Oil Palm'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI013_CSP2'][43] = u'Coconut'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI013_CSP2'][44] = u'Sugar Cane'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI013_CSP2'][45] = u'Cotton'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI013_CSP2'][46] = u'Bamboo'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI013_CSP2'][47] = u'Palmetto'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI013_CSP2'][48] = u'Timber'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI013_CSP2'][117] = u'Opium Poppy'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI013_CSP2'][152] = u'Cannabis'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI013_CSP2'][159] = u'Ornamental Crop'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI013_CSP2'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI013_CSP3'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI013_CSP3'][1] = u'Almond'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI013_CSP3'][2] = u'Apple'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI013_CSP3'][3] = u'Barley'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI013_CSP3'][4] = u'Berry'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI013_CSP3'][5] = u'Carob'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI013_CSP3'][6] = u'Chestnut'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI013_CSP3'][7] = u'Citrus'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI013_CSP3'][8] = u'Cork-Oak'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI013_CSP3'][9] = u'Cacao'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI013_CSP3'][10] = u'Coffee'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI013_CSP3'][11] = u'Maize'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI013_CSP3'][13] = u'Dry Crop'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI013_CSP3'][14] = u'Fibre Crop'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI013_CSP3'][15] = u'Fruit Tree'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI013_CSP3'][17] = u'Hazelnut'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI013_CSP3'][19] = u'Maple'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI013_CSP3'][20] = u'Millet'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI013_CSP3'][21] = u'Oat'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI013_CSP3'][22] = u'Oil Crop'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI013_CSP3'][23] = u'Olive'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI013_CSP3'][24] = u'Peach'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI013_CSP3'][25] = u'Peanut'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI013_CSP3'][26] = u'Potato'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI013_CSP3'][27] = u'Pulse'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI013_CSP3'][29] = u'Rubber'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI013_CSP3'][30] = u'Rye'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI013_CSP3'][31] = u'Sisal'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI013_CSP3'][32] = u'Sorghum'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI013_CSP3'][33] = u'Sugar Crop'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI013_CSP3'][34] = u'Tea'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI013_CSP3'][35] = u'Tobacco'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI013_CSP3'][36] = u'Tuber'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI013_CSP3'][37] = u'Vegetable Crop'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI013_CSP3'][38] = u'Walnut'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI013_CSP3'][39] = u'Wheat'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI013_CSP3'][40] = u'Date'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI013_CSP3'][41] = u'Banana'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI013_CSP3'][42] = u'Oil Palm'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI013_CSP3'][43] = u'Coconut'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI013_CSP3'][44] = u'Sugar Cane'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI013_CSP3'][45] = u'Cotton'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI013_CSP3'][46] = u'Bamboo'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI013_CSP3'][47] = u'Palmetto'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI013_CSP3'][48] = u'Timber'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI013_CSP3'][117] = u'Opium Poppy'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI013_CSP3'][152] = u'Cannabis'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI013_CSP3'][159] = u'Ornamental Crop'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI013_CSP3'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI013_FFP'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI013_FFP'][1] = u'Linear'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI013_FFP'][2] = u'Regular'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI013_FFP'][3] = u'Terraced'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI013_FFP'][4] = u'Intermingled Woods'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI013_FFP'][5] = u'Intermingled Trees'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI013_FFP'][6] = u'Treeless'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI013_FFP'][7] = u'Trellised'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI013_FFP'][8] = u'Irregular'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI013_FFP'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI013_FFP2'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI013_FFP2'][1] = u'Linear'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI013_FFP2'][2] = u'Regular'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI013_FFP2'][3] = u'Terraced'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI013_FFP2'][4] = u'Intermingled Woods'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI013_FFP2'][5] = u'Intermingled Trees'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI013_FFP2'][6] = u'Treeless'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI013_FFP2'][7] = u'Trellised'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI013_FFP2'][8] = u'Irregular'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI013_FFP2'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI013_FFP3'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI013_FFP3'][1] = u'Linear'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI013_FFP3'][2] = u'Regular'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI013_FFP3'][3] = u'Terraced'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI013_FFP3'][4] = u'Intermingled Woods'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI013_FFP3'][5] = u'Intermingled Trees'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI013_FFP3'][6] = u'Treeless'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI013_FFP3'][7] = u'Trellised'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI013_FFP3'][8] = u'Irregular'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI013_FFP3'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI013_FMM'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI013_FMM'][1] = u'Fallow'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI013_FMM'][2] = u'Grazing'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI013_FMM'][3] = u'Permanent'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI013_FMM'][4] = u'Slash and Burn'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI013_FMM'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI013_FMM2'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI013_FMM2'][1] = u'Fallow'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI013_FMM2'][2] = u'Grazing'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI013_FMM2'][3] = u'Permanent'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI013_FMM2'][4] = u'Slash and Burn'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI013_FMM2'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI013_FMM3'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI013_FMM3'][1] = u'Fallow'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI013_FMM3'][2] = u'Grazing'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI013_FMM3'][3] = u'Permanent'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI013_FMM3'][4] = u'Slash and Burn'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI013_FMM3'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI013_IRG'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI013_IRG'][1] = u'Furrow'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI013_IRG'][2] = u'Overhead'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI013_IRG'][3] = u'Centre Pivot'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI013_IRG'][4] = u'Linear Move'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI013_IRG'][5] = u'Lateral Move'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI013_IRG'][6] = u'Drip'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI013_IRG'][7] = u'Subirrigation'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI013_IRG'][8] = u'Terrace'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI013_IRG'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI013_PIG'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI013_PIG'][1000] = u'False'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI013_PIG'][1001] = u'True'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PBY'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PBY'][1] = u'Ash'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PBY'][2] = u'Cinders'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PBY'][6] = u'No Byproduct'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PBY'][7] = u'Radioactive Material'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PBY'][8] = u'Refuse'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PBY'][12] = u'Scrap-metal'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PBY'][13] = u'Sewage'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PBY'][15] = u'Slag'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PBY'][89] = u'Timber'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PBY'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PBY2'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PBY2'][1] = u'Ash'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PBY2'][2] = u'Cinders'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PBY2'][6] = u'No Byproduct'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PBY2'][7] = u'Radioactive Material'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PBY2'][8] = u'Refuse'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PBY2'][12] = u'Scrap-metal'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PBY2'][13] = u'Sewage'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PBY2'][15] = u'Slag'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PBY2'][89] = u'Timber'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PBY2'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PBY3'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PBY3'][1] = u'Ash'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PBY3'][2] = u'Cinders'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PBY3'][6] = u'No Byproduct'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PBY3'][7] = u'Radioactive Material'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PBY3'][8] = u'Refuse'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PBY3'][12] = u'Scrap-metal'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PBY3'][13] = u'Sewage'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PBY3'][15] = u'Slag'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PBY3'][89] = u'Timber'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PBY3'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PPO'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PPO'][1] = u'Aircraft'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PPO'][2] = u'Aluminium'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PPO'][3] = u'Ammunition'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PPO'][4] = u'Asphalt'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PPO'][5] = u'Motor Vehicle'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PPO'][13] = u'Brick'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PPO'][15] = u'Cement'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PPO'][16] = u'Chemical'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PPO'][18] = u'Coal'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PPO'][20] = u'Coffee'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PPO'][21] = u'Coke'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PPO'][23] = u'Concrete'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PPO'][25] = u'Consumer Goods'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PPO'][26] = u'Copper'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PPO'][28] = u'Cotton'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PPO'][32] = u'Desalinated Water'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PPO'][37] = u'Electric Power'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PPO'][38] = u'Explosive'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PPO'][39] = u'Fish'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PPO'][41] = u'Food'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PPO'][43] = u'Frozen Water'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PPO'][44] = u'Fruit'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PPO'][45] = u'Gas'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PPO'][46] = u'Petrol'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PPO'][47] = u'Glass'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PPO'][48] = u'Gold'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PPO'][57] = u'Ice'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PPO'][58] = u'Iron'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PPO'][59] = u'Lead'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PPO'][60] = u'Lime'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PPO'][61] = u'Liquefied Natural Gas (LNG)'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PPO'][62] = u'Liquefied Petroleum Gas (LPG)'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PPO'][63] = u'Lumber'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PPO'][65] = u'Manganese'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PPO'][69] = u'Metal'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PPO'][70] = u'Milk'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PPO'][73] = u'No Product'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PPO'][74] = u'Non-solid Hydrocarbon Fuel'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PPO'][80] = u'Paper'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PPO'][83] = u'Petroleum'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PPO'][84] = u'Plastic'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PPO'][87] = u'Prestressed Concrete'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PPO'][90] = u'Radioactive Material'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PPO'][92] = u'Rice'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PPO'][94] = u'Rubber'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PPO'][95] = u'Salt'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PPO'][101] = u'Sewage'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PPO'][105] = u'Silver'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PPO'][106] = u'Snow'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PPO'][109] = u'Steel'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PPO'][111] = u'Sugar'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PPO'][114] = u'Textile'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PPO'][117] = u'Tobacco'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PPO'][120] = u'Uranium'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PPO'][121] = u'Vegetation Product'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PPO'][122] = u'Water'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PPO'][123] = u'Wine'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PPO'][126] = u'Zinc'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PPO'][136] = u'Biochemical'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PPO'][137] = u'Petrochemical'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PPO'][146] = u'Heating Steam and/or Water'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PPO'][147] = u'Electronic Equipment'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PPO'][148] = u'Electrical Equipment'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PPO'][150] = u'Fertilizer'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PPO'][154] = u'Munitions'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PPO'][155] = u'Olive Oil'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PPO'][156] = u'Whale Products'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PPO'][157] = u'Petroleum and/or Natural Gas'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PPO'][160] = u'Milled Grain'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PPO'][165] = u'Clothing'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PPO'][192] = u'Petroleum Lubricant'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PPO'][200] = u'Iron Ingot'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PPO'][214] = u'Biodiesel'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PPO'][279] = u'Fluorine'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PPO'][325] = u'Phosphorus'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PPO'][435] = u'Nuclear Fuel'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PPO'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PPO2'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PPO2'][1] = u'Aircraft'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PPO2'][2] = u'Aluminium'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PPO2'][3] = u'Ammunition'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PPO2'][4] = u'Asphalt'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PPO2'][5] = u'Motor Vehicle'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PPO2'][13] = u'Brick'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PPO2'][15] = u'Cement'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PPO2'][16] = u'Chemical'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PPO2'][18] = u'Coal'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PPO2'][20] = u'Coffee'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PPO2'][21] = u'Coke'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PPO2'][23] = u'Concrete'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PPO2'][25] = u'Consumer Goods'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PPO2'][26] = u'Copper'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PPO2'][28] = u'Cotton'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PPO2'][32] = u'Desalinated Water'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PPO2'][37] = u'Electric Power'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PPO2'][38] = u'Explosive'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PPO2'][39] = u'Fish'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PPO2'][41] = u'Food'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PPO2'][43] = u'Frozen Water'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PPO2'][44] = u'Fruit'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PPO2'][45] = u'Gas'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PPO2'][46] = u'Petrol'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PPO2'][47] = u'Glass'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PPO2'][48] = u'Gold'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PPO2'][57] = u'Ice'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PPO2'][58] = u'Iron'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PPO2'][59] = u'Lead'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PPO2'][60] = u'Lime'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PPO2'][61] = u'Liquefied Natural Gas (LNG)'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PPO2'][62] = u'Liquefied Petroleum Gas (LPG)'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PPO2'][63] = u'Lumber'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PPO2'][65] = u'Manganese'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PPO2'][69] = u'Metal'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PPO2'][70] = u'Milk'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PPO2'][73] = u'No Product'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PPO2'][74] = u'Non-solid Hydrocarbon Fuel'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PPO2'][80] = u'Paper'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PPO2'][83] = u'Petroleum'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PPO2'][84] = u'Plastic'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PPO2'][87] = u'Prestressed Concrete'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PPO2'][90] = u'Radioactive Material'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PPO2'][92] = u'Rice'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PPO2'][94] = u'Rubber'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PPO2'][95] = u'Salt'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PPO2'][101] = u'Sewage'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PPO2'][105] = u'Silver'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PPO2'][106] = u'Snow'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PPO2'][109] = u'Steel'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PPO2'][111] = u'Sugar'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PPO2'][114] = u'Textile'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PPO2'][117] = u'Tobacco'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PPO2'][120] = u'Uranium'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PPO2'][121] = u'Vegetation Product'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PPO2'][122] = u'Water'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PPO2'][123] = u'Wine'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PPO2'][126] = u'Zinc'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PPO2'][136] = u'Biochemical'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PPO2'][137] = u'Petrochemical'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PPO2'][146] = u'Heating Steam and/or Water'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PPO2'][147] = u'Electronic Equipment'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PPO2'][148] = u'Electrical Equipment'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PPO2'][150] = u'Fertilizer'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PPO2'][154] = u'Munitions'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PPO2'][155] = u'Olive Oil'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PPO2'][156] = u'Whale Products'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PPO2'][157] = u'Petroleum and/or Natural Gas'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PPO2'][160] = u'Milled Grain'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PPO2'][165] = u'Clothing'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PPO2'][192] = u'Petroleum Lubricant'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PPO2'][200] = u'Iron Ingot'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PPO2'][214] = u'Biodiesel'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PPO2'][279] = u'Fluorine'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PPO2'][325] = u'Phosphorus'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PPO2'][435] = u'Nuclear Fuel'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PPO2'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PPO3'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PPO3'][1] = u'Aircraft'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PPO3'][2] = u'Aluminium'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PPO3'][3] = u'Ammunition'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PPO3'][4] = u'Asphalt'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PPO3'][5] = u'Motor Vehicle'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PPO3'][13] = u'Brick'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PPO3'][15] = u'Cement'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PPO3'][16] = u'Chemical'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PPO3'][18] = u'Coal'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PPO3'][20] = u'Coffee'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PPO3'][21] = u'Coke'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PPO3'][23] = u'Concrete'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PPO3'][25] = u'Consumer Goods'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PPO3'][26] = u'Copper'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PPO3'][28] = u'Cotton'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PPO3'][32] = u'Desalinated Water'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PPO3'][37] = u'Electric Power'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PPO3'][38] = u'Explosive'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PPO3'][39] = u'Fish'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PPO3'][41] = u'Food'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PPO3'][43] = u'Frozen Water'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PPO3'][44] = u'Fruit'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PPO3'][45] = u'Gas'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PPO3'][46] = u'Petrol'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PPO3'][47] = u'Glass'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PPO3'][48] = u'Gold'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PPO3'][57] = u'Ice'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PPO3'][58] = u'Iron'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PPO3'][59] = u'Lead'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PPO3'][60] = u'Lime'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PPO3'][61] = u'Liquefied Natural Gas (LNG)'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PPO3'][62] = u'Liquefied Petroleum Gas (LPG)'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PPO3'][63] = u'Lumber'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PPO3'][65] = u'Manganese'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PPO3'][69] = u'Metal'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PPO3'][70] = u'Milk'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PPO3'][73] = u'No Product'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PPO3'][74] = u'Non-solid Hydrocarbon Fuel'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PPO3'][80] = u'Paper'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PPO3'][83] = u'Petroleum'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PPO3'][84] = u'Plastic'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PPO3'][87] = u'Prestressed Concrete'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PPO3'][90] = u'Radioactive Material'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PPO3'][92] = u'Rice'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PPO3'][94] = u'Rubber'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PPO3'][95] = u'Salt'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PPO3'][101] = u'Sewage'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PPO3'][105] = u'Silver'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PPO3'][106] = u'Snow'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PPO3'][109] = u'Steel'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PPO3'][111] = u'Sugar'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PPO3'][114] = u'Textile'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PPO3'][117] = u'Tobacco'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PPO3'][120] = u'Uranium'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PPO3'][121] = u'Vegetation Product'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PPO3'][122] = u'Water'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PPO3'][123] = u'Wine'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PPO3'][126] = u'Zinc'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PPO3'][136] = u'Biochemical'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PPO3'][137] = u'Petrochemical'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PPO3'][146] = u'Heating Steam and/or Water'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PPO3'][147] = u'Electronic Equipment'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PPO3'][148] = u'Electrical Equipment'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PPO3'][150] = u'Fertilizer'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PPO3'][154] = u'Munitions'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PPO3'][155] = u'Olive Oil'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PPO3'][156] = u'Whale Products'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PPO3'][157] = u'Petroleum and/or Natural Gas'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PPO3'][160] = u'Milled Grain'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PPO3'][165] = u'Clothing'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PPO3'][192] = u'Petroleum Lubricant'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PPO3'][200] = u'Iron Ingot'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PPO3'][214] = u'Biodiesel'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PPO3'][279] = u'Fluorine'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PPO3'][325] = u'Phosphorus'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PPO3'][435] = u'Nuclear Fuel'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PPO3'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PRW'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PRW'][1] = u'Aluminium'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PRW'][2] = u'Asphalt'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PRW'][5] = u'Bauxite'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PRW'][9] = u'Cement'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PRW'][10] = u'Chemical'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PRW'][11] = u'Clay'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PRW'][12] = u'Coal'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PRW'][14] = u'Coke'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PRW'][16] = u'Copper'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PRW'][18] = u'Cotton'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PRW'][27] = u'Gas'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PRW'][28] = u'Glass'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PRW'][29] = u'Gold'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PRW'][30] = u'Grain'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PRW'][33] = u'Plant Material'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PRW'][38] = u'Ice'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PRW'][39] = u'Iron'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PRW'][41] = u'Lead'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PRW'][45] = u'Lumber'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PRW'][46] = u'Manganese'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PRW'][48] = u'Metal'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PRW'][50] = u'No Raw Material'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PRW'][52] = u'Oil'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PRW'][54] = u'Ore'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PRW'][57] = u'Paper'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PRW'][60] = u'Plastic'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PRW'][64] = u'Radioactive Material'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PRW'][66] = u'Rubber'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PRW'][68] = u'Sand'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PRW'][70] = u'Wood Fragments'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PRW'][75] = u'Sewage'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PRW'][78] = u'Silver'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PRW'][79] = u'Snow'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PRW'][83] = u'Steel'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PRW'][84] = u'Stone'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PRW'][85] = u'Sugar'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PRW'][87] = u'Textile'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PRW'][90] = u'Tobacco'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PRW'][93] = u'Uranium'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PRW'][94] = u'Vegetation'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PRW'][96] = u'Water'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PRW'][97] = u'Wood'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PRW'][99] = u'Zinc'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PRW'][118] = u'Petroleum and/or Natural Gas'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PRW'][119] = u'Biodiesel'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PRW'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PRW2'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PRW2'][1] = u'Aluminium'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PRW2'][2] = u'Asphalt'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PRW2'][5] = u'Bauxite'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PRW2'][9] = u'Cement'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PRW2'][10] = u'Chemical'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PRW2'][11] = u'Clay'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PRW2'][12] = u'Coal'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PRW2'][14] = u'Coke'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PRW2'][16] = u'Copper'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PRW2'][18] = u'Cotton'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PRW2'][27] = u'Gas'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PRW2'][28] = u'Glass'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PRW2'][29] = u'Gold'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PRW2'][30] = u'Grain'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PRW2'][33] = u'Plant Material'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PRW2'][38] = u'Ice'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PRW2'][39] = u'Iron'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PRW2'][41] = u'Lead'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PRW2'][45] = u'Lumber'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PRW2'][46] = u'Manganese'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PRW2'][48] = u'Metal'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PRW2'][50] = u'No Raw Material'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PRW2'][52] = u'Oil'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PRW2'][54] = u'Ore'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PRW2'][57] = u'Paper'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PRW2'][60] = u'Plastic'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PRW2'][64] = u'Radioactive Material'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PRW2'][66] = u'Rubber'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PRW2'][68] = u'Sand'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PRW2'][70] = u'Wood Fragments'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PRW2'][75] = u'Sewage'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PRW2'][78] = u'Silver'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PRW2'][79] = u'Snow'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PRW2'][83] = u'Steel'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PRW2'][84] = u'Stone'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PRW2'][85] = u'Sugar'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PRW2'][87] = u'Textile'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PRW2'][90] = u'Tobacco'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PRW2'][93] = u'Uranium'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PRW2'][94] = u'Vegetation'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PRW2'][96] = u'Water'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PRW2'][97] = u'Wood'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PRW2'][99] = u'Zinc'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PRW2'][118] = u'Petroleum and/or Natural Gas'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PRW2'][119] = u'Biodiesel'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PRW2'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PRW3'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PRW3'][1] = u'Aluminium'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PRW3'][2] = u'Asphalt'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PRW3'][5] = u'Bauxite'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PRW3'][9] = u'Cement'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PRW3'][10] = u'Chemical'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PRW3'][11] = u'Clay'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PRW3'][12] = u'Coal'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PRW3'][14] = u'Coke'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PRW3'][16] = u'Copper'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PRW3'][18] = u'Cotton'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PRW3'][27] = u'Gas'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PRW3'][28] = u'Glass'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PRW3'][29] = u'Gold'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PRW3'][30] = u'Grain'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PRW3'][33] = u'Plant Material'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PRW3'][38] = u'Ice'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PRW3'][39] = u'Iron'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PRW3'][41] = u'Lead'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PRW3'][45] = u'Lumber'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PRW3'][46] = u'Manganese'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PRW3'][48] = u'Metal'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PRW3'][50] = u'No Raw Material'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PRW3'][52] = u'Oil'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PRW3'][54] = u'Ore'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PRW3'][57] = u'Paper'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PRW3'][60] = u'Plastic'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PRW3'][64] = u'Radioactive Material'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PRW3'][66] = u'Rubber'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PRW3'][68] = u'Sand'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PRW3'][70] = u'Wood Fragments'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PRW3'][75] = u'Sewage'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PRW3'][78] = u'Silver'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PRW3'][79] = u'Snow'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PRW3'][83] = u'Steel'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PRW3'][84] = u'Stone'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PRW3'][85] = u'Sugar'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PRW3'][87] = u'Textile'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PRW3'][90] = u'Tobacco'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PRW3'][93] = u'Uranium'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PRW3'][94] = u'Vegetation'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PRW3'][96] = u'Water'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PRW3'][97] = u'Wood'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PRW3'][99] = u'Zinc'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PRW3'][118] = u'Petroleum and/or Natural Gas'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PRW3'][119] = u'Biodiesel'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI014_PRW3'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI015_GCUC'][2] = u'Open Interval'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI015_GCUC'][3] = u'Greater-than-or-equal to Less-than Interval'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI015_GCUC'][4] = u'Greater-than to Less-than-or-equal Interval'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI015_GCUC'][5] = u'Closed Interval'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI015_GCUC'][6] = u'Greater-than Semi-interval'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI015_GCUC'][7] = u'Greater-than or Equal Semi-interval'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI015_GCUC'][8] = u'Less-than Semi-interval'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI015_GCUC'][9] = u'Less-than or Equal Semi-interval'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI016_ROC'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI016_ROC'][1] = u'Unimproved'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI016_ROC'][2] = u'Stabilized Earth'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI016_ROC'][3] = u'Flexible Pavement'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI016_ROC'][4] = u'Aggregate'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI016_ROC'][5] = u'Macadam'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI016_ROC'][6] = u'Bound Surface'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI016_ROC'][7] = u'Rigid Pavement'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI016_ROC'][8] = u'Concrete'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI016_ROC'][9] = u'Asphalt'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI016_ROC'][10] = u'Asphalt over Concrete'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI016_ROC'][11] = u'Cobble-stone'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI016_ROC'][12] = u'Brick'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI016_ROC'][13] = u'Metal'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI016_ROC'][14] = u'Wood'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI016_ROC'][15] = u'Corduroy'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI016_ROC'][16] = u'Wood Plank'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI016_ROC'][17] = u'Ice'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI016_ROC'][18] = u'Snow'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI016_ROC'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI016_WTC'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI016_WTC'][1] = u'All-weather'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI016_WTC'][2] = u'Fair-weather'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI016_WTC'][3] = u'Winter Only'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI016_WTC'][4] = u'Limited All-weather'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI016_WTC'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI017_RGC'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI017_RGC'][1] = u'Broad'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI017_RGC'][2] = u'Narrow'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI017_RGC'][3] = u'Standard'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI017_RIR'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI017_RIR'][1000] = u'False'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI017_RIR'][1001] = u'True'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI017_RRA'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI017_RRA'][1] = u'Electrified Track'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI017_RRA'][3] = u'Overhead Electrified'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI017_RRA'][4] = u'Non-electrified'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI017_RRA'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI017_TRT'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI017_TRT'][1] = u'Crane Track'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI017_TRT'][2] = u'Drill Track'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI017_TRT'][3] = u'House Track'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI017_TRT'][4] = u'Joint Track'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI017_TRT'][5] = u'Ladder Track'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI017_TRT'][6] = u'Paired Track'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI017_TRT'][7] = u'Rip Track'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI017_TRT'][9] = u'Stub Track'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI017_TRT'][10] = u'Team Track'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI017_TRT'][12] = u'Monorail'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI017_TRT'][13] = u'Maglev'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI017_TRT'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI018_WIT'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI018_WIT'][1] = u'Cellular Phone'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI018_WIT'][2] = u'Microwave Radio Relay'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI018_WIT'][3] = u'Mobile Phone'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI018_WIT'][4] = u'Radio Broadcast'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI018_WIT'][5] = u'Radio Telephone'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI018_WIT'][6] = u'Radio-telegraph'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI018_WIT'][7] = u'Television (TV)'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI018_WIT'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI019_ASP'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI019_ASP'][1] = u'Aggregate Seal Coat'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI019_ASP'][2] = u'Graded'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI019_ASP'][3] = u'Grass'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI019_ASP'][4] = u'Grooved'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI019_ASP'][5] = u'Oiled'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI019_ASP'][6] = u'Porous Friction Course'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI019_ASP'][7] = u'Rolled'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI019_ASP'][8] = u'Rubberized Seal Coat'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI019_ASP'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI019_ASP2'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI019_ASP2'][1] = u'Aggregate Seal Coat'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI019_ASP2'][2] = u'Graded'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI019_ASP2'][3] = u'Grass'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI019_ASP2'][4] = u'Grooved'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI019_ASP2'][5] = u'Oiled'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI019_ASP2'][6] = u'Porous Friction Course'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI019_ASP2'][7] = u'Rolled'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI019_ASP2'][8] = u'Rubberized Seal Coat'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI019_ASP2'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI019_ASP3'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI019_ASP3'][1] = u'Aggregate Seal Coat'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI019_ASP3'][2] = u'Graded'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI019_ASP3'][3] = u'Grass'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI019_ASP3'][4] = u'Grooved'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI019_ASP3'][5] = u'Oiled'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI019_ASP3'][6] = u'Porous Friction Course'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI019_ASP3'][7] = u'Rolled'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI019_ASP3'][8] = u'Rubberized Seal Coat'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI019_ASP3'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI019_ASU'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI019_ASU'][1] = u'Asphalt'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI019_ASU'][2] = u'Bituminous Mix'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI019_ASU'][3] = u'Brick'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI019_ASU'][4] = u'Clay'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI019_ASU'][5] = u'Concrete'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI019_ASU'][6] = u'Coral'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI019_ASU'][7] = u'Earthen'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI019_ASU'][8] = u'Gravel'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI019_ASU'][9] = u'Ice'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI019_ASU'][10] = u'Landing Mat'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI019_ASU'][11] = u'Laterite'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI019_ASU'][12] = u'Macadam'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI019_ASU'][13] = u'Membrane'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI019_ASU'][14] = u'Non-bituminous Mix'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI019_ASU'][15] = u'Pierced Steel Planking'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI019_ASU'][16] = u'Sand'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI019_ASU'][17] = u'Snow'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI019_ASU'][18] = u'Stone'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI019_ASU'][20] = u'Wood'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI019_ASU'][21] = u'Asphalt Over Concrete'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI019_ASU'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI019_ASU2'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI019_ASU2'][1] = u'Asphalt'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI019_ASU2'][2] = u'Bituminous Mix'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI019_ASU2'][3] = u'Brick'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI019_ASU2'][4] = u'Clay'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI019_ASU2'][5] = u'Concrete'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI019_ASU2'][6] = u'Coral'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI019_ASU2'][7] = u'Earthen'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI019_ASU2'][8] = u'Gravel'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI019_ASU2'][9] = u'Ice'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI019_ASU2'][10] = u'Landing Mat'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI019_ASU2'][11] = u'Laterite'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI019_ASU2'][12] = u'Macadam'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI019_ASU2'][13] = u'Membrane'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI019_ASU2'][14] = u'Non-bituminous Mix'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI019_ASU2'][15] = u'Pierced Steel Planking'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI019_ASU2'][16] = u'Sand'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI019_ASU2'][17] = u'Snow'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI019_ASU2'][18] = u'Stone'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI019_ASU2'][20] = u'Wood'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI019_ASU2'][21] = u'Asphalt Over Concrete'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI019_ASU2'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI019_ASU3'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI019_ASU3'][1] = u'Asphalt'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI019_ASU3'][2] = u'Bituminous Mix'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI019_ASU3'][3] = u'Brick'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI019_ASU3'][4] = u'Clay'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI019_ASU3'][5] = u'Concrete'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI019_ASU3'][6] = u'Coral'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI019_ASU3'][7] = u'Earthen'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI019_ASU3'][8] = u'Gravel'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI019_ASU3'][9] = u'Ice'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI019_ASU3'][10] = u'Landing Mat'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI019_ASU3'][11] = u'Laterite'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI019_ASU3'][12] = u'Macadam'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI019_ASU3'][13] = u'Membrane'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI019_ASU3'][14] = u'Non-bituminous Mix'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI019_ASU3'][15] = u'Pierced Steel Planking'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI019_ASU3'][16] = u'Sand'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI019_ASU3'][17] = u'Snow'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI019_ASU3'][18] = u'Stone'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI019_ASU3'][20] = u'Wood'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI019_ASU3'][21] = u'Asphalt Over Concrete'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI019_ASU3'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI019_ASX'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI019_ASX'][1] = u'Completely Paved'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI019_ASX'][2] = u'Mostly Paved'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI019_ASX'][3] = u'Unprepared'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI019_ASX'][4] = u'Partially Paved'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI019_ASX'][5] = u'Unpaved'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI019_ASX'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI019_SFS'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI019_SFS'][1] = u'Fair'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI019_SFS'][2] = u'Fair Estimated'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI019_SFS'][3] = u'Good'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI019_SFS'][4] = u'Good Estimated'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI019_SFS'][5] = u'Poor'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI019_SFS'][6] = u'Poor Estimated'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI019_SFS'][7] = u'Under Construction'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI019_SFS'][8] = u'Unserviceable'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI019_SFS'][9] = u'Excellent'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI024_DRL'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI024_DRL'][17] = u'On Waterbody Bottom'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI024_DRL'][40] = u'Below Ground Surface'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI024_DRL'][44] = u'On Surface'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI024_DRL'][45] = u'Above Surface'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI024_DRL'][50] = u'Submerged'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI024_DRL'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI024_DVPT'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI024_DVPT'][1] = u'Electricity'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI024_DVPT'][2] = u'Petroleum Product'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI024_DVPT'][3] = u'Manual'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI024_DVPT'][4] = u'Gravity'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI024_DVPT'][5] = u'Compressed Air'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI024_DVPT'][6] = u'Steam'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI024_DVPT'][7] = u'Solar'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI024_DVPT'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI024_HYP'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI024_HYP'][1] = u'Perennial'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI024_HYP'][2] = u'Intermittent'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI024_HYP'][4] = u'Dry'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI024_PMP'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI024_PMP'][1] = u'Airlift'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI024_PMP'][2] = u'Centrifugal'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI024_PMP'][3] = u'Jet'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI024_PMP'][4] = u'Reciprocating'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI024_PMP'][5] = u'Turbine'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI024_PMP'][6] = u'Gravity'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI024_PMP'][7] = u'Vacuum'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI024_PMP'][8] = u'Rotary'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI024_PMP'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI024_PUR'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI024_PUR'][1] = u'Desalination'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI024_PUR'][2] = u'Filtration'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI024_PUR'][3] = u'Sedimentation/coagulation'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI024_PUR'][4] = u'Reverse Osmosis'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI024_PUR'][5] = u'Electrolysis'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI024_PUR'][6] = u'Disinfection'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI024_PUR'][7] = u'Blending'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI024_PUR'][8] = u'Freezing'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI024_PUR'][9] = u'Multi-stage flash'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI024_PUR'][10] = u'Multi-effect evaporation'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI024_PUR'][11] = u'Vapor Compression'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI024_PUR'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI024_PUR2'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI024_PUR2'][1] = u'Desalination'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI024_PUR2'][2] = u'Filtration'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI024_PUR2'][3] = u'Sedimentation/coagulation'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI024_PUR2'][4] = u'Reverse Osmosis'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI024_PUR2'][5] = u'Electrolysis'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI024_PUR2'][6] = u'Disinfection'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI024_PUR2'][7] = u'Blending'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI024_PUR2'][8] = u'Freezing'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI024_PUR2'][9] = u'Multi-stage flash'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI024_PUR2'][10] = u'Multi-effect evaporation'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI024_PUR2'][11] = u'Vapor Compression'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI024_PUR2'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI024_PUR3'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI024_PUR3'][1] = u'Desalination'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI024_PUR3'][2] = u'Filtration'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI024_PUR3'][3] = u'Sedimentation/coagulation'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI024_PUR3'][4] = u'Reverse Osmosis'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI024_PUR3'][5] = u'Electrolysis'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI024_PUR3'][6] = u'Disinfection'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI024_PUR3'][7] = u'Blending'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI024_PUR3'][8] = u'Freezing'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI024_PUR3'][9] = u'Multi-stage flash'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI024_PUR3'][10] = u'Multi-effect evaporation'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI024_PUR3'][11] = u'Vapor Compression'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI024_PUR3'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI024_PUR4'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI024_PUR4'][1] = u'Desalination'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI024_PUR4'][2] = u'Filtration'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI024_PUR4'][3] = u'Sedimentation/coagulation'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI024_PUR4'][4] = u'Reverse Osmosis'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI024_PUR4'][5] = u'Electrolysis'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI024_PUR4'][6] = u'Disinfection'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI024_PUR4'][7] = u'Blending'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI024_PUR4'][8] = u'Freezing'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI024_PUR4'][9] = u'Multi-stage flash'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI024_PUR4'][10] = u'Multi-effect evaporation'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI024_PUR4'][11] = u'Vapor Compression'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI024_PUR4'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI024_PUR5'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI024_PUR5'][1] = u'Desalination'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI024_PUR5'][2] = u'Filtration'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI024_PUR5'][3] = u'Sedimentation/coagulation'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI024_PUR5'][4] = u'Reverse Osmosis'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI024_PUR5'][5] = u'Electrolysis'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI024_PUR5'][6] = u'Disinfection'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI024_PUR5'][7] = u'Blending'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI024_PUR5'][8] = u'Freezing'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI024_PUR5'][9] = u'Multi-stage flash'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI024_PUR5'][10] = u'Multi-effect evaporation'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI024_PUR5'][11] = u'Vapor Compression'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI024_PUR5'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI024_RTP'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI024_RTP'][1] = u'Constructed Basin'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI024_RTP'][2] = u'Back-up Water Impounded by a Dam'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI024_RTP'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI024_SCC'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI024_SCC'][1] = u'Alkaline'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI024_SCC'][4] = u'Mineral'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI024_SCC'][10] = u'Saline'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI024_SCC'][11] = u'Fresh'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI024_SCC'][12] = u'Brackish'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI024_SCC'][13] = u'Seawater'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI024_SCC'][14] = u'Brine'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI024_SCC'][998] = u'Not Applicable'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI024_SCC'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI024_SQN'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI024_SQN'][1] = u'Small'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI024_SQN'][2] = u'Moderate'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI024_SQN'][3] = u'Large'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI024_SQN'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI024_WPAC'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI024_WPAC'][100] = u'From Left'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI024_WPAC'][101] = u'From Right'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI024_WPAC'][102] = u'From All Sides'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI024_WPAC'][103] = u'No Accessibility'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI024_WPAC'][104] = u'From North'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI024_WPAC'][105] = u'From South'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI024_WPAC'][106] = u'From East'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI024_WPAC'][107] = u'From West'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI024_WSG'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI024_WSG'][1] = u'Low'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI024_WSG'][2] = u'Mean'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI024_WSG'][3] = u'High'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI024_WSG'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI024_WUR'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI024_WUR'][1] = u'Agricultural Irrigation'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI024_WUR'][2] = u'Commercial'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI024_WUR'][3] = u'Domestic Irrigation '
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI024_WUR'][4] = u'Industrial'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI024_WUR'][5] = u'Institutional'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI024_WUR'][6] = u'Livestock'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI024_WUR'][7] = u'Municipal'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI024_WUR'][8] = u'Power Generation'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI024_WUR'][9] = u'Recreational'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI024_WUR'][10] = u'Sanitary Domestic '
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI024_WUR'][11] = u'Military'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI024_WUR'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI024_WUR2'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI024_WUR2'][1] = u'Agricultural Irrigation'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI024_WUR2'][2] = u'Commercial'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI024_WUR2'][3] = u'Domestic Irrigation '
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI024_WUR2'][4] = u'Industrial'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI024_WUR2'][5] = u'Institutional'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI024_WUR2'][6] = u'Livestock'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI024_WUR2'][7] = u'Municipal'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI024_WUR2'][8] = u'Power Generation'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI024_WUR2'][9] = u'Recreational'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI024_WUR2'][10] = u'Sanitary Domestic '
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI024_WUR2'][11] = u'Military'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI024_WUR2'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI024_WUR3'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI024_WUR3'][1] = u'Agricultural Irrigation'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI024_WUR3'][2] = u'Commercial'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI024_WUR3'][3] = u'Domestic Irrigation '
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI024_WUR3'][4] = u'Industrial'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI024_WUR3'][5] = u'Institutional'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI024_WUR3'][6] = u'Livestock'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI024_WUR3'][7] = u'Municipal'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI024_WUR3'][8] = u'Power Generation'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI024_WUR3'][9] = u'Recreational'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI024_WUR3'][10] = u'Sanitary Domestic '
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI024_WUR3'][11] = u'Military'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI024_WUR3'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI024_WUR4'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI024_WUR4'][1] = u'Agricultural Irrigation'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI024_WUR4'][2] = u'Commercial'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI024_WUR4'][3] = u'Domestic Irrigation '
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI024_WUR4'][4] = u'Industrial'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI024_WUR4'][5] = u'Institutional'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI024_WUR4'][6] = u'Livestock'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI024_WUR4'][7] = u'Municipal'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI024_WUR4'][8] = u'Power Generation'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI024_WUR4'][9] = u'Recreational'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI024_WUR4'][10] = u'Sanitary Domestic '
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI024_WUR4'][11] = u'Military'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI024_WUR4'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI024_YWQ'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI024_YWQ'][1] = u'Potable'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI024_YWQ'][2] = u'Treatable'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI024_YWQ'][3] = u'Contaminated'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI024_YWQ'][4] = u'Nonpotable'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI024_YWQ'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI025_MAN'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI025_MAN'][1000] = u'False'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI025_MAN'][1001] = u'True'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI025_UHS'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI025_UHS'][1000] = u'False'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI025_UHS'][1001] = u'True'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI025_WLE'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI025_WLE'][1] = u'Partly Submerged'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI025_WLE'][2] = u'Always Dry'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI025_WLE'][3] = u'Always Submerged'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI025_WLE'][4] = u'Covers and Uncovers'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI025_WLE'][5] = u'Awash at Low Water'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI025_WLE'][9] = u'Awash at Chart Datum'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI025_WLE'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI026_CTUC'][2] = u'Open Interval'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI026_CTUC'][3] = u'Greater-than-or-equal to Less-than Interval'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI026_CTUC'][4] = u'Greater-than to Less-than-or-equal Interval'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI026_CTUC'][5] = u'Closed Interval'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI026_CTUC'][6] = u'Greater-than Semi-interval'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI026_CTUC'][7] = u'Greater-than or Equal Semi-interval'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI026_CTUC'][8] = u'Less-than Semi-interval'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI026_CTUC'][9] = u'Less-than or Equal Semi-interval'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI026_SUR'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI026_SUR'][1] = u'Surveyed'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI026_SUR'][2] = u'Inadequately Surveyed'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI026_SUR'][3] = u'Unsurveyed'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI032_GUG'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI032_GUG'][1000] = u'False'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI032_GUG'][1001] = u'True'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI032_PYC'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI032_PYC'][1] = u'A\''
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI032_PYC'][2] = u'H\''
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI032_PYC'][3] = u'I\''
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI032_PYC'][4] = u'Y\''
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI032_PYC'][5] = u'T\''
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI032_PYC'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI032_PYM'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI032_PYM'][1] = u'Aluminium'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI032_PYM'][3] = u'Concrete'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI032_PYM'][4] = u'Masonry'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI032_PYM'][5] = u'Metal'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI032_PYM'][7] = u'Wood'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI032_PYM'][8] = u'Steel'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI032_PYM'][9] = u'Fibreglass'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI032_PYM'][10] = u'Iron'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI032_PYM'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI032_TOS'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI032_TOS'][6] = u'Mast'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI032_TOS'][8] = u'Pole'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI032_TOS'][11] = u'Tripod'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI032_TOS'][12] = u'Truss'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI032_TOS'][13] = u'Tubular'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI032_TOS'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI037_REL'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI037_REL'][1] = u'Buddhism'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI037_REL'][2] = u'Islam'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI037_REL'][3] = u'Roman Catholic'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI037_REL'][4] = u'Christian'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI037_REL'][5] = u'Judaism'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI037_REL'][6] = u'Orthodox'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI037_REL'][7] = u'Protestant'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI037_REL'][8] = u'Shinto'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI037_REL'][9] = u'Hinduism'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI037_REL'][10] = u'Shia'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI037_REL'][11] = u'Sunni'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI037_REL'][12] = u'Nestorian'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI037_REL'][13] = u'Chaldean'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI037_REL'][14] = u'Mixed and/or No Designation'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI037_REL'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI037_RFA'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI037_RFA'][1] = u'Cathedral'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI037_RFA'][2] = u'Chapel'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI037_RFA'][3] = u'Church'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI037_RFA'][4] = u'Marabout'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI037_RFA'][5] = u'Minaret'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI037_RFA'][6] = u'Mission'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI037_RFA'][7] = u'Mosque'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI037_RFA'][8] = u'Pagoda'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI037_RFA'][9] = u'Religious Community'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI037_RFA'][10] = u'Seminary'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI037_RFA'][11] = u'Shrine'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI037_RFA'][12] = u'Stupa'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI037_RFA'][13] = u'Synagogue'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI037_RFA'][14] = u'Tabernacle'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI037_RFA'][15] = u'Temple'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI037_RFA'][18] = u'Convent'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI037_RFA'][19] = u'Monastery'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI037_RFA'][20] = u'Noviciate'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI037_RFA'][21] = u'Hermitage'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI037_RFA'][22] = u'Retreat'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI037_RFA'][23] = u'Burial Site'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI037_RFA'][25] = u'Islamic Prayer Hall'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI037_RFA'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI071_CTX'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI071_CTX'][1] = u'Solution'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI071_CTX'][2] = u'Erosional'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI071_CTX'][3] = u'Aeolian'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI071_CTX'][4] = u'Waterbody'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI071_CTX'][5] = u'Glacier'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI071_CTX'][6] = u'Lava'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI071_CTX'][7] = u'Talus'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI071_CTX'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI071_FFN'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI071_FFN'][530] = u'        Warehousing and Storage'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI071_FFN'][563] = u'        Residence'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI071_FFN'][835] = u'    Defence Activities'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI071_FFN'][930] = u'Religious Activities'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI071_FFN'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI071_FFN2'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI071_FFN2'][530] = u'        Warehousing and Storage'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI071_FFN2'][563] = u'        Residence'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI071_FFN2'][835] = u'    Defence Activities'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI071_FFN2'][930] = u'Religious Activities'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI071_FFN2'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI071_FFN3'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI071_FFN3'][530] = u'        Warehousing and Storage'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI071_FFN3'][563] = u'        Residence'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI071_FFN3'][835] = u'    Defence Activities'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI071_FFN3'][930] = u'Religious Activities'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI071_FFN3'][999] = u'Other'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI071_UAO'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI071_UAO'][1] = u'Horizontal'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI071_UAO'][2] = u'Slopes Downward'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI071_UAO'][3] = u'Vertical Down'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI071_UAO'][4] = u'Slopes Upward'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZI071_UAO'][5] = u'Vertical Up'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZSAX_RX3'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZSAX_RX4'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZVH_VDT'][-999999] = u'No Information'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZVH_VDT'][1] = u'WGS 84 Ellipsoid'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZVH_VDT'][2] = u'WGS 84 EGM96 Geoid'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZVH_VDT'][3] = u'Mean Sea Level (MSL)'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZVH_VDT'][4] = u'North American Vertical Datum (NAVD) 1988'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZVH_VDT'][5] = u'National Geodetic Vertical Datum (NGVD) 1929'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZVH_VDT'][6] = u'Ground Level'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZVH_VDT'][7] = u'WGS 84 EGM08 Geoid'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZVH_VDT'][998] = u'Not Applicable'
    field_information['GGDM 3.0']['SummaryDomainValues']['ZVH_VDT'][999] = u'Other'


    field_information['GGDM 3.0']['DefaultValues'] = {}
    field_information['GGDM 3.0']['DefaultValues']['AA010'] = {}
    field_information['GGDM 3.0']['DefaultValues']['AA010']['AOO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AA010']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AA010']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AA010']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AA010']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AA010']['DZP'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AA010']['F_CODE'] = 'AA010'
    field_information['GGDM 3.0']['DefaultValues']['AA010']['FFN'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AA010']['FFN2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AA010']['FFN3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AA010']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AA010']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AA010']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AA010']['HGT'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AA010']['HST'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AA010']['HST2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AA010']['HST3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AA010']['LEA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AA010']['LMC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AA010']['LOC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AA010']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AA010']['MZN'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AA010']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AA010']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AA010']['PPO'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AA010']['PPO2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AA010']['PPO3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AA010']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AA010']['UMA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AA010']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AA010']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AA010']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AA010']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['AA010']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AA010']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AA010']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AA010']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AA010']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AA010']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AA010']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['AA010']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AA010']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AA010']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AA010']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AA010']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['AA010']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AA010']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AA010']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AA010']['ZVH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AA011'] = {}
    field_information['GGDM 3.0']['DefaultValues']['AA011']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AA011']['DZP'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AA011']['F_CODE'] = 'AA011'
    field_information['GGDM 3.0']['DefaultValues']['AA011']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AA011']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AA011']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AA011']['HGT'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AA011']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AA011']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AA011']['PFH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AA011']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AA011']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AA011']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AA011']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['AA011']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AA011']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AA011']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AA011']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AA011']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AA011']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AA011']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['AA011']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AA011']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AA011']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AA011']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AA011']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['AA011']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AA011']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AA011']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AA011']['ZVH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AA020'] = {}
    field_information['GGDM 3.0']['DefaultValues']['AA020']['AOO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AA020']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AA020']['AWP'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AA020']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AA020']['CAA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AA020']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AA020']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AA020']['F_CODE'] = 'AA020'
    field_information['GGDM 3.0']['DefaultValues']['AA020']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AA020']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AA020']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AA020']['HGT'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AA020']['LMC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AA020']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AA020']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AA020']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AA020']['PPO'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AA020']['PPO2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AA020']['PPO3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AA020']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AA020']['VOI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AA020']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AA020']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AA020']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AA020']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['AA020']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AA020']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AA020']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AA020']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['AA020']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AA020']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AA020']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AA020']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AA020']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['AA020']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AA020']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AA020']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AA020']['ZVH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AA040'] = {}
    field_information['GGDM 3.0']['DefaultValues']['AA040']['AOO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AA040']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AA040']['AWP'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AA040']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AA040']['CAA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AA040']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AA040']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AA040']['F_CODE'] = 'AA040'
    field_information['GGDM 3.0']['DefaultValues']['AA040']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AA040']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AA040']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AA040']['HGT'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AA040']['LMC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AA040']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AA040']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AA040']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AA040']['PPO'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AA040']['PPO2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AA040']['PPO3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AA040']['SRL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AA040']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AA040']['VCM'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AA040']['VCM2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AA040']['VCM3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AA040']['VOI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AA040']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AA040']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AA040']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AA040']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['AA040']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AA040']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AA040']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AA040']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AA040']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AA040']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AA040']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['AA040']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AA040']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AA040']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AA040']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AA040']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['AA040']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AA040']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AA040']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AA040']['ZVH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AA045'] = {}
    field_information['GGDM 3.0']['DefaultValues']['AA045']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AA045']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AA045']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AA045']['DZP'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AA045']['F_CODE'] = 'AA045'
    field_information['GGDM 3.0']['DefaultValues']['AA045']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AA045']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AA045']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AA045']['LMC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AA045']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AA045']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AA045']['RIP'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AA045']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AA045']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AA045']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AA045']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['AA045']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AA045']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AA045']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AA045']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AA045']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AA045']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AA045']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['AA045']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AA045']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AA045']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AA045']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AA045']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['AA045']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AA045']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AA045']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AA045']['ZVH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AA052'] = {}
    field_information['GGDM 3.0']['DefaultValues']['AA052']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AA052']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AA052']['F_CODE'] = 'AA052'
    field_information['GGDM 3.0']['DefaultValues']['AA052']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AA052']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AA052']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AA052']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AA052']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AA052']['PPO'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AA052']['PPO2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AA052']['PPO3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AA052']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AA052']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AA052']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AA052']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AA052']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['AA052']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AA052']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AA052']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AA052']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AA052']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AA052']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AA052']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['AA052']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AA052']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AA052']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AA052']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AA052']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['AA052']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AA052']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AA052']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AA054'] = {}
    field_information['GGDM 3.0']['DefaultValues']['AA054']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AA054']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AA054']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AA054']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AA054']['F_CODE'] = 'AA054'
    field_information['GGDM 3.0']['DefaultValues']['AA054']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AA054']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AA054']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AA054']['HGT'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AA054']['LMC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AA054']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AA054']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AA054']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AA054']['PPO'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AA054']['PPO2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AA054']['PPO3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AA054']['RIP'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AA054']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AA054']['WEQ'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AA054']['WEQ2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AA054']['WEQ3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AA054']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AA054']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AA054']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AA054']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['AA054']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AA054']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AA054']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AA054']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AA054']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AA054']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AA054']['ZI025_HDP'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AA054']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['AA054']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AA054']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AA054']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AA054']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AA054']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['AA054']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AA054']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AA054']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AA054']['ZVH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AB000'] = {}
    field_information['GGDM 3.0']['DefaultValues']['AB000']['AOO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AB000']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AB000']['AWP'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AB000']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AB000']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AB000']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AB000']['F_CODE'] = 'AB000'
    field_information['GGDM 3.0']['DefaultValues']['AB000']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AB000']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AB000']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AB000']['HGT'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AB000']['LMC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AB000']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AB000']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AB000']['PBY'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AB000']['PBY2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AB000']['PBY3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AB000']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AB000']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AB000']['VOI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AB000']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AB000']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AB000']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AB000']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['AB000']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AB000']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AB000']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AB000']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AB000']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AB000']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AB000']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['AB000']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AB000']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AB000']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AB000']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AB000']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['AB000']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AB000']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AB000']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AB000']['ZVH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AB010'] = {}
    field_information['GGDM 3.0']['DefaultValues']['AB010']['AOO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AB010']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AB010']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AB010']['CAA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AB010']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AB010']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AB010']['F_CODE'] = 'AB010'
    field_information['GGDM 3.0']['DefaultValues']['AB010']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AB010']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AB010']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AB010']['HGT'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AB010']['LMC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AB010']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AB010']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AB010']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AB010']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AB010']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AB010']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AB010']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AB010']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['AB010']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AB010']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AB010']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AB010']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AB010']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AB010']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AB010']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['AB010']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AB010']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AB010']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AB010']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AB010']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['AB010']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AB010']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AB010']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AB010']['ZVH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AB021'] = {}
    field_information['GGDM 3.0']['DefaultValues']['AB021']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AB021']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AB021']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AB021']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AB021']['F_CODE'] = 'AB021'
    field_information['GGDM 3.0']['DefaultValues']['AB021']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AB021']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AB021']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AB021']['LMC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AB021']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AB021']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AB021']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AB021']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AB021']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AB021']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AB021']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AB021']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['AB021']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AB021']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AB021']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AB021']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AB021']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AB021']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AB021']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['AB021']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AB021']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AB021']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AB021']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AB021']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['AB021']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AB021']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AB021']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AB040'] = {}
    field_information['GGDM 3.0']['DefaultValues']['AB040']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AB040']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AB040']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AB040']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AB040']['F_CODE'] = 'AB040'
    field_information['GGDM 3.0']['DefaultValues']['AB040']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AB040']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AB040']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AB040']['LMC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AB040']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AB040']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AB040']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AB040']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AB040']['VLM'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AB040']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AB040']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AB040']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AB040']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['AB040']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AB040']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AB040']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AB040']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AB040']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AB040']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AB040']['ZI024_ASE'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AB040']['ZI024_CFR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AB040']['ZI024_CLO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AB040']['ZI024_CYN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AB040']['ZI024_FMR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AB040']['ZI024_FRR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AB040']['ZI024_HAR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AB040']['ZI024_MGN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AB040']['ZI024_PHW'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AB040']['ZI024_SCC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AB040']['ZI024_SUL'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AB040']['ZI024_TDS'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AB040']['ZI024_TEP'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AB040']['ZI024_TUR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AB040']['ZI024_WAC'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AB040']['ZI024_WTNO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AB040']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['AB040']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AB040']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AB040']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AB040']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AB040']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['AB040']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AB040']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AB040']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AB507'] = {}
    field_information['GGDM 3.0']['DefaultValues']['AB507']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AB507']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AB507']['F_CODE'] = 'AB507'
    field_information['GGDM 3.0']['DefaultValues']['AB507']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AB507']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AB507']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AB507']['HGT'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AB507']['LMC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AB507']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AB507']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AB507']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AB507']['VOI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AB507']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AB507']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AB507']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AB507']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['AB507']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AB507']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AB507']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AB507']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AB507']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AB507']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AB507']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['AB507']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AB507']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AB507']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AB507']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AB507']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['AB507']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AB507']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AB507']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AB507']['ZVH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AC010'] = {}
    field_information['GGDM 3.0']['DefaultValues']['AC010']['AOO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AC010']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AC010']['AWP'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AC010']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AC010']['CAA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AC010']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AC010']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AC010']['F_CODE'] = 'AC010'
    field_information['GGDM 3.0']['DefaultValues']['AC010']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AC010']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AC010']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AC010']['HGT'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AC010']['LMC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AC010']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AC010']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AC010']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AC010']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AC010']['VOI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AC010']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AC010']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AC010']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AC010']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['AC010']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AC010']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AC010']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AC010']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AC010']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AC010']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AC010']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['AC010']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AC010']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AC010']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AC010']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AC010']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['AC010']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AC010']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AC010']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AC010']['ZVH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AC020'] = {}
    field_information['GGDM 3.0']['DefaultValues']['AC020']['AOO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AC020']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AC020']['AWP'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AC020']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AC020']['CAA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AC020']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AC020']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AC020']['F_CODE'] = 'AC020'
    field_information['GGDM 3.0']['DefaultValues']['AC020']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AC020']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AC020']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AC020']['HGT'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AC020']['LMC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AC020']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AC020']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AC020']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AC020']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AC020']['VCM'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AC020']['VCM2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AC020']['VCM3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AC020']['VOI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AC020']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AC020']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AC020']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AC020']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['AC020']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AC020']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AC020']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AC020']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AC020']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AC020']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AC020']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['AC020']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AC020']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AC020']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AC020']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AC020']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['AC020']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AC020']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AC020']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AC020']['ZVH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AC030'] = {}
    field_information['GGDM 3.0']['DefaultValues']['AC030']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AC030']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AC030']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AC030']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AC030']['DZP'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AC030']['F_CODE'] = 'AC030'
    field_information['GGDM 3.0']['DefaultValues']['AC030']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AC030']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AC030']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AC030']['LMC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AC030']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AC030']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AC030']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AC030']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AC030']['VLM'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AC030']['WDAC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['AC030']['WDAL'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AC030']['WDAU'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AC030']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AC030']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AC030']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AC030']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['AC030']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AC030']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AC030']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AC030']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AC030']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AC030']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AC030']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['AC030']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AC030']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AC030']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AC030']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AC030']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['AC030']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AC030']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AC030']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AC040'] = {}
    field_information['GGDM 3.0']['DefaultValues']['AC040']['ADR'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AC040']['AOO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AC040']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AC040']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AC040']['CAA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AC040']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AC040']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AC040']['F_CODE'] = 'AC040'
    field_information['GGDM 3.0']['DefaultValues']['AC040']['FFN'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AC040']['FFN2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AC040']['FFN3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AC040']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AC040']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AC040']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AC040']['HGT'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AC040']['LMC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AC040']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AC040']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AC040']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AC040']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AC040']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AC040']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AC040']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AC040']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['AC040']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AC040']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AC040']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AC040']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AC040']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AC040']['ZI014_PPO'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AC040']['ZI014_PPO2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AC040']['ZI014_PPO3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AC040']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AC040']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['AC040']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AC040']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AC040']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AC040']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AC040']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['AC040']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AC040']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AC040']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AC040']['ZVH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AC060'] = {}
    field_information['GGDM 3.0']['DefaultValues']['AC060']['AOO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AC060']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AC060']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AC060']['CAA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AC060']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AC060']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AC060']['F_CODE'] = 'AC060'
    field_information['GGDM 3.0']['DefaultValues']['AC060']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AC060']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AC060']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AC060']['HGT'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AC060']['LMC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AC060']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AC060']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AC060']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AC060']['PPO'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AC060']['PPO2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AC060']['PPO3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AC060']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AC060']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AC060']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AC060']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AC060']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['AC060']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AC060']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AC060']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AC060']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AC060']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AC060']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AC060']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['AC060']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AC060']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AC060']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AC060']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AC060']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['AC060']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AC060']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AC060']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AC060']['ZVH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AC507'] = {}
    field_information['GGDM 3.0']['DefaultValues']['AC507']['ADR'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AC507']['AOO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AC507']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AC507']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AC507']['CAA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AC507']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AC507']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AC507']['DCAP'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AC507']['DINF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AC507']['F_CODE'] = 'AC507'
    field_information['GGDM 3.0']['DefaultValues']['AC507']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AC507']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AC507']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AC507']['GRD'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AC507']['HGT'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AC507']['LMC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AC507']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AC507']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AC507']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AC507']['PPO'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AC507']['PPO2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AC507']['PPO3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AC507']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AC507']['VCM'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AC507']['VCM2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AC507']['VCM3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AC507']['WDST'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AC507']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AC507']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AC507']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AC507']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['AC507']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AC507']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AC507']['ZI005_FNA2'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AC507']['ZI005_FNA3'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AC507']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AC507']['ZI005_GNT2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AC507']['ZI005_GNT3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AC507']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AC507']['ZI005_NFN2'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AC507']['ZI005_NFN3'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AC507']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AC507']['ZI014_PBY'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AC507']['ZI014_PBY2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AC507']['ZI014_PBY3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AC507']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AC507']['ZI024_ASE'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AC507']['ZI024_AWO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AC507']['ZI024_AWOI'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AC507']['ZI024_AWOX'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AC507']['ZI024_CFR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AC507']['ZI024_CLO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AC507']['ZI024_CYN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AC507']['ZI024_DRL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AC507']['ZI024_DVPT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AC507']['ZI024_FMR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AC507']['ZI024_FRR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AC507']['ZI024_HAR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AC507']['ZI024_MGN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AC507']['ZI024_PHW'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AC507']['ZI024_PMP'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AC507']['ZI024_PUR'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AC507']['ZI024_PUR2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AC507']['ZI024_PUR3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AC507']['ZI024_PUR4'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AC507']['ZI024_PUR5'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AC507']['ZI024_SCC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AC507']['ZI024_SUL'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AC507']['ZI024_TDS'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AC507']['ZI024_TEP'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AC507']['ZI024_TUR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AC507']['ZI024_WAC'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AC507']['ZI024_WTNO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AC507']['ZI024_WUR'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AC507']['ZI024_WUR2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AC507']['ZI024_WUR3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AC507']['ZI024_WUR4'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AC507']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['AC507']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AC507']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AC507']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AC507']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AC507']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['AC507']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AC507']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AC507']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AC507']['ZVH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AD010'] = {}
    field_information['GGDM 3.0']['DefaultValues']['AD010']['ADR'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AD010']['AOO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AD010']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AD010']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AD010']['CAA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AD010']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AD010']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AD010']['EPW'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AD010']['F_CODE'] = 'AD010'
    field_information['GGDM 3.0']['DefaultValues']['AD010']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AD010']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AD010']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AD010']['HGT'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AD010']['LMC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AD010']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AD010']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AD010']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AD010']['POS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AD010']['POS2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AD010']['POS3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AD010']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AD010']['VCM'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AD010']['VCM2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AD010']['VCM3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AD010']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AD010']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AD010']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AD010']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['AD010']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AD010']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AD010']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AD010']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AD010']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AD010']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AD010']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['AD010']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AD010']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AD010']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AD010']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AD010']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['AD010']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AD010']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AD010']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AD010']['ZVH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AD020'] = {}
    field_information['GGDM 3.0']['DefaultValues']['AD020']['AOO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AD020']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AD020']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AD020']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AD020']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AD020']['F_CODE'] = 'AD020'
    field_information['GGDM 3.0']['DefaultValues']['AD020']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AD020']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AD020']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AD020']['HGT'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AD020']['LMC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AD020']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AD020']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AD020']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AD020']['PPO'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AD020']['PPO2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AD020']['PPO3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AD020']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AD020']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AD020']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AD020']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AD020']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['AD020']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AD020']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AD020']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AD020']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AD020']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AD020']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AD020']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['AD020']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AD020']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AD020']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AD020']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AD020']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['AD020']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AD020']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AD020']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AD020']['ZVH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AD025'] = {}
    field_information['GGDM 3.0']['DefaultValues']['AD025']['ADR'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AD025']['AOO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AD025']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AD025']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AD025']['CAA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AD025']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AD025']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AD025']['F_CODE'] = 'AD025'
    field_information['GGDM 3.0']['DefaultValues']['AD025']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AD025']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AD025']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AD025']['HGT'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AD025']['LMC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AD025']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AD025']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AD025']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AD025']['PPO'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AD025']['PPO2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AD025']['PPO3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AD025']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AD025']['VCM'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AD025']['VCM2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AD025']['VCM3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AD025']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AD025']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AD025']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AD025']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['AD025']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AD025']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AD025']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AD025']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AD025']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AD025']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AD025']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['AD025']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AD025']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AD025']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AD025']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AD025']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['AD025']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AD025']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AD025']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AD025']['ZVH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AD030'] = {}
    field_information['GGDM 3.0']['DefaultValues']['AD030']['ADR'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AD030']['AOO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AD030']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AD030']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AD030']['CAA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AD030']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AD030']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AD030']['F_CODE'] = 'AD030'
    field_information['GGDM 3.0']['DefaultValues']['AD030']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AD030']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AD030']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AD030']['HGT'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AD030']['LMC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AD030']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AD030']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AD030']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AD030']['SBT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AD030']['SBT2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AD030']['SBT3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AD030']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AD030']['VCM'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AD030']['VCM2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AD030']['VCM3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AD030']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AD030']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AD030']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AD030']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['AD030']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AD030']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AD030']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AD030']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AD030']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AD030']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AD030']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['AD030']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AD030']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AD030']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AD030']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AD030']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['AD030']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AD030']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AD030']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AD030']['ZVH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AD041'] = {}
    field_information['GGDM 3.0']['DefaultValues']['AD041']['AOO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AD041']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AD041']['AWP'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AD041']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AD041']['CAA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AD041']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AD041']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AD041']['DZP'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AD041']['F_CODE'] = 'AD041'
    field_information['GGDM 3.0']['DefaultValues']['AD041']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AD041']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AD041']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AD041']['HGT'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AD041']['LEA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AD041']['LMC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AD041']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AD041']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AD041']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AD041']['SSR'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AD041']['SSR2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AD041']['SSR3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AD041']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AD041']['VCM'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AD041']['VCM2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AD041']['VCM3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AD041']['VOI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AD041']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AD041']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AD041']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AD041']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['AD041']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AD041']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AD041']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AD041']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AD041']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AD041']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AD041']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['AD041']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AD041']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AD041']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AD041']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AD041']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['AD041']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AD041']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AD041']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AD041']['ZVH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AD050'] = {}
    field_information['GGDM 3.0']['DefaultValues']['AD050']['ADR'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AD050']['AOO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AD050']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AD050']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AD050']['CAA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AD050']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AD050']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AD050']['F_CODE'] = 'AD050'
    field_information['GGDM 3.0']['DefaultValues']['AD050']['FFN'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AD050']['FFN2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AD050']['FFN3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AD050']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AD050']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AD050']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AD050']['HGT'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AD050']['LMC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AD050']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AD050']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AD050']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AD050']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AD050']['VCM'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AD050']['VCM2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AD050']['VCM3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AD050']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AD050']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AD050']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AD050']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['AD050']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AD050']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AD050']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AD050']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AD050']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AD050']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AD050']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['AD050']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AD050']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AD050']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AD050']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AD050']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['AD050']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AD050']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AD050']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AD050']['ZVH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AD055'] = {}
    field_information['GGDM 3.0']['DefaultValues']['AD055']['ADR'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AD055']['AOO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AD055']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AD055']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AD055']['CAA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AD055']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AD055']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AD055']['F_CODE'] = 'AD055'
    field_information['GGDM 3.0']['DefaultValues']['AD055']['FFN'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AD055']['FFN2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AD055']['FFN3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AD055']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AD055']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AD055']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AD055']['HGT'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AD055']['LMC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AD055']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AD055']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AD055']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AD055']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AD055']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AD055']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AD055']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AD055']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['AD055']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AD055']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AD055']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AD055']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AD055']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AD055']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AD055']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['AD055']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AD055']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AD055']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AD055']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AD055']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['AD055']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AD055']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AD055']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AD055']['ZVH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AD060'] = {}
    field_information['GGDM 3.0']['DefaultValues']['AD060']['ADR'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AD060']['AOO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AD060']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AD060']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AD060']['CAA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AD060']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AD060']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AD060']['F_CODE'] = 'AD060'
    field_information['GGDM 3.0']['DefaultValues']['AD060']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AD060']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AD060']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AD060']['HGT'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AD060']['LMC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AD060']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AD060']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AD060']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AD060']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AD060']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AD060']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AD060']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AD060']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['AD060']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AD060']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AD060']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AD060']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AD060']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AD060']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AD060']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['AD060']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AD060']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AD060']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AD060']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AD060']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['AD060']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AD060']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AD060']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AD060']['ZVH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AF010'] = {}
    field_information['GGDM 3.0']['DefaultValues']['AF010']['AOO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AF010']['AWP'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AF010']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AF010']['CAA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AF010']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AF010']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AF010']['DIM'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AF010']['F_CODE'] = 'AF010'
    field_information['GGDM 3.0']['DefaultValues']['AF010']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AF010']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AF010']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AF010']['HEI'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AF010']['HGT'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AF010']['LMC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AF010']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AF010']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AF010']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AF010']['VCM'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AF010']['VCM2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AF010']['VCM3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AF010']['VOI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AF010']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AF010']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AF010']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['AF010']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AF010']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AF010']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AF010']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AF010']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AF010']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AF010']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['AF010']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AF010']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AF010']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AF010']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AF010']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['AF010']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AF010']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AF010']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AF010']['ZVH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AF020'] = {}
    field_information['GGDM 3.0']['DefaultValues']['AF020']['AOO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AF020']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AF020']['AWP'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AF020']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AF020']['CAA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AF020']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AF020']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AF020']['CVT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AF020']['CVT2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AF020']['CVT3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AF020']['F_CODE'] = 'AF020'
    field_information['GGDM 3.0']['DefaultValues']['AF020']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AF020']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AF020']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AF020']['HGT'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AF020']['LMC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AF020']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AF020']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AF020']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AF020']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AF020']['VCM'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AF020']['VCM2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AF020']['VCM3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AF020']['VOI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AF020']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AF020']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AF020']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AF020']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['AF020']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AF020']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AF020']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AF020']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AF020']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AF020']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AF020']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['AF020']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AF020']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AF020']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AF020']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AF020']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['AF020']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AF020']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AF020']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AF020']['ZVH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AF030'] = {}
    field_information['GGDM 3.0']['DefaultValues']['AF030']['AOO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AF030']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AF030']['AWP'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AF030']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AF030']['CAA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AF030']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AF030']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AF030']['F_CODE'] = 'AF030'
    field_information['GGDM 3.0']['DefaultValues']['AF030']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AF030']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AF030']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AF030']['HGT'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AF030']['LMC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AF030']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AF030']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AF030']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AF030']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AF030']['VCM'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AF030']['VCM2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AF030']['VCM3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AF030']['VOI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AF030']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AF030']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AF030']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AF030']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['AF030']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AF030']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AF030']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AF030']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AF030']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AF030']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AF030']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['AF030']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AF030']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AF030']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AF030']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AF030']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['AF030']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AF030']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AF030']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AF030']['ZVH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AF040'] = {}
    field_information['GGDM 3.0']['DefaultValues']['AF040']['AOO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AF040']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AF040']['AWP'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AF040']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AF040']['CAA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AF040']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AF040']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AF040']['CRA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AF040']['CRM'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AF040']['F_CODE'] = 'AF040'
    field_information['GGDM 3.0']['DefaultValues']['AF040']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AF040']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AF040']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AF040']['HGT'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AF040']['LCA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AF040']['LMC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AF040']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AF040']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AF040']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AF040']['SRL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AF040']['TRS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AF040']['TRS2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AF040']['TRS3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AF040']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AF040']['VCM'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AF040']['VCM2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AF040']['VCM3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AF040']['VOI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AF040']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AF040']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AF040']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AF040']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['AF040']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AF040']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AF040']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AF040']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AF040']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AF040']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AF040']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['AF040']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AF040']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AF040']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AF040']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AF040']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['AF040']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AF040']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AF040']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AF040']['ZVH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AF050'] = {}
    field_information['GGDM 3.0']['DefaultValues']['AF050']['AOO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AF050']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AF050']['AWP'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AF050']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AF050']['CAA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AF050']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AF050']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AF050']['F_CODE'] = 'AF050'
    field_information['GGDM 3.0']['DefaultValues']['AF050']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AF050']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AF050']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AF050']['HGT'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AF050']['LMC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AF050']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AF050']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AF050']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AF050']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AF050']['VOI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AF050']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AF050']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AF050']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AF050']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['AF050']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AF050']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AF050']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AF050']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AF050']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AF050']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AF050']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['AF050']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AF050']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AF050']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AF050']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AF050']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['AF050']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AF050']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AF050']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AF050']['ZVH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AF060'] = {}
    field_information['GGDM 3.0']['DefaultValues']['AF060']['AOO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AF060']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AF060']['AWP'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AF060']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AF060']['CAA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AF060']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AF060']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AF060']['ETY'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AF060']['F_CODE'] = 'AF060'
    field_information['GGDM 3.0']['DefaultValues']['AF060']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AF060']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AF060']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AF060']['HGT'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AF060']['LMC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AF060']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AF060']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AF060']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AF060']['SRL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AF060']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AF060']['VOI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AF060']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AF060']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AF060']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AF060']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['AF060']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AF060']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AF060']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AF060']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AF060']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AF060']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AF060']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['AF060']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AF060']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AF060']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AF060']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AF060']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['AF060']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AF060']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AF060']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AF060']['ZVH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AF070'] = {}
    field_information['GGDM 3.0']['DefaultValues']['AF070']['AOO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AF070']['AWP'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AF070']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AF070']['CAA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AF070']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AF070']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AF070']['F_CODE'] = 'AF070'
    field_information['GGDM 3.0']['DefaultValues']['AF070']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AF070']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AF070']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AF070']['GUG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AF070']['HGT'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AF070']['LMC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AF070']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AF070']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AF070']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AF070']['SRL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AF070']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AF070']['VCM'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AF070']['VCM2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AF070']['VCM3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AF070']['VOI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AF070']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AF070']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AF070']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AF070']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['AF070']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AF070']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AF070']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AF070']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['AF070']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AF070']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AF070']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AF070']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AF070']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['AF070']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AF070']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AF070']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AF070']['ZVH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AF080'] = {}
    field_information['GGDM 3.0']['DefaultValues']['AF080']['AOO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AF080']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AF080']['AWP'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AF080']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AF080']['CAA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AF080']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AF080']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AF080']['F_CODE'] = 'AF080'
    field_information['GGDM 3.0']['DefaultValues']['AF080']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AF080']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AF080']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AF080']['HGT'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AF080']['LMC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AF080']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AF080']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AF080']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AF080']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AF080']['VOI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AF080']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AF080']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AF080']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AF080']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['AF080']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AF080']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AF080']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AF080']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AF080']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AF080']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AF080']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['AF080']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AF080']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AF080']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AF080']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AF080']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['AF080']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AF080']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AF080']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AF080']['ZVH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AG030'] = {}
    field_information['GGDM 3.0']['DefaultValues']['AG030']['ADR'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AG030']['AOO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AG030']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AG030']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AG030']['CAA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AG030']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AG030']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AG030']['F_CODE'] = 'AG030'
    field_information['GGDM 3.0']['DefaultValues']['AG030']['FFN'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AG030']['FFN2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AG030']['FFN3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AG030']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AG030']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AG030']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AG030']['HGT'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AG030']['LMC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AG030']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AG030']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AG030']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AG030']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AG030']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AG030']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AG030']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AG030']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['AG030']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AG030']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AG030']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AG030']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AG030']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AG030']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AG030']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['AG030']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AG030']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AG030']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AG030']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AG030']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['AG030']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AG030']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AG030']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AG030']['ZVH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AG040'] = {}
    field_information['GGDM 3.0']['DefaultValues']['AG040']['ADR'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AG040']['AOO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AG040']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AG040']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AG040']['CAA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AG040']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AG040']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AG040']['F_CODE'] = 'AG040'
    field_information['GGDM 3.0']['DefaultValues']['AG040']['FFN'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AG040']['FFN2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AG040']['FFN3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AG040']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AG040']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AG040']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AG040']['HGT'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AG040']['LMC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AG040']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AG040']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AG040']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AG040']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AG040']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AG040']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AG040']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AG040']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['AG040']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AG040']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AG040']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AG040']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AG040']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AG040']['ZI014_PBY'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AG040']['ZI014_PBY2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AG040']['ZI014_PBY3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AG040']['ZI014_PPO'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AG040']['ZI014_PPO2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AG040']['ZI014_PPO3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AG040']['ZI014_PRW'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AG040']['ZI014_PRW2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AG040']['ZI014_PRW3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AG040']['ZI018_WIT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AG040']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AG040']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['AG040']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AG040']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AG040']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AG040']['ZI037_REL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AG040']['ZI037_RFA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AG040']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AG040']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['AG040']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AG040']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AG040']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AG040']['ZVH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AG050'] = {}
    field_information['GGDM 3.0']['DefaultValues']['AG050']['AOO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AG050']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AG050']['AWP'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AG050']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AG050']['CAA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AG050']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AG050']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AG050']['F_CODE'] = 'AG050'
    field_information['GGDM 3.0']['DefaultValues']['AG050']['FFN'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AG050']['FFN2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AG050']['FFN3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AG050']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AG050']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AG050']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AG050']['HEI'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AG050']['HGT'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AG050']['LMC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AG050']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AG050']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AG050']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AG050']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AG050']['VOI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AG050']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AG050']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AG050']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['AG050']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AG050']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AG050']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AG050']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AG050']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AG050']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AG050']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['AG050']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AG050']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AG050']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AG050']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AG050']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['AG050']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AG050']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AG050']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AG050']['ZVH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AH025'] = {}
    field_information['GGDM 3.0']['DefaultValues']['AH025']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AH025']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AH025']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AH025']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AH025']['DZP'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AH025']['EET'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AH025']['F_CODE'] = 'AH025'
    field_information['GGDM 3.0']['DefaultValues']['AH025']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AH025']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AH025']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AH025']['HST'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AH025']['HST2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AH025']['HST3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AH025']['LMC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AH025']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AH025']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AH025']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AH025']['PFHC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['AH025']['PFHL'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AH025']['PFHU'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AH025']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AH025']['WD3'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AH025']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AH025']['YSU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AH025']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AH025']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AH025']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['AH025']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AH025']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AH025']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AH025']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AH025']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AH025']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AH025']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['AH025']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AH025']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AH025']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AH025']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AH025']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['AH025']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AH025']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AH025']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AH055'] = {}
    field_information['GGDM 3.0']['DefaultValues']['AH055']['ADR'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AH055']['AOO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AH055']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AH055']['ATB'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AH055']['AWP'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AH055']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AH055']['BNF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AH055']['CAA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AH055']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AH055']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AH055']['F_CODE'] = 'AH055'
    field_information['GGDM 3.0']['DefaultValues']['AH055']['FFN'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AH055']['FFN2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AH055']['FFN3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AH055']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AH055']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AH055']['FZR'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AH055']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AH055']['HGT'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AH055']['HST'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AH055']['HST2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AH055']['HST3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AH055']['LMC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AH055']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AH055']['MUB'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AH055']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AH055']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AH055']['RLE'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AH055']['SSR'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AH055']['SSR2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AH055']['SSR3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AH055']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AH055']['VCM'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AH055']['VCM2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AH055']['VCM3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AH055']['VOI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AH055']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AH055']['WPST'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AH055']['WTYP'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AH055']['YSU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AH055']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AH055']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AH055']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['AH055']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AH055']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AH055']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AH055']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AH055']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AH055']['ZI014_PBY'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AH055']['ZI014_PBY2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AH055']['ZI014_PBY3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AH055']['ZI014_PPO'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AH055']['ZI014_PPO2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AH055']['ZI014_PPO3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AH055']['ZI014_PRW'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AH055']['ZI014_PRW2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AH055']['ZI014_PRW3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AH055']['ZI018_WIT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AH055']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AH055']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['AH055']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AH055']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AH055']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AH055']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AH055']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['AH055']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AH055']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AH055']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AH055']['ZVH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AH060'] = {}
    field_information['GGDM 3.0']['DefaultValues']['AH060']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AH060']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AH060']['CAA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AH060']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AH060']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AH060']['DZP'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AH060']['F_CODE'] = 'AH060'
    field_information['GGDM 3.0']['DefaultValues']['AH060']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AH060']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AH060']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AH060']['HST'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AH060']['HST2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AH060']['HST3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AH060']['LEA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AH060']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AH060']['MCC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AH060']['MCC2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AH060']['MCC3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AH060']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AH060']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AH060']['PRM'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AH060']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AH060']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AH060']['YSU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AH060']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AH060']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AH060']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['AH060']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AH060']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AH060']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AH060']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AH060']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AH060']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AH060']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['AH060']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AH060']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AH060']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AH060']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AH060']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['AH060']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AH060']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AH060']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AH070'] = {}
    field_information['GGDM 3.0']['DefaultValues']['AH070']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AH070']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AH070']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AH070']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AH070']['F_CODE'] = 'AH070'
    field_information['GGDM 3.0']['DefaultValues']['AH070']['FFN'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AH070']['FFN2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AH070']['FFN3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AH070']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AH070']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AH070']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AH070']['LMC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AH070']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AH070']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AH070']['TRS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AH070']['TRS2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AH070']['TRS3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AH070']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AH070']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AH070']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AH070']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AH070']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['AH070']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AH070']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AH070']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AH070']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AH070']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AH070']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AH070']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['AH070']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AH070']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AH070']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AH070']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AH070']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['AH070']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AH070']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AH070']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AI020'] = {}
    field_information['GGDM 3.0']['DefaultValues']['AI020']['ADR'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AI020']['AOO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AI020']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AI020']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AI020']['CAA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AI020']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AI020']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AI020']['F_CODE'] = 'AI020'
    field_information['GGDM 3.0']['DefaultValues']['AI020']['FFN'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AI020']['FFN2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AI020']['FFN3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AI020']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AI020']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AI020']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AI020']['HGT'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AI020']['LMC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AI020']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AI020']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AI020']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AI020']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AI020']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AI020']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AI020']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AI020']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['AI020']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AI020']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AI020']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AI020']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AI020']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AI020']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AI020']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['AI020']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AI020']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AI020']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AI020']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AI020']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['AI020']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AI020']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AI020']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AI020']['ZVH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AI021'] = {}
    field_information['GGDM 3.0']['DefaultValues']['AI021']['ADR'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AI021']['AOO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AI021']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AI021']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AI021']['CAA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AI021']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AI021']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AI021']['F_CODE'] = 'AI021'
    field_information['GGDM 3.0']['DefaultValues']['AI021']['FFN'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AI021']['FFN2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AI021']['FFN3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AI021']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AI021']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AI021']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AI021']['HGT'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AI021']['LMC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AI021']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AI021']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AI021']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AI021']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AI021']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AI021']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AI021']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AI021']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['AI021']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AI021']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AI021']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AI021']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AI021']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AI021']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AI021']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['AI021']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AI021']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AI021']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AI021']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AI021']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['AI021']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AI021']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AI021']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AI021']['ZVH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AI030'] = {}
    field_information['GGDM 3.0']['DefaultValues']['AI030']['ADR'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AI030']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AI030']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AI030']['CAA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AI030']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AI030']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AI030']['F_CODE'] = 'AI030'
    field_information['GGDM 3.0']['DefaultValues']['AI030']['FFN'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AI030']['FFN2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AI030']['FFN3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AI030']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AI030']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AI030']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AI030']['HGT'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AI030']['LMC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AI030']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AI030']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AI030']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AI030']['STL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AI030']['STL2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AI030']['STL3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AI030']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AI030']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AI030']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AI030']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AI030']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['AI030']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AI030']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AI030']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AI030']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AI030']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AI030']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AI030']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['AI030']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AI030']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AI030']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AI030']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AI030']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['AI030']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AI030']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AI030']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AI030']['ZVH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AJ030'] = {}
    field_information['GGDM 3.0']['DefaultValues']['AJ030']['AOO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AJ030']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AJ030']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AJ030']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AJ030']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AJ030']['F_CODE'] = 'AJ030'
    field_information['GGDM 3.0']['DefaultValues']['AJ030']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AJ030']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AJ030']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AJ030']['HGT'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AJ030']['LMC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AJ030']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AJ030']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AJ030']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AJ030']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AJ030']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AJ030']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AJ030']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AJ030']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['AJ030']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AJ030']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AJ030']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AJ030']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AJ030']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AJ030']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AJ030']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['AJ030']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AJ030']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AJ030']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AJ030']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AJ030']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['AJ030']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AJ030']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AJ030']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AJ030']['ZVH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AJ050'] = {}
    field_information['GGDM 3.0']['DefaultValues']['AJ050']['AOO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AJ050']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AJ050']['AWP'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AJ050']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AJ050']['CAA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AJ050']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AJ050']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AJ050']['F_CODE'] = 'AJ050'
    field_information['GGDM 3.0']['DefaultValues']['AJ050']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AJ050']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AJ050']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AJ050']['HGT'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AJ050']['LMC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AJ050']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AJ050']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AJ050']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AJ050']['PPO'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AJ050']['PPO2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AJ050']['PPO3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AJ050']['TOS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AJ050']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AJ050']['VCM'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AJ050']['VCM2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AJ050']['VCM3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AJ050']['VOI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AJ050']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AJ050']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AJ050']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AJ050']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['AJ050']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AJ050']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AJ050']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AJ050']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AJ050']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AJ050']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AJ050']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['AJ050']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AJ050']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AJ050']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AJ050']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AJ050']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['AJ050']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AJ050']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AJ050']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AJ050']['ZVH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AJ051'] = {}
    field_information['GGDM 3.0']['DefaultValues']['AJ051']['AOO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AJ051']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AJ051']['AWP'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AJ051']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AJ051']['CAA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AJ051']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AJ051']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AJ051']['F_CODE'] = 'AJ051'
    field_information['GGDM 3.0']['DefaultValues']['AJ051']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AJ051']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AJ051']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AJ051']['GUG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AJ051']['HGT'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AJ051']['LMC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AJ051']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AJ051']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AJ051']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AJ051']['SRL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AJ051']['TOS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AJ051']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AJ051']['VCM'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AJ051']['VCM2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AJ051']['VCM3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AJ051']['VOI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AJ051']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AJ051']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AJ051']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AJ051']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['AJ051']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AJ051']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AJ051']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AJ051']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AJ051']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AJ051']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AJ051']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['AJ051']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AJ051']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AJ051']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AJ051']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AJ051']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['AJ051']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AJ051']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AJ051']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AJ051']['ZVH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AJ055'] = {}
    field_information['GGDM 3.0']['DefaultValues']['AJ055']['ADR'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AJ055']['AOO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AJ055']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AJ055']['AWP'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AJ055']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AJ055']['BNF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AJ055']['CAA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AJ055']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AJ055']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AJ055']['F_CODE'] = 'AJ055'
    field_information['GGDM 3.0']['DefaultValues']['AJ055']['FFN'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AJ055']['FFN2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AJ055']['FFN3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AJ055']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AJ055']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AJ055']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AJ055']['HGT'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AJ055']['LMC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AJ055']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AJ055']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AJ055']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AJ055']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AJ055']['VOI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AJ055']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AJ055']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AJ055']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AJ055']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['AJ055']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AJ055']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AJ055']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AJ055']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AJ055']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AJ055']['ZI014_PPO'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AJ055']['ZI014_PPO2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AJ055']['ZI014_PPO3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AJ055']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AJ055']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['AJ055']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AJ055']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AJ055']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AJ055']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AJ055']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['AJ055']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AJ055']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AJ055']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AJ055']['ZVH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AJ080'] = {}
    field_information['GGDM 3.0']['DefaultValues']['AJ080']['ADR'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AJ080']['AOO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AJ080']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AJ080']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AJ080']['CAA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AJ080']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AJ080']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AJ080']['F_CODE'] = 'AJ080'
    field_information['GGDM 3.0']['DefaultValues']['AJ080']['FFN'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AJ080']['FFN2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AJ080']['FFN3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AJ080']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AJ080']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AJ080']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AJ080']['HGT'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AJ080']['LMC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AJ080']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AJ080']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AJ080']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AJ080']['SSR'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AJ080']['SSR2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AJ080']['SSR3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AJ080']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AJ080']['VCM'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AJ080']['VCM2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AJ080']['VCM3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AJ080']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AJ080']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AJ080']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AJ080']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['AJ080']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AJ080']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AJ080']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AJ080']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AJ080']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AJ080']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AJ080']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['AJ080']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AJ080']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AJ080']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AJ080']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AJ080']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['AJ080']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AJ080']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AJ080']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AJ080']['ZVH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AJ085'] = {}
    field_information['GGDM 3.0']['DefaultValues']['AJ085']['ADR'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AJ085']['AOO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AJ085']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AJ085']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AJ085']['BNF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AJ085']['CAA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AJ085']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AJ085']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AJ085']['F_CODE'] = 'AJ085'
    field_information['GGDM 3.0']['DefaultValues']['AJ085']['FFN'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AJ085']['FFN2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AJ085']['FFN3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AJ085']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AJ085']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AJ085']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AJ085']['HGT'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AJ085']['LMC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AJ085']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AJ085']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AJ085']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AJ085']['SSR'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AJ085']['SSR2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AJ085']['SSR3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AJ085']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AJ085']['VCM'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AJ085']['VCM2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AJ085']['VCM3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AJ085']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AJ085']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AJ085']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AJ085']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['AJ085']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AJ085']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AJ085']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AJ085']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AJ085']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AJ085']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AJ085']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['AJ085']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AJ085']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AJ085']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AJ085']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AJ085']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['AJ085']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AJ085']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AJ085']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AJ085']['ZVH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AJ110'] = {}
    field_information['GGDM 3.0']['DefaultValues']['AJ110']['ADR'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AJ110']['AOO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AJ110']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AJ110']['ATB'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AJ110']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AJ110']['CAA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AJ110']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AJ110']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AJ110']['F_CODE'] = 'AJ110'
    field_information['GGDM 3.0']['DefaultValues']['AJ110']['FFN'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AJ110']['FFN2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AJ110']['FFN3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AJ110']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AJ110']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AJ110']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AJ110']['HGT'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AJ110']['LMC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AJ110']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AJ110']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AJ110']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AJ110']['SSR'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AJ110']['SSR2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AJ110']['SSR3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AJ110']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AJ110']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AJ110']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AJ110']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AJ110']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['AJ110']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AJ110']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AJ110']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AJ110']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AJ110']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AJ110']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AJ110']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['AJ110']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AJ110']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AJ110']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AJ110']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AJ110']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['AJ110']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AJ110']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AJ110']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AJ110']['ZVH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AK020'] = {}
    field_information['GGDM 3.0']['DefaultValues']['AK020']['AMA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AK020']['AOO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AK020']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AK020']['AWP'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AK020']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK020']['CAA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AK020']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK020']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AK020']['F_CODE'] = 'AK020'
    field_information['GGDM 3.0']['DefaultValues']['AK020']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK020']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK020']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AK020']['HGT'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AK020']['LMC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AK020']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AK020']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK020']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AK020']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK020']['VOI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK020']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AK020']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK020']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AK020']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['AK020']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AK020']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AK020']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AK020']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AK020']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AK020']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK020']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['AK020']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AK020']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AK020']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK020']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK020']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['AK020']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK020']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK020']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK020']['ZVH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AK030'] = {}
    field_information['GGDM 3.0']['DefaultValues']['AK030']['ADR'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AK030']['AOO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AK030']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AK030']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK030']['CAA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AK030']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK030']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AK030']['F_CODE'] = 'AK030'
    field_information['GGDM 3.0']['DefaultValues']['AK030']['FFN'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AK030']['FFN2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AK030']['FFN3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AK030']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK030']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK030']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AK030']['HGT'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AK030']['LMC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AK030']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AK030']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK030']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AK030']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK030']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AK030']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK030']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AK030']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['AK030']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AK030']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AK030']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AK030']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AK030']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AK030']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK030']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['AK030']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AK030']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AK030']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK030']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK030']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['AK030']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK030']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK030']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK030']['ZVH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AK040'] = {}
    field_information['GGDM 3.0']['DefaultValues']['AK040']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AK040']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK040']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK040']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AK040']['F_CODE'] = 'AK040'
    field_information['GGDM 3.0']['DefaultValues']['AK040']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK040']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK040']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AK040']['HGT'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AK040']['LMC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AK040']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AK040']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK040']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AK040']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK040']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AK040']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK040']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AK040']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['AK040']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AK040']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AK040']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AK040']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AK040']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AK040']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK040']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['AK040']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AK040']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AK040']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK040']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK040']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['AK040']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK040']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK040']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK040']['ZVH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AK060'] = {}
    field_information['GGDM 3.0']['DefaultValues']['AK060']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AK060']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK060']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK060']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AK060']['F_CODE'] = 'AK060'
    field_information['GGDM 3.0']['DefaultValues']['AK060']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK060']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK060']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AK060']['LMC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AK060']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AK060']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK060']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AK060']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK060']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AK060']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK060']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AK060']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['AK060']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AK060']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AK060']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AK060']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AK060']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AK060']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK060']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['AK060']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AK060']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AK060']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK060']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK060']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['AK060']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK060']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK060']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK061'] = {}
    field_information['GGDM 3.0']['DefaultValues']['AK061']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AK061']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK061']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK061']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AK061']['F_CODE'] = 'AK061'
    field_information['GGDM 3.0']['DefaultValues']['AK061']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK061']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK061']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AK061']['LMC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AK061']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AK061']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK061']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AK061']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK061']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AK061']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK061']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AK061']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['AK061']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AK061']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AK061']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AK061']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AK061']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AK061']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK061']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['AK061']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AK061']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AK061']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK061']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK061']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['AK061']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK061']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK061']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK070'] = {}
    field_information['GGDM 3.0']['DefaultValues']['AK070']['ADR'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AK070']['AOO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AK070']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AK070']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK070']['CAA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AK070']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK070']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AK070']['F_CODE'] = 'AK070'
    field_information['GGDM 3.0']['DefaultValues']['AK070']['FFN'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AK070']['FFN2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AK070']['FFN3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AK070']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK070']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK070']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AK070']['HGT'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AK070']['LMC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AK070']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AK070']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK070']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AK070']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK070']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AK070']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK070']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AK070']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['AK070']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AK070']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AK070']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AK070']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AK070']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AK070']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK070']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['AK070']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AK070']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AK070']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK070']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK070']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['AK070']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK070']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK070']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK070']['ZVH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AK080'] = {}
    field_information['GGDM 3.0']['DefaultValues']['AK080']['AOO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AK080']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AK080']['AWP'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AK080']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK080']['CAA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AK080']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK080']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AK080']['F_CODE'] = 'AK080'
    field_information['GGDM 3.0']['DefaultValues']['AK080']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK080']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK080']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AK080']['HEI'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AK080']['HGT'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AK080']['LMC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AK080']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AK080']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK080']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AK080']['THI'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AK080']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK080']['VOI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK080']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK080']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AK080']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['AK080']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AK080']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AK080']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AK080']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AK080']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AK080']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK080']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['AK080']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AK080']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AK080']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK080']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK080']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['AK080']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK080']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK080']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK080']['ZVH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AK090'] = {}
    field_information['GGDM 3.0']['DefaultValues']['AK090']['ADR'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AK090']['AOO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AK090']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AK090']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK090']['CAA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AK090']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK090']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AK090']['F_CODE'] = 'AK090'
    field_information['GGDM 3.0']['DefaultValues']['AK090']['FFN'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AK090']['FFN2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AK090']['FFN3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AK090']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK090']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK090']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AK090']['HGT'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AK090']['LMC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AK090']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AK090']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK090']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AK090']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK090']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AK090']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK090']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AK090']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['AK090']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AK090']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AK090']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AK090']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AK090']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AK090']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK090']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['AK090']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AK090']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AK090']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK090']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK090']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['AK090']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK090']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK090']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK090']['ZVH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AK100'] = {}
    field_information['GGDM 3.0']['DefaultValues']['AK100']['ADR'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AK100']['AOO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AK100']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AK100']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK100']['CAA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AK100']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK100']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AK100']['F_CODE'] = 'AK100'
    field_information['GGDM 3.0']['DefaultValues']['AK100']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK100']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK100']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AK100']['LMC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AK100']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AK100']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK100']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AK100']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK100']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AK100']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK100']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AK100']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['AK100']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AK100']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AK100']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AK100']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AK100']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AK100']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK100']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['AK100']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AK100']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AK100']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK100']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK100']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['AK100']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK100']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK100']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK101'] = {}
    field_information['GGDM 3.0']['DefaultValues']['AK101']['ADR'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AK101']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AK101']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK101']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK101']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AK101']['F_CODE'] = 'AK101'
    field_information['GGDM 3.0']['DefaultValues']['AK101']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK101']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK101']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AK101']['LMC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AK101']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AK101']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK101']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AK101']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK101']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AK101']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK101']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AK101']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['AK101']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AK101']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AK101']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AK101']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AK101']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AK101']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK101']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['AK101']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AK101']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AK101']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK101']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK101']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['AK101']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK101']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK101']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK110'] = {}
    field_information['GGDM 3.0']['DefaultValues']['AK110']['AOO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AK110']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AK110']['AWP'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AK110']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK110']['CAA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AK110']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK110']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AK110']['F_CODE'] = 'AK110'
    field_information['GGDM 3.0']['DefaultValues']['AK110']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK110']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK110']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AK110']['HGT'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AK110']['LMC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AK110']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AK110']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK110']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AK110']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK110']['VOI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK110']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AK110']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK110']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AK110']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['AK110']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AK110']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AK110']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AK110']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AK110']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AK110']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK110']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['AK110']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AK110']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AK110']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK110']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK110']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['AK110']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK110']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK110']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK110']['ZVH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AK120'] = {}
    field_information['GGDM 3.0']['DefaultValues']['AK120']['ADI'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AK120']['ADR'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AK120']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AK120']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK120']['CAA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AK120']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK120']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AK120']['F_CODE'] = 'AK120'
    field_information['GGDM 3.0']['DefaultValues']['AK120']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK120']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK120']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AK120']['LMC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AK120']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AK120']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK120']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AK120']['SRL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AK120']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK120']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AK120']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK120']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AK120']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['AK120']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AK120']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AK120']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AK120']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AK120']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AK120']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK120']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['AK120']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AK120']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AK120']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK120']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK120']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['AK120']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK120']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK120']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK121'] = {}
    field_information['GGDM 3.0']['DefaultValues']['AK121']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AK121']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK121']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK121']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AK121']['F_CODE'] = 'AK121'
    field_information['GGDM 3.0']['DefaultValues']['AK121']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK121']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK121']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AK121']['LMC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AK121']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AK121']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK121']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AK121']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK121']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AK121']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK121']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AK121']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['AK121']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AK121']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AK121']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AK121']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AK121']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AK121']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK121']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['AK121']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AK121']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AK121']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK121']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK121']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['AK121']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK121']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK121']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK130'] = {}
    field_information['GGDM 3.0']['DefaultValues']['AK130']['ADR'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AK130']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AK130']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK130']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK130']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AK130']['F_CODE'] = 'AK130'
    field_information['GGDM 3.0']['DefaultValues']['AK130']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK130']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK130']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AK130']['HGT'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AK130']['LMC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AK130']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AK130']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK130']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AK130']['RAY'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AK130']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK130']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AK130']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK130']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AK130']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['AK130']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AK130']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AK130']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AK130']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AK130']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AK130']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK130']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['AK130']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AK130']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AK130']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK130']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK130']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['AK130']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK130']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK130']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK150'] = {}
    field_information['GGDM 3.0']['DefaultValues']['AK150']['AOO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AK150']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AK150']['AWP'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AK150']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK150']['CAA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AK150']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK150']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AK150']['F_CODE'] = 'AK150'
    field_information['GGDM 3.0']['DefaultValues']['AK150']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK150']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK150']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AK150']['HGT'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AK150']['LMC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AK150']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AK150']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK150']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AK150']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK150']['VOI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK150']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AK150']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK150']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AK150']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['AK150']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AK150']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AK150']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AK150']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AK150']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AK150']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK150']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['AK150']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AK150']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AK150']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK150']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK150']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['AK150']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK150']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK150']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK150']['ZVH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AK155'] = {}
    field_information['GGDM 3.0']['DefaultValues']['AK155']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AK155']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK155']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK155']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AK155']['F_CODE'] = 'AK155'
    field_information['GGDM 3.0']['DefaultValues']['AK155']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK155']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK155']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AK155']['HGT'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AK155']['LMC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AK155']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AK155']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK155']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AK155']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK155']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AK155']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK155']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AK155']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['AK155']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AK155']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AK155']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AK155']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AK155']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AK155']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK155']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['AK155']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AK155']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AK155']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK155']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK155']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['AK155']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK155']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK155']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK155']['ZVH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AK160'] = {}
    field_information['GGDM 3.0']['DefaultValues']['AK160']['ADR'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AK160']['AOO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AK160']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AK160']['AWP'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AK160']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK160']['CAA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AK160']['CCT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AK160']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK160']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AK160']['F_CODE'] = 'AK160'
    field_information['GGDM 3.0']['DefaultValues']['AK160']['FFN'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AK160']['FFN2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AK160']['FFN3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AK160']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK160']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK160']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AK160']['HGT'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AK160']['LMC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AK160']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AK160']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK160']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AK160']['SSR'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AK160']['SSR2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AK160']['SSR3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AK160']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK160']['VOI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK160']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AK160']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK160']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AK160']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['AK160']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AK160']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AK160']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AK160']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AK160']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AK160']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK160']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['AK160']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AK160']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AK160']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK160']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK160']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['AK160']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK160']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK160']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK160']['ZVH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AK161'] = {}
    field_information['GGDM 3.0']['DefaultValues']['AK161']['AOO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AK161']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AK161']['AWP'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AK161']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK161']['CAA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AK161']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK161']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AK161']['F_CODE'] = 'AK161'
    field_information['GGDM 3.0']['DefaultValues']['AK161']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK161']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK161']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AK161']['HEI'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AK161']['HGT'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AK161']['LMC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AK161']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AK161']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK161']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AK161']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK161']['VOI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK161']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK161']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AK161']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['AK161']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AK161']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AK161']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AK161']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AK161']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AK161']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK161']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['AK161']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AK161']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AK161']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK161']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK161']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['AK161']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK161']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK161']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK161']['ZVH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AK164'] = {}
    field_information['GGDM 3.0']['DefaultValues']['AK164']['ADR'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AK164']['AOO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AK164']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AK164']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK164']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK164']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AK164']['F_CODE'] = 'AK164'
    field_information['GGDM 3.0']['DefaultValues']['AK164']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK164']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK164']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AK164']['HGT'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AK164']['LMC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AK164']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AK164']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK164']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AK164']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK164']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AK164']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK164']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AK164']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['AK164']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AK164']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AK164']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AK164']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AK164']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AK164']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK164']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['AK164']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AK164']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AK164']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK164']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK164']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['AK164']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK164']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK164']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK164']['ZVH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AK170'] = {}
    field_information['GGDM 3.0']['DefaultValues']['AK170']['ADR'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AK170']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AK170']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK170']['CAA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AK170']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK170']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AK170']['DZP'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AK170']['F_CODE'] = 'AK170'
    field_information['GGDM 3.0']['DefaultValues']['AK170']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK170']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK170']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AK170']['HGT'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AK170']['LMC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AK170']['LOC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AK170']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AK170']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK170']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AK170']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK170']['VLM'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AK170']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AK170']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK170']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AK170']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['AK170']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AK170']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AK170']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AK170']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AK170']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AK170']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK170']['ZI024_ASE'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AK170']['ZI024_CFR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AK170']['ZI024_CLO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AK170']['ZI024_CYN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AK170']['ZI024_FMR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AK170']['ZI024_FRR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AK170']['ZI024_HAR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AK170']['ZI024_HYP'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AK170']['ZI024_MGN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AK170']['ZI024_PHW'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AK170']['ZI024_SCC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AK170']['ZI024_SUL'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AK170']['ZI024_TDS'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AK170']['ZI024_TEP'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AK170']['ZI024_TUR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AK170']['ZI024_WAC'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AK170']['ZI024_WTNO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AK170']['ZI024_WUR'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AK170']['ZI024_WUR2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AK170']['ZI024_WUR3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AK170']['ZI024_WUR4'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AK170']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['AK170']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AK170']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AK170']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK170']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK170']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['AK170']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK170']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK170']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK180'] = {}
    field_information['GGDM 3.0']['DefaultValues']['AK180']['ADR'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AK180']['AOO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AK180']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AK180']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK180']['CAA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AK180']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK180']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AK180']['F_CODE'] = 'AK180'
    field_information['GGDM 3.0']['DefaultValues']['AK180']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK180']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK180']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AK180']['HGT'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AK180']['LMC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AK180']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AK180']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK180']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AK180']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK180']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AK180']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK180']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AK180']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['AK180']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AK180']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AK180']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AK180']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AK180']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AK180']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK180']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['AK180']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AK180']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AK180']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK180']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK180']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['AK180']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK180']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK180']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AK180']['ZVH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL010'] = {}
    field_information['GGDM 3.0']['DefaultValues']['AL010']['ADR'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AL010']['ADUR'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL010']['AOO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL010']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL010']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL010']['CAA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL010']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL010']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL010']['F_CODE'] = 'AL010'
    field_information['GGDM 3.0']['DefaultValues']['AL010']['FFN'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL010']['FFN2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL010']['FFN3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL010']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL010']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL010']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL010']['HGT'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL010']['LMC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL010']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL010']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL010']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL010']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL010']['VCM'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL010']['VCM2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL010']['VCM3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL010']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL010']['WLSS'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL010']['WSRC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL010']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL010']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL010']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['AL010']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL010']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AL010']['ZI005_FNA2'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AL010']['ZI005_FNA3'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AL010']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL010']['ZI005_GNT2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL010']['ZI005_GNT3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL010']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AL010']['ZI005_NFN2'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AL010']['ZI005_NFN3'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AL010']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AL010']['ZI014_PBY'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL010']['ZI014_PBY2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL010']['ZI014_PBY3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL010']['ZI014_PPO'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL010']['ZI014_PPO2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL010']['ZI014_PPO3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL010']['ZI014_PRW'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL010']['ZI014_PRW2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL010']['ZI014_PRW3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL010']['ZI018_WIT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL010']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL010']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['AL010']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL010']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL010']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL010']['ZI037_REL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL010']['ZI037_RFA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL010']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL010']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['AL010']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL010']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL010']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL010']['ZVH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL011'] = {}
    field_information['GGDM 3.0']['DefaultValues']['AL011']['ADR'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AL011']['AOO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL011']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL011']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL011']['CAA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL011']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL011']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL011']['F_CODE'] = 'AL011'
    field_information['GGDM 3.0']['DefaultValues']['AL011']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL011']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL011']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL011']['LMC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL011']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL011']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL011']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL011']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL011']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL011']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL011']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL011']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['AL011']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL011']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AL011']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL011']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AL011']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AL011']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL011']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['AL011']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL011']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL011']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL011']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL011']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['AL011']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL011']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL011']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL012'] = {}
    field_information['GGDM 3.0']['DefaultValues']['AL012']['AOO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL012']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL012']['AWP'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL012']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL012']['F_CODE'] = 'AL012'
    field_information['GGDM 3.0']['DefaultValues']['AL012']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL012']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL012']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL012']['HGT'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL012']['LMC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL012']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL012']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL012']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL012']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL012']['VOI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL012']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL012']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL012']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL012']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['AL012']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL012']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AL012']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL012']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AL012']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AL012']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL012']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['AL012']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL012']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL012']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL012']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL012']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['AL012']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL012']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL012']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL012']['ZVH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL013'] = {}
    field_information['GGDM 3.0']['DefaultValues']['AL013']['ADR'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AL013']['AOO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL013']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL013']['ATB'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL013']['AWP'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL013']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL013']['BNF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL013']['CAA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL013']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL013']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL013']['F_CODE'] = 'AL013'
    field_information['GGDM 3.0']['DefaultValues']['AL013']['FFN'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL013']['FFN2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL013']['FFN3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL013']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL013']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL013']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL013']['HGT'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL013']['HSC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL013']['HST'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL013']['HST2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL013']['HST3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL013']['LMC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL013']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL013']['MEL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL013']['MFB'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL013']['MFY'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL013']['MKSZ'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL013']['MUB'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL013']['NOR'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL013']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL013']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL013']['RLE'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL013']['SSR'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL013']['SSR2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL013']['SSR3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL013']['STAF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL013']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL013']['VCM'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL013']['VCM2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL013']['VCM3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL013']['VEC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL013']['VOI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL013']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL013']['WPST'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL013']['WTYP'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL013']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL013']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL013']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['AL013']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL013']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AL013']['ZI005_FNA2'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AL013']['ZI005_FNA3'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AL013']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL013']['ZI005_GNT2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL013']['ZI005_GNT3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL013']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AL013']['ZI005_NFN2'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AL013']['ZI005_NFN3'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AL013']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AL013']['ZI014_PBY'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL013']['ZI014_PBY2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL013']['ZI014_PBY3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL013']['ZI014_PPO'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL013']['ZI014_PPO2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL013']['ZI014_PPO3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL013']['ZI014_PRW'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL013']['ZI014_PRW2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL013']['ZI014_PRW3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL013']['ZI018_WIT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL013']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL013']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['AL013']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL013']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL013']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL013']['ZI037_REL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL013']['ZI037_RFA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL013']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL013']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['AL013']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL013']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL013']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL013']['ZVH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL014'] = {}
    field_information['GGDM 3.0']['DefaultValues']['AL014']['AOO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL014']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL014']['AWP'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL014']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL014']['CAA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL014']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL014']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL014']['F_CODE'] = 'AL014'
    field_information['GGDM 3.0']['DefaultValues']['AL014']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL014']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL014']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL014']['HGT'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL014']['LMC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL014']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL014']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL014']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL014']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL014']['VOI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL014']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL014']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL014']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL014']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['AL014']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL014']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AL014']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL014']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AL014']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AL014']['ZI014_PBY'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL014']['ZI014_PBY2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL014']['ZI014_PBY3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL014']['ZI014_PPO'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL014']['ZI014_PPO2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL014']['ZI014_PPO3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL014']['ZI014_PRW'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL014']['ZI014_PRW2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL014']['ZI014_PRW3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL014']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL014']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['AL014']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL014']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL014']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL014']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL014']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['AL014']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL014']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL014']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL014']['ZVH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL017'] = {}
    field_information['GGDM 3.0']['DefaultValues']['AL017']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL017']['CAA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL017']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL017']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL017']['F_CODE'] = 'AL017'
    field_information['GGDM 3.0']['DefaultValues']['AL017']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL017']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL017']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL017']['HGT'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL017']['LMC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL017']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL017']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL017']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL017']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL017']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL017']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL017']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['AL017']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL017']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AL017']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL017']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AL017']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AL017']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL017']['ZI024_ASE'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL017']['ZI024_CFR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL017']['ZI024_CLO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL017']['ZI024_CYN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL017']['ZI024_FMR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL017']['ZI024_FRR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL017']['ZI024_HAR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL017']['ZI024_MGN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL017']['ZI024_PHW'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL017']['ZI024_SCC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL017']['ZI024_SUL'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL017']['ZI024_TDS'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL017']['ZI024_TEP'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL017']['ZI024_TUR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL017']['ZI024_WAC'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL017']['ZI024_WTNO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL017']['ZI024_WUR'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL017']['ZI024_YWQ'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL017']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['AL017']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL017']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL017']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL017']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL017']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['AL017']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL017']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL017']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL017']['ZVH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL018'] = {}
    field_information['GGDM 3.0']['DefaultValues']['AL018']['AOO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL018']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL018']['AWP'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL018']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL018']['BSU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL018']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL018']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL018']['F_CODE'] = 'AL018'
    field_information['GGDM 3.0']['DefaultValues']['AL018']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL018']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL018']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL018']['HEI'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL018']['HGT'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL018']['LMC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL018']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL018']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL018']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL018']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL018']['VOI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL018']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL018']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL018']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL018']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['AL018']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL018']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AL018']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL018']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AL018']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AL018']['ZI018_WIT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL018']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL018']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['AL018']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL018']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL018']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL018']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL018']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['AL018']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL018']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL018']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL018']['ZVH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL019'] = {}
    field_information['GGDM 3.0']['DefaultValues']['AL019']['ADR'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AL019']['AOO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL019']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL019']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL019']['BNF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL019']['CAA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL019']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL019']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL019']['F_CODE'] = 'AL019'
    field_information['GGDM 3.0']['DefaultValues']['AL019']['FFN'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL019']['FFN2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL019']['FFN3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL019']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL019']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL019']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL019']['HGT'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL019']['LMC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL019']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL019']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL019']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL019']['SSR'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL019']['SSR2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL019']['SSR3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL019']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL019']['VCM'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL019']['VCM2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL019']['VCM3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL019']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL019']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL019']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL019']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['AL019']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL019']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AL019']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL019']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AL019']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AL019']['ZI014_PBY'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL019']['ZI014_PBY2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL019']['ZI014_PBY3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL019']['ZI014_PPO'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL019']['ZI014_PPO2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL019']['ZI014_PPO3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL019']['ZI014_PRW'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL019']['ZI014_PRW2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL019']['ZI014_PRW3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL019']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL019']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['AL019']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL019']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL019']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL019']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL019']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['AL019']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL019']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL019']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL019']['ZVH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL020'] = {}
    field_information['GGDM 3.0']['DefaultValues']['AL020']['AOO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL020']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL020']['BAC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL020']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL020']['BNF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL020']['CAA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL020']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL020']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL020']['DNE'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL020']['F_CODE'] = 'AL020'
    field_information['GGDM 3.0']['DefaultValues']['AL020']['FFN'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL020']['FFN2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL020']['FFN3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL020']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL020']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL020']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL020']['HGT'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL020']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL020']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL020']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL020']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL020']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL020']['WPI'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AL020']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL020']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL020']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['AL020']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL020']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AL020']['ZI005_FNA2'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AL020']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL020']['ZI005_GNT2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL020']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AL020']['ZI005_NFN2'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AL020']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AL020']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL020']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['AL020']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL020']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL020']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL020']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL020']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['AL020']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL020']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL020']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL020']['ZVH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL024'] = {}
    field_information['GGDM 3.0']['DefaultValues']['AL024']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL024']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL024']['F_CODE'] = 'AL024'
    field_information['GGDM 3.0']['DefaultValues']['AL024']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL024']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL024']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL024']['NDX'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL024']['NDX2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL024']['NDX3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL024']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL024']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL024']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL024']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL024']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['AL024']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL024']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AL024']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL024']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AL024']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AL024']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL024']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['AL024']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL024']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL024']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL024']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL024']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['AL024']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL024']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL024']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL025'] = {}
    field_information['GGDM 3.0']['DefaultValues']['AL025']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL025']['F_CODE'] = 'AL025'
    field_information['GGDM 3.0']['DefaultValues']['AL025']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL025']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL025']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL025']['HGT'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL025']['LMC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL025']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL025']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL025']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL025']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL025']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL025']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL025']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL025']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['AL025']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL025']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AL025']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL025']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AL025']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AL025']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL025']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['AL025']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL025']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL025']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL025']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL025']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['AL025']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL025']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL025']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL025']['ZVH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL030'] = {}
    field_information['GGDM 3.0']['DefaultValues']['AL030']['ADR'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AL030']['AOO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL030']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL030']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL030']['CAA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL030']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL030']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL030']['F_CODE'] = 'AL030'
    field_information['GGDM 3.0']['DefaultValues']['AL030']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL030']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL030']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL030']['HGT'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL030']['LMC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL030']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL030']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL030']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL030']['SDQ'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL030']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL030']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL030']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL030']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL030']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['AL030']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL030']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AL030']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL030']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AL030']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AL030']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL030']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['AL030']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL030']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL030']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL030']['ZI037_REL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL030']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL030']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['AL030']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL030']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL030']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL030']['ZVH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL036'] = {}
    field_information['GGDM 3.0']['DefaultValues']['AL036']['AOO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL036']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL036']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL036']['CAA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL036']['DZP'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL036']['F_CODE'] = 'AL036'
    field_information['GGDM 3.0']['DefaultValues']['AL036']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL036']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL036']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL036']['HEI'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL036']['HGT'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL036']['LEA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL036']['LMC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL036']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL036']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL036']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL036']['SSC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL036']['TTY'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL036']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL036']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL036']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL036']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL036']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['AL036']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL036']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AL036']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL036']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AL036']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AL036']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL036']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['AL036']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL036']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL036']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL036']['ZI037_REL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL036']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL036']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['AL036']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL036']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL036']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL036']['ZVH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL060'] = {}
    field_information['GGDM 3.0']['DefaultValues']['AL060']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL060']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL060']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL060']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL060']['F_CODE'] = 'AL060'
    field_information['GGDM 3.0']['DefaultValues']['AL060']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL060']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL060']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL060']['HGT'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL060']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL060']['MCC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL060']['MCC2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL060']['MCC3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL060']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL060']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL060']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL060']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL060']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL060']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL060']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['AL060']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL060']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AL060']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL060']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['AL060']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL060']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL060']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL060']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL060']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['AL060']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL060']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL060']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL065'] = {}
    field_information['GGDM 3.0']['DefaultValues']['AL065']['AOO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL065']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL065']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL065']['F_CODE'] = 'AL065'
    field_information['GGDM 3.0']['DefaultValues']['AL065']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL065']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL065']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL065']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL065']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL065']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL065']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL065']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL065']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL065']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL065']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['AL065']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL065']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AL065']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL065']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['AL065']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL065']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL065']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL065']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL065']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['AL065']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL065']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL065']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL070'] = {}
    field_information['GGDM 3.0']['DefaultValues']['AL070']['BAT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL070']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL070']['CAA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL070']['F_CODE'] = 'AL070'
    field_information['GGDM 3.0']['DefaultValues']['AL070']['FEF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL070']['FTI'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL070']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL070']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL070']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL070']['HGT'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL070']['LMC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL070']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL070']['MCC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL070']['MCC2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL070']['MCC3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL070']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL070']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL070']['PFHC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['AL070']['PFHL'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL070']['PFHU'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL070']['THI'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL070']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL070']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL070']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL070']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['AL070']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL070']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AL070']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL070']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['AL070']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL070']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL070']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL070']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL070']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['AL070']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL070']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL070']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL070']['ZVH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL073'] = {}
    field_information['GGDM 3.0']['DefaultValues']['AL073']['AWP'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL073']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL073']['F_CODE'] = 'AL073'
    field_information['GGDM 3.0']['DefaultValues']['AL073']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL073']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL073']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL073']['HEI'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL073']['HGT'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL073']['LMC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL073']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL073']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL073']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL073']['VOI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL073']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL073']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL073']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['AL073']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL073']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AL073']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL073']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AL073']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AL073']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL073']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['AL073']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL073']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL073']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL073']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL073']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['AL073']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL073']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL073']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL073']['ZVH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL080'] = {}
    field_information['GGDM 3.0']['DefaultValues']['AL080']['AOO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL080']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL080']['AWP'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL080']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL080']['CAA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL080']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL080']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL080']['CRM'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL080']['F_CODE'] = 'AL080'
    field_information['GGDM 3.0']['DefaultValues']['AL080']['FFN'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL080']['FFN2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL080']['FFN3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL080']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL080']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL080']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL080']['HGT'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL080']['LMC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL080']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL080']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL080']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL080']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL080']['VCM'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL080']['VCM2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL080']['VCM3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL080']['VOI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL080']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL080']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL080']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL080']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['AL080']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL080']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AL080']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL080']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['AL080']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL080']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL080']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL080']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL080']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['AL080']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL080']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL080']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL080']['ZVH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL099'] = {}
    field_information['GGDM 3.0']['DefaultValues']['AL099']['ADR'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AL099']['AOO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL099']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL099']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL099']['CAA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL099']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL099']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL099']['F_CODE'] = 'AL099'
    field_information['GGDM 3.0']['DefaultValues']['AL099']['FFN'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL099']['FFN2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL099']['FFN3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL099']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL099']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL099']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL099']['HGT'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL099']['LMC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL099']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL099']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL099']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL099']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL099']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL099']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL099']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL099']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['AL099']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL099']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AL099']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL099']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AL099']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AL099']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL099']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['AL099']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL099']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL099']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL099']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL099']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['AL099']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL099']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL099']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL099']['ZVH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL105'] = {}
    field_information['GGDM 3.0']['DefaultValues']['AL105']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL105']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL105']['CAA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL105']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL105']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL105']['F_CODE'] = 'AL105'
    field_information['GGDM 3.0']['DefaultValues']['AL105']['FFN'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL105']['FFN2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL105']['FFN3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL105']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL105']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL105']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL105']['HGT'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL105']['HHD'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL105']['LMC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL105']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL105']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL105']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL105']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL105']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL105']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL105']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL105']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['AL105']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL105']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AL105']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL105']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AL105']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AL105']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL105']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['AL105']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL105']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL105']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL105']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL105']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['AL105']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL105']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL105']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL105']['ZVH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL110'] = {}
    field_information['GGDM 3.0']['DefaultValues']['AL110']['AOO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL110']['AWP'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL110']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL110']['CAA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL110']['F_CODE'] = 'AL110'
    field_information['GGDM 3.0']['DefaultValues']['AL110']['FFN'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL110']['FFN2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL110']['FFN3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL110']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL110']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL110']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL110']['HGT'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL110']['LMC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL110']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL110']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL110']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL110']['PYC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL110']['PYM'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL110']['TOS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL110']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL110']['VOI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL110']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL110']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL110']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL110']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['AL110']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL110']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AL110']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL110']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AL110']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AL110']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL110']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['AL110']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL110']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL110']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL110']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL110']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['AL110']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL110']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL110']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL110']['ZVH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL120'] = {}
    field_information['GGDM 3.0']['DefaultValues']['AL120']['AOO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL120']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL120']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL120']['CAA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL120']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL120']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL120']['F_CODE'] = 'AL120'
    field_information['GGDM 3.0']['DefaultValues']['AL120']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL120']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL120']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL120']['LMC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL120']['LUN'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL120']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL120']['MST'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL120']['MST2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL120']['MST3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL120']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL120']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL120']['PRM'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL120']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL120']['VCM'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL120']['VCM2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL120']['VCM3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL120']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL120']['YSU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL120']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL120']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL120']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['AL120']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL120']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AL120']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL120']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AL120']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AL120']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL120']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['AL120']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL120']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL120']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL120']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL120']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['AL120']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL120']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL120']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL120']['ZVH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL121'] = {}
    field_information['GGDM 3.0']['DefaultValues']['AL121']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL121']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL121']['CAA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL121']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL121']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL121']['F_CODE'] = 'AL121'
    field_information['GGDM 3.0']['DefaultValues']['AL121']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL121']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL121']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL121']['HGT'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL121']['LMC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL121']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL121']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL121']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL121']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL121']['VCM'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL121']['VCM2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL121']['VCM3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL121']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL121']['YSU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL121']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL121']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL121']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['AL121']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL121']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AL121']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL121']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AL121']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AL121']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL121']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['AL121']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL121']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL121']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL121']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL121']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['AL121']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL121']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL121']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL130'] = {}
    field_information['GGDM 3.0']['DefaultValues']['AL130']['AOO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL130']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL130']['AWP'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL130']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL130']['CAA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL130']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL130']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL130']['F_CODE'] = 'AL130'
    field_information['GGDM 3.0']['DefaultValues']['AL130']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL130']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL130']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL130']['HEI'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL130']['HGT'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL130']['LMC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL130']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL130']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL130']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL130']['SSC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL130']['SSR'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL130']['SSR2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL130']['SSR3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL130']['TOS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL130']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL130']['VOI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL130']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL130']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL130']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL130']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['AL130']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL130']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AL130']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL130']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AL130']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AL130']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL130']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['AL130']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL130']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL130']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL130']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL130']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['AL130']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL130']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL130']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL130']['ZVH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL140'] = {}
    field_information['GGDM 3.0']['DefaultValues']['AL140']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL140']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL140']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL140']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL140']['F_CODE'] = 'AL140'
    field_information['GGDM 3.0']['DefaultValues']['AL140']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL140']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL140']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL140']['LMC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL140']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL140']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL140']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL140']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL140']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL140']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL140']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL140']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['AL140']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL140']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AL140']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL140']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AL140']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AL140']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL140']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['AL140']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL140']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL140']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL140']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL140']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['AL140']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL140']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL140']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL142'] = {}
    field_information['GGDM 3.0']['DefaultValues']['AL142']['ADR'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AL142']['AOO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL142']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL142']['AWP'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL142']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL142']['CAA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL142']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL142']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL142']['F_CODE'] = 'AL142'
    field_information['GGDM 3.0']['DefaultValues']['AL142']['FFN'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL142']['FFN2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL142']['FFN3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL142']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL142']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL142']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL142']['HGT'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL142']['LMC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL142']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL142']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL142']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL142']['SSR'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL142']['SSR2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL142']['SSR3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL142']['TEL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL142']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL142']['VOI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL142']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL142']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL142']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL142']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['AL142']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL142']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AL142']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL142']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AL142']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AL142']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL142']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['AL142']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL142']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL142']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL142']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL142']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['AL142']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL142']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL142']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL142']['ZVH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL155'] = {}
    field_information['GGDM 3.0']['DefaultValues']['AL155']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL155']['BCC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL155']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL155']['DEV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL155']['F_CODE'] = 'AL155'
    field_information['GGDM 3.0']['DefaultValues']['AL155']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL155']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL155']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL155']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL155']['OHC'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL155']['OOC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL155']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL155']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL155']['TRS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL155']['TRS2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL155']['TRS3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL155']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL155']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL155']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL155']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL155']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['AL155']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL155']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AL155']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL155']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['AL155']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL155']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL155']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL155']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL155']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['AL155']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL155']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL155']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL165'] = {}
    field_information['GGDM 3.0']['DefaultValues']['AL165']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL165']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL165']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL165']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL165']['F_CODE'] = 'AL165'
    field_information['GGDM 3.0']['DefaultValues']['AL165']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL165']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL165']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL165']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL165']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL165']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL165']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL165']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL165']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL165']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL165']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['AL165']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL165']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AL165']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL165']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AL165']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AL165']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL165']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['AL165']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL165']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL165']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL165']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL165']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['AL165']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL165']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL165']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL170'] = {}
    field_information['GGDM 3.0']['DefaultValues']['AL170']['ADR'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AL170']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL170']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL170']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL170']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL170']['F_CODE'] = 'AL170'
    field_information['GGDM 3.0']['DefaultValues']['AL170']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL170']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL170']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL170']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL170']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL170']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL170']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL170']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL170']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL170']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL170']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['AL170']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL170']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AL170']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL170']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AL170']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AL170']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL170']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['AL170']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL170']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL170']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL170']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL170']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['AL170']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL170']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL170']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL175'] = {}
    field_information['GGDM 3.0']['DefaultValues']['AL175']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL175']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL175']['F_CODE'] = 'AL175'
    field_information['GGDM 3.0']['DefaultValues']['AL175']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL175']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL175']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL175']['HGT'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL175']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL175']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL175']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL175']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL175']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL175']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL175']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL175']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['AL175']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL175']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AL175']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL175']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AL175']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AL175']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL175']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['AL175']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL175']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL175']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL175']['ZI037_REL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL175']['ZI037_RFA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL175']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL175']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['AL175']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL175']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL175']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL180'] = {}
    field_information['GGDM 3.0']['DefaultValues']['AL180']['AOO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL180']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL180']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL180']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL180']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL180']['F_CODE'] = 'AL180'
    field_information['GGDM 3.0']['DefaultValues']['AL180']['FFN'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL180']['FFN2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL180']['FFN3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL180']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL180']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL180']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL180']['HGT'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL180']['LMC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL180']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL180']['MCC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL180']['MCC2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL180']['MCC3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL180']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL180']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL180']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL180']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL180']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL180']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL180']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['AL180']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL180']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AL180']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL180']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AL180']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AL180']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL180']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['AL180']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL180']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL180']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL180']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL180']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['AL180']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL180']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL180']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL180']['ZVH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL195'] = {}
    field_information['GGDM 3.0']['DefaultValues']['AL195']['AOO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL195']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL195']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL195']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL195']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL195']['F_CODE'] = 'AL195'
    field_information['GGDM 3.0']['DefaultValues']['AL195']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL195']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL195']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL195']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL195']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL195']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL195']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL195']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL195']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL195']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL195']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['AL195']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL195']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AL195']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL195']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AL195']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AL195']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL195']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['AL195']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL195']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL195']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL195']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL195']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['AL195']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL195']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL195']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL200'] = {}
    field_information['GGDM 3.0']['DefaultValues']['AL200']['AOO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL200']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL200']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL200']['F_CODE'] = 'AL200'
    field_information['GGDM 3.0']['DefaultValues']['AL200']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL200']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL200']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL200']['HGT'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL200']['LMC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL200']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL200']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL200']['SRL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL200']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL200']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL200']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL200']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL200']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['AL200']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL200']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AL200']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL200']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AL200']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AL200']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL200']['ZI025_HDP'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL200']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['AL200']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL200']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL200']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL200']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL200']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['AL200']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL200']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL200']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL200']['ZVH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL201'] = {}
    field_information['GGDM 3.0']['DefaultValues']['AL201']['ADR'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AL201']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL201']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL201']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL201']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL201']['F_CODE'] = 'AL201'
    field_information['GGDM 3.0']['DefaultValues']['AL201']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL201']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL201']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL201']['HGT'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL201']['HSS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL201']['LMC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL201']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL201']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL201']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL201']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL201']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL201']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL201']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL201']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['AL201']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL201']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AL201']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL201']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AL201']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AL201']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL201']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['AL201']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL201']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL201']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL201']['ZI037_REL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL201']['ZI037_RFA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL201']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL201']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['AL201']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL201']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL201']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL201']['ZVH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL208'] = {}
    field_information['GGDM 3.0']['DefaultValues']['AL208']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL208']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL208']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL208']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL208']['F_CODE'] = 'AL208'
    field_information['GGDM 3.0']['DefaultValues']['AL208']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL208']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL208']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL208']['HGT'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL208']['LMC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL208']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL208']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL208']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL208']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL208']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL208']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL208']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL208']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['AL208']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL208']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AL208']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL208']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AL208']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AL208']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL208']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['AL208']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL208']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL208']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL208']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL208']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['AL208']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL208']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL208']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL208']['ZVH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL211'] = {}
    field_information['GGDM 3.0']['DefaultValues']['AL211']['AOO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL211']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL211']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL211']['CAA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL211']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL211']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL211']['F_CODE'] = 'AL211'
    field_information['GGDM 3.0']['DefaultValues']['AL211']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL211']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL211']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL211']['HCA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL211']['HGT'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL211']['LMC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL211']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL211']['OHC'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL211']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL211']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL211']['TRP'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL211']['TRS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL211']['TRS2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL211']['TRS3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL211']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL211']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL211']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL211']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL211']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['AL211']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL211']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AL211']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL211']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['AL211']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL211']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL211']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL211']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL211']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['AL211']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL211']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL211']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL211']['ZVH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL241'] = {}
    field_information['GGDM 3.0']['DefaultValues']['AL241']['AOO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL241']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL241']['AWP'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL241']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL241']['CAA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL241']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL241']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL241']['F_CODE'] = 'AL241'
    field_information['GGDM 3.0']['DefaultValues']['AL241']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL241']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL241']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL241']['GUG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL241']['HEI'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL241']['HGT'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL241']['LMC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL241']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL241']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL241']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL241']['PYC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL241']['PYM'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL241']['SPT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL241']['SSR'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL241']['SSR2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL241']['SSR3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL241']['TOS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL241']['TTC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL241']['TTC2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL241']['TTC3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL241']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL241']['VOI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL241']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL241']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL241']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL241']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['AL241']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL241']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AL241']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL241']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AL241']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AL241']['ZI018_WIT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL241']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL241']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['AL241']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL241']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL241']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL241']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL241']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['AL241']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL241']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL241']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL241']['ZVH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL250'] = {}
    field_information['GGDM 3.0']['DefaultValues']['AL250']['ADR'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AL250']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL250']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL250']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL250']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL250']['DZP'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL250']['F_CODE'] = 'AL250'
    field_information['GGDM 3.0']['DefaultValues']['AL250']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL250']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL250']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL250']['HST'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL250']['HST2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL250']['HST3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL250']['LEA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL250']['LMC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL250']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL250']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL250']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL250']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL250']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL250']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL250']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL250']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['AL250']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL250']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AL250']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL250']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AL250']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AL250']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL250']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['AL250']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL250']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL250']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL250']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL250']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['AL250']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL250']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL250']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL260'] = {}
    field_information['GGDM 3.0']['DefaultValues']['AL260']['BAT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL260']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL260']['CAA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL260']['F_CODE'] = 'AL260'
    field_information['GGDM 3.0']['DefaultValues']['AL260']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL260']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL260']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL260']['HGT'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL260']['LMC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL260']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL260']['MCC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL260']['MCC2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL260']['MCC3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL260']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL260']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL260']['PFHC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['AL260']['PFHL'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL260']['PFHU'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL260']['THI'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL260']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL260']['WTI'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL260']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL260']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL260']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['AL260']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL260']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AL260']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL260']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AL260']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AL260']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL260']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['AL260']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL260']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL260']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL260']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL260']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['AL260']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL260']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL260']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL260']['ZVH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL270'] = {}
    field_information['GGDM 3.0']['DefaultValues']['AL270']['ADR'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AL270']['AOO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL270']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL270']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL270']['CAA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL270']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL270']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL270']['DMBC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['AL270']['DMBL'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL270']['DMBU'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL270']['DMT'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL270']['F_CODE'] = 'AL270'
    field_information['GGDM 3.0']['DefaultValues']['AL270']['FFN'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL270']['FFN2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL270']['FFN3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL270']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL270']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL270']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL270']['HGT'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL270']['LMC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL270']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL270']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL270']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL270']['PVH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL270']['SDSC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['AL270']['SDSL'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL270']['SDSU'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL270']['TRE'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL270']['TSCC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['AL270']['TSCL'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL270']['TSCU'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL270']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL270']['VSP'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL270']['VSP2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL270']['VSP3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL270']['VTI'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL270']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL270']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL270']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL270']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['AL270']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL270']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AL270']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL270']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AL270']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AL270']['ZI013_CSP'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL270']['ZI013_CSP2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL270']['ZI013_CSP3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL270']['ZI013_FFP'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL270']['ZI013_FFP2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL270']['ZI013_FFP3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL270']['ZI013_FMM'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL270']['ZI013_FMM2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL270']['ZI013_FMM3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL270']['ZI013_PIG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL270']['ZI014_PPO'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL270']['ZI014_PPO2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL270']['ZI014_PPO3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL270']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL270']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['AL270']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL270']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL270']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL270']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL270']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['AL270']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL270']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL270']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL270']['ZVH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL351'] = {}
    field_information['GGDM 3.0']['DefaultValues']['AL351']['ADR'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AL351']['AOO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL351']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL351']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL351']['CAA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL351']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL351']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL351']['F_CODE'] = 'AL351'
    field_information['GGDM 3.0']['DefaultValues']['AL351']['FFN'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL351']['FFN2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL351']['FFN3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL351']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL351']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL351']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL351']['HGT'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL351']['LMC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL351']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL351']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL351']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL351']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL351']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL351']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL351']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL351']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['AL351']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL351']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AL351']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL351']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AL351']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AL351']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL351']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['AL351']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL351']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL351']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL351']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL351']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['AL351']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL351']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL351']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL351']['ZVH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL371'] = {}
    field_information['GGDM 3.0']['DefaultValues']['AL371']['ADR'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AL371']['AOO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL371']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL371']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL371']['BNF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL371']['CAA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL371']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL371']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL371']['F_CODE'] = 'AL371'
    field_information['GGDM 3.0']['DefaultValues']['AL371']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL371']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL371']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL371']['HGT'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL371']['LMC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL371']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL371']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL371']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL371']['SSR'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL371']['SSR2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL371']['SSR3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL371']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL371']['VCM'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL371']['VCM2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL371']['VCM3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL371']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL371']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL371']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL371']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['AL371']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL371']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AL371']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AL371']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AL371']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL371']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['AL371']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL371']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL371']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL371']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL371']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['AL371']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL371']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL371']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL371']['ZVH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL375'] = {}
    field_information['GGDM 3.0']['DefaultValues']['AL375']['ADR'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AL375']['AOO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL375']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL375']['AWP'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL375']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL375']['BNF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL375']['CAA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL375']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL375']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL375']['F_CODE'] = 'AL375'
    field_information['GGDM 3.0']['DefaultValues']['AL375']['FFN'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL375']['FFN2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL375']['FFN3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL375']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL375']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL375']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL375']['HGT'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL375']['HST'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL375']['HST2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL375']['HST3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL375']['LMC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL375']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL375']['MUB'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL375']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL375']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL375']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL375']['VOI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL375']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL375']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL375']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL375']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['AL375']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL375']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AL375']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL375']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AL375']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AL375']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL375']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['AL375']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL375']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL375']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL375']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL375']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['AL375']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL375']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL375']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL375']['ZVH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL376'] = {}
    field_information['GGDM 3.0']['DefaultValues']['AL376']['ADR'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AL376']['AOO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL376']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL376']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL376']['CAA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL376']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL376']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL376']['F_CODE'] = 'AL376'
    field_information['GGDM 3.0']['DefaultValues']['AL376']['FFN'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL376']['FFN2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL376']['FFN3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL376']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL376']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL376']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL376']['HGT'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL376']['LMC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL376']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL376']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL376']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL376']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL376']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL376']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL376']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL376']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['AL376']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL376']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AL376']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL376']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AL376']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AL376']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL376']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['AL376']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL376']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL376']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL376']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL376']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['AL376']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL376']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL376']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL376']['ZVH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL510'] = {}
    field_information['GGDM 3.0']['DefaultValues']['AL510']['AOO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL510']['AWP'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL510']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL510']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL510']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL510']['F_CODE'] = 'AL510'
    field_information['GGDM 3.0']['DefaultValues']['AL510']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL510']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL510']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL510']['HGT'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AL510']['LMC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL510']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL510']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL510']['VOI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL510']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL510']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL510']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['AL510']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL510']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AL510']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL510']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AL510']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AL510']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL510']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['AL510']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL510']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AL510']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL510']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL510']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['AL510']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL510']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL510']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AL510']['ZVH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AM010'] = {}
    field_information['GGDM 3.0']['DefaultValues']['AM010']['ADR'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AM010']['AOO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AM010']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AM010']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AM010']['CAA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AM010']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AM010']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AM010']['F_CODE'] = 'AM010'
    field_information['GGDM 3.0']['DefaultValues']['AM010']['FFN'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AM010']['FFN2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AM010']['FFN3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AM010']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AM010']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AM010']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AM010']['HGT'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AM010']['LMC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AM010']['LUN'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AM010']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AM010']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AM010']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AM010']['PPO'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AM010']['PPO2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AM010']['PPO3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AM010']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AM010']['VOI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AM010']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AM010']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AM010']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AM010']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['AM010']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AM010']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AM010']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AM010']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AM010']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AM010']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AM010']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['AM010']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AM010']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AM010']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AM010']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AM010']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['AM010']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AM010']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AM010']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AM010']['ZVH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AM011'] = {}
    field_information['GGDM 3.0']['DefaultValues']['AM011']['AOO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AM011']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AM011']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AM011']['CAA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AM011']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AM011']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AM011']['F_CODE'] = 'AM011'
    field_information['GGDM 3.0']['DefaultValues']['AM011']['FFN'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AM011']['FFN2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AM011']['FFN3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AM011']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AM011']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AM011']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AM011']['HGT'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AM011']['LMC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AM011']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AM011']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AM011']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AM011']['SHT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AM011']['SPT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AM011']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AM011']['VCM'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AM011']['VCM2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AM011']['VCM3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AM011']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AM011']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AM011']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AM011']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['AM011']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AM011']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AM011']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AM011']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AM011']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AM011']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AM011']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['AM011']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AM011']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AM011']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AM011']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AM011']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['AM011']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AM011']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AM011']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AM011']['ZVH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AM020'] = {}
    field_information['GGDM 3.0']['DefaultValues']['AM020']['AOO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AM020']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AM020']['AWP'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AM020']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AM020']['CAA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AM020']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AM020']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AM020']['F_CODE'] = 'AM020'
    field_information['GGDM 3.0']['DefaultValues']['AM020']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AM020']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AM020']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AM020']['HGT'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AM020']['LMC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AM020']['LUN'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AM020']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AM020']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AM020']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AM020']['SSR'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AM020']['SSR2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AM020']['SSR3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AM020']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AM020']['VCM'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AM020']['VCM2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AM020']['VCM3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AM020']['VOI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AM020']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AM020']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AM020']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AM020']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['AM020']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AM020']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AM020']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AM020']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AM020']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AM020']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AM020']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['AM020']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AM020']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AM020']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AM020']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AM020']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['AM020']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AM020']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AM020']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AM020']['ZVH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AM030'] = {}
    field_information['GGDM 3.0']['DefaultValues']['AM030']['ADR'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AM030']['AOO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AM030']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AM030']['AWP'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AM030']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AM030']['CAA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AM030']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AM030']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AM030']['F_CODE'] = 'AM030'
    field_information['GGDM 3.0']['DefaultValues']['AM030']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AM030']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AM030']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AM030']['HGT'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AM030']['LMC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AM030']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AM030']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AM030']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AM030']['SSR'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AM030']['SSR2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AM030']['SSR3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AM030']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AM030']['VCM'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AM030']['VCM2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AM030']['VCM3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AM030']['VOI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AM030']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AM030']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AM030']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AM030']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['AM030']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AM030']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AM030']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AM030']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AM030']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AM030']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AM030']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['AM030']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AM030']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AM030']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AM030']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AM030']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['AM030']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AM030']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AM030']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AM030']['ZVH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AM040'] = {}
    field_information['GGDM 3.0']['DefaultValues']['AM040']['AOO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AM040']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AM040']['AWP'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AM040']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AM040']['CAA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AM040']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AM040']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AM040']['F_CODE'] = 'AM040'
    field_information['GGDM 3.0']['DefaultValues']['AM040']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AM040']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AM040']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AM040']['HGT'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AM040']['LMC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AM040']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AM040']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AM040']['PRW'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AM040']['PRW2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AM040']['PRW3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AM040']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AM040']['VOI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AM040']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AM040']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AM040']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AM040']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['AM040']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AM040']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AM040']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AM040']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['AM040']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AM040']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AM040']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AM040']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AM040']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['AM040']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AM040']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AM040']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AM040']['ZVH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AM060'] = {}
    field_information['GGDM 3.0']['DefaultValues']['AM060']['ADR'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AM060']['AOO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AM060']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AM060']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AM060']['CAA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AM060']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AM060']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AM060']['F_CODE'] = 'AM060'
    field_information['GGDM 3.0']['DefaultValues']['AM060']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AM060']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AM060']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AM060']['HGT'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AM060']['HST'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AM060']['HST2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AM060']['HST3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AM060']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AM060']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AM060']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AM060']['PPO'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AM060']['PPO2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AM060']['PPO3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AM060']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AM060']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AM060']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AM060']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AM060']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['AM060']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AM060']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AM060']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AM060']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AM060']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AM060']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AM060']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['AM060']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AM060']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AM060']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AM060']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AM060']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['AM060']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AM060']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AM060']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AM060']['ZVH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AM065'] = {}
    field_information['GGDM 3.0']['DefaultValues']['AM065']['ADR'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AM065']['AOO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AM065']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AM065']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AM065']['CAA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AM065']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AM065']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AM065']['F_CODE'] = 'AM065'
    field_information['GGDM 3.0']['DefaultValues']['AM065']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AM065']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AM065']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AM065']['HGT'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AM065']['LMC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AM065']['LUN'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AM065']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AM065']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AM065']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AM065']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AM065']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AM065']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AM065']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AM065']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['AM065']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AM065']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AM065']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AM065']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AM065']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AM065']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AM065']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['AM065']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AM065']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AM065']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AM065']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AM065']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['AM065']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AM065']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AM065']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AM065']['ZVH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AM070'] = {}
    field_information['GGDM 3.0']['DefaultValues']['AM070']['AOO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AM070']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AM070']['AWP'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AM070']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AM070']['CAA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AM070']['CBP'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AM070']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AM070']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AM070']['F_CODE'] = 'AM070'
    field_information['GGDM 3.0']['DefaultValues']['AM070']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AM070']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AM070']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AM070']['HEI'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AM070']['HGT'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AM070']['LMC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AM070']['LOC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AM070']['LUN'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AM070']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AM070']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AM070']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AM070']['PMPR'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AM070']['PPO'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AM070']['PPO2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AM070']['PPO3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AM070']['SPT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AM070']['SSC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AM070']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AM070']['VCM'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AM070']['VCM2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AM070']['VCM3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AM070']['VLM'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AM070']['VOI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AM070']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AM070']['YWQ'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AM070']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AM070']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AM070']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['AM070']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AM070']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AM070']['ZI005_FNA2'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AM070']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AM070']['ZI005_GNT2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AM070']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AM070']['ZI005_NFN2'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AM070']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AM070']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AM070']['ZI024_ASE'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AM070']['ZI024_CFR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AM070']['ZI024_CLO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AM070']['ZI024_CYN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AM070']['ZI024_FMR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AM070']['ZI024_FRR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AM070']['ZI024_HAR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AM070']['ZI024_MGN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AM070']['ZI024_PHW'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AM070']['ZI024_SCC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AM070']['ZI024_SUL'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AM070']['ZI024_TDS'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AM070']['ZI024_TEP'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AM070']['ZI024_TUR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AM070']['ZI024_WAC'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AM070']['ZI024_WTNO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AM070']['ZI024_WUR'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AM070']['ZI024_WUR2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AM070']['ZI024_WUR3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AM070']['ZI024_WUR4'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AM070']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['AM070']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AM070']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AM070']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AM070']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AM070']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['AM070']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AM070']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AM070']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AM070']['ZVH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AM071'] = {}
    field_information['GGDM 3.0']['DefaultValues']['AM071']['ADR'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AM071']['AOO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AM071']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AM071']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AM071']['CAA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AM071']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AM071']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AM071']['F_CODE'] = 'AM071'
    field_information['GGDM 3.0']['DefaultValues']['AM071']['FFN'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AM071']['FFN2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AM071']['FFN3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AM071']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AM071']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AM071']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AM071']['HGT'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AM071']['LMC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AM071']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AM071']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AM071']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AM071']['PPO'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AM071']['PPO2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AM071']['PPO3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AM071']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AM071']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AM071']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AM071']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AM071']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['AM071']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AM071']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AM071']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AM071']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AM071']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AM071']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AM071']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['AM071']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AM071']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AM071']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AM071']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AM071']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['AM071']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AM071']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AM071']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AM071']['ZVH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AM075'] = {}
    field_information['GGDM 3.0']['DefaultValues']['AM075']['ADR'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AM075']['AOO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AM075']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AM075']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AM075']['CAA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AM075']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AM075']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AM075']['F_CODE'] = 'AM075'
    field_information['GGDM 3.0']['DefaultValues']['AM075']['FFN'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AM075']['FFN2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AM075']['FFN3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AM075']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AM075']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AM075']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AM075']['HGT'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AM075']['LMC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AM075']['LUN'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AM075']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AM075']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AM075']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AM075']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AM075']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AM075']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AM075']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AM075']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['AM075']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AM075']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AM075']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AM075']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AM075']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AM075']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AM075']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['AM075']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AM075']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AM075']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AM075']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AM075']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['AM075']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AM075']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AM075']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AM075']['ZVH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AM080'] = {}
    field_information['GGDM 3.0']['DefaultValues']['AM080']['AOO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AM080']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AM080']['AWP'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AM080']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AM080']['CAA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AM080']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AM080']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AM080']['F_CODE'] = 'AM080'
    field_information['GGDM 3.0']['DefaultValues']['AM080']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AM080']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AM080']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AM080']['HGT'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AM080']['LMC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AM080']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AM080']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AM080']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AM080']['PMPR'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AM080']['SPT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AM080']['SSC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AM080']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AM080']['VLM'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AM080']['VOI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AM080']['WDST'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AM080']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AM080']['YWQ'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AM080']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AM080']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AM080']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['AM080']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AM080']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AM080']['ZI005_FNA2'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AM080']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AM080']['ZI005_GNT2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AM080']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AM080']['ZI005_NFN2'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AM080']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AM080']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AM080']['ZI024_ASE'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AM080']['ZI024_CFR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AM080']['ZI024_CLO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AM080']['ZI024_CYN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AM080']['ZI024_FMR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AM080']['ZI024_FRR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AM080']['ZI024_HAR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AM080']['ZI024_HYP'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AM080']['ZI024_MGN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AM080']['ZI024_PHW'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AM080']['ZI024_SCC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AM080']['ZI024_SUL'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AM080']['ZI024_TDS'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AM080']['ZI024_TEP'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AM080']['ZI024_TUR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AM080']['ZI024_WAC'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AM080']['ZI024_WTNO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AM080']['ZI024_WUR'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AM080']['ZI024_WUR2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AM080']['ZI024_WUR3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AM080']['ZI024_WUR4'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AM080']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['AM080']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AM080']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AM080']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AM080']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AM080']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['AM080']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AM080']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AM080']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AM080']['ZVH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AN010'] = {}
    field_information['GGDM 3.0']['DefaultValues']['AN010']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AN010']['CAA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AN010']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AN010']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AN010']['CWT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AN010']['DEV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AN010']['F_CODE'] = 'AN010'
    field_information['GGDM 3.0']['DefaultValues']['AN010']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AN010']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AN010']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AN010']['LMC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AN010']['LOC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AN010']['LTN'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AN010']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AN010']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AN010']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AN010']['RLE'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AN010']['RRC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AN010']['RRC2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AN010']['RRC3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AN010']['RTA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AN010']['RWC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AN010']['SBB'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AN010']['SGCC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['AN010']['SGCL'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AN010']['SGCU'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AN010']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AN010']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AN010']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AN010']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AN010']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['AN010']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AN010']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AN010']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AN010']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AN010']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AN010']['ZI017_GAW'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AN010']['ZI017_RGC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AN010']['ZI017_RIR'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AN010']['ZI017_RRA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AN010']['ZI017_TRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AN010']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AN010']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['AN010']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AN010']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AN010']['ZI026_SUR'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AN010']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AN010']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AN010']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['AN010']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AN010']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AN010']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AN050'] = {}
    field_information['GGDM 3.0']['DefaultValues']['AN050']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AN050']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AN050']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AN050']['CTL'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AN050']['CWT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AN050']['F_CODE'] = 'AN050'
    field_information['GGDM 3.0']['DefaultValues']['AN050']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AN050']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AN050']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AN050']['LOC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AN050']['LTN'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AN050']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AN050']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AN050']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AN050']['RLE'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AN050']['RRC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AN050']['RRC2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AN050']['RRC3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AN050']['RSA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AN050']['SBB'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AN050']['SGCC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['AN050']['SGCL'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AN050']['SGCU'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AN050']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AN050']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AN050']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AN050']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AN050']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['AN050']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AN050']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AN050']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AN050']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AN050']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AN050']['ZI017_GAW'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AN050']['ZI017_RGC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AN050']['ZI017_RIR'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AN050']['ZI017_RRA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AN050']['ZI017_TRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AN050']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AN050']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['AN050']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AN050']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AN050']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AN050']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AN050']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['AN050']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AN050']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AN050']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AN060'] = {}
    field_information['GGDM 3.0']['DefaultValues']['AN060']['ADR'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AN060']['AOO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AN060']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AN060']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AN060']['CAA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AN060']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AN060']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AN060']['CTL'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AN060']['F_CODE'] = 'AN060'
    field_information['GGDM 3.0']['DefaultValues']['AN060']['FFN'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AN060']['FFN2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AN060']['FFN3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AN060']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AN060']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AN060']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AN060']['HGT'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AN060']['LMC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AN060']['LTN'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AN060']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AN060']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AN060']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AN060']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AN060']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AN060']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AN060']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AN060']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['AN060']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AN060']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AN060']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AN060']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AN060']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AN060']['ZI017_GAW'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AN060']['ZI017_RGC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AN060']['ZI017_RRA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AN060']['ZI017_TRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AN060']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AN060']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['AN060']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AN060']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AN060']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AN060']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AN060']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['AN060']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AN060']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AN060']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AN060']['ZVH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AN075'] = {}
    field_information['GGDM 3.0']['DefaultValues']['AN075']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AN075']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AN075']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AN075']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AN075']['F_CODE'] = 'AN075'
    field_information['GGDM 3.0']['DefaultValues']['AN075']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AN075']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AN075']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AN075']['LMC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AN075']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AN075']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AN075']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AN075']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AN075']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AN075']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AN075']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AN075']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['AN075']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AN075']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AN075']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AN075']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AN075']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AN075']['ZI017_GAW'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AN075']['ZI017_RGC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AN075']['ZI017_RRA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AN075']['ZI017_TRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AN075']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AN075']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['AN075']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AN075']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AN075']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AN075']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AN075']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['AN075']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AN075']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AN075']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AN076'] = {}
    field_information['GGDM 3.0']['DefaultValues']['AN076']['ADR'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AN076']['AOO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AN076']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AN076']['AWP'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AN076']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AN076']['CAA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AN076']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AN076']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AN076']['F_CODE'] = 'AN076'
    field_information['GGDM 3.0']['DefaultValues']['AN076']['FFN'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AN076']['FFN2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AN076']['FFN3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AN076']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AN076']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AN076']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AN076']['HGT'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AN076']['LMC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AN076']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AN076']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AN076']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AN076']['SSR'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AN076']['SSR2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AN076']['SSR3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AN076']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AN076']['VCM'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AN076']['VCM2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AN076']['VCM3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AN076']['VOI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AN076']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AN076']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AN076']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AN076']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['AN076']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AN076']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AN076']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AN076']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AN076']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AN076']['ZI017_GAW'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AN076']['ZI017_RGC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AN076']['ZI017_RRA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AN076']['ZI017_TRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AN076']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AN076']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['AN076']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AN076']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AN076']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AN076']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AN076']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['AN076']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AN076']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AN076']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AN076']['ZVH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AN085'] = {}
    field_information['GGDM 3.0']['DefaultValues']['AN085']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AN085']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AN085']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AN085']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AN085']['F_CODE'] = 'AN085'
    field_information['GGDM 3.0']['DefaultValues']['AN085']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AN085']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AN085']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AN085']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AN085']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AN085']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AN085']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AN085']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AN085']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AN085']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AN085']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['AN085']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AN085']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AN085']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AN085']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AN085']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AN085']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AN085']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['AN085']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AN085']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AN085']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AN085']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AN085']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['AN085']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AN085']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AN085']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AP010'] = {}
    field_information['GGDM 3.0']['DefaultValues']['AP010']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AP010']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AP010']['CIW'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AP010']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AP010']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AP010']['CWT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AP010']['DEV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AP010']['F_CODE'] = 'AP010'
    field_information['GGDM 3.0']['DefaultValues']['AP010']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AP010']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AP010']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AP010']['LOC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AP010']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AP010']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AP010']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AP010']['PSN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AP010']['PTG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AP010']['RLE'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AP010']['RTN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AP010']['RTN2'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AP010']['RTN3'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AP010']['SBB'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AP010']['SPD'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AP010']['SPM'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AP010']['THR'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AP010']['TRS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AP010']['TRS2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AP010']['TRS3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AP010']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AP010']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AP010']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AP010']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AP010']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['AP010']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AP010']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AP010']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AP010']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AP010']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AP010']['ZI016_WD1'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AP010']['ZI016_WTC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AP010']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AP010']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['AP010']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AP010']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AP010']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AP010']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AP010']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['AP010']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AP010']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AP010']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AP020'] = {}
    field_information['GGDM 3.0']['DefaultValues']['AP020']['AOO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AP020']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AP020']['CAA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AP020']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AP020']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AP020']['CWT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AP020']['F_CODE'] = 'AP020'
    field_information['GGDM 3.0']['DefaultValues']['AP020']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AP020']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AP020']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AP020']['LMC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AP020']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AP020']['RIN_ROI'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AP020']['RIN_ROI2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AP020']['RIN_ROI3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AP020']['RIN_RTN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AP020']['RIN_RTN2'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AP020']['RIN_RTN3'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AP020']['RIT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AP020']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AP020']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AP020']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AP020']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['AP020']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AP020']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AP020']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AP020']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AP020']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AP020']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AP020']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['AP020']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AP020']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AP020']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AP020']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AP020']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['AP020']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AP020']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AP020']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AP030'] = {}
    field_information['GGDM 3.0']['DefaultValues']['AP030']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AP030']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AP030']['CAA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AP030']['CIW'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AP030']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AP030']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AP030']['CWT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AP030']['DEV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AP030']['F_CODE'] = 'AP030'
    field_information['GGDM 3.0']['DefaultValues']['AP030']['FCO'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AP030']['FSC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AP030']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AP030']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AP030']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AP030']['LOC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AP030']['LTN'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AP030']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AP030']['MES'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AP030']['MWG'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AP030']['ONE'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AP030']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AP030']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AP030']['PSN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AP030']['PTG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AP030']['RIN_ROI'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AP030']['RIN_ROI2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AP030']['RIN_ROI3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AP030']['RIN_RTN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AP030']['RIN_RTN2'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AP030']['RIN_RTN3'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AP030']['RLE'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AP030']['RMWC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['AP030']['RMWL'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AP030']['RMWU'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AP030']['ROR'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AP030']['RTY'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AP030']['SBB'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AP030']['SEP'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AP030']['SGCC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['AP030']['SGCL'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AP030']['SGCU'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AP030']['SPD'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AP030']['SPM'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AP030']['THR'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AP030']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AP030']['WD2'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AP030']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AP030']['WT2'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AP030']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AP030']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AP030']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['AP030']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AP030']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AP030']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AP030']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AP030']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AP030']['ZI016_ROC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AP030']['ZI016_WD1'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AP030']['ZI016_WTC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AP030']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AP030']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['AP030']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AP030']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AP030']['ZI026_SUR'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AP030']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AP030']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AP030']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['AP030']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AP030']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AP030']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AP033'] = {}
    field_information['GGDM 3.0']['DefaultValues']['AP033']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AP033']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AP033']['CIW'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AP033']['F_CODE'] = 'AP033'
    field_information['GGDM 3.0']['DefaultValues']['AP033']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AP033']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AP033']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AP033']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AP033']['MES'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AP033']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AP033']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AP033']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AP033']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AP033']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AP033']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AP033']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['AP033']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AP033']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AP033']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AP033']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AP033']['ZI016_ROC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AP033']['ZI016_WTC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AP033']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AP033']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['AP033']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AP033']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AP033']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AP033']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AP033']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['AP033']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AP033']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AP033']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AP040'] = {}
    field_information['GGDM 3.0']['DefaultValues']['AP040']['AOO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AP040']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AP040']['CAA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AP040']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AP040']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AP040']['F_CODE'] = 'AP040'
    field_information['GGDM 3.0']['DefaultValues']['AP040']['FFN'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AP040']['FFN2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AP040']['FFN3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AP040']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AP040']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AP040']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AP040']['GTC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AP040']['HGT'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AP040']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AP040']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AP040']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AP040']['THI'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AP040']['TRS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AP040']['TRS2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AP040']['TRS3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AP040']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AP040']['WD2'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AP040']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AP040']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AP040']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['AP040']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AP040']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AP040']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AP040']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AP040']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AP040']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AP040']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['AP040']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AP040']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AP040']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AP040']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AP040']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['AP040']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AP040']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AP040']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AP041'] = {}
    field_information['GGDM 3.0']['DefaultValues']['AP041']['AOO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AP041']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AP041']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AP041']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AP041']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AP041']['F_CODE'] = 'AP041'
    field_information['GGDM 3.0']['DefaultValues']['AP041']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AP041']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AP041']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AP041']['HGT'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AP041']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AP041']['MCC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AP041']['MCC2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AP041']['MCC3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AP041']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AP041']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AP041']['TRS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AP041']['TRS2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AP041']['TRS3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AP041']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AP041']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AP041']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AP041']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AP041']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['AP041']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AP041']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AP041']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AP041']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AP041']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AP041']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AP041']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['AP041']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AP041']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AP041']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AP041']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AP041']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['AP041']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AP041']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AP041']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AP041']['ZVH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AP050'] = {}
    field_information['GGDM 3.0']['DefaultValues']['AP050']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AP050']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AP050']['CAA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AP050']['CIW'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AP050']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AP050']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AP050']['CWT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AP050']['DEV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AP050']['F_CODE'] = 'AP050'
    field_information['GGDM 3.0']['DefaultValues']['AP050']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AP050']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AP050']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AP050']['LMC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AP050']['LOC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AP050']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AP050']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AP050']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AP050']['PTG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AP050']['RLE'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AP050']['SBB'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AP050']['THR'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AP050']['TRS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AP050']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AP050']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AP050']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AP050']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AP050']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['AP050']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AP050']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AP050']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AP050']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AP050']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AP050']['ZI016_WTC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AP050']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AP050']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['AP050']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AP050']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AP050']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AP050']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AP050']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['AP050']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AP050']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AP050']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AP055'] = {}
    field_information['GGDM 3.0']['DefaultValues']['AP055']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AP055']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AP055']['CIW'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AP055']['CWT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AP055']['F_CODE'] = 'AP055'
    field_information['GGDM 3.0']['DefaultValues']['AP055']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AP055']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AP055']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AP055']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AP055']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AP055']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AP055']['PSN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AP055']['RLE'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AP055']['RTN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AP055']['RTN2'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AP055']['RTN3'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AP055']['SBB'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AP055']['SPD'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AP055']['SPM'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AP055']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AP055']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AP055']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AP055']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AP055']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['AP055']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AP055']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AP055']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AP055']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AP055']['ZI016_ROC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AP055']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AP055']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['AP055']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AP055']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AP055']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AP055']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AP055']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['AP055']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AP055']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AP055']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AP056'] = {}
    field_information['GGDM 3.0']['DefaultValues']['AP056']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AP056']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AP056']['CSC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AP056']['CSC2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AP056']['CSC3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AP056']['F_CODE'] = 'AP056'
    field_information['GGDM 3.0']['DefaultValues']['AP056']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AP056']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AP056']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AP056']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AP056']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AP056']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AP056']['TRS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AP056']['TRS2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AP056']['TRS3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AP056']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AP056']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AP056']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AP056']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AP056']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['AP056']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AP056']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AP056']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AP056']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AP056']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AP056']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['AP056']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AP056']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AP056']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AP056']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AP056']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['AP056']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AP056']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AP056']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ035'] = {}
    field_information['GGDM 3.0']['DefaultValues']['AQ035']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AQ035']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ035']['CIW'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ035']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ035']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ035']['CWT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ035']['F_CODE'] = 'AQ035'
    field_information['GGDM 3.0']['DefaultValues']['AQ035']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ035']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ035']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ035']['LMC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ035']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AQ035']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ035']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ035']['SBB'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ035']['SGCC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['AQ035']['SGCL'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AQ035']['SGCU'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AQ035']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ035']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AQ035']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ035']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ035']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['AQ035']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ035']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AQ035']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ035']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AQ035']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AQ035']['ZI016_ROC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ035']['ZI016_WD1'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AQ035']['ZI016_WTC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ035']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ035']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['AQ035']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ035']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ035']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ035']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ035']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['AQ035']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ035']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ035']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ035']['ZVH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AQ040'] = {}
    field_information['GGDM 3.0']['DefaultValues']['AQ040']['AOO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AQ040']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AQ040']['AWP'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ040']['BCC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ040']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ040']['BOT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ040']['BRN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AQ040']['BSC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ040']['BSC2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ040']['BSC3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ040']['BSM'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ040']['CAA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ040']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ040']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ040']['DZC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ040']['F_CODE'] = 'AQ040'
    field_information['GGDM 3.0']['DefaultValues']['AQ040']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ040']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ040']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ040']['HCA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AQ040']['HGT'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AQ040']['LC1'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ040']['LC2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ040']['LC3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ040']['LC4'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ040']['LMC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ040']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AQ040']['NOS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ040']['OHC'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AQ040']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ040']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ040']['RFD'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ040']['TRS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ040']['TRS2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ040']['TRS3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ040']['UBC'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AQ040']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ040']['VCM'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ040']['VCM2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ040']['VCM3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ040']['VCO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AQ040']['VCS'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AQ040']['VCS_VCD'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ040']['VCS_VCR'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AQ040']['VOI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ040']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AQ040']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ040']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ040']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['AQ040']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ040']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AQ040']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ040']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AQ040']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AQ040']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ040']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['AQ040']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ040']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ040']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ040']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ040']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['AQ040']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ040']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ040']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ040']['ZVH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AQ045'] = {}
    field_information['GGDM 3.0']['DefaultValues']['AQ045']['AOO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AQ045']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AQ045']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ045']['BOT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ045']['BRN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AQ045']['BSC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ045']['BSC2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ045']['BSC3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ045']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ045']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ045']['F_CODE'] = 'AQ045'
    field_information['GGDM 3.0']['DefaultValues']['AQ045']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ045']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ045']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ045']['HGT'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AQ045']['LC1'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ045']['LC2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ045']['LC3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ045']['LC4'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ045']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AQ045']['OHC'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AQ045']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ045']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ045']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ045']['VCM'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ045']['VCM2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ045']['VCM3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ045']['VCO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AQ045']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AQ045']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ045']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ045']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['AQ045']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ045']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AQ045']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ045']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AQ045']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AQ045']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ045']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['AQ045']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ045']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ045']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ045']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ045']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['AQ045']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ045']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ045']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ045']['ZVH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AQ050'] = {}
    field_information['GGDM 3.0']['DefaultValues']['AQ050']['AOO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AQ050']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AQ050']['AWP'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ050']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ050']['BRN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AQ050']['BSC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ050']['F_CODE'] = 'AQ050'
    field_information['GGDM 3.0']['DefaultValues']['AQ050']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ050']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ050']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ050']['HEI'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AQ050']['HGT'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AQ050']['LMC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ050']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AQ050']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ050']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ050']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ050']['VOI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ050']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AQ050']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ050']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ050']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['AQ050']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ050']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AQ050']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ050']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['AQ050']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ050']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ050']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ050']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ050']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['AQ050']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ050']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ050']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ050']['ZVH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AQ055'] = {}
    field_information['GGDM 3.0']['DefaultValues']['AQ055']['AOO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AQ055']['AWP'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ055']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ055']['BRN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AQ055']['F_CODE'] = 'AQ055'
    field_information['GGDM 3.0']['DefaultValues']['AQ055']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ055']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ055']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ055']['HGT'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AQ055']['LMC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ055']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AQ055']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ055']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ055']['PYM'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ055']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ055']['VOI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ055']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AQ055']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ055']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ055']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['AQ055']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ055']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AQ055']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ055']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['AQ055']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ055']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ055']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ055']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ055']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['AQ055']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ055']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ055']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ055']['ZVH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AQ056'] = {}
    field_information['GGDM 3.0']['DefaultValues']['AQ056']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AQ056']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ056']['F_CODE'] = 'AQ056'
    field_information['GGDM 3.0']['DefaultValues']['AQ056']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ056']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ056']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ056']['HGT'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AQ056']['LMC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ056']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AQ056']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ056']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ056']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ056']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AQ056']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ056']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ056']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['AQ056']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ056']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AQ056']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ056']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AQ056']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AQ056']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ056']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['AQ056']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ056']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ056']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ056']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ056']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['AQ056']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ056']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ056']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ056']['ZVH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AQ059'] = {}
    field_information['GGDM 3.0']['DefaultValues']['AQ059']['BCC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ059']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ059']['CON'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ059']['EXP'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ059']['F_CODE'] = 'AQ059'
    field_information['GGDM 3.0']['DefaultValues']['AQ059']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ059']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ059']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ059']['HCA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AQ059']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AQ059']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ059']['SHC'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AQ059']['SRE'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ059']['TRS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ059']['TRS2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ059']['TRS3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ059']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ059']['WD1'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AQ059']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ059']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ059']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['AQ059']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ059']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AQ059']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ059']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['AQ059']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ059']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ059']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ059']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ059']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['AQ059']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ059']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ059']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ060'] = {}
    field_information['GGDM 3.0']['DefaultValues']['AQ060']['ADR'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AQ060']['AOO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AQ060']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AQ060']['AWP'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ060']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ060']['CAA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ060']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ060']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ060']['F_CODE'] = 'AQ060'
    field_information['GGDM 3.0']['DefaultValues']['AQ060']['FFN'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ060']['FFN2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ060']['FFN3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ060']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ060']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ060']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ060']['HGT'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AQ060']['LMC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ060']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AQ060']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ060']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ060']['SSR'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ060']['SSR2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ060']['SSR3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ060']['TRS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ060']['TRS2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ060']['TRS3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ060']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ060']['VCM'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ060']['VCM2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ060']['VCM3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ060']['VOI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ060']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AQ060']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ060']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ060']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['AQ060']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ060']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AQ060']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ060']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AQ060']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AQ060']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ060']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['AQ060']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ060']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ060']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ060']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ060']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['AQ060']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ060']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ060']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ060']['ZVH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AQ062'] = {}
    field_information['GGDM 3.0']['DefaultValues']['AQ062']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AQ062']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ062']['CSC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ062']['CSC2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ062']['CSC3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ062']['F_CODE'] = 'AQ062'
    field_information['GGDM 3.0']['DefaultValues']['AQ062']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ062']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ062']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ062']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AQ062']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ062']['TRS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ062']['TRS2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ062']['TRS3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ062']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ062']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AQ062']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ062']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ062']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['AQ062']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ062']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AQ062']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ062']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AQ062']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AQ062']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ062']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['AQ062']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ062']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ062']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ062']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ062']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['AQ062']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ062']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ062']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ063'] = {}
    field_information['GGDM 3.0']['DefaultValues']['AQ063']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AQ063']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ063']['CAA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ063']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ063']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ063']['F_CODE'] = 'AQ063'
    field_information['GGDM 3.0']['DefaultValues']['AQ063']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ063']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ063']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ063']['HGT'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AQ063']['LMC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ063']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AQ063']['MCC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ063']['MCC2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ063']['MCC3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ063']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ063']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ063']['SGCC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['AQ063']['SGCL'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AQ063']['SGCU'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AQ063']['TRS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ063']['TRS2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ063']['TRS3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ063']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ063']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AQ063']['WLE'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ063']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ063']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ063']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['AQ063']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ063']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AQ063']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ063']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AQ063']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AQ063']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ063']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['AQ063']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ063']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ063']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ063']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ063']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['AQ063']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ063']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ063']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ063']['ZVH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AQ065'] = {}
    field_information['GGDM 3.0']['DefaultValues']['AQ065']['AOO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AQ065']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AQ065']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ065']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ065']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ065']['CTC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ065']['F_CODE'] = 'AQ065'
    field_information['GGDM 3.0']['DefaultValues']['AQ065']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ065']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ065']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ065']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AQ065']['MCC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ065']['MCC2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ065']['MCC3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ065']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ065']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ065']['TCS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ065']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ065']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AQ065']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ065']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ065']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['AQ065']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ065']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AQ065']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ065']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['AQ065']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ065']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ065']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ065']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ065']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['AQ065']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ065']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ065']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ068'] = {}
    field_information['GGDM 3.0']['DefaultValues']['AQ068']['AOO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AQ068']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AQ068']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ068']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ068']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ068']['DGC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ068']['F_CODE'] = 'AQ068'
    field_information['GGDM 3.0']['DefaultValues']['AQ068']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ068']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ068']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ068']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AQ068']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ068']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ068']['TRS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ068']['TRS2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ068']['TRS3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ068']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ068']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AQ068']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ068']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ068']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['AQ068']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ068']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AQ068']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ068']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['AQ068']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ068']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ068']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ068']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ068']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['AQ068']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ068']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ068']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ070'] = {}
    field_information['GGDM 3.0']['DefaultValues']['AQ070']['AOO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AQ070']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ070']['CAA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ070']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ070']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ070']['F_CODE'] = 'AQ070'
    field_information['GGDM 3.0']['DefaultValues']['AQ070']['FCL'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AQ070']['FER'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ070']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ070']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ070']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ070']['LMC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ070']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AQ070']['MCX'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ070']['OPT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ070']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ070']['PSN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AQ070']['RIN_ROI'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ070']['RIN_ROI2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ070']['RIN_ROI3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ070']['RIN_RTN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AQ070']['RIN_RTN2'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AQ070']['RIN_RTN3'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AQ070']['SPD'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AQ070']['SPM'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AQ070']['TRS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ070']['TRS2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ070']['TRS3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ070']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ070']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ070']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ070']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['AQ070']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ070']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AQ070']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ070']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AQ070']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AQ070']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ070']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['AQ070']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ070']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ070']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ070']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ070']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['AQ070']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ070']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ070']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ075'] = {}
    field_information['GGDM 3.0']['DefaultValues']['AQ075']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ075']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ075']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ075']['F_CODE'] = 'AQ075'
    field_information['GGDM 3.0']['DefaultValues']['AQ075']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ075']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ075']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ075']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AQ075']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ075']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ075']['PSN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AQ075']['RIN_ROI'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ075']['RIN_ROI2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ075']['RIN_ROI3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ075']['RIN_RTN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AQ075']['RIN_RTN2'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AQ075']['RIN_RTN3'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AQ075']['SPD'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AQ075']['SPM'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AQ075']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ075']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AQ075']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ075']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ075']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['AQ075']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ075']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AQ075']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ075']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AQ075']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AQ075']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ075']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['AQ075']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ075']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ075']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ075']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ075']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['AQ075']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ075']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ075']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ080'] = {}
    field_information['GGDM 3.0']['DefaultValues']['AQ080']['ADR'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AQ080']['AOO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AQ080']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AQ080']['ATB'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ080']['AWP'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ080']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ080']['CAA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ080']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ080']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ080']['F_CODE'] = 'AQ080'
    field_information['GGDM 3.0']['DefaultValues']['AQ080']['FFN'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ080']['FFN2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ080']['FFN3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ080']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ080']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ080']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ080']['HGT'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AQ080']['HST'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ080']['HST2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ080']['HST3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ080']['LMC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ080']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AQ080']['MUB'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ080']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ080']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ080']['SSR'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ080']['SSR2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ080']['SSR3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ080']['TRS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ080']['TRS2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ080']['TRS3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ080']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ080']['VOI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ080']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AQ080']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ080']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ080']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['AQ080']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ080']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AQ080']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ080']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AQ080']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AQ080']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ080']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['AQ080']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ080']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ080']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ080']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ080']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['AQ080']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ080']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ080']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ080']['ZVH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AQ095'] = {}
    field_information['GGDM 3.0']['DefaultValues']['AQ095']['AOO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AQ095']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ095']['CAA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ095']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ095']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ095']['F_CODE'] = 'AQ095'
    field_information['GGDM 3.0']['DefaultValues']['AQ095']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ095']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ095']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ095']['HCA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AQ095']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AQ095']['OHC'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AQ095']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ095']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ095']['TRS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ095']['TRS2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ095']['TRS3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ095']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ095']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ095']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ095']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['AQ095']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ095']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AQ095']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ095']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AQ095']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AQ095']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ095']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['AQ095']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ095']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ095']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ095']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ095']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['AQ095']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ095']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ095']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ095']['ZVH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AQ110'] = {}
    field_information['GGDM 3.0']['DefaultValues']['AQ110']['AOO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AQ110']['AWP'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ110']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ110']['CAA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ110']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ110']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ110']['F_CODE'] = 'AQ110'
    field_information['GGDM 3.0']['DefaultValues']['AQ110']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ110']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ110']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ110']['GUG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ110']['HGT'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AQ110']['LMC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ110']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AQ110']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ110']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ110']['PYM'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ110']['TOS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ110']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ110']['VOI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ110']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AQ110']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ110']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ110']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['AQ110']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ110']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AQ110']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ110']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AQ110']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AQ110']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ110']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['AQ110']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ110']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ110']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ110']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ110']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['AQ110']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ110']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ110']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ110']['ZVH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AQ111'] = {}
    field_information['GGDM 3.0']['DefaultValues']['AQ111']['AOO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AQ111']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ111']['CAA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ111']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ111']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ111']['F_CODE'] = 'AQ111'
    field_information['GGDM 3.0']['DefaultValues']['AQ111']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ111']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ111']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ111']['HGT'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AQ111']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AQ111']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ111']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ111']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ111']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AQ111']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ111']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ111']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['AQ111']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ111']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AQ111']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ111']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AQ111']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AQ111']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ111']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['AQ111']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ111']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ111']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ111']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ111']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['AQ111']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ111']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ111']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ113'] = {}
    field_information['GGDM 3.0']['DefaultValues']['AQ113']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ113']['CAA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ113']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ113']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ113']['CWT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ113']['DEV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ113']['DIM'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AQ113']['DZP'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AQ113']['F_CODE'] = 'AQ113'
    field_information['GGDM 3.0']['DefaultValues']['AQ113']['FLO'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ113']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ113']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ113']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ113']['HGT'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AQ113']['LEA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AQ113']['LMC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ113']['LOC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ113']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AQ113']['MCC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ113']['MCC2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ113']['MCC3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ113']['NPL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ113']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ113']['OWO'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ113']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ113']['PLT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ113']['PLT2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ113']['PLT3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ113']['PMPR'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ113']['PPO'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ113']['PPO2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ113']['PPO3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ113']['RLE'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ113']['RTA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ113']['SBB'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ113']['SPT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ113']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ113']['VCO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AQ113']['WVA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AQ113']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ113']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ113']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['AQ113']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ113']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AQ113']['ZI005_FNA2'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AQ113']['ZI005_FNA3'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AQ113']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ113']['ZI005_GNT2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ113']['ZI005_GNT3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ113']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AQ113']['ZI005_NFN2'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AQ113']['ZI005_NFN3'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AQ113']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AQ113']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ113']['ZI024_ASE'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AQ113']['ZI024_AWO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AQ113']['ZI024_AWOI'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AQ113']['ZI024_AWOX'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AQ113']['ZI024_CFR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AQ113']['ZI024_CLO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AQ113']['ZI024_CYN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AQ113']['ZI024_FMR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AQ113']['ZI024_FRR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AQ113']['ZI024_HAR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AQ113']['ZI024_MGN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AQ113']['ZI024_PHW'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AQ113']['ZI024_SCC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ113']['ZI024_SUL'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AQ113']['ZI024_TDS'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AQ113']['ZI024_TEP'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AQ113']['ZI024_TUR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AQ113']['ZI024_WAC'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AQ113']['ZI024_WTNO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AQ113']['ZI024_WUR'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ113']['ZI024_WUR2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ113']['ZI024_WUR3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ113']['ZI024_WUR4'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ113']['ZI024_YWQ'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ113']['ZI025_HDP'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AQ113']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['AQ113']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ113']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ113']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ113']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ113']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['AQ113']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ113']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ113']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ113']['ZVH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AQ114'] = {}
    field_information['GGDM 3.0']['DefaultValues']['AQ114']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AQ114']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ114']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ114']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ114']['F_CODE'] = 'AQ114'
    field_information['GGDM 3.0']['DefaultValues']['AQ114']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ114']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ114']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ114']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AQ114']['MCC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ114']['MCC2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ114']['MCC3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ114']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ114']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ114']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ114']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AQ114']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ114']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ114']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['AQ114']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ114']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AQ114']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ114']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AQ114']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AQ114']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ114']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['AQ114']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ114']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ114']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ114']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ114']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['AQ114']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ114']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ114']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ115'] = {}
    field_information['GGDM 3.0']['DefaultValues']['AQ115']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AQ115']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ115']['F_CODE'] = 'AQ115'
    field_information['GGDM 3.0']['DefaultValues']['AQ115']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ115']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ115']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ115']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AQ115']['MCC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ115']['MCC2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ115']['MCC3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ115']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ115']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ115']['UTY'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ115']['UTY2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ115']['UTY3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ115']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AQ115']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ115']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ115']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['AQ115']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ115']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AQ115']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ115']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AQ115']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AQ115']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ115']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['AQ115']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ115']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ115']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ115']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ115']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['AQ115']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ115']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ115']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ116'] = {}
    field_information['GGDM 3.0']['DefaultValues']['AQ116']['ADR'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AQ116']['AOO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AQ116']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AQ116']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ116']['CAA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ116']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ116']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ116']['DZP'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AQ116']['F_CODE'] = 'AQ116'
    field_information['GGDM 3.0']['DefaultValues']['AQ116']['FFN'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ116']['FFN2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ116']['FFN3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ116']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ116']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ116']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ116']['HGT'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AQ116']['LMC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ116']['LUN'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ116']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AQ116']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ116']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ116']['PPO'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ116']['PPO2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ116']['PPO3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ116']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ116']['VCM'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ116']['VCM2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ116']['VCM3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ116']['WDAC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['AQ116']['WDAL'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AQ116']['WDAU'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AQ116']['WDH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AQ116']['WDL'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AQ116']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AQ116']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ116']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ116']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['AQ116']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ116']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AQ116']['ZI005_FNA2'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AQ116']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ116']['ZI005_GNT2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ116']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AQ116']['ZI005_NFN2'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AQ116']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AQ116']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ116']['ZI024_ASE'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AQ116']['ZI024_AWO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AQ116']['ZI024_AWOI'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AQ116']['ZI024_AWOX'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AQ116']['ZI024_CFR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AQ116']['ZI024_CLO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AQ116']['ZI024_CYN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AQ116']['ZI024_DRL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ116']['ZI024_DVPT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ116']['ZI024_FMR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AQ116']['ZI024_FRR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AQ116']['ZI024_HAR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AQ116']['ZI024_MGN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AQ116']['ZI024_PHW'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AQ116']['ZI024_PMP'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ116']['ZI024_SCC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ116']['ZI024_SUL'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AQ116']['ZI024_TDS'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AQ116']['ZI024_TEP'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AQ116']['ZI024_TUR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AQ116']['ZI024_WAC'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AQ116']['ZI024_WTNO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AQ116']['ZI024_WUR'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ116']['ZI024_WUR2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ116']['ZI024_WUR3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ116']['ZI024_WUR4'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ116']['ZI024_YWQ'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ116']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['AQ116']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ116']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ116']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ116']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ116']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['AQ116']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ116']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ116']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ116']['ZVH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AQ118'] = {}
    field_information['GGDM 3.0']['DefaultValues']['AQ118']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ118']['F_CODE'] = 'AQ118'
    field_information['GGDM 3.0']['DefaultValues']['AQ118']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ118']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ118']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ118']['LMC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ118']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AQ118']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ118']['RAD'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AQ118']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ118']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ118']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ118']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['AQ118']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ118']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AQ118']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ118']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['AQ118']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ118']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ118']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ118']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ118']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['AQ118']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ118']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ118']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ120'] = {}
    field_information['GGDM 3.0']['DefaultValues']['AQ120']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ120']['F_CODE'] = 'AQ120'
    field_information['GGDM 3.0']['DefaultValues']['AQ120']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ120']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ120']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ120']['LMC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ120']['LOG'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AQ120']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AQ120']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ120']['SGCC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['AQ120']['SGCL'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AQ120']['SGCU'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AQ120']['TRS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ120']['TRS2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ120']['TRS3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ120']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ120']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ120']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ120']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['AQ120']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ120']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AQ120']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ120']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['AQ120']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ120']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ120']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ120']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ120']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['AQ120']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ120']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ120']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ125'] = {}
    field_information['GGDM 3.0']['DefaultValues']['AQ125']['ADR'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AQ125']['AOO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AQ125']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AQ125']['ATB'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ125']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ125']['CAA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ125']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ125']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ125']['F_CODE'] = 'AQ125'
    field_information['GGDM 3.0']['DefaultValues']['AQ125']['FFN'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ125']['FFN2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ125']['FFN3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ125']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ125']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ125']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ125']['HGT'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AQ125']['HST'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ125']['HST2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ125']['HST3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ125']['LMC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ125']['LUN'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ125']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AQ125']['MUB'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ125']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ125']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ125']['SPT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ125']['SSR'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ125']['SSR2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ125']['SSR3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ125']['TRS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ125']['TRS2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ125']['TRS3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ125']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ125']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AQ125']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ125']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ125']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['AQ125']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ125']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AQ125']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ125']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AQ125']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AQ125']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ125']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['AQ125']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ125']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ125']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ125']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ125']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['AQ125']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ125']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ125']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ125']['ZVH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AQ130'] = {}
    field_information['GGDM 3.0']['DefaultValues']['AQ130']['AOO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AQ130']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AQ130']['BCC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ130']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ130']['CAA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ130']['CIW'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ130']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ130']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ130']['DZC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ130']['DZP'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AQ130']['F_CODE'] = 'AQ130'
    field_information['GGDM 3.0']['DefaultValues']['AQ130']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ130']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ130']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ130']['HCA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AQ130']['HGT'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AQ130']['HST'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ130']['HST2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ130']['HST3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ130']['LEA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AQ130']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AQ130']['OHC'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AQ130']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ130']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ130']['TRA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ130']['TRS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ130']['TRS2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ130']['TRS3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ130']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ130']['WD2'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AQ130']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AQ130']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ130']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ130']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['AQ130']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ130']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AQ130']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ130']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AQ130']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AQ130']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ130']['ZI025_HDP'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AQ130']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['AQ130']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ130']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ130']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ130']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ130']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['AQ130']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ130']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ130']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ135'] = {}
    field_information['GGDM 3.0']['DefaultValues']['AQ135']['ADR'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AQ135']['AOO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AQ135']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AQ135']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ135']['CAA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ135']['CIW'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ135']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ135']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ135']['F_CODE'] = 'AQ135'
    field_information['GGDM 3.0']['DefaultValues']['AQ135']['FFN'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ135']['FFN2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ135']['FFN3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ135']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ135']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ135']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ135']['HGT'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AQ135']['LMC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ135']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AQ135']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ135']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ135']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ135']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AQ135']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ135']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ135']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['AQ135']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ135']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AQ135']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ135']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AQ135']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AQ135']['ZI016_ROC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ135']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ135']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['AQ135']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ135']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ135']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ135']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ135']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['AQ135']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ135']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ135']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ135']['ZVH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AQ140'] = {}
    field_information['GGDM 3.0']['DefaultValues']['AQ140']['ADR'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AQ140']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AQ140']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ140']['CAA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ140']['CIW'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ140']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ140']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ140']['F_CODE'] = 'AQ140'
    field_information['GGDM 3.0']['DefaultValues']['AQ140']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ140']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ140']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ140']['LMC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ140']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AQ140']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ140']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ140']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ140']['VET'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ140']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AQ140']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ140']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ140']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['AQ140']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ140']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AQ140']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ140']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AQ140']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AQ140']['ZI016_ROC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ140']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ140']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['AQ140']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ140']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ140']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ140']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ140']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['AQ140']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ140']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ140']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ141'] = {}
    field_information['GGDM 3.0']['DefaultValues']['AQ141']['ADR'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AQ141']['AOO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AQ141']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AQ141']['AWP'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ141']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ141']['BNF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ141']['CAA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ141']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ141']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ141']['F_CODE'] = 'AQ141'
    field_information['GGDM 3.0']['DefaultValues']['AQ141']['FFN'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ141']['FFN2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ141']['FFN3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ141']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ141']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ141']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ141']['HGT'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AQ141']['LMC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ141']['LUN'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ141']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AQ141']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ141']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ141']['SSR'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ141']['SSR2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ141']['SSR3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ141']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ141']['VOI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ141']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AQ141']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ141']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ141']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['AQ141']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ141']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AQ141']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ141']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AQ141']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AQ141']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ141']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['AQ141']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ141']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ141']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ141']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ141']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['AQ141']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ141']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ141']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ141']['ZVH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AQ150'] = {}
    field_information['GGDM 3.0']['DefaultValues']['AQ150']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AQ150']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ150']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ150']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ150']['F_CODE'] = 'AQ150'
    field_information['GGDM 3.0']['DefaultValues']['AQ150']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ150']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ150']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ150']['HGT'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AQ150']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AQ150']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ150']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ150']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ150']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AQ150']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ150']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ150']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['AQ150']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ150']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AQ150']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ150']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AQ150']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AQ150']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ150']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['AQ150']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ150']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ150']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ150']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ150']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['AQ150']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ150']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ150']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ150']['ZVH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AQ151'] = {}
    field_information['GGDM 3.0']['DefaultValues']['AQ151']['AOO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AQ151']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AQ151']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ151']['CAA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ151']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ151']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ151']['F_CODE'] = 'AQ151'
    field_information['GGDM 3.0']['DefaultValues']['AQ151']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ151']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ151']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ151']['HGT'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AQ151']['LMC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ151']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AQ151']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ151']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ151']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ151']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AQ151']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ151']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ151']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['AQ151']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ151']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AQ151']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ151']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AQ151']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AQ151']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ151']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['AQ151']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ151']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ151']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ151']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ151']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['AQ151']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ151']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ151']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ151']['ZVH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AQ160'] = {}
    field_information['GGDM 3.0']['DefaultValues']['AQ160']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ160']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ160']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ160']['F_CODE'] = 'AQ160'
    field_information['GGDM 3.0']['DefaultValues']['AQ160']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ160']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ160']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ160']['HGT'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AQ160']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AQ160']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ160']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ160']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ160']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ160']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ160']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['AQ160']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ160']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AQ160']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ160']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AQ160']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AQ160']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ160']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['AQ160']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ160']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ160']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ160']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ160']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['AQ160']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ160']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ160']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ160']['ZVH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AQ161'] = {}
    field_information['GGDM 3.0']['DefaultValues']['AQ161']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ161']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ161']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ161']['F_CODE'] = 'AQ161'
    field_information['GGDM 3.0']['DefaultValues']['AQ161']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ161']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ161']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ161']['HGT'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AQ161']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AQ161']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ161']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ161']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ161']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ161']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ161']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['AQ161']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ161']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AQ161']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ161']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AQ161']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AQ161']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ161']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['AQ161']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ161']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ161']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ161']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ161']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['AQ161']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ161']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ161']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ161']['ZVH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AQ162'] = {}
    field_information['GGDM 3.0']['DefaultValues']['AQ162']['ADI'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ162']['AOO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AQ162']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ162']['CAA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ162']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ162']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ162']['F_CODE'] = 'AQ162'
    field_information['GGDM 3.0']['DefaultValues']['AQ162']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ162']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ162']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ162']['HEI'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AQ162']['HGT'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AQ162']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AQ162']['MCC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ162']['MCC2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ162']['MCC3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ162']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ162']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ162']['SSG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ162']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ162']['VOI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ162']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ162']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ162']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['AQ162']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ162']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AQ162']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ162']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AQ162']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AQ162']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ162']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['AQ162']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ162']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ162']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ162']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ162']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['AQ162']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ162']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ162']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ162']['ZVH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AQ170'] = {}
    field_information['GGDM 3.0']['DefaultValues']['AQ170']['ADR'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AQ170']['AOO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AQ170']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AQ170']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ170']['CAA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ170']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ170']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ170']['F_CODE'] = 'AQ170'
    field_information['GGDM 3.0']['DefaultValues']['AQ170']['FFN'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ170']['FFN2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ170']['FFN3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ170']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ170']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ170']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ170']['HGT'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AQ170']['LMC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ170']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AQ170']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ170']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ170']['SSR'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ170']['SSR2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ170']['SSR3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ170']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ170']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AQ170']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ170']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ170']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['AQ170']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ170']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AQ170']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ170']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AQ170']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AQ170']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ170']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['AQ170']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ170']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AQ170']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ170']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ170']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['AQ170']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ170']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ170']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AQ170']['ZVH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AT005'] = {}
    field_information['GGDM 3.0']['DefaultValues']['AT005']['AWP'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AT005']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AT005']['CAA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AT005']['CAB'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AT005']['CAB2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AT005']['CAB3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AT005']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AT005']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AT005']['CST'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AT005']['DZP'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AT005']['F_CODE'] = 'AT005'
    field_information['GGDM 3.0']['DefaultValues']['AT005']['FLO'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AT005']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AT005']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AT005']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AT005']['HGT'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AT005']['KVA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AT005']['LEA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AT005']['LMC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AT005']['LOC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AT005']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AT005']['NPL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AT005']['OHC'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AT005']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AT005']['OWO'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AT005']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AT005']['PFH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AT005']['TST'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AT005']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AT005']['VCO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AT005']['VOI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AT005']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AT005']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AT005']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['AT005']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AT005']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AT005']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AT005']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AT005']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AT005']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AT005']['ZI025_HDP'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AT005']['ZI025_WLE'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AT005']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['AT005']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AT005']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AT005']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AT005']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AT005']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['AT005']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AT005']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AT005']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AT005']['ZVH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AT010'] = {}
    field_information['GGDM 3.0']['DefaultValues']['AT010']['AOO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AT010']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AT010']['CAA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AT010']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AT010']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AT010']['F_CODE'] = 'AT010'
    field_information['GGDM 3.0']['DefaultValues']['AT010']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AT010']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AT010']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AT010']['HEI'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AT010']['HGT'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AT010']['LMC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AT010']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AT010']['MCC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AT010']['MCC2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AT010']['MCC3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AT010']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AT010']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AT010']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AT010']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AT010']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AT010']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AT010']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['AT010']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AT010']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AT010']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AT010']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AT010']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AT010']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AT010']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['AT010']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AT010']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AT010']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AT010']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AT010']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['AT010']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AT010']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AT010']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AT010']['ZVH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AT011'] = {}
    field_information['GGDM 3.0']['DefaultValues']['AT011']['AOO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AT011']['AWP'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AT011']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AT011']['CAA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AT011']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AT011']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AT011']['F_CODE'] = 'AT011'
    field_information['GGDM 3.0']['DefaultValues']['AT011']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AT011']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AT011']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AT011']['HEI'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AT011']['HGT'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AT011']['LMC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AT011']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AT011']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AT011']['RAC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AT011']['SPT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AT011']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AT011']['VOI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AT011']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AT011']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AT011']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['AT011']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AT011']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AT011']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AT011']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AT011']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AT011']['ZI018_WIT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AT011']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AT011']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['AT011']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AT011']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AT011']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AT011']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AT011']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['AT011']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AT011']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AT011']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AT011']['ZVH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AT012'] = {}
    field_information['GGDM 3.0']['DefaultValues']['AT012']['ADR'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AT012']['AOO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AT012']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AT012']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AT012']['CAA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AT012']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AT012']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AT012']['F_CODE'] = 'AT012'
    field_information['GGDM 3.0']['DefaultValues']['AT012']['FFN'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AT012']['FFN2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AT012']['FFN3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AT012']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AT012']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AT012']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AT012']['HGT'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AT012']['LMC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AT012']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AT012']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AT012']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AT012']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AT012']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AT012']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AT012']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AT012']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['AT012']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AT012']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AT012']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AT012']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AT012']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AT012']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AT012']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['AT012']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AT012']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AT012']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AT012']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AT012']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['AT012']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AT012']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AT012']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AT012']['ZVH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AT041'] = {}
    field_information['GGDM 3.0']['DefaultValues']['AT041']['AWP'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AT041']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AT041']['CAT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AT041']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AT041']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AT041']['F_CODE'] = 'AT041'
    field_information['GGDM 3.0']['DefaultValues']['AT041']['FFN'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AT041']['FFN2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AT041']['FFN3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AT041']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AT041']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AT041']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AT041']['HGT'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AT041']['LMC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AT041']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AT041']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AT041']['OWO'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AT041']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AT041']['PFH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AT041']['TST'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AT041']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AT041']['VCO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AT041']['VOI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AT041']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AT041']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AT041']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AT041']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['AT041']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AT041']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AT041']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AT041']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AT041']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AT041']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AT041']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['AT041']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AT041']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AT041']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AT041']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AT041']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['AT041']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AT041']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AT041']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AT041']['ZVH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AT042'] = {}
    field_information['GGDM 3.0']['DefaultValues']['AT042']['AOO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AT042']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AT042']['AT005_CAB'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AT042']['AT005_CAB2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AT042']['AT005_CAB3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AT042']['AWP'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AT042']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AT042']['CAA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AT042']['F_CODE'] = 'AT042'
    field_information['GGDM 3.0']['DefaultValues']['AT042']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AT042']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AT042']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AT042']['HGT'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AT042']['LMC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AT042']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AT042']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AT042']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AT042']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AT042']['VOI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AT042']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AT042']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AT042']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AT042']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['AT042']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AT042']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AT042']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AT042']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AT042']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AT042']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AT042']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['AT042']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AT042']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AT042']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AT042']['ZI032_GUG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AT042']['ZI032_PYC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AT042']['ZI032_PYM'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AT042']['ZI032_TOS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AT042']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AT042']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['AT042']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AT042']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AT042']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AT042']['ZVH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AT045'] = {}
    field_information['GGDM 3.0']['DefaultValues']['AT045']['ADR'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AT045']['AOO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AT045']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AT045']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AT045']['CAA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AT045']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AT045']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AT045']['F_CODE'] = 'AT045'
    field_information['GGDM 3.0']['DefaultValues']['AT045']['FFN'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AT045']['FFN2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AT045']['FFN3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AT045']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AT045']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AT045']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AT045']['HGT'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AT045']['LMC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AT045']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AT045']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AT045']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AT045']['PRM'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AT045']['RAS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AT045']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AT045']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['AT045']['YSU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AT045']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AT045']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AT045']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['AT045']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AT045']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AT045']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AT045']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AT045']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['AT045']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AT045']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['AT045']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AT045']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['AT045']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AT045']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AT045']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['AT045']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AT045']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AT045']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['AT045']['ZVH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BA010'] = {}
    field_information['GGDM 3.0']['DefaultValues']['BA010']['AZC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BA010']['BA000_VDC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BA010']['BA000_VDR'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BA010']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BA010']['F_CODE'] = 'BA010'
    field_information['GGDM 3.0']['DefaultValues']['BA010']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BA010']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BA010']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BA010']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BA010']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BA010']['SHD'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BA010']['SHO'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BA010']['SLT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BA010']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BA010']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BA010']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BA010']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['BA010']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BA010']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BA010']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BA010']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BA010']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BA010']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BA010']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['BA010']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BA010']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BA010']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BA010']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BA010']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['BA010']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BA010']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BA010']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BA023'] = {}
    field_information['GGDM 3.0']['DefaultValues']['BA023']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BA023']['F_CODE'] = 'BA023'
    field_information['GGDM 3.0']['DefaultValues']['BA023']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BA023']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BA023']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BA023']['MBC_MCC1'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BA023']['MBC_MCC2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BA023']['MBC_PSC1'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BA023']['MBC_PSC2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BA023']['MBC_SCO1'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BA023']['MBC_SCO2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BA023']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BA023']['STP'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BA023']['SWC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BA023']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BA023']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BA023']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BA023']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['BA023']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BA023']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BA023']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BA023']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BA023']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BA023']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BA023']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['BA023']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BA023']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BA023']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BA023']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BA023']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['BA023']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BA023']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BA023']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BA024'] = {}
    field_information['GGDM 3.0']['DefaultValues']['BA024']['AZC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BA024']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BA024']['F_CODE'] = 'BA024'
    field_information['GGDM 3.0']['DefaultValues']['BA024']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BA024']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BA024']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BA024']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BA024']['SLT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BA024']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BA024']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BA024']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BA024']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['BA024']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BA024']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BA024']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BA024']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['BA024']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BA024']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BA024']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BA024']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BA024']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['BA024']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BA024']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BA024']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BA030'] = {}
    field_information['GGDM 3.0']['DefaultValues']['BA030']['AOO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BA030']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BA030']['BA000_VDC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BA030']['BA000_VDR'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BA030']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BA030']['F_CODE'] = 'BA030'
    field_information['GGDM 3.0']['DefaultValues']['BA030']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BA030']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BA030']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BA030']['HGT'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BA030']['LMC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BA030']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BA030']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BA030']['SHD'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BA030']['SLT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BA030']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BA030']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BA030']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BA030']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BA030']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['BA030']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BA030']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BA030']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BA030']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BA030']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BA030']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BA030']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['BA030']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BA030']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BA030']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BA030']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BA030']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['BA030']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BA030']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BA030']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BA030']['ZVH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BA040'] = {}
    field_information['GGDM 3.0']['DefaultValues']['BA040']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BA040']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BA040']['BMC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BA040']['BMC2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BA040']['BMC3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BA040']['DOXY'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BA040']['F_CODE'] = 'BA040'
    field_information['GGDM 3.0']['DefaultValues']['BA040']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BA040']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BA040']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BA040']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BA040']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BA040']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BA040']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BA040']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BA040']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BA040']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['BA040']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BA040']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BA040']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BA040']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BA040']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BA040']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BA040']['ZI024_ASE'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BA040']['ZI024_CFR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BA040']['ZI024_CLO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BA040']['ZI024_CYN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BA040']['ZI024_FMR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BA040']['ZI024_FRR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BA040']['ZI024_HAR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BA040']['ZI024_MGN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BA040']['ZI024_PHW'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BA040']['ZI024_SCC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BA040']['ZI024_SUL'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BA040']['ZI024_TDS'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BA040']['ZI024_TEP'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BA040']['ZI024_TUR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BA040']['ZI024_WAC'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BA040']['ZI024_WTNO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BA040']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['BA040']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BA040']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BA040']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BA040']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BA040']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['BA040']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BA040']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BA040']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BA050'] = {}
    field_information['GGDM 3.0']['DefaultValues']['BA050']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BA050']['F_CODE'] = 'BA050'
    field_information['GGDM 3.0']['DefaultValues']['BA050']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BA050']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BA050']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BA050']['MBC_MCC1'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BA050']['MBC_MCC2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BA050']['MBC_PSC1'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BA050']['MBC_PSC2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BA050']['MBC_SCO1'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BA050']['MBC_SCO2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BA050']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BA050']['STP'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BA050']['SWC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BA050']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BA050']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BA050']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BA050']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['BA050']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BA050']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BA050']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BA050']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BA050']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BA050']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BA050']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['BA050']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BA050']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BA050']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BA050']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BA050']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['BA050']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BA050']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BA050']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB005'] = {}
    field_information['GGDM 3.0']['DefaultValues']['BB005']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BB005']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB005']['CAA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BB005']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB005']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BB005']['F_CODE'] = 'BB005'
    field_information['GGDM 3.0']['DefaultValues']['BB005']['FHC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BB005']['FHC2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BB005']['FHC3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BB005']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB005']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB005']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BB005']['LMC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BB005']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BB005']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB005']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BB005']['TID'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BB005']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB005']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BB005']['WPI'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BB005']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB005']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BB005']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['BB005']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BB005']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BB005']['ZI005_FNA2'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BB005']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BB005']['ZI005_GNT2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BB005']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BB005']['ZI005_NFN2'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BB005']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BB005']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB005']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['BB005']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BB005']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BB005']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB005']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB005']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['BB005']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB005']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB005']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB008'] = {}
    field_information['GGDM 3.0']['DefaultValues']['BB008']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BB008']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB008']['CAA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BB008']['DOXY'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BB008']['F_CODE'] = 'BB008'
    field_information['GGDM 3.0']['DefaultValues']['BB008']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB008']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB008']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BB008']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BB008']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB008']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB008']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BB008']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB008']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BB008']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['BB008']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BB008']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BB008']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB008']['ZI024_ASE'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BB008']['ZI024_CFR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BB008']['ZI024_CLO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BB008']['ZI024_CYN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BB008']['ZI024_FMR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BB008']['ZI024_FRR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BB008']['ZI024_HAR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BB008']['ZI024_HYP'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BB008']['ZI024_MGN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BB008']['ZI024_PHW'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BB008']['ZI024_SCC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BB008']['ZI024_SUL'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BB008']['ZI024_TDS'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BB008']['ZI024_TEP'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BB008']['ZI024_TUR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BB008']['ZI024_WAC'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BB008']['ZI024_WTNO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BB008']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['BB008']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BB008']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BB008']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB008']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB008']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['BB008']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB008']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB008']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB009'] = {}
    field_information['GGDM 3.0']['DefaultValues']['BB009']['ADR'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BB009']['AOO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BB009']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BB009']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB009']['CAA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BB009']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB009']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BB009']['F_CODE'] = 'BB009'
    field_information['GGDM 3.0']['DefaultValues']['BB009']['FFN'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BB009']['FFN2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BB009']['FFN3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BB009']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB009']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB009']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BB009']['HGT'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BB009']['LMC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BB009']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BB009']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB009']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BB009']['TID'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BB009']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB009']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BB009']['WPI'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BB009']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB009']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BB009']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['BB009']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BB009']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BB009']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BB009']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BB009']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BB009']['ZI014_PBY'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BB009']['ZI014_PBY2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BB009']['ZI014_PBY3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BB009']['ZI014_PPO'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BB009']['ZI014_PPO2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BB009']['ZI014_PPO3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BB009']['ZI014_PRW'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BB009']['ZI014_PRW2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BB009']['ZI014_PRW3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BB009']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB009']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['BB009']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BB009']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BB009']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB009']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB009']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['BB009']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB009']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB009']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB009']['ZVH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BB010'] = {}
    field_information['GGDM 3.0']['DefaultValues']['BB010']['ACH'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BB010']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BB010']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB010']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB010']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BB010']['F_CODE'] = 'BB010'
    field_information['GGDM 3.0']['DefaultValues']['BB010']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB010']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB010']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BB010']['HDP'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BB010']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB010']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BB010']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB010']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB010']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BB010']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['BB010']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BB010']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BB010']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BB010']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BB010']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BB010']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB010']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['BB010']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BB010']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BB010']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB010']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB010']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['BB010']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB010']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB010']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB019'] = {}
    field_information['GGDM 3.0']['DefaultValues']['BB019']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB019']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB019']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BB019']['F_CODE'] = 'BB019'
    field_information['GGDM 3.0']['DefaultValues']['BB019']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB019']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB019']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BB019']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB019']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BB019']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB019']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB019']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BB019']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['BB019']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BB019']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BB019']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BB019']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BB019']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BB019']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB019']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['BB019']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BB019']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BB019']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB019']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB019']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['BB019']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB019']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB019']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB020'] = {}
    field_information['GGDM 3.0']['DefaultValues']['BB020']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB020']['BER'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BB020']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB020']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BB020']['F_CODE'] = 'BB020'
    field_information['GGDM 3.0']['DefaultValues']['BB020']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB020']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB020']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BB020']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB020']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BB020']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB020']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB020']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BB020']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['BB020']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BB020']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BB020']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB020']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['BB020']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BB020']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BB020']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB020']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB020']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['BB020']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB020']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB020']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB050'] = {}
    field_information['GGDM 3.0']['DefaultValues']['BB050']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB050']['DF1'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BB050']['DF2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BB050']['DF3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BB050']['DF4'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BB050']['F_CODE'] = 'BB050'
    field_information['GGDM 3.0']['DefaultValues']['BB050']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB050']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB050']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BB050']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB050']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB050']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB050']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BB050']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['BB050']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BB050']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BB050']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BB050']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BB050']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BB050']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB050']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['BB050']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BB050']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BB050']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB050']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB050']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['BB050']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB050']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB050']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB080'] = {}
    field_information['GGDM 3.0']['DefaultValues']['BB080']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BB080']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB080']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB080']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BB080']['F_CODE'] = 'BB080'
    field_information['GGDM 3.0']['DefaultValues']['BB080']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB080']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB080']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BB080']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BB080']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB080']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BB080']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB080']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB080']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BB080']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['BB080']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BB080']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BB080']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BB080']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BB080']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BB080']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB080']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['BB080']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BB080']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BB080']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB080']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB080']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['BB080']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB080']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB080']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB081'] = {}
    field_information['GGDM 3.0']['DefaultValues']['BB081']['AOO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BB081']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BB081']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB081']['CAA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BB081']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB081']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BB081']['F_CODE'] = 'BB081'
    field_information['GGDM 3.0']['DefaultValues']['BB081']['FAC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BB081']['FFN'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BB081']['FFN2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BB081']['FFN3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BB081']['FLO'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BB081']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB081']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB081']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BB081']['HGT'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BB081']['LMC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BB081']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BB081']['MCC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BB081']['MCC2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BB081']['MCC3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BB081']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB081']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BB081']['PWC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BB081']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB081']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BB081']['WLE'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BB081']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB081']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BB081']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['BB081']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BB081']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BB081']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BB081']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BB081']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BB081']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB081']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['BB081']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BB081']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BB081']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB081']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB081']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['BB081']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB081']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB081']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB081']['ZVH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BB082'] = {}
    field_information['GGDM 3.0']['DefaultValues']['BB082']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BB082']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB082']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB082']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BB082']['F_CODE'] = 'BB082'
    field_information['GGDM 3.0']['DefaultValues']['BB082']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB082']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB082']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BB082']['HGT'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BB082']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BB082']['MCC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BB082']['MCC2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BB082']['MCC3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BB082']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB082']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BB082']['SGCC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['BB082']['SGCL'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BB082']['SGCU'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BB082']['SLR'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BB082']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB082']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BB082']['WLE'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BB082']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB082']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BB082']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['BB082']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BB082']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BB082']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BB082']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BB082']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BB082']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB082']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['BB082']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BB082']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BB082']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB082']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB082']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['BB082']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB082']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB082']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB082']['ZVH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BB090'] = {}
    field_information['GGDM 3.0']['DefaultValues']['BB090']['AOO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BB090']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BB090']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB090']['CAA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BB090']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB090']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BB090']['DZP'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BB090']['F_CODE'] = 'BB090'
    field_information['GGDM 3.0']['DefaultValues']['BB090']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB090']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB090']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BB090']['HGT'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BB090']['LMC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BB090']['LNU'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BB090']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BB090']['MCC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BB090']['MCC2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BB090']['MCC3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BB090']['MWD'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BB090']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB090']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BB090']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB090']['WDU'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BB090']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BB090']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB090']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BB090']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['BB090']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BB090']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BB090']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BB090']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BB090']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BB090']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB090']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['BB090']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BB090']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BB090']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB090']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB090']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['BB090']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB090']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB090']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB090']['ZVH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BB100'] = {}
    field_information['GGDM 3.0']['DefaultValues']['BB100']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BB100']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB100']['F_CODE'] = 'BB100'
    field_information['GGDM 3.0']['DefaultValues']['BB100']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB100']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB100']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BB100']['HGT'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BB100']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BB100']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB100']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BB100']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB100']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BB100']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB100']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BB100']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['BB100']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BB100']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BB100']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BB100']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BB100']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BB100']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB100']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['BB100']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BB100']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BB100']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB100']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB100']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['BB100']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB100']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB100']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB110'] = {}
    field_information['GGDM 3.0']['DefaultValues']['BB110']['AOO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BB110']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB110']['CAA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BB110']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB110']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BB110']['F_CODE'] = 'BB110'
    field_information['GGDM 3.0']['DefaultValues']['BB110']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB110']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB110']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BB110']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BB110']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB110']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BB110']['PSE'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB110']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB110']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB110']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BB110']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['BB110']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BB110']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BB110']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BB110']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BB110']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BB110']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB110']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['BB110']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BB110']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BB110']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB110']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB110']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['BB110']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB110']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB110']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB115'] = {}
    field_information['GGDM 3.0']['DefaultValues']['BB115']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BB115']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB115']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB115']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BB115']['F_CODE'] = 'BB115'
    field_information['GGDM 3.0']['DefaultValues']['BB115']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB115']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB115']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BB115']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BB115']['MCC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BB115']['MCC2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BB115']['MCC3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BB115']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB115']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BB115']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB115']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BB115']['WLE'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BB115']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB115']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BB115']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['BB115']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BB115']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BB115']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BB115']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BB115']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BB115']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB115']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['BB115']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BB115']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BB115']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB115']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB115']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['BB115']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB115']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB115']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB150'] = {}
    field_information['GGDM 3.0']['DefaultValues']['BB150']['AZC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BB150']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB150']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB150']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BB150']['F_CODE'] = 'BB150'
    field_information['GGDM 3.0']['DefaultValues']['BB150']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB150']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB150']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BB150']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB150']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BB150']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB150']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB150']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BB150']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['BB150']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BB150']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BB150']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB150']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['BB150']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BB150']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BB150']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB150']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB150']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['BB150']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB150']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB150']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB155'] = {}
    field_information['GGDM 3.0']['DefaultValues']['BB155']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BB155']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB155']['CAA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BB155']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB155']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BB155']['F_CODE'] = 'BB155'
    field_information['GGDM 3.0']['DefaultValues']['BB155']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB155']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB155']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BB155']['HGT'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BB155']['LMC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BB155']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BB155']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB155']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BB155']['STA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BB155']['STA2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BB155']['STA3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BB155']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB155']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BB155']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB155']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BB155']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['BB155']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BB155']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BB155']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BB155']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BB155']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BB155']['ZI018_BRF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BB155']['ZI018_WIT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BB155']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB155']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['BB155']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BB155']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BB155']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB155']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB155']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['BB155']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB155']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB155']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB199'] = {}
    field_information['GGDM 3.0']['DefaultValues']['BB199']['AOO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BB199']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BB199']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB199']['CAA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BB199']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB199']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BB199']['DZP'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BB199']['F_CODE'] = 'BB199'
    field_information['GGDM 3.0']['DefaultValues']['BB199']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB199']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB199']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BB199']['HGT'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BB199']['LMC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BB199']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BB199']['MCC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BB199']['MCC2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BB199']['MWD'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BB199']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB199']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BB199']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB199']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BB199']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB199']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BB199']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['BB199']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BB199']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BB199']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BB199']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BB199']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BB199']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB199']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['BB199']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BB199']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BB199']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB199']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB199']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['BB199']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB199']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB199']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB199']['ZVH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BB201'] = {}
    field_information['GGDM 3.0']['DefaultValues']['BB201']['ADR'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BB201']['AOO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BB201']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BB201']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB201']['CAA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BB201']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB201']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BB201']['F_CODE'] = 'BB201'
    field_information['GGDM 3.0']['DefaultValues']['BB201']['FFN'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BB201']['FFN2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BB201']['FFN3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BB201']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB201']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB201']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BB201']['HGT'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BB201']['LMC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BB201']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BB201']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB201']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BB201']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB201']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BB201']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB201']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BB201']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['BB201']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BB201']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BB201']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BB201']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BB201']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BB201']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB201']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['BB201']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BB201']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BB201']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB201']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB201']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['BB201']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB201']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB201']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB201']['ZVH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BB241'] = {}
    field_information['GGDM 3.0']['DefaultValues']['BB241']['ADR'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BB241']['AOO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BB241']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BB241']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB241']['CAA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BB241']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB241']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BB241']['F_CODE'] = 'BB241'
    field_information['GGDM 3.0']['DefaultValues']['BB241']['FFN'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BB241']['FFN2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BB241']['FFN3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BB241']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB241']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB241']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BB241']['HGT'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BB241']['LMC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BB241']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BB241']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB241']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BB241']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB241']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BB241']['YSU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BB241']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB241']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BB241']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['BB241']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BB241']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BB241']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BB241']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BB241']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BB241']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB241']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['BB241']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BB241']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BB241']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB241']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB241']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['BB241']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB241']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB241']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BB241']['ZVH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BC010'] = {}
    field_information['GGDM 3.0']['DefaultValues']['BC010']['BC040_COL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BC010']['BC040_MLR'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BC010']['BC101_SST'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BC010']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BC010']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BC010']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BC010']['F_CODE'] = 'BC010'
    field_information['GGDM 3.0']['DefaultValues']['BC010']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BC010']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BC010']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BC010']['NMC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BC010']['NMC2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BC010']['NMC3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BC010']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BC010']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BC010']['REF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BC010']['TZP'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BC010']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BC010']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BC010']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BC010']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['BC010']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BC010']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BC010']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BC010']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BC010']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BC010']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BC010']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['BC010']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BC010']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BC010']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BC010']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BC010']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['BC010']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BC010']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BC010']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BC020'] = {}
    field_information['GGDM 3.0']['DefaultValues']['BC020']['BC034_BRF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BC020']['BC034_BRF2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BC020']['BC034_MRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BC020']['BC034_MRT2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BC020']['BC034_MRT3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BC020']['BC040_COL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BC020']['BC040_EOL'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BC020']['BC040_LVN'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BC020']['BC040_MLR'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BC020']['BC101_SST'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BC020']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BC020']['BUS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BC020']['BUT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BC020']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BC020']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BC020']['CSS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BC020']['F_CODE'] = 'BC020'
    field_information['GGDM 3.0']['DefaultValues']['BC020']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BC020']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BC020']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BC020']['NMC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BC020']['NMC2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BC020']['NMC3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BC020']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BC020']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BC020']['REF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BC020']['TZP'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BC020']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BC020']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BC020']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BC020']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['BC020']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BC020']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BC020']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BC020']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BC020']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BC020']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BC020']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['BC020']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BC020']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BC020']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BC020']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BC020']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['BC020']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BC020']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BC020']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BC034'] = {}
    field_information['GGDM 3.0']['DefaultValues']['BC034']['BC010_REF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BC034']['BC010_TZP'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BC034']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BC034']['BRF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BC034']['BRF2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BC034']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BC034']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BC034']['F_CODE'] = 'BC034'
    field_information['GGDM 3.0']['DefaultValues']['BC034']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BC034']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BC034']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BC034']['MRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BC034']['ORC'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BC034']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BC034']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BC034']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BC034']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BC034']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BC034']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['BC034']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BC034']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BC034']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BC034']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BC034']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BC034']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BC034']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['BC034']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BC034']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BC034']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BC034']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BC034']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['BC034']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BC034']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BC034']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BC040'] = {}
    field_information['GGDM 3.0']['DefaultValues']['BC040']['BC010_REF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BC040']['BC010_TZP'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BC040']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BC040']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BC040']['COL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BC040']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BC040']['EOL'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BC040']['F_CODE'] = 'BC040'
    field_information['GGDM 3.0']['DefaultValues']['BC040']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BC040']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BC040']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BC040']['IAA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BC040']['LFC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BC040']['LFC2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BC040']['LFC3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BC040']['LVN'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BC040']['MLR'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BC040']['NMC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BC040']['NMC2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BC040']['NMC3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BC040']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BC040']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BC040']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BC040']['VOI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BC040']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BC040']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BC040']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['BC040']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BC040']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BC040']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BC040']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BC040']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BC040']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BC040']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['BC040']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BC040']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BC040']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BC040']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BC040']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['BC040']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BC040']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BC040']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BC041'] = {}
    field_information['GGDM 3.0']['DefaultValues']['BC041']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BC041']['BC034_BRF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BC041']['BC034_BRF2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BC041']['BC034_MRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BC041']['BC034_MRT2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BC041']['BC034_MRT3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BC041']['BC040_COL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BC041']['BC040_MLR'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BC041']['BC101_SST'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BC041']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BC041']['CAA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BC041']['CCR'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BC041']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BC041']['COC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BC041']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BC041']['CPT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BC041']['DKS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BC041']['F_CODE'] = 'BC041'
    field_information['GGDM 3.0']['DefaultValues']['BC041']['FLT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BC041']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BC041']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BC041']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BC041']['GUG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BC041']['HGT'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BC041']['IAA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BC041']['IAS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BC041']['LOC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BC041']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BC041']['MCC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BC041']['MRP'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BC041']['NSC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BC041']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BC041']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BC041']['PRM'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BC041']['REF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BC041']['SPT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BC041']['SRL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BC041']['TOS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BC041']['TZP'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BC041']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BC041']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BC041']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BC041']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BC041']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['BC041']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BC041']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BC041']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BC041']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['BC041']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BC041']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BC041']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BC041']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BC041']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['BC041']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BC041']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BC041']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BC041']['ZVH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BC050'] = {}
    field_information['GGDM 3.0']['DefaultValues']['BC050']['ADR'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BC050']['AOO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BC050']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BC050']['ATB'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BC050']['AWP'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BC050']['BC040_LCN'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BC050']['BC040_PER'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BC050']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BC050']['CAA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BC050']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BC050']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BC050']['F_CODE'] = 'BC050'
    field_information['GGDM 3.0']['DefaultValues']['BC050']['FFN'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BC050']['FFN2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BC050']['FFN3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BC050']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BC050']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BC050']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BC050']['HGT'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BC050']['LMC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BC050']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BC050']['MAN'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BC050']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BC050']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BC050']['SSR'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BC050']['SSR2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BC050']['SSR3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BC050']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BC050']['VCM'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BC050']['VCM2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BC050']['VCM3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BC050']['VOI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BC050']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BC050']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BC050']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BC050']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['BC050']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BC050']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BC050']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BC050']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BC050']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BC050']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BC050']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['BC050']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BC050']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BC050']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BC050']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BC050']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['BC050']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BC050']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BC050']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BC050']['ZVH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BC055'] = {}
    field_information['GGDM 3.0']['DefaultValues']['BC055']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BC055']['F_CODE'] = 'BC055'
    field_information['GGDM 3.0']['DefaultValues']['BC055']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BC055']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BC055']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BC055']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BC055']['MCC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BC055']['MCC2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BC055']['MCC3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BC055']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BC055']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BC055']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BC055']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BC055']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BC055']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['BC055']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BC055']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BC055']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BC055']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BC055']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BC055']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BC055']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['BC055']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BC055']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BC055']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BC055']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BC055']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['BC055']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BC055']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BC055']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BC060'] = {}
    field_information['GGDM 3.0']['DefaultValues']['BC060']['BC040_CAA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BC060']['BC040_ZVH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BC060']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BC060']['COL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BC060']['F_CODE'] = 'BC060'
    field_information['GGDM 3.0']['DefaultValues']['BC060']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BC060']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BC060']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BC060']['LSA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BC060']['LSI'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BC060']['LST'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BC060']['LVN'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BC060']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BC060']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BC060']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BC060']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BC060']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['BC060']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BC060']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BC060']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BC060']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['BC060']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BC060']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BC060']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BC060']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BC060']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['BC060']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BC060']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BC060']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BC070'] = {}
    field_information['GGDM 3.0']['DefaultValues']['BC070']['AOO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BC070']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BC070']['AWP'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BC070']['BC034_BRF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BC070']['BC034_BRF2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BC070']['BC034_MRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BC070']['BC034_MRT2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BC070']['BC034_MRT3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BC070']['BC040_COL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BC070']['BC040_EOL'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BC070']['BC040_LVN'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BC070']['BC040_MLR'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BC070']['BC101_SST'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BC070']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BC070']['CAA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BC070']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BC070']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BC070']['F_CODE'] = 'BC070'
    field_information['GGDM 3.0']['DefaultValues']['BC070']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BC070']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BC070']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BC070']['HGT'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BC070']['LMC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BC070']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BC070']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BC070']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BC070']['REF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BC070']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BC070']['VOI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BC070']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BC070']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BC070']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BC070']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['BC070']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BC070']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BC070']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BC070']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BC070']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BC070']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BC070']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['BC070']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BC070']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BC070']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BC070']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BC070']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['BC070']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BC070']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BC070']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BC070']['ZVH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BC080'] = {}
    field_information['GGDM 3.0']['DefaultValues']['BC080']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BC080']['BET'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BC080']['F_CODE'] = 'BC080'
    field_information['GGDM 3.0']['DefaultValues']['BC080']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BC080']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BC080']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BC080']['HBH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BC080']['HGT'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BC080']['MCC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BC080']['MCC2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BC080']['MCC3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BC080']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BC080']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BC080']['TZP'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BC080']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BC080']['ZHBH_DCR'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BC080']['ZHBH_DKC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BC080']['ZHBH_DKC2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BC080']['ZHBH_DKC3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BC080']['ZHBH_SVC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BC080']['ZHBH_TEC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BC080']['ZHBH_TEC2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BC080']['ZHBH_TEC3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BC080']['ZHBH_VDC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BC080']['ZHBH_VDR'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BC080']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BC080']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BC080']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['BC080']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BC080']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BC080']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BC080']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BC080']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BC080']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BC080']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['BC080']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BC080']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BC080']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BC080']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BC080']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['BC080']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BC080']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BC080']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BC080']['ZVH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BD020'] = {}
    field_information['GGDM 3.0']['DefaultValues']['BD020']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BD020']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BD020']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BD020']['F_CODE'] = 'BD020'
    field_information['GGDM 3.0']['DefaultValues']['BD020']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BD020']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BD020']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BD020']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BD020']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BD020']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BD020']['ZHBH_TEC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BD020']['ZHBH_TEC2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BD020']['ZHBH_TEC3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BD020']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BD020']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BD020']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['BD020']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BD020']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BD020']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BD020']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BD020']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BD020']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BD020']['ZI025_HDP'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BD020']['ZI025_WLE'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BD020']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['BD020']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BD020']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BD020']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BD020']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BD020']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['BD020']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BD020']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BD020']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BD030'] = {}
    field_information['GGDM 3.0']['DefaultValues']['BD030']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BD030']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BD030']['F_CODE'] = 'BD030'
    field_information['GGDM 3.0']['DefaultValues']['BD030']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BD030']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BD030']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BD030']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BD030']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BD030']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BD030']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BD030']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BD030']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BD030']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['BD030']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BD030']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BD030']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BD030']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BD030']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BD030']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BD030']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['BD030']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BD030']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BD030']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BD030']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BD030']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['BD030']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BD030']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BD030']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BD050'] = {}
    field_information['GGDM 3.0']['DefaultValues']['BD050']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BD050']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BD050']['DTN'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BD050']['F_CODE'] = 'BD050'
    field_information['GGDM 3.0']['DefaultValues']['BD050']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BD050']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BD050']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BD050']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BD050']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BD050']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BD050']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BD050']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BD050']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BD050']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['BD050']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BD050']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BD050']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BD050']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BD050']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BD050']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BD050']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['BD050']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BD050']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BD050']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BD050']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BD050']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['BD050']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BD050']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BD050']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BD061'] = {}
    field_information['GGDM 3.0']['DefaultValues']['BD061']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BD061']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BD061']['DTN'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BD061']['F_CODE'] = 'BD061'
    field_information['GGDM 3.0']['DefaultValues']['BD061']['FLO'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BD061']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BD061']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BD061']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BD061']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BD061']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BD061']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BD061']['VSP'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BD061']['VSP2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BD061']['VSP3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BD061']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BD061']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BD061']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BD061']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['BD061']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BD061']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BD061']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BD061']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BD061']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BD061']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BD061']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['BD061']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BD061']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BD061']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BD061']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BD061']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['BD061']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BD061']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BD061']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BD100'] = {}
    field_information['GGDM 3.0']['DefaultValues']['BD100']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BD100']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BD100']['F_CODE'] = 'BD100'
    field_information['GGDM 3.0']['DefaultValues']['BD100']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BD100']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BD100']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BD100']['HGT'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BD100']['LMC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BD100']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BD100']['MCC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BD100']['MCC2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BD100']['MCC3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BD100']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BD100']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BD100']['PLC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BD100']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BD100']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BD100']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BD100']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BD100']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['BD100']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BD100']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BD100']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BD100']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BD100']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BD100']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BD100']['ZI025_HDP'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BD100']['ZI025_WLE'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BD100']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['BD100']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BD100']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BD100']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BD100']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BD100']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['BD100']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BD100']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BD100']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BD100']['ZVH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BD115'] = {}
    field_information['GGDM 3.0']['DefaultValues']['BD115']['AOO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BD115']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BD115']['AWP'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BD115']['BC034_MRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BD115']['BC034_MRT2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BD115']['BC034_MRT3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BD115']['BC101_SST'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BD115']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BD115']['CAA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BD115']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BD115']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BD115']['F_CODE'] = 'BD115'
    field_information['GGDM 3.0']['DefaultValues']['BD115']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BD115']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BD115']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BD115']['HGT'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BD115']['LMC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BD115']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BD115']['OCS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BD115']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BD115']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BD115']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BD115']['VCM'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BD115']['VCM2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BD115']['VCM3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BD115']['VOI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BD115']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BD115']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BD115']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BD115']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['BD115']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BD115']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BD115']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BD115']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BD115']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BD115']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BD115']['ZI025_HDP'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BD115']['ZI025_MAN'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BD115']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['BD115']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BD115']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BD115']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BD115']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BD115']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['BD115']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BD115']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BD115']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BD115']['ZVH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BD120'] = {}
    field_information['GGDM 3.0']['DefaultValues']['BD120']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BD120']['F_CODE'] = 'BD120'
    field_information['GGDM 3.0']['DefaultValues']['BD120']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BD120']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BD120']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BD120']['MCC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BD120']['MCC2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BD120']['MCC3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BD120']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BD120']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BD120']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BD120']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BD120']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['BD120']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BD120']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BD120']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BD120']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BD120']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BD120']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BD120']['ZI025_HDP'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BD120']['ZI025_WLE'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BD120']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['BD120']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BD120']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BD120']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BD120']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BD120']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['BD120']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BD120']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BD120']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BD130'] = {}
    field_information['GGDM 3.0']['DefaultValues']['BD130']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BD130']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BD130']['F_CODE'] = 'BD130'
    field_information['GGDM 3.0']['DefaultValues']['BD130']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BD130']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BD130']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BD130']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BD130']['MCC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BD130']['MCC2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BD130']['MCC3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BD130']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BD130']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BD130']['ZHBH_TEC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BD130']['ZHBH_TEC2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BD130']['ZHBH_TEC3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BD130']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BD130']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BD130']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['BD130']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BD130']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BD130']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BD130']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BD130']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BD130']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BD130']['ZI025_HDP'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BD130']['ZI025_UHS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BD130']['ZI025_WLE'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BD130']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['BD130']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BD130']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BD130']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BD130']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BD130']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['BD130']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BD130']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BD130']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BD140'] = {}
    field_information['GGDM 3.0']['DefaultValues']['BD140']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BD140']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BD140']['F_CODE'] = 'BD140'
    field_information['GGDM 3.0']['DefaultValues']['BD140']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BD140']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BD140']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BD140']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BD140']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BD140']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BD140']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BD140']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BD140']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BD140']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['BD140']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BD140']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BD140']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BD140']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BD140']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BD140']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BD140']['ZI025_HDP'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BD140']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['BD140']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BD140']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BD140']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BD140']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BD140']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['BD140']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BD140']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BD140']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BD180'] = {}
    field_information['GGDM 3.0']['DefaultValues']['BD180']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BD180']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BD180']['DKC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BD180']['DKC2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BD180']['DKC3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BD180']['DTN'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BD180']['F_CODE'] = 'BD180'
    field_information['GGDM 3.0']['DefaultValues']['BD180']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BD180']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BD180']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BD180']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BD180']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BD180']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BD180']['WLO'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BD180']['ZHBH_TEC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BD180']['ZHBH_TEC2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BD180']['ZHBH_TEC3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BD180']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BD180']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BD180']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['BD180']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BD180']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BD180']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BD180']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BD180']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BD180']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BD180']['ZI025_HDP'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BD180']['ZI025_WLE'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BD180']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['BD180']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BD180']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BD180']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BD180']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BD180']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['BD180']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BD180']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BD180']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BD181'] = {}
    field_information['GGDM 3.0']['DefaultValues']['BD181']['AOO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BD181']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BD181']['AWP'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BD181']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BD181']['CAA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BD181']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BD181']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BD181']['F_CODE'] = 'BD181'
    field_information['GGDM 3.0']['DefaultValues']['BD181']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BD181']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BD181']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BD181']['HGT'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BD181']['LMC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BD181']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BD181']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BD181']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BD181']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BD181']['VOI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BD181']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BD181']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BD181']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BD181']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['BD181']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BD181']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BD181']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BD181']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BD181']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BD181']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BD181']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['BD181']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BD181']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BD181']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BD181']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BD181']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['BD181']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BD181']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BD181']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BD181']['ZVH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BE010'] = {}
    field_information['GGDM 3.0']['DefaultValues']['BE010']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BE010']['CRV'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BE010']['F_CODE'] = 'BE010'
    field_information['GGDM 3.0']['DefaultValues']['BE010']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BE010']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BE010']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BE010']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BE010']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BE010']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BE010']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BE010']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['BE010']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BE010']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BE010']['ZI012_DCR'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BE010']['ZI012_DKC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BE010']['ZI012_DKC2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BE010']['ZI012_DKC3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BE010']['ZI012_SVC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BE010']['ZI012_TEC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BE010']['ZI012_TEC2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BE010']['ZI012_TEC3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BE010']['ZI012_VDC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BE010']['ZI012_VDR'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BE010']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BE010']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['BE010']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BE010']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BE010']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BE010']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BE010']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['BE010']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BE010']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BE010']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BE015'] = {}
    field_information['GGDM 3.0']['DefaultValues']['BE015']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BE015']['CRV'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BE015']['F_CODE'] = 'BE015'
    field_information['GGDM 3.0']['DefaultValues']['BE015']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BE015']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BE015']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BE015']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BE015']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BE015']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BE015']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BE015']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['BE015']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BE015']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BE015']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BE015']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['BE015']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BE015']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BE015']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BE015']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BE015']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['BE015']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BE015']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BE015']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BE019'] = {}
    field_information['GGDM 3.0']['DefaultValues']['BE019']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BE019']['F_CODE'] = 'BE019'
    field_information['GGDM 3.0']['DefaultValues']['BE019']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BE019']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BE019']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BE019']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BE019']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BE019']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BE019']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BE019']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['BE019']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BE019']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BE019']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BE019']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['BE019']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BE019']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BE019']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BE019']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BE019']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['BE019']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BE019']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BE019']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BE020'] = {}
    field_information['GGDM 3.0']['DefaultValues']['BE020']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BE020']['F_CODE'] = 'BE020'
    field_information['GGDM 3.0']['DefaultValues']['BE020']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BE020']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BE020']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BE020']['HDH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BE020']['HDP'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BE020']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BE020']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BE020']['ZHDP_SVC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BE020']['ZHDP_TEC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BE020']['ZHDP_TEC2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BE020']['ZHDP_TEC3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BE020']['ZHDP_VDC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BE020']['ZHDP_VDR'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BE020']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BE020']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BE020']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['BE020']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BE020']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BE020']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BE020']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['BE020']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BE020']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BE020']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BE020']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BE020']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['BE020']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BE020']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BE020']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BE050'] = {}
    field_information['GGDM 3.0']['DefaultValues']['BE050']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BE050']['F_CODE'] = 'BE050'
    field_information['GGDM 3.0']['DefaultValues']['BE050']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BE050']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BE050']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BE050']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BE050']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BE050']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BE050']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BE050']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['BE050']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BE050']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BE050']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BE050']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['BE050']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BE050']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BE050']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BE050']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BE050']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['BE050']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BE050']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BE050']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BF010'] = {}
    field_information['GGDM 3.0']['DefaultValues']['BF010']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BF010']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BF010']['F_CODE'] = 'BF010'
    field_information['GGDM 3.0']['DefaultValues']['BF010']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BF010']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BF010']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BF010']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BF010']['MBC_MCC1'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BF010']['MBC_MCC2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BF010']['MBC_PSC1'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BF010']['MBC_PSC2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BF010']['MBC_SCO1'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BF010']['MBC_SCO2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BF010']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BF010']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BF010']['VEG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BF010']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BF010']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BF010']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BF010']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['BF010']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BF010']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BF010']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BF010']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BF010']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BF010']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BF010']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['BF010']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BF010']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BF010']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BF010']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BF010']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['BF010']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BF010']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BF010']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BG010'] = {}
    field_information['GGDM 3.0']['DefaultValues']['BG010']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BG010']['C35'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BG010']['C36'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BG010']['C37'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BG010']['C38'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BG010']['C39'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BG010']['C40'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BG010']['C41'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BG010']['C42'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BG010']['C43'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BG010']['C44'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BG010']['C45'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BG010']['C46'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BG010']['CRN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BG010']['CRS'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BG010']['CRX'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BG010']['CUR'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BG010']['D35'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BG010']['D36'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BG010']['D37'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BG010']['D38'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BG010']['D39'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BG010']['D40'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BG010']['D41'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BG010']['D42'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BG010']['D43'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BG010']['D44'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BG010']['D45'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BG010']['D46'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BG010']['DOF'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BG010']['DZP'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BG010']['F_CODE'] = 'BG010'
    field_information['GGDM 3.0']['DefaultValues']['BG010']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BG010']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BG010']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BG010']['HDP'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BG010']['HSE'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BG010']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BG010']['REW'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BG010']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BG010']['ZHDP_DCR'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BG010']['ZHDP_DKC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BG010']['ZHDP_DKC2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BG010']['ZHDP_DKC3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BG010']['ZHDP_SVC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BG010']['ZHDP_TEC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BG010']['ZHDP_TEC2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BG010']['ZHDP_TEC3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BG010']['ZHDP_VDC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BG010']['ZHDP_VDR'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BG010']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BG010']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BG010']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['BG010']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BG010']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BG010']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BG010']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BG010']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BG010']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BG010']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['BG010']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BG010']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BG010']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BG010']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BG010']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['BG010']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BG010']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BG010']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BG012'] = {}
    field_information['GGDM 3.0']['DefaultValues']['BG012']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BG012']['F_CODE'] = 'BG012'
    field_information['GGDM 3.0']['DefaultValues']['BG012']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BG012']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BG012']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BG012']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BG012']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BG012']['WTT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BG012']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BG012']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BG012']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['BG012']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BG012']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BG012']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BG012']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BG012']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BG012']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BG012']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['BG012']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BG012']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BG012']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BG012']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BG012']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['BG012']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BG012']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BG012']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BG030'] = {}
    field_information['GGDM 3.0']['DefaultValues']['BG030']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BG030']['C35'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BG030']['C36'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BG030']['C37'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BG030']['C38'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BG030']['C39'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BG030']['C40'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BG030']['C41'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BG030']['C42'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BG030']['C43'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BG030']['C44'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BG030']['C45'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BG030']['C46'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BG030']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BG030']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BG030']['D35'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BG030']['D36'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BG030']['D37'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BG030']['D38'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BG030']['D39'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BG030']['D40'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BG030']['D41'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BG030']['D42'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BG030']['D43'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BG030']['D44'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BG030']['D45'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BG030']['D46'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BG030']['F_CODE'] = 'BG030'
    field_information['GGDM 3.0']['DefaultValues']['BG030']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BG030']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BG030']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BG030']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BG030']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BG030']['REW'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BG030']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BG030']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BG030']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BG030']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['BG030']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BG030']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BG030']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BG030']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BG030']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BG030']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BG030']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['BG030']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BG030']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BG030']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BG030']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BG030']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['BG030']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BG030']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BG030']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH010'] = {}
    field_information['GGDM 3.0']['DefaultValues']['BH010']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH010']['ATC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH010']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH010']['BH141_AWBA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH010']['BH141_AWBB'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH010']['BH141_IBOA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH010']['BH141_IBOB'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH010']['BH141_SHDA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH010']['BH141_SHDB'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH010']['BH141_SLTA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH010']['BH141_SLTB'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH010']['BH141_WBHA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH010']['BH141_WBHB'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH010']['BPWHAC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['BH010']['BPWHAL'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH010']['BPWHAU'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH010']['BPWHBC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['BH010']['BPWHBL'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH010']['BPWHBU'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH010']['BPWSAC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['BH010']['BPWSAL'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH010']['BPWSAU'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH010']['BPWSBC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['BH010']['BPWSBL'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH010']['BPWSBU'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH010']['BWVCAC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['BH010']['BWVCAL'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH010']['BWVCAU'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH010']['BWVCBC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['BH010']['BWVCBL'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH010']['BWVCBU'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH010']['CAA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH010']['CDA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH010']['CDL'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH010']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH010']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH010']['CWT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH010']['DEV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH010']['DOXY'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH010']['DZP'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH010']['F_CODE'] = 'BH010'
    field_information['GGDM 3.0']['DefaultValues']['BH010']['FRZ'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH010']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH010']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH010']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH010']['HGT'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH010']['LEA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH010']['LMC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH010']['LUN'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH010']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH010']['MWD'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH010']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH010']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH010']['PWAC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['BH010']['PWAL'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH010']['PWAU'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH010']['RLE'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH010']['SBB'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH010']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH010']['WD3'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH010']['WDAC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['BH010']['WDAL'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH010']['WDAU'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH010']['WDH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH010']['WDL'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH010']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH010']['WVA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH010']['WVH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH010']['WVL'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH010']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH010']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH010']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['BH010']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH010']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BH010']['ZI005_FNA2'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BH010']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH010']['ZI005_GNT2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH010']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BH010']['ZI005_NFN2'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BH010']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BH010']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH010']['ZI024_ASE'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH010']['ZI024_AWO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH010']['ZI024_AWOI'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH010']['ZI024_AWOX'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH010']['ZI024_CFR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH010']['ZI024_CLO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH010']['ZI024_CYN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH010']['ZI024_FMR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH010']['ZI024_FRR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH010']['ZI024_HAR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH010']['ZI024_HYP'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH010']['ZI024_MGN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH010']['ZI024_PHW'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH010']['ZI024_SCC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH010']['ZI024_SQN'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH010']['ZI024_SUL'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH010']['ZI024_TDS'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH010']['ZI024_TEP'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH010']['ZI024_TUR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH010']['ZI024_WAC'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH010']['ZI024_WPAC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH010']['ZI024_WTNO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH010']['ZI024_WUR'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH010']['ZI024_WUR2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH010']['ZI024_WUR3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH010']['ZI024_WUR4'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH010']['ZI024_YWQ'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH010']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['BH010']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH010']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH010']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH010']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH010']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['BH010']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH010']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH010']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH010']['ZVH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH012'] = {}
    field_information['GGDM 3.0']['DefaultValues']['BH012']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH012']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH012']['BH010_CAA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH012']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH012']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH012']['DZP'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH012']['F_CODE'] = 'BH012'
    field_information['GGDM 3.0']['DefaultValues']['BH012']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH012']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH012']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH012']['HGT'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH012']['LMC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH012']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH012']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH012']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH012']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH012']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH012']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH012']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH012']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['BH012']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH012']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BH012']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH012']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BH012']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BH012']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH012']['ZI024_ASE'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH012']['ZI024_CFR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH012']['ZI024_CLO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH012']['ZI024_CYN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH012']['ZI024_FMR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH012']['ZI024_FRR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH012']['ZI024_HAR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH012']['ZI024_MGN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH012']['ZI024_PHW'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH012']['ZI024_SCC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH012']['ZI024_SUL'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH012']['ZI024_TDS'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH012']['ZI024_TEP'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH012']['ZI024_TUR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH012']['ZI024_WAC'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH012']['ZI024_WTNO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH012']['ZI024_YWQ'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH012']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['BH012']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH012']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH012']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH012']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH012']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['BH012']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH012']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH012']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH012']['ZVH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH015'] = {}
    field_information['GGDM 3.0']['DefaultValues']['BH015']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH015']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH015']['BMC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH015']['BMC2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH015']['BMC3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH015']['BOC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH015']['CAA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH015']['DZP'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH015']['F_CODE'] = 'BH015'
    field_information['GGDM 3.0']['DefaultValues']['BH015']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH015']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH015']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH015']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH015']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH015']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH015']['VTI'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH015']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH015']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH015']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH015']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['BH015']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH015']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BH015']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH015']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BH015']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BH015']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH015']['ZI024_ASE'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH015']['ZI024_CFR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH015']['ZI024_CLO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH015']['ZI024_CYN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH015']['ZI024_FMR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH015']['ZI024_FRR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH015']['ZI024_HAR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH015']['ZI024_MGN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH015']['ZI024_PHW'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH015']['ZI024_SCC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH015']['ZI024_SUL'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH015']['ZI024_TDS'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH015']['ZI024_TEP'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH015']['ZI024_TUR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH015']['ZI024_WAC'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH015']['ZI024_WTNO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH015']['ZI024_WUR'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH015']['ZI024_YWQ'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH015']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['BH015']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH015']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH015']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH015']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH015']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['BH015']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH015']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH015']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH020'] = {}
    field_information['GGDM 3.0']['DefaultValues']['BH020']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH020']['BBMCA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH020']['BBMCA2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH020']['BBMCA3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH020']['BBMCB'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH020']['BBMCB2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH020']['BBMCB3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH020']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH020']['BH141_AWBA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH020']['BH141_AWBB'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH020']['BH141_IBOA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH020']['BH141_IBOB'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH020']['BH141_SHDA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH020']['BH141_SHDB'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH020']['BH141_SLTA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH020']['BH141_SLTB'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH020']['BH141_WBHA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH020']['BH141_WBHB'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH020']['BMC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH020']['BMC2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH020']['BMC3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH020']['BPWHAC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['BH020']['BPWHAL'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH020']['BPWHAU'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH020']['BPWHBC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['BH020']['BPWHBL'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH020']['BPWHBU'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH020']['BPWSAC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['BH020']['BPWSAL'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH020']['BPWSAU'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH020']['BPWSBC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['BH020']['BPWSBL'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH020']['BPWSBU'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH020']['BWVCAC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['BH020']['BWVCAL'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH020']['BWVCAU'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH020']['BWVCBC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['BH020']['BWVCBL'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH020']['BWVCBU'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH020']['CAA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH020']['CDA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH020']['CDL'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH020']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH020']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH020']['CWT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH020']['DEV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH020']['DOXY'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH020']['DZP'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH020']['F_CODE'] = 'BH020'
    field_information['GGDM 3.0']['DefaultValues']['BH020']['FRZ'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH020']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH020']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH020']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH020']['HDP'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH020']['HGT'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH020']['LEA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH020']['LMC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH020']['LOC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH020']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH020']['MWD'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH020']['NVS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH020']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH020']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH020']['PWA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH020']['RLE'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH020']['SBB'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH020']['TID'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH020']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH020']['WD3'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH020']['WDAC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['BH020']['WDAL'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH020']['WDAU'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH020']['WDH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH020']['WDL'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH020']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH020']['WVA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH020']['WVH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH020']['WVL'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH020']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH020']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH020']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['BH020']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH020']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BH020']['ZI005_FNA2'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BH020']['ZI005_FNA3'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BH020']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH020']['ZI005_GNT2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH020']['ZI005_GNT3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH020']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BH020']['ZI005_NFN2'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BH020']['ZI005_NFN3'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BH020']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BH020']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH020']['ZI024_ASE'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH020']['ZI024_AWO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH020']['ZI024_AWOI'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH020']['ZI024_AWOX'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH020']['ZI024_CFR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH020']['ZI024_CLO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH020']['ZI024_CYN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH020']['ZI024_FMR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH020']['ZI024_FRR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH020']['ZI024_HAR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH020']['ZI024_HYP'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH020']['ZI024_MGN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH020']['ZI024_PHW'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH020']['ZI024_SCC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH020']['ZI024_SQN'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH020']['ZI024_SUL'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH020']['ZI024_TDS'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH020']['ZI024_TEP'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH020']['ZI024_TUR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH020']['ZI024_WAC'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH020']['ZI024_WPAC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH020']['ZI024_WSG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH020']['ZI024_WTNO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH020']['ZI024_WUR'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH020']['ZI024_WUR2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH020']['ZI024_WUR3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH020']['ZI024_WUR4'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH020']['ZI024_YWQ'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH020']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['BH020']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH020']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH020']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH020']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH020']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['BH020']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH020']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH020']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH020']['ZVH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH030'] = {}
    field_information['GGDM 3.0']['DefaultValues']['BH030']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH030']['BBMCA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH030']['BBMCA2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH030']['BBMCA3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH030']['BBMCB'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH030']['BBMCB2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH030']['BBMCB3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH030']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH030']['BH141_AWBA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH030']['BH141_AWBB'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH030']['BH141_IBOA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH030']['BH141_IBOB'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH030']['BH141_SHDA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH030']['BH141_SHDB'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH030']['BH141_SLTA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH030']['BH141_SLTB'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH030']['BH141_WBHA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH030']['BH141_WBHB'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH030']['BMC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH030']['BMC2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH030']['BMC3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH030']['BPWHAC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['BH030']['BPWHAL'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH030']['BPWHAU'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH030']['BPWHBC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['BH030']['BPWHBL'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH030']['BPWHBU'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH030']['BPWSAC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['BH030']['BPWSAL'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH030']['BPWSAU'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH030']['BPWSBC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['BH030']['BPWSBL'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH030']['BPWSBU'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH030']['BWVCAC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['BH030']['BWVCAL'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH030']['BWVCAU'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH030']['BWVCBC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['BH030']['BWVCBL'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH030']['BWVCBU'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH030']['CAA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH030']['CDA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH030']['CDL'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH030']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH030']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH030']['CWT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH030']['DEV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH030']['DIT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH030']['DOXY'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH030']['DZP'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH030']['F_CODE'] = 'BH030'
    field_information['GGDM 3.0']['DefaultValues']['BH030']['FRZ'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH030']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH030']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH030']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH030']['HDP'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH030']['HGT'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH030']['LEA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH030']['LMC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH030']['LOC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH030']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH030']['MWD'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH030']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH030']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH030']['PWA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH030']['RLE'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH030']['SBB'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH030']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH030']['WD3'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH030']['WDAC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['BH030']['WDAL'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH030']['WDAU'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH030']['WDH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH030']['WDL'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH030']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH030']['WVA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH030']['WVH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH030']['WVL'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH030']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH030']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH030']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['BH030']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH030']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BH030']['ZI005_FNA2'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BH030']['ZI005_FNA3'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BH030']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH030']['ZI005_GNT2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH030']['ZI005_GNT3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH030']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BH030']['ZI005_NFN2'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BH030']['ZI005_NFN3'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BH030']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BH030']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH030']['ZI024_ASE'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH030']['ZI024_AWO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH030']['ZI024_AWOI'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH030']['ZI024_AWOX'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH030']['ZI024_CFR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH030']['ZI024_CLO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH030']['ZI024_CYN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH030']['ZI024_FMR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH030']['ZI024_FRR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH030']['ZI024_HAR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH030']['ZI024_HYP'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH030']['ZI024_MGN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH030']['ZI024_PHW'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH030']['ZI024_SCC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH030']['ZI024_SQN'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH030']['ZI024_SUL'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH030']['ZI024_TDS'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH030']['ZI024_TEP'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH030']['ZI024_TUR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH030']['ZI024_WAC'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH030']['ZI024_WPAC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH030']['ZI024_WSG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH030']['ZI024_WTNO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH030']['ZI024_WUR'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH030']['ZI024_WUR2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH030']['ZI024_WUR3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH030']['ZI024_WUR4'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH030']['ZI024_YWQ'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH030']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['BH030']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH030']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH030']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH030']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH030']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['BH030']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH030']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH030']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH030']['ZVH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH040'] = {}
    field_information['GGDM 3.0']['DefaultValues']['BH040']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH040']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH040']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH040']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH040']['DZP'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH040']['F_CODE'] = 'BH040'
    field_information['GGDM 3.0']['DefaultValues']['BH040']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH040']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH040']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH040']['LMC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH040']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH040']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH040']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH040']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH040']['VLM'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH040']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH040']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH040']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH040']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['BH040']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH040']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BH040']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH040']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BH040']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BH040']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH040']['ZI024_ASE'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH040']['ZI024_CFR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH040']['ZI024_CLO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH040']['ZI024_CYN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH040']['ZI024_FMR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH040']['ZI024_FRR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH040']['ZI024_HAR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH040']['ZI024_MGN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH040']['ZI024_PHW'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH040']['ZI024_SCC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH040']['ZI024_SUL'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH040']['ZI024_TDS'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH040']['ZI024_TEP'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH040']['ZI024_TUR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH040']['ZI024_WAC'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH040']['ZI024_WTNO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH040']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['BH040']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH040']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH040']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH040']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH040']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['BH040']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH040']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH040']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH050'] = {}
    field_information['GGDM 3.0']['DefaultValues']['BH050']['AQF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH050']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH050']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH050']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH050']['COA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH050']['COC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH050']['COG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH050']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH050']['F_CODE'] = 'BH050'
    field_information['GGDM 3.0']['DefaultValues']['BH050']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH050']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH050']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH050']['LMC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH050']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH050']['MFE'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH050']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH050']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH050']['PPO'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH050']['PPO2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH050']['PPO3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH050']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH050']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH050']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH050']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH050']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['BH050']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH050']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BH050']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH050']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BH050']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BH050']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH050']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['BH050']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH050']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH050']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH050']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH050']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['BH050']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH050']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH050']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH051'] = {}
    field_information['GGDM 3.0']['DefaultValues']['BH051']['AOO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH051']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH051']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH051']['CAA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH051']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH051']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH051']['F_CODE'] = 'BH051'
    field_information['GGDM 3.0']['DefaultValues']['BH051']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH051']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH051']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH051']['LMC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH051']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH051']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH051']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH051']['PPO'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH051']['PPO2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH051']['PPO3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH051']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH051']['VLM'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH051']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH051']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH051']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH051']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['BH051']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH051']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BH051']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH051']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BH051']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BH051']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH051']['ZI024_ASE'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH051']['ZI024_CFR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH051']['ZI024_CLO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH051']['ZI024_CYN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH051']['ZI024_FMR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH051']['ZI024_FRR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH051']['ZI024_HAR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH051']['ZI024_HYP'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH051']['ZI024_MGN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH051']['ZI024_PHW'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH051']['ZI024_SCC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH051']['ZI024_SUL'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH051']['ZI024_TDS'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH051']['ZI024_TEP'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH051']['ZI024_TUR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH051']['ZI024_WAC'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH051']['ZI024_WTNO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH051']['ZI024_WUR'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH051']['ZI024_WUR2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH051']['ZI024_WUR3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH051']['ZI024_WUR4'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH051']['ZI024_YWQ'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH051']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['BH051']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH051']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH051']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH051']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH051']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['BH051']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH051']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH051']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH065'] = {}
    field_information['GGDM 3.0']['DefaultValues']['BH065']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH065']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH065']['CAA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH065']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH065']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH065']['F_CODE'] = 'BH065'
    field_information['GGDM 3.0']['DefaultValues']['BH065']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH065']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH065']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH065']['HGT'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH065']['LMC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH065']['LOC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH065']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH065']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH065']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH065']['RLE'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH065']['SPT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH065']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH065']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH065']['WRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH065']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH065']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH065']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['BH065']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH065']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BH065']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH065']['ZI024_ASE'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH065']['ZI024_CFR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH065']['ZI024_CLO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH065']['ZI024_CYN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH065']['ZI024_FMR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH065']['ZI024_FRR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH065']['ZI024_HAR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH065']['ZI024_HYP'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH065']['ZI024_MGN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH065']['ZI024_PHW'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH065']['ZI024_SCC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH065']['ZI024_SUL'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH065']['ZI024_TDS'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH065']['ZI024_TEP'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH065']['ZI024_TUR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH065']['ZI024_WAC'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH065']['ZI024_WTNO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH065']['ZI024_WUR'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH065']['ZI024_WUR2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH065']['ZI024_WUR3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH065']['ZI024_WUR4'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH065']['ZI024_YWQ'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH065']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['BH065']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH065']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH065']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH065']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH065']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['BH065']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH065']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH065']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH070'] = {}
    field_information['GGDM 3.0']['DefaultValues']['BH070']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH070']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH070']['BMC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH070']['BMC2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH070']['BMC3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH070']['CIW'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH070']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH070']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH070']['F_CODE'] = 'BH070'
    field_information['GGDM 3.0']['DefaultValues']['BH070']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH070']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH070']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH070']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH070']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH070']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH070']['TRS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH070']['TRS2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH070']['TRS3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH070']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH070']['WBD'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH070']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH070']['WVA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH070']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH070']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH070']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['BH070']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH070']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BH070']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH070']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BH070']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BH070']['ZI016_ROC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH070']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH070']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['BH070']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH070']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH070']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH070']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH070']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['BH070']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH070']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH070']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH075'] = {}
    field_information['GGDM 3.0']['DefaultValues']['BH075']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH075']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH075']['CAA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH075']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH075']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH075']['F_CODE'] = 'BH075'
    field_information['GGDM 3.0']['DefaultValues']['BH075']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH075']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH075']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH075']['HGT'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH075']['LMC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH075']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH075']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH075']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH075']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH075']['VLM'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH075']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH075']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH075']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH075']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['BH075']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH075']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BH075']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH075']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BH075']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BH075']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH075']['ZI024_ASE'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH075']['ZI024_CFR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH075']['ZI024_CLO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH075']['ZI024_CYN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH075']['ZI024_FMR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH075']['ZI024_FRR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH075']['ZI024_HAR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH075']['ZI024_MGN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH075']['ZI024_PHW'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH075']['ZI024_SCC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH075']['ZI024_SUL'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH075']['ZI024_TDS'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH075']['ZI024_TEP'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH075']['ZI024_TUR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH075']['ZI024_WAC'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH075']['ZI024_WTNO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH075']['ZI024_WUR'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH075']['ZI024_WUR2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH075']['ZI024_WUR3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH075']['ZI024_WUR4'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH075']['ZI024_YWQ'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH075']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['BH075']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH075']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH075']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH075']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH075']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['BH075']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH075']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH075']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH075']['ZVH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH077'] = {}
    field_information['GGDM 3.0']['DefaultValues']['BH077']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH077']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH077']['F_CODE'] = 'BH077'
    field_information['GGDM 3.0']['DefaultValues']['BH077']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH077']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH077']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH077']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH077']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH077']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH077']['VTI'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH077']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH077']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH077']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH077']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['BH077']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH077']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BH077']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH077']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['BH077']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH077']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH077']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH077']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH077']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['BH077']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH077']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH077']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH082'] = {}
    field_information['GGDM 3.0']['DefaultValues']['BH082']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH082']['AZC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH082']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH082']['BH141_AWBA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH082']['BH141_AWBB'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH082']['BH141_IBOA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH082']['BH141_IBOB'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH082']['BH141_SHDA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH082']['BH141_SHDB'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH082']['BH141_SLTA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH082']['BH141_SLTB'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH082']['BH141_WBHA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH082']['BH141_WBHB'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH082']['BPWHAC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['BH082']['BPWHAL'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH082']['BPWHAU'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH082']['BPWHBC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['BH082']['BPWHBL'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH082']['BPWHBU'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH082']['BPWSAC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['BH082']['BPWSAL'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH082']['BPWSAU'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH082']['BPWSBC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['BH082']['BPWSBL'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH082']['BPWSBU'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH082']['BWVCAC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['BH082']['BWVCAL'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH082']['BWVCAU'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH082']['BWVCBC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['BH082']['BWVCBL'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH082']['BWVCBU'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH082']['CAA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH082']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH082']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH082']['DMD'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH082']['DOXY'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH082']['DZP'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH082']['F_CODE'] = 'BH082'
    field_information['GGDM 3.0']['DefaultValues']['BH082']['FFN'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH082']['FFN2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH082']['FFN3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH082']['FRZ'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH082']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH082']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH082']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH082']['IWT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH082']['LMC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH082']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH082']['MNS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH082']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH082']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH082']['PWAC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['BH082']['PWAL'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH082']['PWAU'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH082']['TID'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH082']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH082']['VLM'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH082']['WDAC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['BH082']['WDAL'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH082']['WDAU'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH082']['WDH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH082']['WDL'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH082']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH082']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH082']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH082']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['BH082']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH082']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BH082']['ZI005_FNA2'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BH082']['ZI005_FNA3'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BH082']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH082']['ZI005_GNT2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH082']['ZI005_GNT3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH082']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BH082']['ZI005_NFN2'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BH082']['ZI005_NFN3'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BH082']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BH082']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH082']['ZI024_ASE'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH082']['ZI024_CFR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH082']['ZI024_CLO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH082']['ZI024_CYN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH082']['ZI024_FMR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH082']['ZI024_FRR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH082']['ZI024_HAR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH082']['ZI024_HYP'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH082']['ZI024_MGN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH082']['ZI024_PHW'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH082']['ZI024_RTP'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH082']['ZI024_SCC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH082']['ZI024_SUL'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH082']['ZI024_TDS'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH082']['ZI024_TEP'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH082']['ZI024_TUR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH082']['ZI024_WAC'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH082']['ZI024_WTNO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH082']['ZI024_WUR'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH082']['ZI024_WUR2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH082']['ZI024_WUR3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH082']['ZI024_WUR4'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH082']['ZI024_YWQ'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH082']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['BH082']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH082']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH082']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH082']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH082']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['BH082']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH082']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH082']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH082']['ZVH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH090'] = {}
    field_information['GGDM 3.0']['DefaultValues']['BH090']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH090']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH090']['DZP'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH090']['F_CODE'] = 'BH090'
    field_information['GGDM 3.0']['DefaultValues']['BH090']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH090']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH090']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH090']['INU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH090']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH090']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH090']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH090']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH090']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH090']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH090']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['BH090']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH090']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BH090']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH090']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BH090']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BH090']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH090']['ZI024_HYP'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH090']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['BH090']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH090']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH090']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH090']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH090']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['BH090']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH090']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH090']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH100'] = {}
    field_information['GGDM 3.0']['DefaultValues']['BH100']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH100']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH100']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH100']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH100']['DZP'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH100']['F_CODE'] = 'BH100'
    field_information['GGDM 3.0']['DefaultValues']['BH100']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH100']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH100']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH100']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH100']['MWD'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH100']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH100']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH100']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH100']['VLM'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH100']['WD3'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH100']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH100']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH100']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH100']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['BH100']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH100']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BH100']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH100']['ZI024_ASE'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH100']['ZI024_CFR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH100']['ZI024_CLO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH100']['ZI024_CYN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH100']['ZI024_FMR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH100']['ZI024_FRR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH100']['ZI024_HAR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH100']['ZI024_HYP'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH100']['ZI024_MGN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH100']['ZI024_PHW'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH100']['ZI024_SCC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH100']['ZI024_SUL'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH100']['ZI024_TDS'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH100']['ZI024_TEP'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH100']['ZI024_TUR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH100']['ZI024_WAC'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH100']['ZI024_WTNO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH100']['ZI024_YWQ'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH100']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['BH100']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH100']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH100']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH100']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH100']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['BH100']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH100']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH100']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH100']['ZVH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH110'] = {}
    field_information['GGDM 3.0']['DefaultValues']['BH110']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH110']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH110']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH110']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH110']['DIM'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH110']['F_CODE'] = 'BH110'
    field_information['GGDM 3.0']['DefaultValues']['BH110']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH110']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH110']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH110']['HGT'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH110']['LMC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH110']['LOC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH110']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH110']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH110']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH110']['SPT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH110']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH110']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH110']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH110']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['BH110']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH110']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BH110']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH110']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['BH110']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH110']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH110']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH110']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH110']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['BH110']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH110']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH110']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH110']['ZVH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH116'] = {}
    field_information['GGDM 3.0']['DefaultValues']['BH116']['AQN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BH116']['AQO'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH116']['AQO2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH116']['AQO3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH116']['AQP'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH116']['AQP2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH116']['AQP3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH116']['AQTC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['BH116']['AQTL'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH116']['AQTU'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH116']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH116']['AYRC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['BH116']['AYRL'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH116']['AYRU'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH116']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH116']['CAA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH116']['CNF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH116']['DPAC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['BH116']['DPAL'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH116']['DPAU'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH116']['F_CODE'] = 'BH116'
    field_information['GGDM 3.0']['DefaultValues']['BH116']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH116']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH116']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH116']['GWS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH116']['GWTR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH116']['HYCD'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH116']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH116']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH116']['SWCP'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH116']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH116']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH116']['WRCC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['BH116']['WRCL'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH116']['WRCU'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH116']['WWRC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['BH116']['WWRL'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH116']['WWRU'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH116']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH116']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH116']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['BH116']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH116']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BH116']['ZI005_FNA2'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BH116']['ZI005_FNA3'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BH116']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH116']['ZI005_GNT2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH116']['ZI005_GNT3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH116']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BH116']['ZI005_NFN2'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BH116']['ZI005_NFN3'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BH116']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BH116']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH116']['ZI024_ASE'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH116']['ZI024_CFR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH116']['ZI024_CLO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH116']['ZI024_CYN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH116']['ZI024_FMR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH116']['ZI024_FRR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH116']['ZI024_HAR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH116']['ZI024_MGN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH116']['ZI024_PHW'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH116']['ZI024_SCC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH116']['ZI024_SUL'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH116']['ZI024_TDS'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH116']['ZI024_TEP'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH116']['ZI024_TUR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH116']['ZI024_WAC'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH116']['ZI024_WTNO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH116']['ZI024_WUR'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH116']['ZI024_WUR2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH116']['ZI024_WUR3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH116']['ZI024_WUR4'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH116']['ZI024_YWQ'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH116']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['BH116']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH116']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH116']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH116']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH116']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['BH116']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH116']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH116']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH120'] = {}
    field_information['GGDM 3.0']['DefaultValues']['BH120']['AOO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH120']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH120']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH120']['F_CODE'] = 'BH120'
    field_information['GGDM 3.0']['DefaultValues']['BH120']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH120']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH120']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH120']['LMC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH120']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH120']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH120']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH120']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH120']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH120']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH120']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['BH120']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH120']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BH120']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH120']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BH120']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BH120']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH120']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['BH120']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH120']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH120']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH120']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH120']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['BH120']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH120']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH120']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH135'] = {}
    field_information['GGDM 3.0']['DefaultValues']['BH135']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH135']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH135']['CAA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH135']['DZP'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH135']['F_CODE'] = 'BH135'
    field_information['GGDM 3.0']['DefaultValues']['BH135']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH135']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH135']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH135']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH135']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH135']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH135']['VTI'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH135']['WDAC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['BH135']['WDAL'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH135']['WDAU'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH135']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH135']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH135']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH135']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['BH135']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH135']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BH135']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH135']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BH135']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BH135']['ZI013_CSP'] = 28
    field_information['GGDM 3.0']['DefaultValues']['BH135']['ZI013_FFP'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH135']['ZI013_FFP2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH135']['ZI013_FFP3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH135']['ZI013_FMM'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH135']['ZI013_FMM2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH135']['ZI013_FMM3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH135']['ZI013_PIG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH135']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH135']['ZI024_ASE'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH135']['ZI024_CFR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH135']['ZI024_CLO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH135']['ZI024_CYN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH135']['ZI024_FMR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH135']['ZI024_FRR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH135']['ZI024_HAR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH135']['ZI024_HYP'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH135']['ZI024_MGN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH135']['ZI024_PHW'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH135']['ZI024_SCC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH135']['ZI024_SUL'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH135']['ZI024_TDS'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH135']['ZI024_TEP'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH135']['ZI024_TUR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH135']['ZI024_WAC'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH135']['ZI024_WTNO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH135']['ZI024_WUR'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH135']['ZI024_YWQ'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH135']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['BH135']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH135']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH135']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH135']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH135']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['BH135']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH135']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH135']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH140'] = {}
    field_information['GGDM 3.0']['DefaultValues']['BH140']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH140']['BBMCA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH140']['BBMCA2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH140']['BBMCA3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH140']['BBMCB'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH140']['BBMCB2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH140']['BBMCB3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH140']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH140']['BH141_AWBA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH140']['BH141_AWBB'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH140']['BH141_IBOA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH140']['BH141_IBOB'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH140']['BH141_SHDA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH140']['BH141_SHDB'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH140']['BH141_SLTA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH140']['BH141_SLTB'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH140']['BH141_WBHA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH140']['BH141_WBHB'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH140']['BMC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH140']['BMC2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH140']['BMC3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH140']['BPWHAC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['BH140']['BPWHAL'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH140']['BPWHAU'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH140']['BPWHBC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['BH140']['BPWHBL'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH140']['BPWHBU'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH140']['BPWSAC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['BH140']['BPWSAL'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH140']['BPWSAU'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH140']['BPWSBC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['BH140']['BPWSBL'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH140']['BPWSBU'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH140']['BWVCAC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['BH140']['BWVCAL'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH140']['BWVCAU'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH140']['BWVCBC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['BH140']['BWVCBL'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH140']['BWVCBU'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH140']['CAA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH140']['CDA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH140']['CDL'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH140']['DOXY'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH140']['DZP'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH140']['F_CODE'] = 'BH140'
    field_information['GGDM 3.0']['DefaultValues']['BH140']['FRZ'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH140']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH140']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH140']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH140']['LEA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH140']['LMC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH140']['LOC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH140']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH140']['NVS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH140']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH140']['PWA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH140']['STNB'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH140']['TID'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH140']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH140']['WCC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH140']['WD3'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH140']['WDAC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['BH140']['WDAL'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH140']['WDAU'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH140']['WDH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH140']['WDL'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH140']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH140']['WMT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH140']['WVA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH140']['WVH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH140']['WVL'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH140']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH140']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH140']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['BH140']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH140']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BH140']['ZI005_FNA2'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BH140']['ZI005_FNA3'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BH140']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH140']['ZI005_GNT2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH140']['ZI005_GNT3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH140']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BH140']['ZI005_NFN2'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BH140']['ZI005_NFN3'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BH140']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BH140']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH140']['ZI024_ASE'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH140']['ZI024_AWO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH140']['ZI024_AWOI'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH140']['ZI024_AWOX'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH140']['ZI024_CFR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH140']['ZI024_CLO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH140']['ZI024_CYN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH140']['ZI024_FMR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH140']['ZI024_FRR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH140']['ZI024_HAR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH140']['ZI024_HYP'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH140']['ZI024_MGN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH140']['ZI024_PHW'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH140']['ZI024_SCC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH140']['ZI024_SQN'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH140']['ZI024_SUL'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH140']['ZI024_TDS'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH140']['ZI024_TEP'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH140']['ZI024_TUR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH140']['ZI024_WAC'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH140']['ZI024_WPAC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH140']['ZI024_WSG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH140']['ZI024_WTNO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH140']['ZI024_WUR'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH140']['ZI024_WUR2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH140']['ZI024_WUR3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH140']['ZI024_WUR4'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH140']['ZI024_YWQ'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH140']['ZI025_HDP'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH140']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['BH140']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH140']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH140']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH140']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH140']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['BH140']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH140']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH140']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH140']['ZVH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH145'] = {}
    field_information['GGDM 3.0']['DefaultValues']['BH145']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH145']['DOF'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH145']['F_CODE'] = 'BH145'
    field_information['GGDM 3.0']['DefaultValues']['BH145']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH145']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH145']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH145']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH145']['PWAC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['BH145']['PWAL'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH145']['PWAU'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH145']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH145']['WDAC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['BH145']['WDAL'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH145']['WDAU'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH145']['WDH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH145']['WST'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH145']['WVA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH145']['WVH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH145']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH145']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH145']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['BH145']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH145']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BH145']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH145']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BH145']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BH145']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH145']['ZI024_ASE'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH145']['ZI024_CFR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH145']['ZI024_CLO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH145']['ZI024_CYN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH145']['ZI024_FMR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH145']['ZI024_FRR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH145']['ZI024_HAR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH145']['ZI024_MGN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH145']['ZI024_PHW'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH145']['ZI024_SCC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH145']['ZI024_SUL'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH145']['ZI024_TDS'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH145']['ZI024_TEP'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH145']['ZI024_TUR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH145']['ZI024_WAC'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH145']['ZI024_WTNO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH145']['ZI024_YWQ'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH145']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['BH145']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH145']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH145']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH145']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH145']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['BH145']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH145']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH145']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH150'] = {}
    field_information['GGDM 3.0']['DefaultValues']['BH150']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH150']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH150']['F_CODE'] = 'BH150'
    field_information['GGDM 3.0']['DefaultValues']['BH150']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH150']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH150']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH150']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH150']['MCC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH150']['MCC2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH150']['MCC3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH150']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH150']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH150']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH150']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH150']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH150']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['BH150']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH150']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BH150']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH150']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BH150']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BH150']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH150']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['BH150']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH150']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH150']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH150']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH150']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['BH150']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH150']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH150']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH155'] = {}
    field_information['GGDM 3.0']['DefaultValues']['BH155']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH155']['AZC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH155']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH155']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH155']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH155']['F_CODE'] = 'BH155'
    field_information['GGDM 3.0']['DefaultValues']['BH155']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH155']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH155']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH155']['LMC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH155']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH155']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH155']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH155']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH155']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH155']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH155']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH155']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['BH155']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH155']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BH155']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH155']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BH155']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BH155']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH155']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['BH155']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH155']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH155']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH155']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH155']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['BH155']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH155']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH155']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH160'] = {}
    field_information['GGDM 3.0']['DefaultValues']['BH160']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH160']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH160']['F_CODE'] = 'BH160'
    field_information['GGDM 3.0']['DefaultValues']['BH160']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH160']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH160']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH160']['LMC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH160']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH160']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH160']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH160']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH160']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH160']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH160']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['BH160']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH160']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BH160']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH160']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BH160']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BH160']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH160']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['BH160']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH160']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH160']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH160']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH160']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['BH160']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH160']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH160']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH165'] = {}
    field_information['GGDM 3.0']['DefaultValues']['BH165']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH165']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH165']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH165']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH165']['F_CODE'] = 'BH165'
    field_information['GGDM 3.0']['DefaultValues']['BH165']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH165']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH165']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH165']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH165']['MCC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH165']['MCC2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH165']['MCC3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH165']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH165']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH165']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH165']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH165']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH165']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH165']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['BH165']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH165']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BH165']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH165']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BH165']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BH165']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH165']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['BH165']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH165']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH165']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH165']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH165']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['BH165']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH165']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH165']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH170'] = {}
    field_information['GGDM 3.0']['DefaultValues']['BH170']['AQN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BH170']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH170']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH170']['CAA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH170']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH170']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH170']['DOF'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH170']['DZP'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH170']['F_CODE'] = 'BH170'
    field_information['GGDM 3.0']['DefaultValues']['BH170']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH170']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH170']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH170']['LUN'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH170']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH170']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH170']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH170']['SWT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH170']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH170']['VLM'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH170']['WDST'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH170']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH170']['WWM'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH170']['WWM2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH170']['WWM3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH170']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH170']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH170']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['BH170']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH170']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BH170']['ZI005_FNA2'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BH170']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH170']['ZI005_GNT2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH170']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BH170']['ZI005_NFN2'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BH170']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BH170']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH170']['ZI024_ASE'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH170']['ZI024_AWO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH170']['ZI024_AWOI'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH170']['ZI024_AWOX'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH170']['ZI024_CFR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH170']['ZI024_CLO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH170']['ZI024_CYN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH170']['ZI024_FMR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH170']['ZI024_FRR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH170']['ZI024_HAR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH170']['ZI024_HYP'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH170']['ZI024_MGN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH170']['ZI024_PHW'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH170']['ZI024_SCC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH170']['ZI024_SUL'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH170']['ZI024_TDS'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH170']['ZI024_TEP'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH170']['ZI024_TUR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH170']['ZI024_WAC'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH170']['ZI024_WTNO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH170']['ZI024_WUR'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH170']['ZI024_WUR2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH170']['ZI024_WUR3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH170']['ZI024_WUR4'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH170']['ZI024_YWQ'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH170']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['BH170']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH170']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH170']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH170']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH170']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['BH170']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH170']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH170']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH180'] = {}
    field_information['GGDM 3.0']['DefaultValues']['BH180']['AOO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH180']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH180']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH180']['F_CODE'] = 'BH180'
    field_information['GGDM 3.0']['DefaultValues']['BH180']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH180']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH180']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH180']['HGT'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH180']['LMC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH180']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH180']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH180']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH180']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH180']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH180']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH180']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['BH180']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH180']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BH180']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH180']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BH180']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BH180']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH180']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['BH180']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH180']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH180']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH180']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH180']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['BH180']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH180']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH180']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH180']['ZVH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH190'] = {}
    field_information['GGDM 3.0']['DefaultValues']['BH190']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH190']['BMC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH190']['BMC2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH190']['BMC3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH190']['F_CODE'] = 'BH190'
    field_information['GGDM 3.0']['DefaultValues']['BH190']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH190']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH190']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH190']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH190']['PWAC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['BH190']['PWAL'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH190']['PWAU'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH190']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH190']['WDAC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['BH190']['WDAL'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH190']['WDAU'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH190']['WDH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH190']['WDL'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH190']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH190']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH190']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['BH190']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH190']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BH190']['ZI005_FNA2'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BH190']['ZI005_FNA3'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BH190']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH190']['ZI005_GNT2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH190']['ZI005_GNT3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH190']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BH190']['ZI005_NFN2'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BH190']['ZI005_NFN3'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BH190']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BH190']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH190']['ZI024_ASE'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH190']['ZI024_CFR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH190']['ZI024_CLO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH190']['ZI024_CYN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH190']['ZI024_FMR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH190']['ZI024_FRR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH190']['ZI024_HAR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH190']['ZI024_HYP'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH190']['ZI024_MGN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH190']['ZI024_PHW'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH190']['ZI024_SCC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH190']['ZI024_SUL'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH190']['ZI024_TDS'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH190']['ZI024_TEP'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH190']['ZI024_TUR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH190']['ZI024_WAC'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH190']['ZI024_WTNO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH190']['ZI025_HDP'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH190']['ZI025_WLE'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH190']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['BH190']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH190']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH190']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH190']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH190']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['BH190']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH190']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH190']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH220'] = {}
    field_information['GGDM 3.0']['DefaultValues']['BH220']['ADR'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BH220']['ADUR'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH220']['ANFL'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH220']['AOO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH220']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH220']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH220']['CAA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH220']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH220']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH220']['DCAP'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH220']['DINF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH220']['F_CODE'] = 'BH220'
    field_information['GGDM 3.0']['DefaultValues']['BH220']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH220']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH220']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH220']['GRD'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH220']['HGT'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH220']['LMC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH220']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH220']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH220']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH220']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH220']['WDST'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH220']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH220']['WLSS'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH220']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH220']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH220']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['BH220']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH220']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BH220']['ZI005_FNA2'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BH220']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH220']['ZI005_GNT2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH220']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BH220']['ZI005_NFN2'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BH220']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BH220']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH220']['ZI024_ASE'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH220']['ZI024_AWO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH220']['ZI024_AWOI'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH220']['ZI024_AWOX'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH220']['ZI024_CFR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH220']['ZI024_CLO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH220']['ZI024_CYN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH220']['ZI024_DRL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH220']['ZI024_DVPT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH220']['ZI024_FMR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH220']['ZI024_FRR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH220']['ZI024_HAR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH220']['ZI024_MGN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH220']['ZI024_PHW'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH220']['ZI024_PMP'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH220']['ZI024_PUR'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH220']['ZI024_PUR2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH220']['ZI024_PUR3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH220']['ZI024_PUR4'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH220']['ZI024_PUR5'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH220']['ZI024_SCC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH220']['ZI024_SUL'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH220']['ZI024_TDS'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH220']['ZI024_TEP'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH220']['ZI024_TUR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH220']['ZI024_WAC'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH220']['ZI024_WTNO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH220']['ZI024_WUR'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH220']['ZI024_WUR2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH220']['ZI024_WUR3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH220']['ZI024_WUR4'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH220']['ZI024_YWQ'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH220']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['BH220']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH220']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH220']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH220']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH220']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['BH220']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH220']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH220']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH220']['ZVH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH230'] = {}
    field_information['GGDM 3.0']['DefaultValues']['BH230']['AQN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BH230']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH230']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH230']['CAA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH230']['CDI'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH230']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH230']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH230']['DWL'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH230']['DZP'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH230']['F_CODE'] = 'BH230'
    field_information['GGDM 3.0']['DefaultValues']['BH230']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH230']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH230']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH230']['HGT'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH230']['LMC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH230']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH230']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH230']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH230']['PUD'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH230']['SWW'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH230']['TSSM'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH230']['TSSM2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH230']['TSSM3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH230']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH230']['WAD'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BH230']['WCAC'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH230']['WDST'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH230']['WFT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH230']['WHCO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH230']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH230']['WWM'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH230']['WWM2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH230']['WWM3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH230']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH230']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH230']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['BH230']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH230']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BH230']['ZI005_FNA2'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BH230']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH230']['ZI005_GNT2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH230']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BH230']['ZI005_NFN2'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BH230']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BH230']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH230']['ZI024_ASE'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH230']['ZI024_AWO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH230']['ZI024_AWOI'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH230']['ZI024_AWOX'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH230']['ZI024_CFR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH230']['ZI024_CLO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH230']['ZI024_CYN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH230']['ZI024_DRL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH230']['ZI024_DVPT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH230']['ZI024_FMR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH230']['ZI024_FRR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH230']['ZI024_HAR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH230']['ZI024_HYP'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH230']['ZI024_MGN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH230']['ZI024_PHW'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH230']['ZI024_PMP'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH230']['ZI024_SCC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH230']['ZI024_SUL'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH230']['ZI024_TDS'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH230']['ZI024_TEP'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH230']['ZI024_TUR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH230']['ZI024_WAC'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH230']['ZI024_WTBB'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH230']['ZI024_WTCA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH230']['ZI024_WTFE'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH230']['ZI024_WTKK'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH230']['ZI024_WTMN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH230']['ZI024_WTNA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH230']['ZI024_WTNO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH230']['ZI024_WTPO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH230']['ZI024_WTSI'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BH230']['ZI024_WUR'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH230']['ZI024_WUR2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH230']['ZI024_WUR3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH230']['ZI024_WUR4'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH230']['ZI024_YWQ'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH230']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['BH230']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH230']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BH230']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH230']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH230']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['BH230']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH230']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH230']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BH230']['ZVH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BI005'] = {}
    field_information['GGDM 3.0']['DefaultValues']['BI005']['AOO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BI005']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BI005']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BI005']['CAA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BI005']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BI005']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BI005']['F_CODE'] = 'BI005'
    field_information['GGDM 3.0']['DefaultValues']['BI005']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BI005']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BI005']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BI005']['HGT'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BI005']['LCA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BI005']['LMC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BI005']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BI005']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BI005']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BI005']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BI005']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BI005']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BI005']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BI005']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['BI005']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BI005']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BI005']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BI005']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BI005']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BI005']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BI005']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['BI005']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BI005']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BI005']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BI005']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BI005']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['BI005']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BI005']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BI005']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BI005']['ZVH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BI006'] = {}
    field_information['GGDM 3.0']['DefaultValues']['BI006']['AOO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BI006']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BI006']['AWP'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BI006']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BI006']['CAA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BI006']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BI006']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BI006']['DZP'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BI006']['F_CODE'] = 'BI006'
    field_information['GGDM 3.0']['DefaultValues']['BI006']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BI006']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BI006']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BI006']['HGT'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BI006']['LMC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BI006']['LNU'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BI006']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BI006']['MCC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BI006']['MCC2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BI006']['MCC3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BI006']['MWD'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BI006']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BI006']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BI006']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BI006']['VOI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BI006']['WDU'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BI006']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BI006']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BI006']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BI006']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['BI006']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BI006']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BI006']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BI006']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BI006']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BI006']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BI006']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['BI006']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BI006']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BI006']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BI006']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BI006']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['BI006']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BI006']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BI006']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BI006']['ZVH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BI010'] = {}
    field_information['GGDM 3.0']['DefaultValues']['BI010']['AOO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BI010']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BI010']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BI010']['CAA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BI010']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BI010']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BI010']['F_CODE'] = 'BI010'
    field_information['GGDM 3.0']['DefaultValues']['BI010']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BI010']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BI010']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BI010']['HGT'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BI010']['LMC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BI010']['LUN'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BI010']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BI010']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BI010']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BI010']['PMPR'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BI010']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BI010']['VCM'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BI010']['VCM2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BI010']['VCM3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BI010']['VLM'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BI010']['WDST'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BI010']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BI010']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BI010']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BI010']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['BI010']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BI010']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BI010']['ZI005_FNA2'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BI010']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BI010']['ZI005_GNT2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BI010']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BI010']['ZI005_NFN2'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BI010']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BI010']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BI010']['ZI024_ASE'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BI010']['ZI024_CFR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BI010']['ZI024_CLO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BI010']['ZI024_CYN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BI010']['ZI024_FMR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BI010']['ZI024_FRR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BI010']['ZI024_HAR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BI010']['ZI024_HYP'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BI010']['ZI024_MGN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BI010']['ZI024_PHW'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BI010']['ZI024_SCC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BI010']['ZI024_SUL'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BI010']['ZI024_TDS'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BI010']['ZI024_TEP'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BI010']['ZI024_TUR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BI010']['ZI024_WAC'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BI010']['ZI024_WTNO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BI010']['ZI024_WUR'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BI010']['ZI024_WUR2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BI010']['ZI024_WUR3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BI010']['ZI024_WUR4'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BI010']['ZI024_YWQ'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BI010']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['BI010']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BI010']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BI010']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BI010']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BI010']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['BI010']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BI010']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BI010']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BI010']['ZVH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BI020'] = {}
    field_information['GGDM 3.0']['DefaultValues']['BI020']['AOO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BI020']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BI020']['AWP'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BI020']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BI020']['CAA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BI020']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BI020']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BI020']['DFT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BI020']['DFU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BI020']['DFU2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BI020']['DFU3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BI020']['DSD'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BI020']['F_CODE'] = 'BI020'
    field_information['GGDM 3.0']['DefaultValues']['BI020']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BI020']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BI020']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BI020']['HGS'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BI020']['HGT'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BI020']['LDC'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BI020']['LMC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BI020']['MCC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BI020']['MCC2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BI020']['MCC3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BI020']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BI020']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BI020']['TRS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BI020']['TRS2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BI020']['TRS3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BI020']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BI020']['VOI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BI020']['WOC'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BI020']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BI020']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BI020']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['BI020']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BI020']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BI020']['ZI005_FNA2'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BI020']['ZI005_FNA3'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BI020']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BI020']['ZI005_GNT2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BI020']['ZI005_GNT3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BI020']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BI020']['ZI005_NFN2'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BI020']['ZI005_NFN3'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BI020']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BI020']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BI020']['ZI024_WPAC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BI020']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['BI020']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BI020']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BI020']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BI020']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BI020']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['BI020']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BI020']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BI020']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BI020']['ZVH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BI030'] = {}
    field_information['GGDM 3.0']['DefaultValues']['BI030']['AOO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BI030']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BI030']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BI030']['CAA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BI030']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BI030']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BI030']['DZP'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BI030']['F_CODE'] = 'BI030'
    field_information['GGDM 3.0']['DefaultValues']['BI030']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BI030']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BI030']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BI030']['HDP'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BI030']['HGT'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BI030']['LMC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BI030']['LNU'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BI030']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BI030']['MCC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BI030']['MCC2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BI030']['MCC3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BI030']['MWD'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BI030']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BI030']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BI030']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BI030']['WDU'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BI030']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BI030']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BI030']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BI030']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['BI030']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BI030']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BI030']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BI030']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BI030']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BI030']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BI030']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['BI030']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BI030']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BI030']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BI030']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BI030']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['BI030']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BI030']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BI030']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BI030']['ZVH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BI040'] = {}
    field_information['GGDM 3.0']['DefaultValues']['BI040']['AOO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BI040']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BI040']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BI040']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BI040']['F_CODE'] = 'BI040'
    field_information['GGDM 3.0']['DefaultValues']['BI040']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BI040']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BI040']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BI040']['LMC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BI040']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BI040']['MCC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BI040']['MCC2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BI040']['MCC3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BI040']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BI040']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BI040']['THI'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BI040']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BI040']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BI040']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BI040']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['BI040']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BI040']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BI040']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BI040']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['BI040']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BI040']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BI040']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BI040']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BI040']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['BI040']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BI040']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BI040']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BI044'] = {}
    field_information['GGDM 3.0']['DefaultValues']['BI044']['AOO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BI044']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BI044']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BI044']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BI044']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BI044']['F_CODE'] = 'BI044'
    field_information['GGDM 3.0']['DefaultValues']['BI044']['FCS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BI044']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BI044']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BI044']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BI044']['HDP'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BI044']['HGT'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BI044']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BI044']['MCC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BI044']['MCC2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BI044']['MCC3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BI044']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BI044']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BI044']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BI044']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BI044']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BI044']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BI044']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['BI044']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BI044']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BI044']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BI044']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BI044']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BI044']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BI044']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['BI044']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BI044']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BI044']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BI044']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BI044']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['BI044']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BI044']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BI044']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BI044']['ZVH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BI045'] = {}
    field_information['GGDM 3.0']['DefaultValues']['BI045']['AOO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BI045']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BI045']['BGT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BI045']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BI045']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BI045']['F_CODE'] = 'BI045'
    field_information['GGDM 3.0']['DefaultValues']['BI045']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BI045']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BI045']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BI045']['HDP'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BI045']['HEI'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BI045']['HGT'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BI045']['LMC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BI045']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BI045']['MCC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BI045']['MCC2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BI045']['MCC3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BI045']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BI045']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BI045']['THI'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BI045']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BI045']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BI045']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BI045']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['BI045']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BI045']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BI045']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BI045']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['BI045']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BI045']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BI045']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BI045']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BI045']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['BI045']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BI045']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BI045']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BI045']['ZVH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BI050'] = {}
    field_information['GGDM 3.0']['DefaultValues']['BI050']['AOO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BI050']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BI050']['AWP'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BI050']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BI050']['CAA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BI050']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BI050']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BI050']['F_CODE'] = 'BI050'
    field_information['GGDM 3.0']['DefaultValues']['BI050']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BI050']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BI050']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BI050']['HGT'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BI050']['LMC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BI050']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BI050']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BI050']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BI050']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BI050']['VCM'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BI050']['VCM2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BI050']['VCM3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BI050']['VOI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BI050']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BI050']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BI050']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BI050']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['BI050']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BI050']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BI050']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BI050']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BI050']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BI050']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BI050']['ZI024_ASE'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BI050']['ZI024_CFR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BI050']['ZI024_CLO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BI050']['ZI024_CYN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BI050']['ZI024_FMR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BI050']['ZI024_FRR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BI050']['ZI024_HAR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BI050']['ZI024_HYP'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BI050']['ZI024_MGN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BI050']['ZI024_PHW'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BI050']['ZI024_SCC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BI050']['ZI024_SUL'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BI050']['ZI024_TDS'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BI050']['ZI024_TEP'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BI050']['ZI024_TUR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BI050']['ZI024_WAC'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BI050']['ZI024_WTNO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BI050']['ZI024_YWQ'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BI050']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['BI050']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BI050']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BI050']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BI050']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BI050']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['BI050']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BI050']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BI050']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BI050']['ZVH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BI060'] = {}
    field_information['GGDM 3.0']['DefaultValues']['BI060']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BI060']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BI060']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BI060']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BI060']['F_CODE'] = 'BI060'
    field_information['GGDM 3.0']['DefaultValues']['BI060']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BI060']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BI060']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BI060']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BI060']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BI060']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BI060']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BI060']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BI060']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BI060']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BI060']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['BI060']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BI060']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BI060']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BI060']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BI060']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BI060']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BI060']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['BI060']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BI060']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BI060']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BI060']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BI060']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['BI060']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BI060']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BI060']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BI070'] = {}
    field_information['GGDM 3.0']['DefaultValues']['BI070']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BI070']['CAA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BI070']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BI070']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BI070']['DZP'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BI070']['F_CODE'] = 'BI070'
    field_information['GGDM 3.0']['DefaultValues']['BI070']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BI070']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BI070']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BI070']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BI070']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BI070']['PWAC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['BI070']['PWAL'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BI070']['PWAU'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BI070']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BI070']['WDAC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['BI070']['WDAL'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BI070']['WDAU'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BI070']['WDH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BI070']['WDL'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BI070']['WVA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BI070']['WVH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BI070']['WVL'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BI070']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BI070']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BI070']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['BI070']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BI070']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BI070']['ZI005_FNA2'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BI070']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BI070']['ZI005_GNT2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BI070']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BI070']['ZI005_NFN2'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BI070']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BI070']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BI070']['ZI024_ASE'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BI070']['ZI024_AWO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BI070']['ZI024_AWOI'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BI070']['ZI024_AWOX'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BI070']['ZI024_CFR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BI070']['ZI024_CLO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BI070']['ZI024_CYN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BI070']['ZI024_FMR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BI070']['ZI024_FRR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BI070']['ZI024_HAR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BI070']['ZI024_MGN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BI070']['ZI024_PHW'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BI070']['ZI024_SCC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BI070']['ZI024_SUL'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BI070']['ZI024_TDS'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BI070']['ZI024_TEP'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BI070']['ZI024_TUR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BI070']['ZI024_WAC'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BI070']['ZI024_WTNO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BI070']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['BI070']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BI070']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BI070']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BI070']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BI070']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['BI070']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BI070']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BI070']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BJ020'] = {}
    field_information['GGDM 3.0']['DefaultValues']['BJ020']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BJ020']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BJ020']['F_CODE'] = 'BJ020'
    field_information['GGDM 3.0']['DefaultValues']['BJ020']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BJ020']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BJ020']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BJ020']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BJ020']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BJ020']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BJ020']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BJ020']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BJ020']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BJ020']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['BJ020']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BJ020']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BJ020']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BJ020']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BJ020']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BJ020']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BJ020']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['BJ020']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BJ020']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BJ020']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BJ020']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BJ020']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['BJ020']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BJ020']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BJ020']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BJ030'] = {}
    field_information['GGDM 3.0']['DefaultValues']['BJ030']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BJ030']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BJ030']['F_CODE'] = 'BJ030'
    field_information['GGDM 3.0']['DefaultValues']['BJ030']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BJ030']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BJ030']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BJ030']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BJ030']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BJ030']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BJ030']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BJ030']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BJ030']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BJ030']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['BJ030']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BJ030']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BJ030']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BJ030']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BJ030']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BJ030']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BJ030']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['BJ030']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BJ030']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BJ030']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BJ030']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BJ030']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['BJ030']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BJ030']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BJ030']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BJ030']['ZVH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BJ031'] = {}
    field_information['GGDM 3.0']['DefaultValues']['BJ031']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BJ031']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BJ031']['DZP'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BJ031']['F_CODE'] = 'BJ031'
    field_information['GGDM 3.0']['DefaultValues']['BJ031']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BJ031']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BJ031']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BJ031']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BJ031']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BJ031']['PFD'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BJ031']['SNDC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['BJ031']['SNDL'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BJ031']['SNDU'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BJ031']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BJ031']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BJ031']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BJ031']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BJ031']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['BJ031']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BJ031']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BJ031']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BJ031']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['BJ031']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BJ031']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BJ031']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BJ031']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BJ031']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['BJ031']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BJ031']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BJ031']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BJ031']['ZVH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BJ040'] = {}
    field_information['GGDM 3.0']['DefaultValues']['BJ040']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BJ040']['F_CODE'] = 'BJ040'
    field_information['GGDM 3.0']['DefaultValues']['BJ040']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BJ040']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BJ040']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BJ040']['HGT'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BJ040']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BJ040']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BJ040']['PFH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BJ040']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BJ040']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BJ040']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BJ040']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['BJ040']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BJ040']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BJ040']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BJ040']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BJ040']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BJ040']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BJ040']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['BJ040']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BJ040']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BJ040']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BJ040']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BJ040']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['BJ040']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BJ040']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BJ040']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BJ040']['ZVH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BJ060'] = {}
    field_information['GGDM 3.0']['DefaultValues']['BJ060']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BJ060']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BJ060']['F_CODE'] = 'BJ060'
    field_information['GGDM 3.0']['DefaultValues']['BJ060']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BJ060']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BJ060']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BJ060']['HGT'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BJ060']['LMC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BJ060']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BJ060']['MCC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BJ060']['MCC2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BJ060']['MCC3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BJ060']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BJ060']['SNDC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['BJ060']['SNDL'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BJ060']['SNDU'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BJ060']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BJ060']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BJ060']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BJ060']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BJ060']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['BJ060']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BJ060']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BJ060']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BJ060']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BJ060']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BJ060']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BJ060']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['BJ060']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BJ060']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BJ060']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BJ060']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BJ060']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['BJ060']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BJ060']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BJ060']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BJ060']['ZVH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BJ065'] = {}
    field_information['GGDM 3.0']['DefaultValues']['BJ065']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BJ065']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BJ065']['F_CODE'] = 'BJ065'
    field_information['GGDM 3.0']['DefaultValues']['BJ065']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BJ065']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BJ065']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BJ065']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BJ065']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BJ065']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BJ065']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BJ065']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BJ065']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BJ065']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['BJ065']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BJ065']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BJ065']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BJ065']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BJ065']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BJ065']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BJ065']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['BJ065']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BJ065']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BJ065']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BJ065']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BJ065']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['BJ065']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BJ065']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BJ065']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BJ070'] = {}
    field_information['GGDM 3.0']['DefaultValues']['BJ070']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BJ070']['F_CODE'] = 'BJ070'
    field_information['GGDM 3.0']['DefaultValues']['BJ070']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BJ070']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BJ070']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BJ070']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BJ070']['SSE'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BJ070']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BJ070']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BJ070']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BJ070']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['BJ070']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BJ070']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BJ070']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BJ070']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BJ070']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BJ070']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BJ070']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['BJ070']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BJ070']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BJ070']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BJ070']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BJ070']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['BJ070']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BJ070']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BJ070']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BJ080'] = {}
    field_information['GGDM 3.0']['DefaultValues']['BJ080']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BJ080']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BJ080']['F_CODE'] = 'BJ080'
    field_information['GGDM 3.0']['DefaultValues']['BJ080']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BJ080']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BJ080']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BJ080']['HGT'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BJ080']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BJ080']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BJ080']['PFH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BJ080']['SNDC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['BJ080']['SNDL'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BJ080']['SNDU'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BJ080']['SSE'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BJ080']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BJ080']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BJ080']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BJ080']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BJ080']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['BJ080']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BJ080']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BJ080']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BJ080']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BJ080']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BJ080']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BJ080']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['BJ080']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BJ080']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BJ080']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BJ080']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BJ080']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['BJ080']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BJ080']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BJ080']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BJ080']['ZVH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BJ099'] = {}
    field_information['GGDM 3.0']['DefaultValues']['BJ099']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BJ099']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BJ099']['F_CODE'] = 'BJ099'
    field_information['GGDM 3.0']['DefaultValues']['BJ099']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BJ099']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BJ099']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BJ099']['LND'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BJ099']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BJ099']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BJ099']['SNDC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['BJ099']['SNDL'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BJ099']['SNDU'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BJ099']['SRD'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BJ099']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BJ099']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BJ099']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BJ099']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BJ099']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['BJ099']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BJ099']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BJ099']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BJ099']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BJ099']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BJ099']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BJ099']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['BJ099']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BJ099']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BJ099']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BJ099']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BJ099']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['BJ099']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BJ099']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BJ099']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BJ100'] = {}
    field_information['GGDM 3.0']['DefaultValues']['BJ100']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BJ100']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BJ100']['F_CODE'] = 'BJ100'
    field_information['GGDM 3.0']['DefaultValues']['BJ100']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BJ100']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BJ100']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BJ100']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BJ100']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BJ100']['SDCC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['BJ100']['SDCL'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BJ100']['SDCU'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BJ100']['SIC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BJ100']['SNDC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['BJ100']['SNDL'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BJ100']['SNDU'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BJ100']['SRD'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BJ100']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BJ100']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BJ100']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BJ100']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BJ100']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['BJ100']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BJ100']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BJ100']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BJ100']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BJ100']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BJ100']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BJ100']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['BJ100']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BJ100']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BJ100']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BJ100']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BJ100']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['BJ100']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BJ100']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BJ100']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BJ110'] = {}
    field_information['GGDM 3.0']['DefaultValues']['BJ110']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BJ110']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BJ110']['F_CODE'] = 'BJ110'
    field_information['GGDM 3.0']['DefaultValues']['BJ110']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BJ110']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BJ110']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BJ110']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BJ110']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BJ110']['SNDC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['BJ110']['SNDL'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BJ110']['SNDU'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BJ110']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BJ110']['VTI'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BJ110']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['BJ110']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BJ110']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BJ110']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['BJ110']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BJ110']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BJ110']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BJ110']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BJ110']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['BJ110']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BJ110']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['BJ110']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BJ110']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['BJ110']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BJ110']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BJ110']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['BJ110']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BJ110']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['BJ110']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['CA010'] = {}
    field_information['GGDM 3.0']['DefaultValues']['CA010']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['CA010']['ESC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['CA010']['F_CODE'] = 'CA010'
    field_information['GGDM 3.0']['DefaultValues']['CA010']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['CA010']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['CA010']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['CA010']['HQC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['CA010']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['CA010']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['CA010']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['CA010']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['CA010']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['CA010']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['CA010']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['CA010']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['CA010']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['CA010']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['CA010']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['CA010']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['CA010']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['CA010']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['CA010']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['CA010']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['CA010']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['CA010']['ZVH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['CA030'] = {}
    field_information['GGDM 3.0']['DefaultValues']['CA030']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['CA030']['ESC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['CA030']['F_CODE'] = 'CA030'
    field_information['GGDM 3.0']['DefaultValues']['CA030']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['CA030']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['CA030']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['CA030']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['CA030']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['CA030']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['CA030']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['CA030']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['CA030']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['CA030']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['CA030']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['CA030']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['CA030']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['CA030']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['CA030']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['CA030']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['CA030']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['CA030']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['CA030']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['CA030']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['CA030']['ZVH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['CA030']['ZVH_AVA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['CA030']['ZVH_VDT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['DA005'] = {}
    field_information['GGDM 3.0']['DefaultValues']['DA005']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['DA005']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['DA005']['F_CODE'] = 'DA005'
    field_information['GGDM 3.0']['DefaultValues']['DA005']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['DA005']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['DA005']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['DA005']['LMC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['DA005']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['DA005']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['DA005']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['DA005']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['DA005']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['DA005']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['DA005']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['DA005']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['DA005']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['DA005']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['DA005']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['DA005']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['DA005']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['DA005']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['DA005']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['DA005']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['DA005']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['DA005']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['DA005']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['DA005']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['DA005']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['DA005']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['DA010'] = {}
    field_information['GGDM 3.0']['DefaultValues']['DA010']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['DA010']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['DA010']['F_CODE'] = 'DA010'
    field_information['GGDM 3.0']['DefaultValues']['DA010']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['DA010']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['DA010']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['DA010']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['DA010']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['DA010']['SDCC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['DA010']['SDCL'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['DA010']['SDCU'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['DA010']['SRD'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['DA010']['STP'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['DA010']['SWC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['DA010']['TSM'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['DA010']['TSM2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['DA010']['TSM3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['DA010']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['DA010']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['DA010']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['DA010']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['DA010']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['DA010']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['DA010']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['DA010']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['DA010']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['DA010']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['DA010']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['DA010']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['DA010']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['DA010']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['DA010']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['DA010']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['DA010']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['DA010']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['DA010']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['DA010']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['DB010'] = {}
    field_information['GGDM 3.0']['DefaultValues']['DB010']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['DB010']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['DB010']['F_CODE'] = 'DB010'
    field_information['GGDM 3.0']['DefaultValues']['DB010']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['DB010']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['DB010']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['DB010']['HGT'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['DB010']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['DB010']['MCC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['DB010']['MCC2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['DB010']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['DB010']['PFH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['DB010']['SGCC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['DB010']['SGCL'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['DB010']['SGCU'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['DB010']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['DB010']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['DB010']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['DB010']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['DB010']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['DB010']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['DB010']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['DB010']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['DB010']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['DB010']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['DB010']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['DB010']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['DB010']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['DB010']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['DB010']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['DB010']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['DB010']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['DB010']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['DB010']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['DB010']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['DB010']['ZVH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['DB028'] = {}
    field_information['GGDM 3.0']['DefaultValues']['DB028']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['DB028']['CAA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['DB028']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['DB028']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['DB028']['DZP'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['DB028']['F_CODE'] = 'DB028'
    field_information['GGDM 3.0']['DefaultValues']['DB028']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['DB028']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['DB028']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['DB028']['LEA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['DB028']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['DB028']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['DB028']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['DB028']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['DB028']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['DB028']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['DB028']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['DB028']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['DB028']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['DB028']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['DB028']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['DB028']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['DB028']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['DB028']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['DB028']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['DB028']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['DB028']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['DB028']['ZI071_CTX'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['DB028']['ZI071_FFN'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['DB028']['ZI071_FFN2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['DB028']['ZI071_FFN3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['DB028']['ZI071_UAO'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['DB028']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['DB028']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['DB028']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['DB028']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['DB029'] = {}
    field_information['GGDM 3.0']['DefaultValues']['DB029']['AOO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['DB029']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['DB029']['CAA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['DB029']['F_CODE'] = 'DB029'
    field_information['GGDM 3.0']['DefaultValues']['DB029']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['DB029']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['DB029']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['DB029']['LMC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['DB029']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['DB029']['OHC'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['DB029']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['DB029']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['DB029']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['DB029']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['DB029']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['DB029']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['DB029']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['DB029']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['DB029']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['DB029']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['DB029']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['DB029']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['DB029']['ZI025_HDP'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['DB029']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['DB029']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['DB029']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['DB029']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['DB029']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['DB029']['ZI071_CTX'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['DB029']['ZI071_FFN'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['DB029']['ZI071_FFN2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['DB029']['ZI071_FFN3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['DB029']['ZI071_UAO'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['DB029']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['DB029']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['DB029']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['DB029']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['DB061'] = {}
    field_information['GGDM 3.0']['DefaultValues']['DB061']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['DB061']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['DB061']['DZP'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['DB061']['F_CODE'] = 'DB061'
    field_information['GGDM 3.0']['DefaultValues']['DB061']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['DB061']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['DB061']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['DB061']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['DB061']['MCC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['DB061']['MCC2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['DB061']['MCC3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['DB061']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['DB061']['PFD'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['DB061']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['DB061']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['DB061']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['DB061']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['DB061']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['DB061']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['DB061']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['DB061']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['DB061']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['DB061']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['DB061']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['DB061']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['DB061']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['DB061']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['DB061']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['DB061']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['DB061']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['DB061']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['DB061']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['DB061']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['DB061']['ZVH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['DB070'] = {}
    field_information['GGDM 3.0']['DefaultValues']['DB070']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['DB070']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['DB070']['CET'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['DB070']['DZP'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['DB070']['F_CODE'] = 'DB070'
    field_information['GGDM 3.0']['DefaultValues']['DB070']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['DB070']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['DB070']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['DB070']['HDP'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['DB070']['HGT'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['DB070']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['DB070']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['DB070']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['DB070']['PFD'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['DB070']['PFH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['DB070']['SGCC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['DB070']['SGCL'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['DB070']['SGCU'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['DB070']['TRS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['DB070']['TRS2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['DB070']['TRS3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['DB070']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['DB070']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['DB070']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['DB070']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['DB070']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['DB070']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['DB070']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['DB070']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['DB070']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['DB070']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['DB070']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['DB070']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['DB070']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['DB070']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['DB070']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['DB070']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['DB070']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['DB070']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['DB070']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['DB070']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['DB071'] = {}
    field_information['GGDM 3.0']['DefaultValues']['DB071']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['DB071']['F_CODE'] = 'DB071'
    field_information['GGDM 3.0']['DefaultValues']['DB071']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['DB071']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['DB071']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['DB071']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['DB071']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['DB071']['PFH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['DB071']['SGCC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['DB071']['SGCL'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['DB071']['SGCU'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['DB071']['TRS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['DB071']['TRS2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['DB071']['TRS3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['DB071']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['DB071']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['DB071']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['DB071']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['DB071']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['DB071']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['DB071']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['DB071']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['DB071']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['DB071']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['DB071']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['DB071']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['DB071']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['DB071']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['DB071']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['DB071']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['DB080'] = {}
    field_information['GGDM 3.0']['DefaultValues']['DB080']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['DB080']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['DB080']['DZP'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['DB080']['F_CODE'] = 'DB080'
    field_information['GGDM 3.0']['DefaultValues']['DB080']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['DB080']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['DB080']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['DB080']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['DB080']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['DB080']['PFD'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['DB080']['SGCC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['DB080']['SGCL'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['DB080']['SGCU'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['DB080']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['DB080']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['DB080']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['DB080']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['DB080']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['DB080']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['DB080']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['DB080']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['DB080']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['DB080']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['DB080']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['DB080']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['DB080']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['DB080']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['DB080']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['DB080']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['DB080']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['DB080']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['DB080']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['DB080']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['DB090'] = {}
    field_information['GGDM 3.0']['DefaultValues']['DB090']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['DB090']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['DB090']['CAA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['DB090']['CET'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['DB090']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['DB090']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['DB090']['F_CODE'] = 'DB090'
    field_information['GGDM 3.0']['DefaultValues']['DB090']['FIC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['DB090']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['DB090']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['DB090']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['DB090']['HGT'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['DB090']['LMC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['DB090']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['DB090']['MCC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['DB090']['MCC2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['DB090']['MCC3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['DB090']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['DB090']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['DB090']['PFH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['DB090']['SGCC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['DB090']['SGCL'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['DB090']['SGCU'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['DB090']['TRS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['DB090']['TRS2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['DB090']['TRS3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['DB090']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['DB090']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['DB090']['WLE'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['DB090']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['DB090']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['DB090']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['DB090']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['DB090']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['DB090']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['DB090']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['DB090']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['DB090']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['DB090']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['DB090']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['DB090']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['DB090']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['DB090']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['DB090']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['DB090']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['DB090']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['DB090']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['DB090']['ZVH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['DB100'] = {}
    field_information['GGDM 3.0']['DefaultValues']['DB100']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['DB100']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['DB100']['F_CODE'] = 'DB100'
    field_information['GGDM 3.0']['DefaultValues']['DB100']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['DB100']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['DB100']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['DB100']['HGT'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['DB100']['LMC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['DB100']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['DB100']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['DB100']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['DB100']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['DB100']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['DB100']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['DB100']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['DB100']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['DB100']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['DB100']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['DB100']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['DB100']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['DB100']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['DB100']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['DB100']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['DB100']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['DB100']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['DB100']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['DB100']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['DB100']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['DB100']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['DB100']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['DB100']['ZVH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['DB110'] = {}
    field_information['GGDM 3.0']['DefaultValues']['DB110']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['DB110']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['DB110']['F_CODE'] = 'DB110'
    field_information['GGDM 3.0']['DefaultValues']['DB110']['FDI'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['DB110']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['DB110']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['DB110']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['DB110']['GFT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['DB110']['GFY'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['DB110']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['DB110']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['DB110']['SDI'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['DB110']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['DB110']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['DB110']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['DB110']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['DB110']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['DB110']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['DB110']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['DB110']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['DB110']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['DB110']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['DB110']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['DB110']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['DB110']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['DB110']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['DB110']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['DB110']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['DB110']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['DB110']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['DB110']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['DB110']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['DB115'] = {}
    field_information['GGDM 3.0']['DefaultValues']['DB115']['AQN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['DB115']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['DB115']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['DB115']['CAA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['DB115']['DOF'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['DB115']['F_CODE'] = 'DB115'
    field_information['GGDM 3.0']['DefaultValues']['DB115']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['DB115']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['DB115']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['DB115']['GOT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['DB115']['LMC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['DB115']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['DB115']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['DB115']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['DB115']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['DB115']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['DB115']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['DB115']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['DB115']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['DB115']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['DB115']['ZI005_FNA2'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['DB115']['ZI005_FNA3'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['DB115']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['DB115']['ZI005_GNT2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['DB115']['ZI005_GNT3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['DB115']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['DB115']['ZI005_NFN2'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['DB115']['ZI005_NFN3'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['DB115']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['DB115']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['DB115']['ZI024_ASE'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['DB115']['ZI024_AWO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['DB115']['ZI024_AWOI'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['DB115']['ZI024_AWOX'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['DB115']['ZI024_CFR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['DB115']['ZI024_CLO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['DB115']['ZI024_CYN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['DB115']['ZI024_FMR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['DB115']['ZI024_FRR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['DB115']['ZI024_HAR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['DB115']['ZI024_HYP'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['DB115']['ZI024_MGN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['DB115']['ZI024_PHW'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['DB115']['ZI024_SCC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['DB115']['ZI024_SUL'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['DB115']['ZI024_TDS'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['DB115']['ZI024_TEP'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['DB115']['ZI024_TUR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['DB115']['ZI024_WAC'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['DB115']['ZI024_WTNO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['DB115']['ZI024_WUR'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['DB115']['ZI024_WUR2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['DB115']['ZI024_WUR3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['DB115']['ZI024_WUR4'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['DB115']['ZI024_YWQ'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['DB115']['ZI025_HDP'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['DB115']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['DB115']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['DB115']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['DB115']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['DB115']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['DB115']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['DB115']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['DB115']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['DB115']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['DB150'] = {}
    field_information['GGDM 3.0']['DefaultValues']['DB150']['AOO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['DB150']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['DB150']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['DB150']['F_CODE'] = 'DB150'
    field_information['GGDM 3.0']['DefaultValues']['DB150']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['DB150']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['DB150']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['DB150']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['DB150']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['DB150']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['DB150']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['DB150']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['DB150']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['DB150']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['DB150']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['DB150']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['DB150']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['DB150']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['DB150']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['DB150']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['DB150']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['DB150']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['DB150']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['DB150']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['DB150']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['DB150']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['DB150']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['DB150']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['DB150']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['DB150']['ZVH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['DB160'] = {}
    field_information['GGDM 3.0']['DefaultValues']['DB160']['AOO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['DB160']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['DB160']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['DB160']['F_CODE'] = 'DB160'
    field_information['GGDM 3.0']['DefaultValues']['DB160']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['DB160']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['DB160']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['DB160']['HGT'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['DB160']['LMC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['DB160']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['DB160']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['DB160']['PFH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['DB160']['RKF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['DB160']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['DB160']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['DB160']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['DB160']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['DB160']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['DB160']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['DB160']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['DB160']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['DB160']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['DB160']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['DB160']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['DB160']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['DB160']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['DB160']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['DB160']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['DB160']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['DB160']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['DB160']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['DB160']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['DB160']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['DB160']['ZVH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['DB170'] = {}
    field_information['GGDM 3.0']['DefaultValues']['DB170']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['DB170']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['DB170']['F_CODE'] = 'DB170'
    field_information['GGDM 3.0']['DefaultValues']['DB170']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['DB170']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['DB170']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['DB170']['HGT'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['DB170']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['DB170']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['DB170']['SAD'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['DB170']['SDO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['DB170']['SDT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['DB170']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['DB170']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['DB170']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['DB170']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['DB170']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['DB170']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['DB170']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['DB170']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['DB170']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['DB170']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['DB170']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['DB170']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['DB170']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['DB170']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['DB170']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['DB170']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['DB170']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['DB170']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['DB170']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['DB170']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['DB170']['ZVH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['DB180'] = {}
    field_information['GGDM 3.0']['DefaultValues']['DB180']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['DB180']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['DB180']['F_CODE'] = 'DB180'
    field_information['GGDM 3.0']['DefaultValues']['DB180']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['DB180']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['DB180']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['DB180']['HGT'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['DB180']['LMC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['DB180']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['DB180']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['DB180']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['DB180']['VGT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['DB180']['VOA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['DB180']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['DB180']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['DB180']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['DB180']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['DB180']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['DB180']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['DB180']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['DB180']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['DB180']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['DB180']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['DB180']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['DB180']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['DB180']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['DB180']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['DB180']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['DB180']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['DB180']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['DB180']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['DB180']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['DB180']['ZVH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['DB185'] = {}
    field_information['GGDM 3.0']['DefaultValues']['DB185']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['DB185']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['DB185']['DZP'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['DB185']['F_CODE'] = 'DB185'
    field_information['GGDM 3.0']['DefaultValues']['DB185']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['DB185']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['DB185']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['DB185']['LMC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['DB185']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['DB185']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['DB185']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['DB185']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['DB185']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['DB185']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['DB185']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['DB185']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['DB185']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['DB185']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['DB185']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['DB185']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['DB185']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['DB185']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['DB185']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['DB185']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['DB185']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['DB185']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['DB185']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['DB185']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['DB185']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['DB185']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['DB190'] = {}
    field_information['GGDM 3.0']['DefaultValues']['DB190']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['DB190']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['DB190']['F_CODE'] = 'DB190'
    field_information['GGDM 3.0']['DefaultValues']['DB190']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['DB190']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['DB190']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['DB190']['HGT'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['DB190']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['DB190']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['DB190']['SGCC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['DB190']['SGCL'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['DB190']['SGCU'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['DB190']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['DB190']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['DB190']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['DB190']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['DB190']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['DB190']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['DB190']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['DB190']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['DB190']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['DB190']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['DB190']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['DB190']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['DB190']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['DB190']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['DB190']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['DB190']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['DB190']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['DB190']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['DB190']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['DB190']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['DB190']['ZVH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['DB211'] = {}
    field_information['GGDM 3.0']['DefaultValues']['DB211']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['DB211']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['DB211']['F_CODE'] = 'DB211'
    field_information['GGDM 3.0']['DefaultValues']['DB211']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['DB211']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['DB211']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['DB211']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['DB211']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['DB211']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['DB211']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['DB211']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['DB211']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['DB211']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['DB211']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['DB211']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['DB211']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['DB211']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['DB211']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['DB211']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['DB211']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['DB211']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['DB211']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['DB211']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['DB211']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['DB211']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['DB211']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['DB211']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['DB211']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['EA010'] = {}
    field_information['GGDM 3.0']['DefaultValues']['EA010']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['EA010']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['EA010']['F_CODE'] = 'EA010'
    field_information['GGDM 3.0']['DefaultValues']['EA010']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['EA010']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['EA010']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['EA010']['LMC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['EA010']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['EA010']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['EA010']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['EA010']['VTI'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['EA010']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['EA010']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['EA010']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['EA010']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['EA010']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['EA010']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['EA010']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['EA010']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['EA010']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['EA010']['ZI013_CSP'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['EA010']['ZI013_CSP2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['EA010']['ZI013_CSP3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['EA010']['ZI013_FFP'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['EA010']['ZI013_FFP2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['EA010']['ZI013_FFP3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['EA010']['ZI013_FMM'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['EA010']['ZI013_FMM2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['EA010']['ZI013_FMM3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['EA010']['ZI013_IRG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['EA010']['ZI013_PIG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['EA010']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['EA010']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['EA010']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['EA010']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['EA010']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['EA010']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['EA010']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['EA010']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['EA010']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['EA010']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['EA020'] = {}
    field_information['GGDM 3.0']['DefaultValues']['EA020']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['EA020']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['EA020']['F_CODE'] = 'EA020'
    field_information['GGDM 3.0']['DefaultValues']['EA020']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['EA020']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['EA020']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['EA020']['HGT'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['EA020']['LMC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['EA020']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['EA020']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['EA020']['PVH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['EA020']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['EA020']['VTI'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['EA020']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['EA020']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['EA020']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['EA020']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['EA020']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['EA020']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['EA020']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['EA020']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['EA020']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['EA020']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['EA020']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['EA020']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['EA020']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['EA020']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['EA020']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['EA020']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['EA030'] = {}
    field_information['GGDM 3.0']['DefaultValues']['EA030']['ADR'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['EA030']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['EA030']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['EA030']['F_CODE'] = 'EA030'
    field_information['GGDM 3.0']['DefaultValues']['EA030']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['EA030']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['EA030']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['EA030']['LMC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['EA030']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['EA030']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['EA030']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['EA030']['VTI'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['EA030']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['EA030']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['EA030']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['EA030']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['EA030']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['EA030']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['EA030']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['EA030']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['EA030']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['EA030']['ZI013_CSP'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['EA030']['ZI013_FFP'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['EA030']['ZI013_FFP2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['EA030']['ZI013_FFP3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['EA030']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['EA030']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['EA030']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['EA030']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['EA030']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['EA030']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['EA030']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['EA030']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['EA030']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['EA030']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['EA031'] = {}
    field_information['GGDM 3.0']['DefaultValues']['EA031']['ADR'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['EA031']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['EA031']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['EA031']['F_CODE'] = 'EA031'
    field_information['GGDM 3.0']['DefaultValues']['EA031']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['EA031']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['EA031']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['EA031']['LMC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['EA031']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['EA031']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['EA031']['TRE'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['EA031']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['EA031']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['EA031']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['EA031']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['EA031']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['EA031']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['EA031']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['EA031']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['EA031']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['EA031']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['EA031']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['EA031']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['EA031']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['EA031']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['EA031']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['EA031']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['EA031']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['EA031']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['EA031']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['EA031']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['EA031']['ZVH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['EA040'] = {}
    field_information['GGDM 3.0']['DefaultValues']['EA040']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['EA040']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['EA040']['DMBC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['EA040']['DMBL'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['EA040']['DMBU'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['EA040']['DMT'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['EA040']['F_CODE'] = 'EA040'
    field_information['GGDM 3.0']['DefaultValues']['EA040']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['EA040']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['EA040']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['EA040']['HGT'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['EA040']['LMC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['EA040']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['EA040']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['EA040']['PVH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['EA040']['SDSC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['EA040']['SDSL'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['EA040']['SDSU'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['EA040']['TRE'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['EA040']['TSCC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['EA040']['TSCL'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['EA040']['TSCU'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['EA040']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['EA040']['VTI'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['EA040']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['EA040']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['EA040']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['EA040']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['EA040']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['EA040']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['EA040']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['EA040']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['EA040']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['EA040']['ZI013_CSP'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['EA040']['ZI013_CSP2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['EA040']['ZI013_CSP3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['EA040']['ZI013_FFP'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['EA040']['ZI013_FFP2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['EA040']['ZI013_FFP3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['EA040']['ZI013_IRG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['EA040']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['EA040']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['EA040']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['EA040']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['EA040']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['EA040']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['EA040']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['EA040']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['EA040']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['EA040']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['EA040']['ZVH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['EA050'] = {}
    field_information['GGDM 3.0']['DefaultValues']['EA050']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['EA050']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['EA050']['F_CODE'] = 'EA050'
    field_information['GGDM 3.0']['DefaultValues']['EA050']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['EA050']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['EA050']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['EA050']['HGT'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['EA050']['LMC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['EA050']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['EA050']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['EA050']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['EA050']['VTI'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['EA050']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['EA050']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['EA050']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['EA050']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['EA050']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['EA050']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['EA050']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['EA050']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['EA050']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['EA050']['ZI013_CSP'] = 16
    field_information['GGDM 3.0']['DefaultValues']['EA050']['ZI013_FFP'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['EA050']['ZI013_FFP2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['EA050']['ZI013_FFP3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['EA050']['ZI013_IRG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['EA050']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['EA050']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['EA050']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['EA050']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['EA050']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['EA050']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['EA050']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['EA050']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['EA050']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['EA050']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['EA050']['ZVH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['EA055'] = {}
    field_information['GGDM 3.0']['DefaultValues']['EA055']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['EA055']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['EA055']['F_CODE'] = 'EA055'
    field_information['GGDM 3.0']['DefaultValues']['EA055']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['EA055']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['EA055']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['EA055']['HGT'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['EA055']['LMC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['EA055']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['EA055']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['EA055']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['EA055']['VTI'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['EA055']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['EA055']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['EA055']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['EA055']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['EA055']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['EA055']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['EA055']['ZI013_CSP'] = 18
    field_information['GGDM 3.0']['DefaultValues']['EA055']['ZI013_FFP'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['EA055']['ZI013_FFP2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['EA055']['ZI013_FFP3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['EA055']['ZI013_IRG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['EA055']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['EA055']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['EA055']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['EA055']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['EA055']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['EA055']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['EA055']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['EA055']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['EA055']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['EA055']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['EA055']['ZVH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['EB010'] = {}
    field_information['GGDM 3.0']['DefaultValues']['EB010']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['EB010']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['EB010']['F_CODE'] = 'EB010'
    field_information['GGDM 3.0']['DefaultValues']['EB010']['FFN'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['EB010']['FFN2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['EB010']['FFN3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['EB010']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['EB010']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['EB010']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['EB010']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['EB010']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['EB010']['TWS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['EB010']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['EB010']['VEG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['EB010']['VTI'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['EB010']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['EB010']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['EB010']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['EB010']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['EB010']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['EB010']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['EB010']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['EB010']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['EB010']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['EB010']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['EB010']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['EB010']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['EB010']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['EB010']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['EB010']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['EB010']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['EB010']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['EB010']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['EB010']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['EB020'] = {}
    field_information['GGDM 3.0']['DefaultValues']['EB020']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['EB020']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['EB020']['DMBC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['EB020']['DMBL'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['EB020']['DMBU'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['EB020']['F_CODE'] = 'EB020'
    field_information['GGDM 3.0']['DefaultValues']['EB020']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['EB020']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['EB020']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['EB020']['HGT'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['EB020']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['EB020']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['EB020']['PVH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['EB020']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['EB020']['VTI'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['EB020']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['EB020']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['EB020']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['EB020']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['EB020']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['EB020']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['EB020']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['EB020']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['EB020']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['EB020']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['EB020']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['EB020']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['EB020']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['EB020']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['EB020']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['EB020']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['EB020']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['EB020']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['EB020']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['EB070'] = {}
    field_information['GGDM 3.0']['DefaultValues']['EB070']['AOO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['EB070']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['EB070']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['EB070']['F_CODE'] = 'EB070'
    field_information['GGDM 3.0']['DefaultValues']['EB070']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['EB070']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['EB070']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['EB070']['HGT'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['EB070']['LMC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['EB070']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['EB070']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['EB070']['PVH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['EB070']['TRE'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['EB070']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['EB070']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['EB070']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['EB070']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['EB070']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['EB070']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['EB070']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['EB070']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['EB070']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['EB070']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['EB070']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['EB070']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['EB070']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['EB070']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['EB070']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['EB070']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['EB070']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['EB070']['ZVH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['EC005'] = {}
    field_information['GGDM 3.0']['DefaultValues']['EC005']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['EC005']['F_CODE'] = 'EC005'
    field_information['GGDM 3.0']['DefaultValues']['EC005']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['EC005']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['EC005']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['EC005']['HGT'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['EC005']['LMC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['EC005']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['EC005']['SDSC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['EC005']['SDSL'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['EC005']['SDSU'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['EC005']['TRE'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['EC005']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['EC005']['VSP'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['EC005']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['EC005']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['EC005']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['EC005']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['EC005']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['EC005']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['EC005']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['EC005']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['EC005']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['EC005']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['EC005']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['EC005']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['EC005']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['EC005']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['EC005']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['EC005']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['EC005']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['EC005']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['EC005']['ZVH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['EC010'] = {}
    field_information['GGDM 3.0']['DefaultValues']['EC010']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['EC010']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['EC010']['F_CODE'] = 'EC010'
    field_information['GGDM 3.0']['DefaultValues']['EC010']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['EC010']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['EC010']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['EC010']['HGT'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['EC010']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['EC010']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['EC010']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['EC010']['VTI'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['EC010']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['EC010']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['EC010']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['EC010']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['EC010']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['EC010']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['EC010']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['EC010']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['EC010']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['EC010']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['EC010']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['EC010']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['EC010']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['EC010']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['EC010']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['EC010']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['EC010']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['EC010']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['EC010']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['EC015'] = {}
    field_information['GGDM 3.0']['DefaultValues']['EC015']['AOO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['EC015']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['EC015']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['EC015']['DMBC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['EC015']['DMBL'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['EC015']['DMBU'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['EC015']['DMT'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['EC015']['F_CODE'] = 'EC015'
    field_information['GGDM 3.0']['DefaultValues']['EC015']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['EC015']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['EC015']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['EC015']['HGT'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['EC015']['LMC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['EC015']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['EC015']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['EC015']['PVH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['EC015']['SBC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['EC015']['SDSC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['EC015']['SDSL'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['EC015']['SDSU'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['EC015']['TRE'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['EC015']['TSCC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['EC015']['TSCL'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['EC015']['TSCU'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['EC015']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['EC015']['VSP'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['EC015']['VSP2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['EC015']['VSP3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['EC015']['VTI'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['EC015']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['EC015']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['EC015']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['EC015']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['EC015']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['EC015']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['EC015']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['EC015']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['EC015']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['EC015']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['EC015']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['EC015']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['EC015']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['EC015']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['EC015']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['EC015']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['EC015']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['EC015']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['EC015']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['EC015']['ZVH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['EC020'] = {}
    field_information['GGDM 3.0']['DefaultValues']['EC020']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['EC020']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['EC020']['F_CODE'] = 'EC020'
    field_information['GGDM 3.0']['DefaultValues']['EC020']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['EC020']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['EC020']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['EC020']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['EC020']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['EC020']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['EC020']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['EC020']['VTI'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['EC020']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['EC020']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['EC020']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['EC020']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['EC020']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['EC020']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['EC020']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['EC020']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['EC020']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['EC020']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['EC020']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['EC020']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['EC020']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['EC020']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['EC020']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['EC020']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['EC020']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['EC020']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['EC020']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['EC040'] = {}
    field_information['GGDM 3.0']['DefaultValues']['EC040']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['EC040']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['EC040']['F_CODE'] = 'EC040'
    field_information['GGDM 3.0']['DefaultValues']['EC040']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['EC040']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['EC040']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['EC040']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['EC040']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['EC040']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['EC040']['VTI'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['EC040']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['EC040']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['EC040']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['EC040']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['EC040']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['EC040']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['EC040']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['EC040']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['EC040']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['EC040']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['EC040']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['EC040']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['EC040']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['EC040']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['EC040']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['EC040']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['EC040']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['EC040']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['EC040']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['EC050'] = {}
    field_information['GGDM 3.0']['DefaultValues']['EC050']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['EC050']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['EC050']['COA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['EC050']['COC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['EC050']['COG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['EC050']['DMBC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['EC050']['DMBL'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['EC050']['DMBU'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['EC050']['DMT'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['EC050']['F_CODE'] = 'EC050'
    field_information['GGDM 3.0']['DefaultValues']['EC050']['FEO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['EC050']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['EC050']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['EC050']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['EC050']['HGT'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['EC050']['LMC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['EC050']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['EC050']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['EC050']['PVH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['EC050']['SBC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['EC050']['SDSC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['EC050']['SDSL'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['EC050']['SDSU'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['EC050']['STR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['EC050']['TRE'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['EC050']['TSCC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['EC050']['TSCL'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['EC050']['TSCU'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['EC050']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['EC050']['VSP'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['EC050']['VSP2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['EC050']['VSP3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['EC050']['VTI'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['EC050']['WCL'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['EC050']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['EC050']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['EC050']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['EC050']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['EC050']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['EC050']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['EC050']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['EC050']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['EC050']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['EC050']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['EC050']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['EC050']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['EC050']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['EC050']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['EC050']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['EC050']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['EC050']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['EC050']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['EC050']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['EC050']['ZVH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['EC060'] = {}
    field_information['GGDM 3.0']['DefaultValues']['EC060']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['EC060']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['EC060']['F_CODE'] = 'EC060'
    field_information['GGDM 3.0']['DefaultValues']['EC060']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['EC060']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['EC060']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['EC060']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['EC060']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['EC060']['TWS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['EC060']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['EC060']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['EC060']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['EC060']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['EC060']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['EC060']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['EC060']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['EC060']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['EC060']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['EC060']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['EC060']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['EC060']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['EC060']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['EC060']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['EC060']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['EC060']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['EC060']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['EC060']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['EC060']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['EC060']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['ED010'] = {}
    field_information['GGDM 3.0']['DefaultValues']['ED010']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['ED010']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['ED010']['BMC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['ED010']['BMC2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['ED010']['BMC3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['ED010']['CAA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['ED010']['DMBC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['ED010']['DMBL'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['ED010']['DMBU'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['ED010']['DZP'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['ED010']['F_CODE'] = 'ED010'
    field_information['GGDM 3.0']['DefaultValues']['ED010']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['ED010']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['ED010']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['ED010']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['ED010']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['ED010']['TID'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['ED010']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['ED010']['WDAC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['ED010']['WDAL'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['ED010']['WDAU'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['ED010']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['ED010']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['ED010']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['ED010']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['ED010']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['ED010']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['ED010']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['ED010']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['ED010']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['ED010']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['ED010']['ZI024_ASE'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['ED010']['ZI024_CFR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['ED010']['ZI024_CLO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['ED010']['ZI024_CYN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['ED010']['ZI024_FMR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['ED010']['ZI024_FRR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['ED010']['ZI024_HAR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['ED010']['ZI024_HYP'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['ED010']['ZI024_MGN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['ED010']['ZI024_PHW'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['ED010']['ZI024_SCC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['ED010']['ZI024_SUL'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['ED010']['ZI024_TDS'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['ED010']['ZI024_TEP'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['ED010']['ZI024_TUR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['ED010']['ZI024_WAC'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['ED010']['ZI024_WTNO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['ED010']['ZI024_WUR'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['ED010']['ZI024_YWQ'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['ED010']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['ED010']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['ED010']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['ED010']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['ED010']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['ED010']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['ED010']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['ED010']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['ED010']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['ED020'] = {}
    field_information['GGDM 3.0']['DefaultValues']['ED020']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['ED020']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['ED020']['BMC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['ED020']['BMC2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['ED020']['BMC3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['ED020']['CAA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['ED020']['DMBC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['ED020']['DMBL'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['ED020']['DMBU'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['ED020']['DMT'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['ED020']['DZP'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['ED020']['F_CODE'] = 'ED020'
    field_information['GGDM 3.0']['DefaultValues']['ED020']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['ED020']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['ED020']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['ED020']['HDP'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['ED020']['HGT'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['ED020']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['ED020']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['ED020']['PVH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['ED020']['SDSC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['ED020']['SDSL'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['ED020']['SDSU'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['ED020']['TID'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['ED020']['TRE'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['ED020']['TSCC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['ED020']['TSCL'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['ED020']['TSCU'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['ED020']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['ED020']['VSP'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['ED020']['VSP2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['ED020']['VSP3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['ED020']['WDAC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['ED020']['WDAL'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['ED020']['WDAU'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['ED020']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['ED020']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['ED020']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['ED020']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['ED020']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['ED020']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['ED020']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['ED020']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['ED020']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['ED020']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['ED020']['ZI024_ASE'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['ED020']['ZI024_CFR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['ED020']['ZI024_CLO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['ED020']['ZI024_CYN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['ED020']['ZI024_FMR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['ED020']['ZI024_FRR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['ED020']['ZI024_HAR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['ED020']['ZI024_HYP'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['ED020']['ZI024_MGN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['ED020']['ZI024_PHW'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['ED020']['ZI024_SCC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['ED020']['ZI024_SUL'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['ED020']['ZI024_TDS'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['ED020']['ZI024_TEP'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['ED020']['ZI024_TUR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['ED020']['ZI024_WAC'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['ED020']['ZI024_WTNO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['ED020']['ZI024_WUR'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['ED020']['ZI024_YWQ'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['ED020']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['ED020']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['ED020']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['ED020']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['ED020']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['ED020']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['ED020']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['ED020']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['ED020']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['EE010'] = {}
    field_information['GGDM 3.0']['DefaultValues']['EE010']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['EE010']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['EE010']['F_CODE'] = 'EE010'
    field_information['GGDM 3.0']['DefaultValues']['EE010']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['EE010']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['EE010']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['EE010']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['EE010']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['EE010']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['EE010']['VTI'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['EE010']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['EE010']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['EE010']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['EE010']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['EE010']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['EE010']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['EE010']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['EE010']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['EE010']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['EE010']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['EE010']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['EE010']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['EE010']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['EE010']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['EE010']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['EE010']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['EE010']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['EE010']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['EE010']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['EE030'] = {}
    field_information['GGDM 3.0']['DefaultValues']['EE030']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['EE030']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['EE030']['F_CODE'] = 'EE030'
    field_information['GGDM 3.0']['DefaultValues']['EE030']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['EE030']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['EE030']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['EE030']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['EE030']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['EE030']['TSM'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['EE030']['TSM2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['EE030']['TSM3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['EE030']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['EE030']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['EE030']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['EE030']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['EE030']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['EE030']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['EE030']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['EE030']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['EE030']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['EE030']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['EE030']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['EE030']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['EE030']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['EE030']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['EE030']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['EE030']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['EE030']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['EE030']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['EE030']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['EE030']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['FA000'] = {}
    field_information['GGDM 3.0']['DefaultValues']['FA000']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['FA000']['BST'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['FA000']['CAA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['FA000']['DSP'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['FA000']['F_CODE'] = 'FA000'
    field_information['GGDM 3.0']['DefaultValues']['FA000']['FA003_BAL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['FA000']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['FA000']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['FA000']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['FA000']['LSP'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['FA000']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['FA000']['MGL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['FA000']['MGL2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['FA000']['MGL3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['FA000']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['FA000']['RPC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['FA000']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['FA000']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['FA000']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['FA000']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['FA000']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['FA000']['ZI005_FNAA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['FA000']['ZI005_FNAB'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['FA000']['ZI005_GNTA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['FA000']['ZI005_GNTB'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['FA000']['ZI005_NFNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['FA000']['ZI005_NFNB'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['FA000']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['FA000']['ZI020_FI2A'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['FA000']['ZI020_FI2B'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['FA000']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['FA000']['ZI020_GE4A'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['FA000']['ZI020_GE4B'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['FA000']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['FA000']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['FA000']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['FA000']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['FA000']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['FA000']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['FA000']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['FA000']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['FA000']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['FA002'] = {}
    field_information['GGDM 3.0']['DefaultValues']['FA002']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['FA002']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['FA002']['F_CODE'] = 'FA002'
    field_information['GGDM 3.0']['DefaultValues']['FA002']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['FA002']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['FA002']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['FA002']['GEC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['FA002']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['FA002']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['FA002']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['FA002']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['FA002']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['FA002']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['FA002']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['FA002']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['FA002']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['FA002']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['FA002']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['FA002']['ZI020_IC4'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['FA002']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['FA002']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['FA002']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['FA002']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['FA002']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['FA002']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['FA002']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['FA002']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['FA002']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['FA003'] = {}
    field_information['GGDM 3.0']['DefaultValues']['FA003']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['FA003']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['FA003']['CAA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['FA003']['F_CODE'] = 'FA003'
    field_information['GGDM 3.0']['DefaultValues']['FA003']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['FA003']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['FA003']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['FA003']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['FA003']['PPL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['FA003']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['FA003']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['FA003']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['FA003']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['FA003']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['FA003']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['FA003']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['FA003']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['FA003']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['FA003']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['FA003']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['FA003']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['FA003']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['FA003']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['FA003']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['FA003']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['FA003']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['FA003']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['FA003']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['FA012'] = {}
    field_information['GGDM 3.0']['DefaultValues']['FA012']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['FA012']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['FA012']['CCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['FA012']['CSO'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['FA012']['F_CODE'] = 'FA012'
    field_information['GGDM 3.0']['DefaultValues']['FA012']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['FA012']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['FA012']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['FA012']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['FA012']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['FA012']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['FA012']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['FA012']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['FA012']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['FA012']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['FA012']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['FA012']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['FA012']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['FA012']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['FA012']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['FA012']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['FA012']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['FA012']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['FA012']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['FA012']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['FA012']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['FA012']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['FA012']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['FA012']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['FA012']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['FA015'] = {}
    field_information['GGDM 3.0']['DefaultValues']['FA015']['AOO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['FA015']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['FA015']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['FA015']['CAA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['FA015']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['FA015']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['FA015']['F_CODE'] = 'FA015'
    field_information['GGDM 3.0']['DefaultValues']['FA015']['FFN'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['FA015']['FFN2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['FA015']['FFN3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['FA015']['FRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['FA015']['FRT2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['FA015']['FRT3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['FA015']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['FA015']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['FA015']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['FA015']['HGT'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['FA015']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['FA015']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['FA015']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['FA015']['PRM'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['FA015']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['FA015']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['FA015']['YSU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['FA015']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['FA015']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['FA015']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['FA015']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['FA015']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['FA015']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['FA015']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['FA015']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['FA015']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['FA015']['ZI025_HDP'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['FA015']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['FA015']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['FA015']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['FA015']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['FA015']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['FA015']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['FA015']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['FA015']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['FA015']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['FA015']['ZVH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['FA100'] = {}
    field_information['GGDM 3.0']['DefaultValues']['FA100']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['FA100']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['FA100']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['FA100']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['FA100']['F_CODE'] = 'FA100'
    field_information['GGDM 3.0']['DefaultValues']['FA100']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['FA100']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['FA100']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['FA100']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['FA100']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['FA100']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['FA100']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['FA100']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['FA100']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['FA100']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['FA100']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['FA100']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['FA100']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['FA100']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['FA100']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['FA100']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['FA100']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['FA100']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['FA100']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['FA100']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['FA100']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['FA100']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['FA100']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['FA100']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['FA100']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['FA100']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['FA110'] = {}
    field_information['GGDM 3.0']['DefaultValues']['FA110']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['FA110']['F_CODE'] = 'FA110'
    field_information['GGDM 3.0']['DefaultValues']['FA110']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['FA110']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['FA110']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['FA110']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['FA110']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['FA110']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['FA110']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['FA110']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['FA110']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['FA110']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['FA110']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['FA110']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['FA110']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['FA110']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['FA110']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['FA110']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['FA110']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['FA110']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['FA110']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['FA110']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['FA165'] = {}
    field_information['GGDM 3.0']['DefaultValues']['FA165']['ADR'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['FA165']['AOO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['FA165']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['FA165']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['FA165']['CAA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['FA165']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['FA165']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['FA165']['F_CODE'] = 'FA165'
    field_information['GGDM 3.0']['DefaultValues']['FA165']['FFN'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['FA165']['FFN2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['FA165']['FFN3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['FA165']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['FA165']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['FA165']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['FA165']['HGT'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['FA165']['LMC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['FA165']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['FA165']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['FA165']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['FA165']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['FA165']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['FA165']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['FA165']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['FA165']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['FA165']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['FA165']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['FA165']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['FA165']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['FA165']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['FA165']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['FA165']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['FA165']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['FA165']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['FA165']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['FA165']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['FA165']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['FA165']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['FA165']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['FA165']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['FA165']['ZVH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['FA210'] = {}
    field_information['GGDM 3.0']['DefaultValues']['FA210']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['FA210']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['FA210']['CAA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['FA210']['CAM'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['FA210']['F_CODE'] = 'FA210'
    field_information['GGDM 3.0']['DefaultValues']['FA210']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['FA210']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['FA210']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['FA210']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['FA210']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['FA210']['SRL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['FA210']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['FA210']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['FA210']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['FA210']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['FA210']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['FA210']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['FA210']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['FA210']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['FA210']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['FA210']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['FA210']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['FA210']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['FA210']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['FA210']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['FA210']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['FA210']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['FA210']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['FA210']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['FA210']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['FA210']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['FC021'] = {}
    field_information['GGDM 3.0']['DefaultValues']['FC021']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['FC021']['BRG'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['FC021']['CAA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['FC021']['CFT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['FC021']['DMC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['FC021']['DPG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['FC021']['DPG2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['FC021']['DPG3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['FC021']['DRP'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['FC021']['DSP'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['FC021']['F_CODE'] = 'FC021'
    field_information['GGDM 3.0']['DefaultValues']['FC021']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['FC021']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['FC021']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['FC021']['LAF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['FC021']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['FC021']['MAN'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['FC021']['MAS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['FC021']['MCY'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['FC021']['MCY2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['FC021']['MCY3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['FC021']['MLO'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['FC021']['MNR'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['FC021']['MNR2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['FC021']['MNR3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['FC021']['MRR'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['FC021']['MRR2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['FC021']['MRR3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['FC021']['NFP'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['FC021']['NFP2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['FC021']['NFP3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['FC021']['NOA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['FC021']['NOA2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['FC021']['NOA3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['FC021']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['FC021']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['FC021']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['FC021']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['FC021']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['FC021']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['FC021']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['FC021']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['FC021']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['FC021']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['FC021']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['FC021']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['FC021']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['FC021']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['FC021']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['FC021']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['FC021']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['FC021']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['FC021']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['FC021']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['FC034'] = {}
    field_information['GGDM 3.0']['DefaultValues']['FC034']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['FC034']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['FC034']['CAA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['FC034']['DAN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['FC034']['F_CODE'] = 'FC034'
    field_information['GGDM 3.0']['DefaultValues']['FC034']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['FC034']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['FC034']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['FC034']['HDP'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['FC034']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['FC034']['MAN'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['FC034']['MAS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['FC034']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['FC034']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['FC034']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['FC034']['ZHDP_DCR'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['FC034']['ZHDP_DKC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['FC034']['ZHDP_DKC2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['FC034']['ZHDP_DKC3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['FC034']['ZHDP_SVC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['FC034']['ZHDP_TEC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['FC034']['ZHDP_TEC2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['FC034']['ZHDP_TEC3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['FC034']['ZHDP_VDC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['FC034']['ZHDP_VDR'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['FC034']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['FC034']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['FC034']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['FC034']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['FC034']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['FC034']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['FC034']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['FC034']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['FC034']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['FC034']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['FC034']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['FC034']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['FC034']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['FC034']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['FC034']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['FC034']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['FC034']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['FC034']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['FC035'] = {}
    field_information['GGDM 3.0']['DefaultValues']['FC035']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['FC035']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['FC035']['F_CODE'] = 'FC035'
    field_information['GGDM 3.0']['DefaultValues']['FC035']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['FC035']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['FC035']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['FC035']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['FC035']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['FC035']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['FC035']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['FC035']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['FC035']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['FC035']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['FC035']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['FC035']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['FC035']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['FC035']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['FC035']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['FC035']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['FC035']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['FC035']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['FC035']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['FC035']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['FC035']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['FC035']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['FC035']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['FC035']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['FC035']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['FC037'] = {}
    field_information['GGDM 3.0']['DefaultValues']['FC037']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['FC037']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['FC037']['CAB'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['FC037']['DAN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['FC037']['F_CODE'] = 'FC037'
    field_information['GGDM 3.0']['DefaultValues']['FC037']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['FC037']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['FC037']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['FC037']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['FC037']['MAN'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['FC037']['MCY'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['FC037']['MCY2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['FC037']['MCY3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['FC037']['MLO'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['FC037']['MNR'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['FC037']['MNR2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['FC037']['MNR3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['FC037']['MRR'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['FC037']['MRR2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['FC037']['MRR3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['FC037']['OPT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['FC037']['ORS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['FC037']['ORS2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['FC037']['ORS3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['FC037']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['FC037']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['FC037']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['FC037']['WPC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['FC037']['WPC2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['FC037']['WPC3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['FC037']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['FC037']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['FC037']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['FC037']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['FC037']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['FC037']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['FC037']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['FC037']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['FC037']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['FC037']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['FC037']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['FC037']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['FC037']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['FC037']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['FC037']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['FC037']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['FC037']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['FC037']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['FC041'] = {}
    field_information['GGDM 3.0']['DefaultValues']['FC041']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['FC041']['CAA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['FC041']['DOF'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['FC041']['F_CODE'] = 'FC041'
    field_information['GGDM 3.0']['DefaultValues']['FC041']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['FC041']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['FC041']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['FC041']['IAS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['FC041']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['FC041']['MAN'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['FC041']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['FC041']['TAN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['FC041']['TSP'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['FC041']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['FC041']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['FC041']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['FC041']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['FC041']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['FC041']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['FC041']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['FC041']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['FC041']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['FC041']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['FC041']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['FC041']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['FC041']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['FC041']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['FC041']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['FC041']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['FC041']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['FC041']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['FC041']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['FC041']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['FC100'] = {}
    field_information['GGDM 3.0']['DefaultValues']['FC100']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['FC100']['BRR'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['FC100']['F_CODE'] = 'FC100'
    field_information['GGDM 3.0']['DefaultValues']['FC100']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['FC100']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['FC100']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['FC100']['LOR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['FC100']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['FC100']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['FC100']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['FC100']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['FC100']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['FC100']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['FC100']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['FC100']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['FC100']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['FC100']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['FC100']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['FC100']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['FC100']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['FC100']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['FC100']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['FC100']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['FC100']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['FC100']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['FC100']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['FC100']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['FC130'] = {}
    field_information['GGDM 3.0']['DefaultValues']['FC130']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['FC130']['BRR'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['FC130']['F_CODE'] = 'FC130'
    field_information['GGDM 3.0']['DefaultValues']['FC130']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['FC130']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['FC130']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['FC130']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['FC130']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['FC130']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['FC130']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['FC130']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['FC130']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['FC130']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['FC130']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['FC130']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['FC130']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['FC130']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['FC130']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['FC130']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['FC130']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['FC130']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['FC130']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['FC130']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['FC130']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['FC130']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['FC130']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['FC165'] = {}
    field_information['GGDM 3.0']['DefaultValues']['FC165']['BDS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['FC165']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['FC165']['BRR'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['FC165']['BRS'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['FC165']['DAN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['FC165']['DOF'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['FC165']['DRP'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['FC165']['F_CODE'] = 'FC165'
    field_information['GGDM 3.0']['DefaultValues']['FC165']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['FC165']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['FC165']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['FC165']['HDP'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['FC165']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['FC165']['MAN'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['FC165']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['FC165']['RTT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['FC165']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['FC165']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['FC165']['ZHDP_DCR'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['FC165']['ZHDP_DKC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['FC165']['ZHDP_DKC2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['FC165']['ZHDP_DKC3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['FC165']['ZHDP_SVC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['FC165']['ZHDP_TEC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['FC165']['ZHDP_TEC2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['FC165']['ZHDP_TEC3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['FC165']['ZHDP_VDC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['FC165']['ZHDP_VDR'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['FC165']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['FC165']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['FC165']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['FC165']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['FC165']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['FC165']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['FC165']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['FC165']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['FC165']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['FC165']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['FC165']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['FC165']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['FC165']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['FC165']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['FC165']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['FC165']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['FC165']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['FC165']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['FC177'] = {}
    field_information['GGDM 3.0']['DefaultValues']['FC177']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['FC177']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['FC177']['F_CODE'] = 'FC177'
    field_information['GGDM 3.0']['DefaultValues']['FC177']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['FC177']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['FC177']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['FC177']['HDP'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['FC177']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['FC177']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['FC177']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['FC177']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['FC177']['ZHDP_DCR'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['FC177']['ZHDP_DKC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['FC177']['ZHDP_DKC2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['FC177']['ZHDP_DKC3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['FC177']['ZHDP_SVC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['FC177']['ZHDP_TEC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['FC177']['ZHDP_TEC2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['FC177']['ZHDP_TEC3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['FC177']['ZHDP_VDC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['FC177']['ZHDP_VDR'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['FC177']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['FC177']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['FC177']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['FC177']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['FC177']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['FC177']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['FC177']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['FC177']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['FC177']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['FC177']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['FC177']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['FC177']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['FC177']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['FC177']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['FC177']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['FC177']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['FC177']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['FC177']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['GA033'] = {}
    field_information['GGDM 3.0']['DefaultValues']['GA033']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['GA033']['ART'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['GA033']['ASO'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['GA033']['AWP'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['GA033']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['GA033']['CMS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['GA033']['DIA'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['GA033']['DIR'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['GA033']['F_CODE'] = 'GA033'
    field_information['GGDM 3.0']['DefaultValues']['GA033']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['GA033']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['GA033']['GA032_NSX'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['GA033']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['GA033']['LOC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['GA033']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['GA033']['MCA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['GA033']['MCC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['GA033']['MCC2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['GA033']['MCC3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['GA033']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['GA033']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['GA033']['PRM'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['GA033']['PWR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['GA033']['RAC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['GA033']['RSI'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['GA033']['SPT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['GA033']['SRL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['GA033']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['GA033']['VOI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['GA033']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['GA033']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['GA033']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['GA033']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['GA033']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['GA033']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['GA033']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['GA033']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['GA033']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['GA033']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['GA033']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['GA033']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['GA033']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['GA033']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['GA033']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['GA033']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['GA033']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['GA033']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['GA033']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['GA033']['ZVH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['GB005'] = {}
    field_information['GGDM 3.0']['DefaultValues']['GB005']['APT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['GB005']['APT2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['GB005']['APT3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['GB005']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['GB005']['ASY'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['GB005']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['GB005']['CAA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['GB005']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['GB005']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['GB005']['F_CODE'] = 'GB005'
    field_information['GGDM 3.0']['DefaultValues']['GB005']['FPT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['GB005']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['GB005']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['GB005']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['GB005']['IKO'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['GB005']['LASZ'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['GB005']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['GB005']['MAG'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['GB005']['NA8'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['GB005']['NAO'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['GB005']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['GB005']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['GB005']['PEC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['GB005']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['GB005']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['GB005']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['GB005']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['GB005']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['GB005']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['GB005']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['GB005']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['GB005']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['GB005']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['GB005']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['GB005']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['GB005']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['GB005']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['GB005']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['GB005']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['GB005']['ZI103_MVD'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['GB005']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['GB005']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['GB005']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['GB005']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['GB005']['ZVA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['GB005']['ZVH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['GB013'] = {}
    field_information['GGDM 3.0']['DefaultValues']['GB013']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['GB013']['CAA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['GB013']['CHA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['GB013']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['GB013']['COC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['GB013']['COL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['GB013']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['GB013']['F_CODE'] = 'GB013'
    field_information['GGDM 3.0']['DefaultValues']['GB013']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['GB013']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['GB013']['GB001_AID'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['GB013']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['GB013']['HGT'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['GB013']['LCN'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['GB013']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['GB013']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['GB013']['PER'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['GB013']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['GB013']['VIS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['GB013']['VIS2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['GB013']['VIS3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['GB013']['VOI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['GB013']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['GB013']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['GB013']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['GB013']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['GB013']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['GB013']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['GB013']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['GB013']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['GB013']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['GB013']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['GB013']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['GB013']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['GB013']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['GB013']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['GB013']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['GB013']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['GB013']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['GB013']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['GB013']['ZVH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['GB015'] = {}
    field_information['GGDM 3.0']['DefaultValues']['GB015']['APU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['GB015']['APU2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['GB015']['APU3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['GB015']['APY'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['GB015']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['GB015']['AXS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['GB015']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['GB015']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['GB015']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['GB015']['F_CODE'] = 'GB015'
    field_information['GGDM 3.0']['DefaultValues']['GB015']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['GB015']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['GB015']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['GB015']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['GB015']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['GB015']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['GB015']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['GB015']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['GB015']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['GB015']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['GB015']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['GB015']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['GB015']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['GB015']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['GB015']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['GB015']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['GB015']['ZI019_ASP'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['GB015']['ZI019_ASP2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['GB015']['ZI019_ASP3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['GB015']['ZI019_ASU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['GB015']['ZI019_ASU2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['GB015']['ZI019_ASU3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['GB015']['ZI019_ASX'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['GB015']['ZI019_SFS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['GB015']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['GB015']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['GB015']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['GB015']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['GB015']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['GB015']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['GB015']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['GB015']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['GB015']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['GB015']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['GB015']['ZVH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['GB030'] = {}
    field_information['GGDM 3.0']['DefaultValues']['GB030']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['GB030']['AXS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['GB030']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['GB030']['CAA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['GB030']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['GB030']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['GB030']['F_CODE'] = 'GB030'
    field_information['GGDM 3.0']['DefaultValues']['GB030']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['GB030']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['GB030']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['GB030']['HAF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['GB030']['HGT'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['GB030']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['GB030']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['GB030']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['GB030']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['GB030']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['GB030']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['GB030']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['GB030']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['GB030']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['GB030']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['GB030']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['GB030']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['GB030']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['GB030']['ZI019_ASP'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['GB030']['ZI019_ASP2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['GB030']['ZI019_ASP3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['GB030']['ZI019_ASU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['GB030']['ZI019_ASU2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['GB030']['ZI019_ASU3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['GB030']['ZI019_ASX'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['GB030']['ZI019_SFS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['GB030']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['GB030']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['GB030']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['GB030']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['GB030']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['GB030']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['GB030']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['GB030']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['GB030']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['GB030']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['GB030']['ZVH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['GB035'] = {}
    field_information['GGDM 3.0']['DefaultValues']['GB035']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['GB035']['ASY'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['GB035']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['GB035']['CAA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['GB035']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['GB035']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['GB035']['F_CODE'] = 'GB035'
    field_information['GGDM 3.0']['DefaultValues']['GB035']['FPT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['GB035']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['GB035']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['GB035']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['GB035']['IKO'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['GB035']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['GB035']['MAG'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['GB035']['NA8'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['GB035']['NAO'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['GB035']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['GB035']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['GB035']['PEC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['GB035']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['GB035']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['GB035']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['GB035']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['GB035']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['GB035']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['GB035']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['GB035']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['GB035']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['GB035']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['GB035']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['GB035']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['GB035']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['GB035']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['GB035']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['GB035']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['GB035']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['GB035']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['GB035']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['GB035']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['GB035']['ZVA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['GB035']['ZVH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['GB040'] = {}
    field_information['GGDM 3.0']['DefaultValues']['GB040']['AOO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['GB040']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['GB040']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['GB040']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['GB040']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['GB040']['F_CODE'] = 'GB040'
    field_information['GGDM 3.0']['DefaultValues']['GB040']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['GB040']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['GB040']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['GB040']['HGT'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['GB040']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['GB040']['MCC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['GB040']['MCC2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['GB040']['MCC3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['GB040']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['GB040']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['GB040']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['GB040']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['GB040']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['GB040']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['GB040']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['GB040']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['GB040']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['GB040']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['GB040']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['GB040']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['GB040']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['GB040']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['GB040']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['GB040']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['GB040']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['GB040']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['GB040']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['GB040']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['GB040']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['GB040']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['GB040']['ZVH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['GB045'] = {}
    field_information['GGDM 3.0']['DefaultValues']['GB045']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['GB045']['ASU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['GB045']['ASU2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['GB045']['ASU3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['GB045']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['GB045']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['GB045']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['GB045']['F_CODE'] = 'GB045'
    field_information['GGDM 3.0']['DefaultValues']['GB045']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['GB045']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['GB045']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['GB045']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['GB045']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['GB045']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['GB045']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['GB045']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['GB045']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['GB045']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['GB045']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['GB045']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['GB045']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['GB045']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['GB045']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['GB045']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['GB045']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['GB045']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['GB045']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['GB045']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['GB045']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['GB045']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['GB045']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['GB045']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['GB045']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['GB045']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['GB045']['ZVH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['GB050'] = {}
    field_information['GGDM 3.0']['DefaultValues']['GB050']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['GB050']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['GB050']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['GB050']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['GB050']['F_CODE'] = 'GB050'
    field_information['GGDM 3.0']['DefaultValues']['GB050']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['GB050']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['GB050']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['GB050']['HGT'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['GB050']['LNU'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['GB050']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['GB050']['MCC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['GB050']['MCC2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['GB050']['MCC3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['GB050']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['GB050']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['GB050']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['GB050']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['GB050']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['GB050']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['GB050']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['GB050']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['GB050']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['GB050']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['GB050']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['GB050']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['GB050']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['GB050']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['GB050']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['GB050']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['GB050']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['GB050']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['GB050']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['GB050']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['GB050']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['GB050']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['GB050']['ZVH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['GB055'] = {}
    field_information['GGDM 3.0']['DefaultValues']['GB055']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['GB055']['AXS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['GB055']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['GB055']['CAA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['GB055']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['GB055']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['GB055']['DEV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['GB055']['F_CODE'] = 'GB055'
    field_information['GGDM 3.0']['DefaultValues']['GB055']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['GB055']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['GB055']['GB052_RIDH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['GB055']['GB052_RIDL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['GB055']['GB052_TRHH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['GB055']['GB052_TRHL'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['GB055']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['GB055']['GSGCHC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['GB055']['GSGCHL'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['GB055']['GSGCHU'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['GB055']['GSGCLC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['GB055']['GSGCLL'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['GB055']['GSGCLU'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['GB055']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['GB055']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['GB055']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['GB055']['SBB'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['GB055']['SERP'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['GB055']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['GB055']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['GB055']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['GB055']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['GB055']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['GB055']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['GB055']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['GB055']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['GB055']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['GB055']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['GB055']['ZI019_ASP'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['GB055']['ZI019_ASP2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['GB055']['ZI019_ASP3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['GB055']['ZI019_ASU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['GB055']['ZI019_ASU2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['GB055']['ZI019_ASU3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['GB055']['ZI019_ASX'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['GB055']['ZI019_SFS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['GB055']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['GB055']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['GB055']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['GB055']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['GB055']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['GB055']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['GB055']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['GB055']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['GB055']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['GB055']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['GB055']['ZVH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['GB065'] = {}
    field_information['GGDM 3.0']['DefaultValues']['GB065']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['GB065']['ASY'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['GB065']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['GB065']['CAA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['GB065']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['GB065']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['GB065']['F_CODE'] = 'GB065'
    field_information['GGDM 3.0']['DefaultValues']['GB065']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['GB065']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['GB065']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['GB065']['IKO'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['GB065']['LASZ'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['GB065']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['GB065']['MAG'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['GB065']['NA8'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['GB065']['NAO'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['GB065']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['GB065']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['GB065']['PEC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['GB065']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['GB065']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['GB065']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['GB065']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['GB065']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['GB065']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['GB065']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['GB065']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['GB065']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['GB065']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['GB065']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['GB065']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['GB065']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['GB065']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['GB065']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['GB065']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['GB065']['ZI103_MVD'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['GB065']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['GB065']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['GB065']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['GB065']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['GB065']['ZVA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['GB065']['ZVH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['GB070'] = {}
    field_information['GGDM 3.0']['DefaultValues']['GB070']['AOO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['GB070']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['GB070']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['GB070']['CAA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['GB070']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['GB070']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['GB070']['F_CODE'] = 'GB070'
    field_information['GGDM 3.0']['DefaultValues']['GB070']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['GB070']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['GB070']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['GB070']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['GB070']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['GB070']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['GB070']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['GB070']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['GB070']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['GB070']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['GB070']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['GB070']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['GB070']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['GB070']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['GB070']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['GB070']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['GB070']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['GB070']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['GB070']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['GB070']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['GB070']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['GB070']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['GB070']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['GB070']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['GB070']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['GB070']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['GB070']['ZVH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['GB075'] = {}
    field_information['GGDM 3.0']['DefaultValues']['GB075']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['GB075']['AXS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['GB075']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['GB075']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['GB075']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['GB075']['DEV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['GB075']['F_CODE'] = 'GB075'
    field_information['GGDM 3.0']['DefaultValues']['GB075']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['GB075']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['GB075']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['GB075']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['GB075']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['GB075']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['GB075']['SBB'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['GB075']['TXP'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['GB075']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['GB075']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['GB075']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['GB075']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['GB075']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['GB075']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['GB075']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['GB075']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['GB075']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['GB075']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['GB075']['ZI019_ASP'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['GB075']['ZI019_ASP2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['GB075']['ZI019_ASP3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['GB075']['ZI019_ASU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['GB075']['ZI019_ASU2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['GB075']['ZI019_ASU3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['GB075']['ZI019_ASX'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['GB075']['ZI019_SFS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['GB075']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['GB075']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['GB075']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['GB075']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['GB075']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['GB075']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['GB075']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['GB075']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['GB075']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['GB075']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['GB075']['ZVH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['GB230'] = {}
    field_information['GGDM 3.0']['DefaultValues']['GB230']['ADR'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['GB230']['AOO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['GB230']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['GB230']['ATB'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['GB230']['AWP'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['GB230']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['GB230']['CAA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['GB230']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['GB230']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['GB230']['F_CODE'] = 'GB230'
    field_information['GGDM 3.0']['DefaultValues']['GB230']['FFN'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['GB230']['FFN2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['GB230']['FFN3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['GB230']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['GB230']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['GB230']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['GB230']['HGT'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['GB230']['HTP'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['GB230']['LMC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['GB230']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['GB230']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['GB230']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['GB230']['SSR'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['GB230']['SSR2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['GB230']['SSR3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['GB230']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['GB230']['VCM'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['GB230']['VCM2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['GB230']['VCM3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['GB230']['VOI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['GB230']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['GB230']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['GB230']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['GB230']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['GB230']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['GB230']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['GB230']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['GB230']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['GB230']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['GB230']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['GB230']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['GB230']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['GB230']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['GB230']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['GB230']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['GB230']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['GB230']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['GB230']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['GB230']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['GB230']['ZVH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['GB250'] = {}
    field_information['GGDM 3.0']['DefaultValues']['GB250']['ADR'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['GB250']['AOO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['GB250']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['GB250']['AWP'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['GB250']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['GB250']['CAA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['GB250']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['GB250']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['GB250']['F_CODE'] = 'GB250'
    field_information['GGDM 3.0']['DefaultValues']['GB250']['FFN'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['GB250']['FFN2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['GB250']['FFN3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['GB250']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['GB250']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['GB250']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['GB250']['HGT'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['GB250']['HST'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['GB250']['HST2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['GB250']['HST3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['GB250']['HTP'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['GB250']['LMC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['GB250']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['GB250']['MUB'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['GB250']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['GB250']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['GB250']['SSR'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['GB250']['SSR2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['GB250']['SSR3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['GB250']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['GB250']['VOI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['GB250']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['GB250']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['GB250']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['GB250']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['GB250']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['GB250']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['GB250']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['GB250']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['GB250']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['GB250']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['GB250']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['GB250']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['GB250']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['GB250']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['GB250']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['GB250']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['GB250']['ZVH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['IA040'] = {}
    field_information['GGDM 3.0']['DefaultValues']['IA040']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['IA040']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['IA040']['CAA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['IA040']['CDM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['IA040']['CDY'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['IA040']['CSI'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['IA040']['CSY'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['IA040']['F_CODE'] = 'IA040'
    field_information['GGDM 3.0']['DefaultValues']['IA040']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['IA040']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['IA040']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['IA040']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['IA040']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['IA040']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['IA040']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['IA040']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['IA040']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['IA040']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['IA040']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['IA040']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['IA040']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['IA040']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['IA040']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['IA040']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['IA040']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['IA040']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['IA040']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['IA040']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['IA040']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['IA040']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['IA040']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['NA170'] = {}
    field_information['GGDM 3.0']['DefaultValues']['NA170']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NA170']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['NA170']['F_CODE'] = 'NA170'
    field_information['GGDM 3.0']['DefaultValues']['NA170']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['NA170']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['NA170']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NA170']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NA170']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['NA170']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NA170']['PRVR'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['NA170']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['NA170']['VTI'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NA170']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NA170']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['NA170']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NA170']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['NA170']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NA170']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['NA170']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NA170']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['NA170']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['NA170']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['NA170']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['NA170']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NA170']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NA170']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['NA170']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['NA170']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['NA170']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['NA170']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['NA170']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['NM010'] = {}
    field_information['GGDM 3.0']['DefaultValues']['NM010']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM010']['ATC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NM010']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['NM010']['BWVCAC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['NM010']['BWVCAL'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM010']['BWVCAU'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM010']['BWVCBC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['NM010']['BWVCBL'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM010']['BWVCBU'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM010']['CAA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NM010']['CDA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NM010']['CDL'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM010']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['NM010']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NM010']['CWT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NM010']['DEV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NM010']['DMF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NM010']['DOXY'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM010']['F_CODE'] = 'NM010'
    field_information['GGDM 3.0']['DefaultValues']['NM010']['FRZ'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NM010']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['NM010']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['NM010']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NM010']['LMC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NM010']['MWD'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM010']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['NM010']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NM010']['PWAC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['NM010']['PWAL'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM010']['PWAU'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM010']['RLE'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NM010']['SBB'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NM010']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['NM010']['WDAC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['NM010']['WDAL'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM010']['WDAU'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM010']['WVA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM010']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['NM010']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NM010']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['NM010']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NM010']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['NM010']['ZI005_FNA2'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['NM010']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NM010']['ZI005_GNT2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NM010']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['NM010']['ZI005_NFN2'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['NM010']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['NM010']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['NM010']['ZI024_ASE'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM010']['ZI024_AWO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM010']['ZI024_AWOI'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM010']['ZI024_AWOX'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM010']['ZI024_CFR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM010']['ZI024_CLO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM010']['ZI024_CYN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM010']['ZI024_FMR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM010']['ZI024_FRR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM010']['ZI024_HAR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM010']['ZI024_HYP'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NM010']['ZI024_MGN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM010']['ZI024_PHW'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM010']['ZI024_SCC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NM010']['ZI024_SUL'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM010']['ZI024_TDS'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM010']['ZI024_TEP'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM010']['ZI024_TUR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM010']['ZI024_WAC'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM010']['ZI024_WPAC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NM010']['ZI024_WTNO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM010']['ZI024_WUR'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NM010']['ZI024_WUR2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NM010']['ZI024_WUR3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NM010']['ZI024_WUR4'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NM010']['ZI024_YWQ'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NM010']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['NM010']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NM010']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NM010']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['NM010']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['NM010']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['NM010']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['NM010']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['NM010']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['NM020'] = {}
    field_information['GGDM 3.0']['DefaultValues']['NM020']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM020']['BBMCA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NM020']['BBMCA2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NM020']['BBMCA3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NM020']['BBMCB'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NM020']['BBMCB2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NM020']['BBMCB3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NM020']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['NM020']['BH141_AWBA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM020']['BH141_AWBB'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM020']['BH141_IBOA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NM020']['BH141_IBOB'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NM020']['BH141_SHDA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NM020']['BH141_SHDB'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NM020']['BH141_SLTA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NM020']['BH141_SLTB'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NM020']['BH141_WBHA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM020']['BH141_WBHB'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM020']['BMC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NM020']['BMC2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NM020']['BMC3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NM020']['BPWHAC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['NM020']['BPWHAL'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM020']['BPWHAU'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM020']['BPWHBC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['NM020']['BPWHBL'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM020']['BPWHBU'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM020']['BPWSAC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['NM020']['BPWSAL'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM020']['BPWSAU'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM020']['BPWSBC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['NM020']['BPWSBL'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM020']['BPWSBU'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM020']['BWVCAC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['NM020']['BWVCAL'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM020']['BWVCAU'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM020']['BWVCBC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['NM020']['BWVCBL'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM020']['BWVCBU'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM020']['CAA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NM020']['CDA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NM020']['CDL'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM020']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['NM020']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NM020']['CWT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NM020']['DEV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NM020']['DMF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NM020']['DOXY'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM020']['DZP'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM020']['F_CODE'] = 'NM020'
    field_information['GGDM 3.0']['DefaultValues']['NM020']['FRZ'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NM020']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['NM020']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['NM020']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NM020']['HDP'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM020']['HGT'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM020']['LEA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM020']['LMC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NM020']['LOC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NM020']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM020']['MWD'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM020']['NVS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NM020']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['NM020']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NM020']['PWA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM020']['RLE'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NM020']['SBB'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NM020']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['NM020']['WD3'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM020']['WDAC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['NM020']['WDAL'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM020']['WDAU'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM020']['WDH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM020']['WDL'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM020']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM020']['WVA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM020']['WVH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM020']['WVL'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM020']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['NM020']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NM020']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['NM020']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NM020']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['NM020']['ZI005_FNA2'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['NM020']['ZI005_FNA3'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['NM020']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NM020']['ZI005_GNT2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NM020']['ZI005_GNT3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NM020']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['NM020']['ZI005_NFN2'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['NM020']['ZI005_NFN3'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['NM020']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['NM020']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['NM020']['ZI024_ASE'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM020']['ZI024_AWO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM020']['ZI024_AWOI'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM020']['ZI024_AWOX'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM020']['ZI024_CFR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM020']['ZI024_CLO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM020']['ZI024_CYN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM020']['ZI024_FMR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM020']['ZI024_FRR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM020']['ZI024_HAR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM020']['ZI024_HYP'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NM020']['ZI024_MGN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM020']['ZI024_PHW'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM020']['ZI024_SCC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NM020']['ZI024_SQN'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NM020']['ZI024_SUL'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM020']['ZI024_TDS'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM020']['ZI024_TEP'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM020']['ZI024_TUR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM020']['ZI024_WAC'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM020']['ZI024_WPAC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NM020']['ZI024_WSG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NM020']['ZI024_WTNO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM020']['ZI024_WUR'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NM020']['ZI024_WUR2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NM020']['ZI024_WUR3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NM020']['ZI024_WUR4'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NM020']['ZI024_YWQ'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NM020']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['NM020']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NM020']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NM020']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['NM020']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['NM020']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['NM020']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['NM020']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['NM020']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['NM020']['ZVH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM030'] = {}
    field_information['GGDM 3.0']['DefaultValues']['NM030']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM030']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['NM030']['BH141_AWBA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM030']['BH141_AWBB'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM030']['BH141_SHDA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NM030']['BH141_SHDB'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NM030']['BH141_SLTA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NM030']['BH141_SLTB'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NM030']['BH141_WBHA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM030']['BPWHAC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['NM030']['BPWHAL'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM030']['BPWHAU'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM030']['BPWHBC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['NM030']['BPWHBL'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM030']['BPWHBU'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM030']['BWVCAC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['NM030']['BWVCAL'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM030']['BWVCAU'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM030']['BWVCBC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['NM030']['BWVCBL'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM030']['BWVCBU'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM030']['CAA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NM030']['CDA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NM030']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['NM030']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NM030']['DIT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NM030']['DMF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NM030']['DOXY'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM030']['DZP'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM030']['F_CODE'] = 'NM030'
    field_information['GGDM 3.0']['DefaultValues']['NM030']['FRZ'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NM030']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['NM030']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['NM030']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NM030']['LMC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NM030']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['NM030']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NM030']['PWAC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['NM030']['PWAL'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM030']['PWAU'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM030']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['NM030']['WVA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM030']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['NM030']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NM030']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['NM030']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NM030']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['NM030']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['NM030']['ZI024_ASE'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM030']['ZI024_CFR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM030']['ZI024_CLO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM030']['ZI024_CYN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM030']['ZI024_FMR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM030']['ZI024_FRR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM030']['ZI024_HAR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM030']['ZI024_HYP'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NM030']['ZI024_MGN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM030']['ZI024_PHW'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM030']['ZI024_SCC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NM030']['ZI024_SUL'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM030']['ZI024_TDS'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM030']['ZI024_TEP'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM030']['ZI024_TUR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM030']['ZI024_WAC'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM030']['ZI024_WPAC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NM030']['ZI024_WTNO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM030']['ZI024_WUR'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NM030']['ZI024_WUR2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NM030']['ZI024_WUR3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NM030']['ZI024_WUR4'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NM030']['ZI024_YWQ'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NM030']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['NM030']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NM030']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NM030']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['NM030']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['NM030']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['NM030']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['NM030']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['NM030']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['NM030']['ZVH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM082'] = {}
    field_information['GGDM 3.0']['DefaultValues']['NM082']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM082']['AZC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NM082']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['NM082']['BH141_AWBA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM082']['BH141_AWBB'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM082']['BH141_SHDA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NM082']['BH141_SHDB'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NM082']['BH141_SLTA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NM082']['BH141_SLTB'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NM082']['BH141_WBHA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM082']['BPWHAC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['NM082']['BPWHAL'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM082']['BPWHAU'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM082']['BPWHBC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['NM082']['BPWHBL'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM082']['BPWHBU'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM082']['BWVCAC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['NM082']['BWVCAL'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM082']['BWVCAU'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM082']['BWVCBC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['NM082']['BWVCBL'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM082']['BWVCBU'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM082']['CAA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NM082']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['NM082']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NM082']['DMD'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NM082']['DMF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NM082']['DOXY'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM082']['DZP'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM082']['F_CODE'] = 'NM082'
    field_information['GGDM 3.0']['DefaultValues']['NM082']['FFN'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NM082']['FFN2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NM082']['FFN3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NM082']['FRZ'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NM082']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['NM082']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['NM082']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NM082']['IWT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NM082']['LMC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NM082']['MNS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NM082']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['NM082']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NM082']['PWAC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['NM082']['PWAL'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM082']['PWAU'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM082']['TID'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NM082']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['NM082']['VLM'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM082']['WDAC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['NM082']['WDAL'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM082']['WDAU'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM082']['WDH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM082']['WDL'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM082']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['NM082']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NM082']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['NM082']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NM082']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['NM082']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['NM082']['ZI024_ASE'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM082']['ZI024_CFR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM082']['ZI024_CLO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM082']['ZI024_CYN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM082']['ZI024_FMR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM082']['ZI024_FRR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM082']['ZI024_HAR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM082']['ZI024_HYP'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NM082']['ZI024_MGN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM082']['ZI024_PHW'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM082']['ZI024_RTP'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NM082']['ZI024_SCC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NM082']['ZI024_SUL'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM082']['ZI024_TDS'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM082']['ZI024_TEP'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM082']['ZI024_TUR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM082']['ZI024_WAC'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM082']['ZI024_WTNO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM082']['ZI024_WUR'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NM082']['ZI024_WUR2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NM082']['ZI024_WUR3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NM082']['ZI024_WUR4'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NM082']['ZI024_YWQ'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NM082']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['NM082']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NM082']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NM082']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['NM082']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['NM082']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['NM082']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['NM082']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['NM082']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['NM082']['ZVH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM140'] = {}
    field_information['GGDM 3.0']['DefaultValues']['NM140']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM140']['BBMCA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NM140']['BBMCA2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NM140']['BBMCA3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NM140']['BBMCB'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NM140']['BBMCB2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NM140']['BBMCB3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NM140']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['NM140']['BH141_AWBA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM140']['BH141_AWBB'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM140']['BH141_IBOA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NM140']['BH141_IBOB'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NM140']['BH141_SHDA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NM140']['BH141_SHDB'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NM140']['BH141_SLTA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NM140']['BH141_SLTB'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NM140']['BH141_WBHA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM140']['BH141_WBHB'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM140']['BMC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NM140']['BMC2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NM140']['BMC3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NM140']['BPWHAC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['NM140']['BPWHAL'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM140']['BPWHAU'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM140']['BPWHBC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['NM140']['BPWHBL'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM140']['BPWHBU'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM140']['BPWSAC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['NM140']['BPWSAL'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM140']['BPWSAU'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM140']['BPWSBC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['NM140']['BPWSBL'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM140']['BPWSBU'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM140']['BWVCAC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['NM140']['BWVCAL'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM140']['BWVCAU'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM140']['BWVCBC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['NM140']['BWVCBL'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM140']['BWVCBU'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM140']['CAA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NM140']['CDA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NM140']['CDL'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM140']['DMF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NM140']['DOXY'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM140']['DZP'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM140']['F_CODE'] = 'NM140'
    field_information['GGDM 3.0']['DefaultValues']['NM140']['FRZ'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NM140']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['NM140']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['NM140']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NM140']['LOC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NM140']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM140']['NVS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NM140']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['NM140']['PWA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM140']['TID'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NM140']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['NM140']['WCC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NM140']['WD3'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM140']['WDAC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['NM140']['WDAL'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM140']['WDAU'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM140']['WDH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM140']['WDL'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM140']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM140']['WMT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NM140']['WVA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM140']['WVH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM140']['WVL'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM140']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['NM140']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NM140']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['NM140']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NM140']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['NM140']['ZI005_FNA2'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['NM140']['ZI005_FNA3'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['NM140']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NM140']['ZI005_GNT2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NM140']['ZI005_GNT3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NM140']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['NM140']['ZI005_NFN2'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['NM140']['ZI005_NFN3'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['NM140']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['NM140']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['NM140']['ZI024_ASE'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM140']['ZI024_AWO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM140']['ZI024_AWOI'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM140']['ZI024_AWOX'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM140']['ZI024_CFR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM140']['ZI024_CLO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM140']['ZI024_CYN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM140']['ZI024_FMR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM140']['ZI024_FRR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM140']['ZI024_HAR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM140']['ZI024_HYP'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NM140']['ZI024_MGN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM140']['ZI024_PHW'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM140']['ZI024_SCC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NM140']['ZI024_SQN'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NM140']['ZI024_SUL'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM140']['ZI024_TDS'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM140']['ZI024_TEP'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM140']['ZI024_TUR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM140']['ZI024_WAC'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM140']['ZI024_WPAC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NM140']['ZI024_WSG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NM140']['ZI024_WTNO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM140']['ZI024_WUR'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NM140']['ZI024_WUR2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NM140']['ZI024_WUR3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NM140']['ZI024_WUR4'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NM140']['ZI024_YWQ'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NM140']['ZI025_HDP'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM140']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['NM140']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NM140']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NM140']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['NM140']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['NM140']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['NM140']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['NM140']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['NM140']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['NM160'] = {}
    field_information['GGDM 3.0']['DefaultValues']['NM160']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM160']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['NM160']['DMF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NM160']['F_CODE'] = 'NM160'
    field_information['GGDM 3.0']['DefaultValues']['NM160']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['NM160']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['NM160']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NM160']['LMC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NM160']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM160']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['NM160']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['NM160']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM160']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['NM160']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NM160']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['NM160']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NM160']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['NM160']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NM160']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['NM160']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['NM160']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['NM160']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['NM160']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NM160']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NM160']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['NM160']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['NM160']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['NM160']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['NM160']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['NM160']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['NM170'] = {}
    field_information['GGDM 3.0']['DefaultValues']['NM170']['AQN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['NM170']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM170']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['NM170']['CAA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NM170']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['NM170']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NM170']['DMF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NM170']['DOF'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM170']['DZP'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM170']['F_CODE'] = 'NM170'
    field_information['GGDM 3.0']['DefaultValues']['NM170']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['NM170']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['NM170']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NM170']['LUN'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NM170']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['NM170']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NM170']['SWT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NM170']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['NM170']['VLM'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM170']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['NM170']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NM170']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['NM170']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NM170']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['NM170']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['NM170']['ZI024_ASE'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM170']['ZI024_AWO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM170']['ZI024_AWOI'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM170']['ZI024_AWOX'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM170']['ZI024_CFR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM170']['ZI024_CLO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM170']['ZI024_CYN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM170']['ZI024_FMR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM170']['ZI024_FRR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM170']['ZI024_HAR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM170']['ZI024_HYP'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NM170']['ZI024_MGN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM170']['ZI024_PHW'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM170']['ZI024_SCC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NM170']['ZI024_SUL'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM170']['ZI024_TDS'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM170']['ZI024_TEP'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM170']['ZI024_TUR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM170']['ZI024_WAC'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM170']['ZI024_WTNO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM170']['ZI024_WUR'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NM170']['ZI024_WUR2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NM170']['ZI024_WUR3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NM170']['ZI024_WUR4'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NM170']['ZI024_YWQ'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NM170']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['NM170']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NM170']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NM170']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['NM170']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['NM170']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['NM170']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['NM170']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['NM170']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['NM230'] = {}
    field_information['GGDM 3.0']['DefaultValues']['NM230']['AQN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['NM230']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM230']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['NM230']['CAA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NM230']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['NM230']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NM230']['DMF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NM230']['F_CODE'] = 'NM230'
    field_information['GGDM 3.0']['DefaultValues']['NM230']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['NM230']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['NM230']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NM230']['LMC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NM230']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['NM230']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NM230']['SWW'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM230']['TSSM'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NM230']['TSSM2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NM230']['TSSM3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NM230']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['NM230']['WAD'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['NM230']['WDST'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NM230']['WFT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NM230']['WWM'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NM230']['WWM2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NM230']['WWM3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NM230']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['NM230']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NM230']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['NM230']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NM230']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['NM230']['ZI005_FNA2'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['NM230']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NM230']['ZI005_GNT2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NM230']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['NM230']['ZI005_NFN2'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['NM230']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['NM230']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['NM230']['ZI024_ASE'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM230']['ZI024_AWO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM230']['ZI024_AWOI'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM230']['ZI024_AWOX'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM230']['ZI024_CFR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM230']['ZI024_CLO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM230']['ZI024_CYN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM230']['ZI024_DRL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NM230']['ZI024_FMR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM230']['ZI024_FRR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM230']['ZI024_HAR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM230']['ZI024_HYP'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NM230']['ZI024_MGN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM230']['ZI024_PHW'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM230']['ZI024_PMP'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NM230']['ZI024_SCC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NM230']['ZI024_SUL'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM230']['ZI024_TDS'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM230']['ZI024_TEP'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM230']['ZI024_TUR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM230']['ZI024_WAC'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM230']['ZI024_WTNO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NM230']['ZI024_WUR'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NM230']['ZI024_WUR2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NM230']['ZI024_WUR3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NM230']['ZI024_WUR4'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NM230']['ZI024_YWQ'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NM230']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['NM230']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NM230']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NM230']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['NM230']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['NM230']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['NM230']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['NM230']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['NM230']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['NU010'] = {}
    field_information['GGDM 3.0']['DefaultValues']['NU010']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NU010']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['NU010']['CAA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NU010']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['NU010']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NU010']['DMF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NU010']['F_CODE'] = 'NU010'
    field_information['GGDM 3.0']['DefaultValues']['NU010']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['NU010']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['NU010']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NU010']['HGT'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NU010']['LMC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NU010']['LUN'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NU010']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NU010']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['NU010']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NU010']['PMPR'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NU010']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['NU010']['VCM'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NU010']['VCM2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NU010']['VCM3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NU010']['VLM'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NU010']['WDST'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NU010']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['NU010']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NU010']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['NU010']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NU010']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['NU010']['ZI005_FNA2'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['NU010']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NU010']['ZI005_GNT2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NU010']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['NU010']['ZI005_NFN2'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['NU010']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['NU010']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['NU010']['ZI024_ASE'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NU010']['ZI024_CFR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NU010']['ZI024_CLO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NU010']['ZI024_CYN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NU010']['ZI024_FMR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NU010']['ZI024_FRR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NU010']['ZI024_HAR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NU010']['ZI024_HYP'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NU010']['ZI024_MGN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NU010']['ZI024_PHW'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NU010']['ZI024_SCC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NU010']['ZI024_SUL'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NU010']['ZI024_TDS'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NU010']['ZI024_TEP'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NU010']['ZI024_TUR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NU010']['ZI024_WAC'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NU010']['ZI024_WTNO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NU010']['ZI024_WUR'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NU010']['ZI024_WUR2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NU010']['ZI024_WUR3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NU010']['ZI024_WUR4'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NU010']['ZI024_YWQ'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NU010']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['NU010']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NU010']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NU010']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['NU010']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['NU010']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['NU010']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['NU010']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['NU010']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['NU010']['ZVH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NU070'] = {}
    field_information['GGDM 3.0']['DefaultValues']['NU070']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NU070']['AWP'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NU070']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['NU070']['CAA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NU070']['CBP'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NU070']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['NU070']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NU070']['DMF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NU070']['F_CODE'] = 'NU070'
    field_information['GGDM 3.0']['DefaultValues']['NU070']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['NU070']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['NU070']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NU070']['HEI'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NU070']['HGT'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NU070']['LMC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NU070']['LUN'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NU070']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NU070']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['NU070']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NU070']['PPO'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NU070']['PPO2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NU070']['PPO3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NU070']['SPT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NU070']['SSC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NU070']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['NU070']['VCM'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NU070']['VCM2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NU070']['VCM3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NU070']['VLM'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NU070']['VOI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['NU070']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NU070']['YWQ'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NU070']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['NU070']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NU070']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['NU070']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NU070']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['NU070']['ZI005_FNA2'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['NU070']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NU070']['ZI005_GNT2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NU070']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['NU070']['ZI005_NFN2'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['NU070']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['NU070']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['NU070']['ZI024_ASE'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NU070']['ZI024_CFR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NU070']['ZI024_CLO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NU070']['ZI024_CYN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NU070']['ZI024_FMR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NU070']['ZI024_FRR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NU070']['ZI024_HAR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NU070']['ZI024_MGN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NU070']['ZI024_PHW'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NU070']['ZI024_SCC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NU070']['ZI024_SUL'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NU070']['ZI024_TDS'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NU070']['ZI024_TEP'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NU070']['ZI024_TUR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NU070']['ZI024_WAC'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NU070']['ZI024_WTNO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NU070']['ZI024_WUR'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NU070']['ZI024_WUR2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NU070']['ZI024_WUR3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NU070']['ZI024_WUR4'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NU070']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['NU070']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NU070']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NU070']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['NU070']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['NU070']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['NU070']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['NU070']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['NU070']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['NU070']['ZVH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NU113'] = {}
    field_information['GGDM 3.0']['DefaultValues']['NU113']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['NU113']['CAA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NU113']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['NU113']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NU113']['CWT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NU113']['DEV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NU113']['DIM'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NU113']['DMF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NU113']['DZP'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NU113']['F_CODE'] = 'NU113'
    field_information['GGDM 3.0']['DefaultValues']['NU113']['FLO'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NU113']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['NU113']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['NU113']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NU113']['HGT'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NU113']['LEA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NU113']['LMC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NU113']['LOC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NU113']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NU113']['MCC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NU113']['MCC2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NU113']['MCC3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NU113']['NPL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NU113']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['NU113']['OWO'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NU113']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NU113']['PLT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NU113']['PLT2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NU113']['PLT3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NU113']['PMPR'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NU113']['PPO'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NU113']['PPO2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NU113']['PPO3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NU113']['RLE'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NU113']['RTA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NU113']['SBB'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NU113']['SPT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NU113']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['NU113']['WVA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NU113']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['NU113']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NU113']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['NU113']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NU113']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['NU113']['ZI005_FNA2'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['NU113']['ZI005_FNA3'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['NU113']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NU113']['ZI005_GNT2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NU113']['ZI005_GNT3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NU113']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['NU113']['ZI005_NFN2'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['NU113']['ZI005_NFN3'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['NU113']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['NU113']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['NU113']['ZI024_ASE'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NU113']['ZI024_AWO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NU113']['ZI024_AWOI'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NU113']['ZI024_AWOX'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NU113']['ZI024_CFR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NU113']['ZI024_CLO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NU113']['ZI024_CYN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NU113']['ZI024_FMR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NU113']['ZI024_FRR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NU113']['ZI024_HAR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NU113']['ZI024_MGN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NU113']['ZI024_PHW'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NU113']['ZI024_SCC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NU113']['ZI024_SUL'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NU113']['ZI024_TDS'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NU113']['ZI024_TEP'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NU113']['ZI024_TUR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NU113']['ZI024_WAC'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NU113']['ZI024_WTNO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NU113']['ZI024_WUR'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NU113']['ZI024_WUR2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NU113']['ZI024_WUR3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NU113']['ZI024_WUR4'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NU113']['ZI024_YWQ'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NU113']['ZI025_HDP'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NU113']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['NU113']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NU113']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NU113']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['NU113']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['NU113']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['NU113']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['NU113']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['NU113']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['NU113']['ZVH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NU116'] = {}
    field_information['GGDM 3.0']['DefaultValues']['NU116']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NU116']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['NU116']['CAA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NU116']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['NU116']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NU116']['DMF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NU116']['DZP'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NU116']['F_CODE'] = 'NU116'
    field_information['GGDM 3.0']['DefaultValues']['NU116']['FFN'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NU116']['FFN2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NU116']['FFN3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NU116']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['NU116']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['NU116']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NU116']['HGT'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NU116']['LMC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NU116']['LUN'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NU116']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NU116']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['NU116']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NU116']['PPO'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NU116']['PPO2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NU116']['PPO3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NU116']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['NU116']['VCM'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NU116']['VCM2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NU116']['VCM3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NU116']['WDAC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['NU116']['WDAL'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NU116']['WDAU'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NU116']['WDH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NU116']['WDL'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NU116']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NU116']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['NU116']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NU116']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['NU116']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NU116']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['NU116']['ZI005_FNA2'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['NU116']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NU116']['ZI005_GNT2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NU116']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['NU116']['ZI005_NFN2'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['NU116']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['NU116']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['NU116']['ZI024_ASE'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NU116']['ZI024_AWO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NU116']['ZI024_AWOI'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NU116']['ZI024_AWOX'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NU116']['ZI024_CFR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NU116']['ZI024_CLO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NU116']['ZI024_CYN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NU116']['ZI024_DRL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NU116']['ZI024_DVPT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NU116']['ZI024_FMR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NU116']['ZI024_FRR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NU116']['ZI024_HAR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NU116']['ZI024_MGN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NU116']['ZI024_PHW'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NU116']['ZI024_PMP'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NU116']['ZI024_SCC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NU116']['ZI024_SUL'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NU116']['ZI024_TDS'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NU116']['ZI024_TEP'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NU116']['ZI024_TUR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NU116']['ZI024_WAC'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NU116']['ZI024_WTNO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NU116']['ZI024_WUR'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NU116']['ZI024_WUR2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NU116']['ZI024_WUR3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NU116']['ZI024_WUR4'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NU116']['ZI024_YWQ'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NU116']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['NU116']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NU116']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NU116']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['NU116']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['NU116']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['NU116']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['NU116']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['NU116']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['NU116']['ZVH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NU170'] = {}
    field_information['GGDM 3.0']['DefaultValues']['NU170']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NU170']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['NU170']['CAA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NU170']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['NU170']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NU170']['DMF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NU170']['DZP'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NU170']['F_CODE'] = 'NU170'
    field_information['GGDM 3.0']['DefaultValues']['NU170']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['NU170']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['NU170']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NU170']['HGT'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NU170']['LMC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NU170']['LOC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NU170']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NU170']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['NU170']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NU170']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['NU170']['VLM'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NU170']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NU170']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['NU170']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NU170']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['NU170']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NU170']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['NU170']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NU170']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['NU170']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['NU170']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['NU170']['ZI024_ASE'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NU170']['ZI024_CFR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NU170']['ZI024_CLO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NU170']['ZI024_CYN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NU170']['ZI024_FMR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NU170']['ZI024_FRR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NU170']['ZI024_HAR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NU170']['ZI024_HYP'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NU170']['ZI024_MGN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NU170']['ZI024_PHW'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NU170']['ZI024_SCC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NU170']['ZI024_SUL'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NU170']['ZI024_TDS'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NU170']['ZI024_TEP'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NU170']['ZI024_TUR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NU170']['ZI024_WAC'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NU170']['ZI024_WTNO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['NU170']['ZI024_WUR'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NU170']['ZI024_WUR2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NU170']['ZI024_WUR3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NU170']['ZI024_WUR4'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NU170']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['NU170']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NU170']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['NU170']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['NU170']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['NU170']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['NU170']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['NU170']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['NU170']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['SA050'] = {}
    field_information['GGDM 3.0']['DefaultValues']['SA050']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['SA050']['F_CODE'] = 'SA050'
    field_information['GGDM 3.0']['DefaultValues']['SA050']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['SA050']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['SA050']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['SA050']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['SA050']['SGCC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['SA050']['SGCL'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['SA050']['SGCU'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['SA050']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['SA050']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['SA050']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['SA050']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['SA050']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['SA050']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['SA050']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['SA050']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['SA050']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['SA050']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['SA050']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['SA050']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['SA050']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['SA050']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['SA050']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['SA050']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['STB23'] = {}
    field_information['GGDM 3.0']['DefaultValues']['STB23']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['STB23']['F_CODE'] = 'STB23'
    field_information['GGDM 3.0']['DefaultValues']['STB23']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['STB23']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['STB23']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['STB23']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['STB23']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['STB23']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['STB23']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['STB23']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['STB23']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['STB23']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['STB23']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['STB23']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['STB23']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['STB23']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['STB23']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['STB23']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['STB23']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['STB23']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['STB23']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['STB23']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['STBM1'] = {}
    field_information['GGDM 3.0']['DefaultValues']['STBM1']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['STBM1']['CAA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['STBM1']['DSP'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['STBM1']['F_CODE'] = 'STBM1'
    field_information['GGDM 3.0']['DefaultValues']['STBM1']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['STBM1']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['STBM1']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['STBM1']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['STBM1']['MLUS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['STBM1']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['STBM1']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['STBM1']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['STBM1']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['STBM1']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['STBM1']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['STBM1']['ZI005_FNAA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['STBM1']['ZI005_FNAB'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['STBM1']['ZI005_GNTA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['STBM1']['ZI005_GNTB'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['STBM1']['ZI005_NFNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['STBM1']['ZI005_NFNB'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['STBM1']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['STBM1']['ZI020_FI2A'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['STBM1']['ZI020_FI2B'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['STBM1']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['STBM1']['ZI020_GE4A'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['STBM1']['ZI020_GE4B'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['STBM1']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['STBM1']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['STBM1']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['STBM1']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['STBM1']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['STBM1']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['STBM1']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['STBM1']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['STBM1']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['STDPP'] = {}
    field_information['GGDM 3.0']['DefaultValues']['STDPP']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['STDPP']['CAA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['STDPP']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['STDPP']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['STDPP']['F_CODE'] = 'STDPP'
    field_information['GGDM 3.0']['DefaultValues']['STDPP']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['STDPP']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['STDPP']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['STDPP']['HGT'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['STDPP']['HSCD'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['STDPP']['LMC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['STDPP']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['STDPP']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['STDPP']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['STDPP']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['STDPP']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['STDPP']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['STDPP']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['STDPP']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['STDPP']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['STDPP']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['STDPP']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['STDPP']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['STDPP']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['STDPP']['ZI024_ASE'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['STDPP']['ZI024_CFR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['STDPP']['ZI024_CLO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['STDPP']['ZI024_CYN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['STDPP']['ZI024_FMR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['STDPP']['ZI024_FRR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['STDPP']['ZI024_HAR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['STDPP']['ZI024_MGN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['STDPP']['ZI024_PHW'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['STDPP']['ZI024_SCC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['STDPP']['ZI024_SUL'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['STDPP']['ZI024_TDS'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['STDPP']['ZI024_TEP'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['STDPP']['ZI024_TUR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['STDPP']['ZI024_WAC'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['STDPP']['ZI024_WTNO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['STDPP']['ZI024_WUR'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['STDPP']['ZI024_YWQ'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['STDPP']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['STDPP']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['STDPP']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['STDPP']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['STDPP']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['STDPP']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['STDPP']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['STDPP']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['STDPP']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['STDPP']['ZVH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['SU001'] = {}
    field_information['GGDM 3.0']['DefaultValues']['SU001']['ADR'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['SU001']['AOO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['SU001']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['SU001']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['SU001']['CAA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['SU001']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['SU001']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['SU001']['F_CODE'] = 'SU001'
    field_information['GGDM 3.0']['DefaultValues']['SU001']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['SU001']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['SU001']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['SU001']['LMC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['SU001']['LUN'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['SU001']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['SU001']['MLOP'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['SU001']['MLUS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['SU001']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['SU001']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['SU001']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['SU001']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['SU001']['YSU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['SU001']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['SU001']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['SU001']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['SU001']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['SU001']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['SU001']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['SU001']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['SU001']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['SU001']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['SU001']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['SU001']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['SU001']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['SU001']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['SU001']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['SU001']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['SU001']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['SU001']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['SU001']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['SU004'] = {}
    field_information['GGDM 3.0']['DefaultValues']['SU004']['ADR'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['SU004']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['SU004']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['SU004']['CAA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['SU004']['F_CODE'] = 'SU004'
    field_information['GGDM 3.0']['DefaultValues']['SU004']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['SU004']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['SU004']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['SU004']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['SU004']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['SU004']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['SU004']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['SU004']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['SU004']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['SU004']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['SU004']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['SU004']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['SU004']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['SU004']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['SU004']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['SU004']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['SU004']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['SU004']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['SU004']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['SU004']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['SU004']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['SU004']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['SU004']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['SU004']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['SU004']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['SU004']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['SU030'] = {}
    field_information['GGDM 3.0']['DefaultValues']['SU030']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['SU030']['F_CODE'] = 'SU030'
    field_information['GGDM 3.0']['DefaultValues']['SU030']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['SU030']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['SU030']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['SU030']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['SU030']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['SU030']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['SU030']['VOI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['SU030']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['SU030']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['SU030']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['SU030']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['SU030']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['SU030']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['SU030']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['SU030']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['SU030']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['SU030']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['SU030']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['SU030']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['SU030']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['SU030']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['SU030']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['SU030']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['SU030']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['SU030']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['T0181'] = {}
    field_information['GGDM 3.0']['DefaultValues']['T0181']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['T0181']['CAA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['T0181']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['T0181']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['T0181']['DZP'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['T0181']['F_CODE'] = 'T0181'
    field_information['GGDM 3.0']['DefaultValues']['T0181']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['T0181']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['T0181']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['T0181']['HGT'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['T0181']['LUN'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['T0181']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['T0181']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['T0181']['SPT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['T0181']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['T0181']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['T0181']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['T0181']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['T0181']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['T0181']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['T0181']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['T0181']['ZI024_DRL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['T0181']['ZI024_DVPT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['T0181']['ZI024_PMP'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['T0181']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['T0181']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['T0181']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['T0181']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['T0181']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['T0181']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['T0181']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['T0181']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['T0181']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['TBCDL'] = {}
    field_information['GGDM 3.0']['DefaultValues']['TBCDL']['RS6'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['TBCDL']['RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['TBCDL']['RX1'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['TBCDL']['RX2'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['TBCDL']['RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['TBCDL']['RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['TBCDL']['RX5'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['TBCDL']['RX6'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['TBCDL']['RX7'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['TBCDL']['RY1'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['TBCDL']['RY2'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['ZB020'] = {}
    field_information['GGDM 3.0']['DefaultValues']['ZB020']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['ZB020']['CPA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['ZB020']['F_CODE'] = 'ZB020'
    field_information['GGDM 3.0']['DefaultValues']['ZB020']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['ZB020']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['ZB020']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['ZB020']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['ZB020']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['ZB020']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['ZB020']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['ZB020']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['ZB020']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['ZB020']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['ZB020']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['ZB020']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['ZB020']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['ZB020']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['ZB020']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['ZB020']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['ZB020']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['ZB020']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['ZB020']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['ZB020']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['ZB020']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['ZB020']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['ZB020']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['ZB020']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['ZB020']['ZVH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['ZB030'] = {}
    field_information['GGDM 3.0']['DefaultValues']['ZB030']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['ZB030']['CNCP'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['ZB030']['COS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['ZB030']['F_CODE'] = 'ZB030'
    field_information['GGDM 3.0']['DefaultValues']['ZB030']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['ZB030']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['ZB030']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['ZB030']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['ZB030']['MCC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['ZB030']['MCC2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['ZB030']['MCC3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['ZB030']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['ZB030']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['ZB030']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['ZB030']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['ZB030']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['ZB030']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['ZB030']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['ZB030']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['ZB030']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['ZB030']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['ZB030']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['ZB030']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['ZB030']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['ZB030']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['ZB030']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['ZB030']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['ZB030']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['ZB030']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['ZB030']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['ZB030']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['ZB030']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['ZB030']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['ZB030']['ZVH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['ZB036'] = {}
    field_information['GGDM 3.0']['DefaultValues']['ZB036']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['ZB036']['F_CODE'] = 'ZB036'
    field_information['GGDM 3.0']['DefaultValues']['ZB036']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['ZB036']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['ZB036']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['ZB036']['HGT'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['ZB036']['MAN'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['ZB036']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['ZB036']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['ZB036']['TRS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['ZB036']['TRS2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['ZB036']['TRS3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['ZB036']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['ZB036']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['ZB036']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['ZB036']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['ZB036']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['ZB036']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['ZB036']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['ZB036']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['ZB036']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['ZB036']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['ZB036']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['ZB036']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['ZB036']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['ZB036']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['ZB036']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['ZB036']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['ZB036']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['ZB036']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['ZB036']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['ZB036']['ZVH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['ZB050'] = {}
    field_information['GGDM 3.0']['DefaultValues']['ZB050']['BEL'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['ZB050']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['ZB050']['CAA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['ZB050']['F_CODE'] = 'ZB050'
    field_information['GGDM 3.0']['DefaultValues']['ZB050']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['ZB050']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['ZB050']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['ZB050']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['ZB050']['PCF'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['ZB050']['SUY'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['ZB050']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['ZB050']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['ZB050']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['ZB050']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['ZB050']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['ZB050']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['ZB050']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['ZB050']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['ZB050']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['ZB050']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['ZB050']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['ZB050']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['ZB050']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['ZB050']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['ZB050']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['ZB050']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['ZB050']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['ZB050']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['ZB050']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['ZB050']['ZVH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['ZB060'] = {}
    field_information['GGDM 3.0']['DefaultValues']['ZB060']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['ZB060']['CPA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['ZB060']['F_CODE'] = 'ZB060'
    field_information['GGDM 3.0']['DefaultValues']['ZB060']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['ZB060']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['ZB060']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['ZB060']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['ZB060']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['ZB060']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['ZB060']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['ZB060']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['ZB060']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['ZB060']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['ZB060']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['ZB060']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['ZB060']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['ZB060']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['ZB060']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['ZB060']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['ZB060']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['ZB060']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['ZB060']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['ZB060']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['ZB060']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['ZB060']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['ZB060']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['ZB060']['ZVH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['ZC040'] = {}
    field_information['GGDM 3.0']['DefaultValues']['ZC040']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['ZC040']['F_CODE'] = 'ZC040'
    field_information['GGDM 3.0']['DefaultValues']['ZC040']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['ZC040']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['ZC040']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['ZC040']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['ZC040']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['ZC040']['VAVC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['ZC040']['VAVL'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['ZC040']['VAVU'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['ZC040']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['ZC040']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['ZC040']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['ZC040']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['ZC040']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['ZC040']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['ZC040']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['ZC040']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['ZC040']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['ZC040']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['ZC040']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['ZC040']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['ZC040']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['ZC040']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['ZC040']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['ZD020'] = {}
    field_information['GGDM 3.0']['DefaultValues']['ZD020']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['ZD020']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['ZD020']['F_CODE'] = 'ZD020'
    field_information['GGDM 3.0']['DefaultValues']['ZD020']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['ZD020']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['ZD020']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['ZD020']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['ZD020']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['ZD020']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['ZD020']['VCA'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['ZD020']['VCA2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['ZD020']['VCA3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['ZD020']['VCT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['ZD020']['VCT2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['ZD020']['VCT3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['ZD020']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['ZD020']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['ZD020']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['ZD020']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['ZD020']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['ZD020']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['ZD020']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['ZD020']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['ZD020']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['ZD020']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['ZD020']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['ZD020']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['ZD020']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['ZD020']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['ZD020']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['ZD020']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['ZD030'] = {}
    field_information['GGDM 3.0']['DefaultValues']['ZD030']['ARA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['ZD030']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['ZD030']['CUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['ZD030']['F_CODE'] = 'ZD030'
    field_information['GGDM 3.0']['DefaultValues']['ZD030']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['ZD030']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['ZD030']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['ZD030']['LZN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['ZD030']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['ZD030']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['ZD030']['WID'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['ZD030']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['ZD030']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['ZD030']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['ZD030']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['ZD030']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['ZD030']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['ZD030']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['ZD030']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['ZD030']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['ZD030']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['ZD030']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['ZD030']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['ZD030']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['ZD030']['ZI037_REL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['ZD030']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['ZD030']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['ZD030']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['ZD030']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['ZD030']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['ZD040'] = {}
    field_information['GGDM 3.0']['DefaultValues']['ZD040']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['ZD040']['F_CODE'] = 'ZD040'
    field_information['GGDM 3.0']['DefaultValues']['ZD040']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['ZD040']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['ZD040']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['ZD040']['NLT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['ZD040']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['ZD040']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['ZD040']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['ZD040']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['ZD040']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['ZD040']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['ZD040']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['ZD040']['ZI005_FNA2'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['ZD040']['ZI005_FNA3'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['ZD040']['ZI005_GNR'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['ZD040']['ZI005_GNR2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['ZD040']['ZI005_GNR3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['ZD040']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['ZD040']['ZI005_GNT2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['ZD040']['ZI005_GNT3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['ZD040']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['ZD040']['ZI005_NFN2'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['ZD040']['ZI005_NFN3'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['ZD040']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['ZD040']['ZI015_GCUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['ZD040']['ZI015_GCUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['ZD040']['ZI015_GCUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['ZD040']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['ZD040']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['ZD040']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['ZD040']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['ZD040']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['ZD040']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['ZD040']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['ZD040']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['ZD040']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['ZD040']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['ZD045'] = {}
    field_information['GGDM 3.0']['DefaultValues']['ZD045']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['ZD045']['F_CODE'] = 'ZD045'
    field_information['GGDM 3.0']['DefaultValues']['ZD045']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['ZD045']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['ZD045']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['ZD045']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['ZD045']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['ZD045']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['ZD045']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['ZD045']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['ZD045']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['ZD045']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['ZD045']['ZI005_FNA2'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['ZD045']['ZI005_FNA3'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['ZD045']['ZI005_GNR'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['ZD045']['ZI005_GNR2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['ZD045']['ZI005_GNR3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['ZD045']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['ZD045']['ZI005_GNT2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['ZD045']['ZI005_GNT3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['ZD045']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['ZD045']['ZI005_NFN2'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['ZD045']['ZI005_NFN3'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['ZD045']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['ZD045']['ZI015_GCUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['ZD045']['ZI015_GCUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['ZD045']['ZI015_GCUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['ZD045']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['ZD045']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['ZD045']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['ZD045']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['ZD045']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['ZD045']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['ZD045']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['ZD045']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['ZD045']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['ZD045']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['ZD070'] = {}
    field_information['GGDM 3.0']['DefaultValues']['ZD070']['BEN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['ZD070']['DOXY'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['ZD070']['F_CODE'] = 'ZD070'
    field_information['GGDM 3.0']['DefaultValues']['ZD070']['FUFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['ZD070']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['ZD070']['GDBV'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['ZD070']['LEA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['ZD070']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['ZD070']['PWAC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['ZD070']['PWAL'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['ZD070']['PWAU'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['ZD070']['SCOG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['ZD070']['TSTE'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['ZD070']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['ZD070']['WCAC'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['ZD070']['WDAC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['ZD070']['WDAL'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['ZD070']['WDAU'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['ZD070']['WDH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['ZD070']['WDL'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['ZD070']['WHCO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['ZD070']['WODR'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['ZD070']['WTBB'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['ZD070']['WTCA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['ZD070']['WTCL'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['ZD070']['WTFE'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['ZD070']['WTKK'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['ZD070']['WTMN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['ZD070']['WTNA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['ZD070']['WTNO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['ZD070']['WTPO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['ZD070']['WTSI'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['ZD070']['WTST'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['ZD070']['WVA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['ZD070']['WVH'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['ZD070']['WVL'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['ZD070']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['ZD070']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['ZD070']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['ZD070']['ZI004_RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['ZD070']['ZI005_FNA'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['ZD070']['ZI005_FNA2'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['ZD070']['ZI005_FNA3'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['ZD070']['ZI005_GNT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['ZD070']['ZI005_GNT2'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['ZD070']['ZI005_GNT3'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['ZD070']['ZI005_NFN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['ZD070']['ZI005_NFN2'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['ZD070']['ZI005_NFN3'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['ZD070']['ZI006_MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['ZD070']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['ZD070']['ZI024_ASE'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['ZD070']['ZI024_CFR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['ZD070']['ZI024_CLO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['ZD070']['ZI024_CYN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['ZD070']['ZI024_FMR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['ZD070']['ZI024_FRR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['ZD070']['ZI024_HAR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['ZD070']['ZI024_HYP'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['ZD070']['ZI024_MGN'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['ZD070']['ZI024_PHW'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['ZD070']['ZI024_SCC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['ZD070']['ZI024_SUL'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['ZD070']['ZI024_TDS'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['ZD070']['ZI024_TEP'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['ZD070']['ZI024_TUR'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['ZD070']['ZI024_WAC'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['ZD070']['ZI024_WTNO'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['ZD070']['ZI024_YWQ'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['ZD070']['ZI026_CTUC'] = 5
    field_information['GGDM 3.0']['DefaultValues']['ZD070']['ZI026_CTUL'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['ZD070']['ZI026_CTUU'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['ZD070']['ZI031S_URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['ZD070']['ZI039S_UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['ZD070']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['ZD070']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['ZD070']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['ZD070']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['ZI002'] = {}
    field_information['GGDM 3.0']['DefaultValues']['ZI002']['CCN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['ZI002']['CDR'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['ZI002']['F_CODE'] = 'ZI002'
    field_information['GGDM 3.0']['DefaultValues']['ZI002']['SAX_RS1'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['ZI002']['SAX_RS2'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['ZI002']['SAX_RS4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['ZI002']['SAX_RS5'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['ZI002']['SAX_RS6'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['ZI002']['SAX_RS8'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['ZI002']['SAX_RS9'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['ZI002']['SAX_RX1'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['ZI002']['SAX_RX2'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['ZI002']['SAX_RX5'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['ZI002']['SAX_RX6'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['ZI002']['SAX_RX7'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['ZI002']['SAX_RX9'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['ZI002']['SAX_RY0'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['ZI002']['SAX_RY1'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['ZI002']['SAX_RY2'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['ZI002']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['ZI031'] = {}
    field_information['GGDM 3.0']['DefaultValues']['ZI031']['AHA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['ZI031']['AVA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['ZI031']['CID'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['ZI031']['CPS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['ZI031']['DQS'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['ZI031']['EQS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['ZI031']['ETS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['ZI031']['ETZ'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['ZI031']['EVA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['ZI031']['F_CODE'] = 'ZI031'
    field_information['GGDM 3.0']['DefaultValues']['ZI031']['FURL'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['ZI031']['HVA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['ZI031']['HZD'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['ZI031']['MDE'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['ZI031']['MEM'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['ZI031']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['ZI031']['RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['ZI031']['RTL'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['ZI031']['SCVN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['ZI031']['URI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['ZI031']['VDT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['ZI031']['ZI002_UFI'] = 'pimGUID'
    field_information['GGDM 3.0']['DefaultValues']['ZI031']['ZI020_GE4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['ZI031']['ZI020_GE42'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['ZI031']['ZI020_GE43'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['ZI031']['ZI020_GE44'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['ZI031']['ZSAX_RS0'] = 'U'
    field_information['GGDM 3.0']['DefaultValues']['ZI031']['ZSAX_RX0'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['ZI031']['ZSAX_RX3'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['ZI031']['ZSAX_RX4'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['ZI039'] = {}
    field_information['GGDM 3.0']['DefaultValues']['ZI039']['AHA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['ZI039']['AVA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['ZI039']['DQS'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['ZI039']['EQS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['ZI039']['EVA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['ZI039']['F_CODE'] = 'ZI039'
    field_information['GGDM 3.0']['DefaultValues']['ZI039']['HVA'] = -999999.0
    field_information['GGDM 3.0']['DefaultValues']['ZI039']['MDE'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['ZI039']['OTH'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['ZI039']['RCG'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['ZI039']['SCVN'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['ZI039']['UFI'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['ZI039']['ZI001_SDP'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['ZI039']['ZI001_SDV'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['ZI039']['ZI001_SPS'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['ZI039']['ZI001_SRT'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['ZI039']['ZI001_VSC'] = -999999
    field_information['GGDM 3.0']['DefaultValues']['ZI039']['ZI001_VSD'] = 'noInformation'
    field_information['GGDM 3.0']['DefaultValues']['ZI039']['ZI001_VSN'] = 'No Information'
    field_information['GGDM 3.0']['DefaultValues']['ZI039']['ZI004_PRE'] = 'No Information'


    field_information['GGDM 3.0']['Levels'] = {}
    field_information['GGDM 3.0']['Levels']['Global'] = {}
    field_information['GGDM 3.0']['Levels']['Regional'] = {}
    field_information['GGDM 3.0']['Levels']['Local'] = {}
    field_information['GGDM 3.0']['Levels']['Specialized'] = {}
    field_information['GGDM 3.0']['Levels']['Global']['EXTRACTION_MINE_P'] = ('AA010', '100001', 'IndustryPnt')
    field_information['GGDM 3.0']['Levels']['Local']['EXTRACTION_MINE_P'] = ('AA010', '100001', 'IndustryPnt')
    field_information['GGDM 3.0']['Levels']['Regional']['EXTRACTION_MINE_P'] = ('AA010', '100001', 'IndustryPnt')
    field_information['GGDM 3.0']['Levels']['Specialized']['EXTRACTION_MINE_P'] = ('AA010', '100001', 'IndustryPnt')
    field_information['GGDM 3.0']['Levels']['Global']['EXTRACTION_MINE_S'] = ('AA010', '100001', 'IndustrySrf')
    field_information['GGDM 3.0']['Levels']['Local']['EXTRACTION_MINE_S'] = ('AA010', '100001', 'IndustrySrf')
    field_information['GGDM 3.0']['Levels']['Regional']['EXTRACTION_MINE_S'] = ('AA010', '100001', 'IndustrySrf')
    field_information['GGDM 3.0']['Levels']['Specialized']['EXTRACTION_MINE_S'] = ('AA010', '100001', 'IndustrySrf')
    field_information['GGDM 3.0']['Levels']['Specialized']['SHEAR_WALL_C'] = ('AA011', '100002', 'IndustryCrv')
    field_information['GGDM 3.0']['Levels']['Global']['MINE_SHAFT_SUPERSTRUCTURE_P'] = ('AA020', '100003', 'IndustryPnt')
    field_information['GGDM 3.0']['Levels']['Local']['MINE_SHAFT_SUPERSTRUCTURE_P'] = ('AA020', '100003', 'IndustryPnt')
    field_information['GGDM 3.0']['Levels']['Regional']['MINE_SHAFT_SUPERSTRUCTURE_P'] = ('AA020', '100003', 'IndustryPnt')
    field_information['GGDM 3.0']['Levels']['Specialized']['MINE_SHAFT_SUPERSTRUCTURE_P'] = ('AA020', '100003', 'IndustryPnt')
    field_information['GGDM 3.0']['Levels']['Specialized']['MINE_SHAFT_SUPERSTRUCTURE_S'] = ('AA020', '100003', 'IndustrySrf')
    field_information['GGDM 3.0']['Levels']['Global']['RIG_P'] = ('AA040', '100004', 'IndustryPnt')
    field_information['GGDM 3.0']['Levels']['Local']['RIG_P'] = ('AA040', '100004', 'IndustryPnt')
    field_information['GGDM 3.0']['Levels']['Regional']['RIG_P'] = ('AA040', '100004', 'IndustryPnt')
    field_information['GGDM 3.0']['Levels']['Specialized']['RIG_P'] = ('AA040', '100004', 'IndustryPnt')
    field_information['GGDM 3.0']['Levels']['Specialized']['RIG_S'] = ('AA040', '100004', 'IndustrySrf')
    field_information['GGDM 3.0']['Levels']['Specialized']['BOREHOLE_P'] = ('AA045', '100696', 'IndustryPnt')
    field_information['GGDM 3.0']['Levels']['Global']['HYDROCARBONS_FIELD_P'] = ('AA052', '100006', 'IndustryPntExt')
    field_information['GGDM 3.0']['Levels']['Regional']['HYDROCARBONS_FIELD_P'] = ('AA052', '100006', 'IndustryPntExt')
    field_information['GGDM 3.0']['Levels']['Global']['HYDROCARBONS_FIELD_S'] = ('AA052', '100006', 'IndustrySrf')
    field_information['GGDM 3.0']['Levels']['Local']['HYDROCARBONS_FIELD_S'] = ('AA052', '100006', 'IndustrySrf')
    field_information['GGDM 3.0']['Levels']['Regional']['HYDROCARBONS_FIELD_S'] = ('AA052', '100006', 'IndustrySrf')
    field_information['GGDM 3.0']['Levels']['Specialized']['HYDROCARBONS_FIELD_S'] = ('AA052', '100006', 'IndustrySrf')
    field_information['GGDM 3.0']['Levels']['Global']['NON_WATER_WELL_P'] = ('AA054', '155023', 'IndustryPnt')
    field_information['GGDM 3.0']['Levels']['Local']['NON_WATER_WELL_P'] = ('AA054', '155023', 'IndustryPnt')
    field_information['GGDM 3.0']['Levels']['Regional']['NON_WATER_WELL_P'] = ('AA054', '155023', 'IndustryPnt')
    field_information['GGDM 3.0']['Levels']['Specialized']['NON_WATER_WELL_P'] = ('AA054', '155023', 'IndustryPnt')
    field_information['GGDM 3.0']['Levels']['Global']['DISPOSAL_SITE_P'] = ('AB000', '100007', 'IndustryPnt')
    field_information['GGDM 3.0']['Levels']['Regional']['DISPOSAL_SITE_P'] = ('AB000', '100007', 'IndustryPnt')
    field_information['GGDM 3.0']['Levels']['Global']['DISPOSAL_SITE_S'] = ('AB000', '100007', 'IndustrySrf')
    field_information['GGDM 3.0']['Levels']['Local']['DISPOSAL_SITE_S'] = ('AB000', '100007', 'IndustrySrf')
    field_information['GGDM 3.0']['Levels']['Regional']['DISPOSAL_SITE_S'] = ('AB000', '100007', 'IndustrySrf')
    field_information['GGDM 3.0']['Levels']['Specialized']['DISPOSAL_SITE_S'] = ('AB000', '100007', 'IndustrySrf')
    field_information['GGDM 3.0']['Levels']['Global']['RECYCLING_SITE_S'] = ('AB010', '100008', 'IndustrySrf')
    field_information['GGDM 3.0']['Levels']['Local']['RECYCLING_SITE_S'] = ('AB010', '100008', 'IndustrySrf')
    field_information['GGDM 3.0']['Levels']['Regional']['RECYCLING_SITE_S'] = ('AB010', '100008', 'IndustrySrf')
    field_information['GGDM 3.0']['Levels']['Specialized']['RECYCLING_SITE_S'] = ('AB010', '100008', 'IndustrySrf')
    field_information['GGDM 3.0']['Levels']['Specialized']['LIQUID_DIFFUSER_P'] = ('AB021', '100009', 'UtilityInfrastructurePnt')
    field_information['GGDM 3.0']['Levels']['Local']['AERATION_BASIN_S'] = ('AB040', '100010', 'IndustrySrf')
    field_information['GGDM 3.0']['Levels']['Specialized']['AERATION_BASIN_S'] = ('AB040', '100010', 'IndustrySrf')
    field_information['GGDM 3.0']['Levels']['Regional']['WASTE_HEAP_P'] = ('AB507', '177962', 'IndustryPnt')
    field_information['GGDM 3.0']['Levels']['Local']['WASTE_HEAP_S'] = ('AB507', '177962', 'IndustrySrf')
    field_information['GGDM 3.0']['Levels']['Specialized']['WASTE_HEAP_S'] = ('AB507', '177962', 'IndustrySrf')
    field_information['GGDM 3.0']['Levels']['Global']['BLAST_FURNACE_P'] = ('AC010', '100012', 'IndustryPnt')
    field_information['GGDM 3.0']['Levels']['Local']['BLAST_FURNACE_P'] = ('AC010', '100012', 'IndustryPnt')
    field_information['GGDM 3.0']['Levels']['Regional']['BLAST_FURNACE_P'] = ('AC010', '100012', 'IndustryPnt')
    field_information['GGDM 3.0']['Levels']['Specialized']['BLAST_FURNACE_P'] = ('AC010', '100012', 'IndustryPnt')
    field_information['GGDM 3.0']['Levels']['Local']['BLAST_FURNACE_S'] = ('AC010', '100012', 'IndustrySrf')
    field_information['GGDM 3.0']['Levels']['Specialized']['BLAST_FURNACE_S'] = ('AC010', '100012', 'IndustrySrf')
    field_information['GGDM 3.0']['Levels']['Global']['CATALYTIC_CRACKER_P'] = ('AC020', '100013', 'IndustryPnt')
    field_information['GGDM 3.0']['Levels']['Local']['CATALYTIC_CRACKER_P'] = ('AC020', '100013', 'IndustryPnt')
    field_information['GGDM 3.0']['Levels']['Regional']['CATALYTIC_CRACKER_P'] = ('AC020', '100013', 'IndustryPnt')
    field_information['GGDM 3.0']['Levels']['Specialized']['CATALYTIC_CRACKER_P'] = ('AC020', '100013', 'IndustryPnt')
    field_information['GGDM 3.0']['Levels']['Specialized']['CATALYTIC_CRACKER_S'] = ('AC020', '100013', 'IndustrySrf')
    field_information['GGDM 3.0']['Levels']['Local']['SETTLING_POND_S'] = ('AC030', '100014', 'IndustrySrf')
    field_information['GGDM 3.0']['Levels']['Regional']['SETTLING_POND_S'] = ('AC030', '100014', 'IndustrySrf')
    field_information['GGDM 3.0']['Levels']['Specialized']['SETTLING_POND_S'] = ('AC030', '100014', 'IndustrySrf')
    field_information['GGDM 3.0']['Levels']['Global']['HYDROCARBON_PROD_FACILITY_P'] = ('AC040', '100015', 'IndustryPnt')
    field_information['GGDM 3.0']['Levels']['Local']['HYDROCARBON_PROD_FACILITY_P'] = ('AC040', '100015', 'IndustryPnt')
    field_information['GGDM 3.0']['Levels']['Regional']['HYDROCARBON_PROD_FACILITY_P'] = ('AC040', '100015', 'IndustryPnt')
    field_information['GGDM 3.0']['Levels']['Specialized']['HYDROCARBON_PROD_FACILITY_P'] = ('AC040', '100015', 'IndustryPnt')
    field_information['GGDM 3.0']['Levels']['Global']['HYDROCARBON_PROD_FACILITY_S'] = ('AC040', '100015', 'IndustrySrf')
    field_information['GGDM 3.0']['Levels']['Local']['HYDROCARBON_PROD_FACILITY_S'] = ('AC040', '100015', 'IndustrySrf')
    field_information['GGDM 3.0']['Levels']['Regional']['HYDROCARBON_PROD_FACILITY_S'] = ('AC040', '100015', 'IndustrySrf')
    field_information['GGDM 3.0']['Levels']['Specialized']['HYDROCARBON_PROD_FACILITY_S'] = ('AC040', '100015', 'IndustrySrf')
    field_information['GGDM 3.0']['Levels']['Local']['INDUSTRIAL_FURNACE_P'] = ('AC060', '100016', 'IndustryPnt')
    field_information['GGDM 3.0']['Levels']['Specialized']['INDUSTRIAL_FURNACE_P'] = ('AC060', '100016', 'IndustryPnt')
    field_information['GGDM 3.0']['Levels']['Local']['INDUSTRIAL_FURNACE_S'] = ('AC060', '100016', 'IndustrySrf')
    field_information['GGDM 3.0']['Levels']['Specialized']['INDUSTRIAL_FURNACE_S'] = ('AC060', '100016', 'IndustrySrf')
    field_information['GGDM 3.0']['Levels']['Global']['SEWAGE_TREATMENT_PLANT_P'] = ('AC507', '134665', 'UtilityInfrastructurePnt')
    field_information['GGDM 3.0']['Levels']['Local']['SEWAGE_TREATMENT_PLANT_P'] = ('AC507', '134665', 'UtilityInfrastructurePnt')
    field_information['GGDM 3.0']['Levels']['Regional']['SEWAGE_TREATMENT_PLANT_P'] = ('AC507', '134665', 'UtilityInfrastructurePnt')
    field_information['GGDM 3.0']['Levels']['Specialized']['SEWAGE_TREATMENT_PLANT_P'] = ('AC507', '134665', 'UtilityInfrastructurePnt')
    field_information['GGDM 3.0']['Levels']['Global']['SEWAGE_TREATMENT_PLANT_S'] = ('AC507', '134665', 'UtilityInfrastructureSrf')
    field_information['GGDM 3.0']['Levels']['Local']['SEWAGE_TREATMENT_PLANT_S'] = ('AC507', '134665', 'UtilityInfrastructureSrf')
    field_information['GGDM 3.0']['Levels']['Regional']['SEWAGE_TREATMENT_PLANT_S'] = ('AC507', '134665', 'UtilityInfrastructureSrf')
    field_information['GGDM 3.0']['Levels']['Specialized']['SEWAGE_TREATMENT_PLANT_S'] = ('AC507', '134665', 'UtilityInfrastructureSrf')
    field_information['GGDM 3.0']['Levels']['Global']['ELECTRIC_POWER_STATION_P'] = ('AD010', '100018', 'UtilityInfrastructurePnt')
    field_information['GGDM 3.0']['Levels']['Local']['ELECTRIC_POWER_STATION_P'] = ('AD010', '100018', 'UtilityInfrastructurePnt')
    field_information['GGDM 3.0']['Levels']['Regional']['ELECTRIC_POWER_STATION_P'] = ('AD010', '100018', 'UtilityInfrastructurePnt')
    field_information['GGDM 3.0']['Levels']['Specialized']['ELECTRIC_POWER_STATION_P'] = ('AD010', '100018', 'UtilityInfrastructurePnt')
    field_information['GGDM 3.0']['Levels']['Global']['ELECTRIC_POWER_STATION_S'] = ('AD010', '100018', 'UtilityInfrastructureSrf')
    field_information['GGDM 3.0']['Levels']['Local']['ELECTRIC_POWER_STATION_S'] = ('AD010', '100018', 'UtilityInfrastructureSrf')
    field_information['GGDM 3.0']['Levels']['Regional']['ELECTRIC_POWER_STATION_S'] = ('AD010', '100018', 'UtilityInfrastructureSrf')
    field_information['GGDM 3.0']['Levels']['Specialized']['ELECTRIC_POWER_STATION_S'] = ('AD010', '100018', 'UtilityInfrastructureSrf')
    field_information['GGDM 3.0']['Levels']['Local']['SOLAR_PANEL_P'] = ('AD020', '100019', 'UtilityInfrastructurePnt')
    field_information['GGDM 3.0']['Levels']['Specialized']['SOLAR_PANEL_P'] = ('AD020', '100019', 'UtilityInfrastructurePnt')
    field_information['GGDM 3.0']['Levels']['Specialized']['SOLAR_PANEL_S'] = ('AD020', '100019', 'UtilityInfrastructureSrf')
    field_information['GGDM 3.0']['Levels']['Global']['SOLAR_FARM_P'] = ('AD025', '100020', 'UtilityInfrastructurePnt')
    field_information['GGDM 3.0']['Levels']['Local']['SOLAR_FARM_P'] = ('AD025', '100020', 'UtilityInfrastructurePnt')
    field_information['GGDM 3.0']['Levels']['Regional']['SOLAR_FARM_P'] = ('AD025', '100020', 'UtilityInfrastructurePnt')
    field_information['GGDM 3.0']['Levels']['Specialized']['SOLAR_FARM_P'] = ('AD025', '100020', 'UtilityInfrastructurePnt')
    field_information['GGDM 3.0']['Levels']['Global']['SOLAR_FARM_S'] = ('AD025', '100020', 'UtilityInfrastructureSrf')
    field_information['GGDM 3.0']['Levels']['Local']['SOLAR_FARM_S'] = ('AD025', '100020', 'UtilityInfrastructureSrf')
    field_information['GGDM 3.0']['Levels']['Regional']['SOLAR_FARM_S'] = ('AD025', '100020', 'UtilityInfrastructureSrf')
    field_information['GGDM 3.0']['Levels']['Specialized']['SOLAR_FARM_S'] = ('AD025', '100020', 'UtilityInfrastructureSrf')
    field_information['GGDM 3.0']['Levels']['Global']['POWER_SUBSTATION_P'] = ('AD030', '100021', 'UtilityInfrastructurePnt')
    field_information['GGDM 3.0']['Levels']['Local']['POWER_SUBSTATION_P'] = ('AD030', '100021', 'UtilityInfrastructurePnt')
    field_information['GGDM 3.0']['Levels']['Regional']['POWER_SUBSTATION_P'] = ('AD030', '100021', 'UtilityInfrastructurePnt')
    field_information['GGDM 3.0']['Levels']['Specialized']['POWER_SUBSTATION_P'] = ('AD030', '100021', 'UtilityInfrastructurePnt')
    field_information['GGDM 3.0']['Levels']['Local']['POWER_SUBSTATION_S'] = ('AD030', '100021', 'UtilityInfrastructureSrf')
    field_information['GGDM 3.0']['Levels']['Specialized']['POWER_SUBSTATION_S'] = ('AD030', '100021', 'UtilityInfrastructureSrf')
    field_information['GGDM 3.0']['Levels']['Global']['NUCLEAR_REACTOR_CONTAINMENT_P'] = ('AD041', '100022', 'UtilityInfrastructurePnt')
    field_information['GGDM 3.0']['Levels']['Local']['NUCLEAR_REACTOR_CONTAINMENT_P'] = ('AD041', '100022', 'UtilityInfrastructurePnt')
    field_information['GGDM 3.0']['Levels']['Regional']['NUCLEAR_REACTOR_CONTAINMENT_P'] = ('AD041', '100022', 'UtilityInfrastructurePnt')
    field_information['GGDM 3.0']['Levels']['Specialized']['NUCLEAR_REACTOR_CONTAINMENT_P'] = ('AD041', '100022', 'UtilityInfrastructurePnt')
    field_information['GGDM 3.0']['Levels']['Global']['NUCLEAR_REACTOR_CONTAINMENT_S'] = ('AD041', '100022', 'UtilityInfrastructureSrf')
    field_information['GGDM 3.0']['Levels']['Local']['NUCLEAR_REACTOR_CONTAINMENT_S'] = ('AD041', '100022', 'UtilityInfrastructureSrf')
    field_information['GGDM 3.0']['Levels']['Regional']['NUCLEAR_REACTOR_CONTAINMENT_S'] = ('AD041', '100022', 'UtilityInfrastructureSrf')
    field_information['GGDM 3.0']['Levels']['Specialized']['NUCLEAR_REACTOR_CONTAINMENT_S'] = ('AD041', '100022', 'UtilityInfrastructureSrf')
    field_information['GGDM 3.0']['Levels']['Global']['HEATING_FACILITY_P'] = ('AD050', '100023', 'UtilityInfrastructurePnt')
    field_information['GGDM 3.0']['Levels']['Local']['HEATING_FACILITY_P'] = ('AD050', '100023', 'UtilityInfrastructurePnt')
    field_information['GGDM 3.0']['Levels']['Regional']['HEATING_FACILITY_P'] = ('AD050', '100023', 'UtilityInfrastructurePnt')
    field_information['GGDM 3.0']['Levels']['Specialized']['HEATING_FACILITY_P'] = ('AD050', '100023', 'UtilityInfrastructurePnt')
    field_information['GGDM 3.0']['Levels']['Global']['HEATING_FACILITY_S'] = ('AD050', '100023', 'UtilityInfrastructureSrf')
    field_information['GGDM 3.0']['Levels']['Local']['HEATING_FACILITY_S'] = ('AD050', '100023', 'UtilityInfrastructureSrf')
    field_information['GGDM 3.0']['Levels']['Regional']['HEATING_FACILITY_S'] = ('AD050', '100023', 'UtilityInfrastructureSrf')
    field_information['GGDM 3.0']['Levels']['Specialized']['HEATING_FACILITY_S'] = ('AD050', '100023', 'UtilityInfrastructureSrf')
    field_information['GGDM 3.0']['Levels']['Global']['COOLING_FACILITY_P'] = ('AD055', '100697', 'UtilityInfrastructurePnt')
    field_information['GGDM 3.0']['Levels']['Local']['COOLING_FACILITY_P'] = ('AD055', '100697', 'UtilityInfrastructurePnt')
    field_information['GGDM 3.0']['Levels']['Regional']['COOLING_FACILITY_P'] = ('AD055', '100697', 'UtilityInfrastructurePnt')
    field_information['GGDM 3.0']['Levels']['Specialized']['COOLING_FACILITY_P'] = ('AD055', '100697', 'UtilityInfrastructurePnt')
    field_information['GGDM 3.0']['Levels']['Global']['COOLING_FACILITY_S'] = ('AD055', '100697', 'UtilityInfrastructureSrf')
    field_information['GGDM 3.0']['Levels']['Local']['COOLING_FACILITY_S'] = ('AD055', '100697', 'UtilityInfrastructureSrf')
    field_information['GGDM 3.0']['Levels']['Regional']['COOLING_FACILITY_S'] = ('AD055', '100697', 'UtilityInfrastructureSrf')
    field_information['GGDM 3.0']['Levels']['Specialized']['COOLING_FACILITY_S'] = ('AD055', '100697', 'UtilityInfrastructureSrf')
    field_information['GGDM 3.0']['Levels']['Global']['WIND_FARM_P'] = ('AD060', '100687', 'UtilityInfrastructurePnt')
    field_information['GGDM 3.0']['Levels']['Local']['WIND_FARM_P'] = ('AD060', '100687', 'UtilityInfrastructurePnt')
    field_information['GGDM 3.0']['Levels']['Regional']['WIND_FARM_P'] = ('AD060', '100687', 'UtilityInfrastructurePnt')
    field_information['GGDM 3.0']['Levels']['Global']['WIND_FARM_S'] = ('AD060', '100687', 'UtilityInfrastructureSrf')
    field_information['GGDM 3.0']['Levels']['Local']['WIND_FARM_S'] = ('AD060', '100687', 'UtilityInfrastructureSrf')
    field_information['GGDM 3.0']['Levels']['Regional']['WIND_FARM_S'] = ('AD060', '100687', 'UtilityInfrastructureSrf')
    field_information['GGDM 3.0']['Levels']['Specialized']['WIND_FARM_S'] = ('AD060', '100687', 'UtilityInfrastructureSrf')
    field_information['GGDM 3.0']['Levels']['Global']['SMOKESTACK_P'] = ('AF010', '100025', 'UtilityInfrastructurePnt')
    field_information['GGDM 3.0']['Levels']['Local']['SMOKESTACK_P'] = ('AF010', '100025', 'UtilityInfrastructurePnt')
    field_information['GGDM 3.0']['Levels']['Regional']['SMOKESTACK_P'] = ('AF010', '100025', 'UtilityInfrastructurePnt')
    field_information['GGDM 3.0']['Levels']['Specialized']['SMOKESTACK_P'] = ('AF010', '100025', 'UtilityInfrastructurePnt')
    field_information['GGDM 3.0']['Levels']['Global']['CONVEYOR_C'] = ('AF020', '100026', 'IndustryCrv')
    field_information['GGDM 3.0']['Levels']['Local']['CONVEYOR_C'] = ('AF020', '100026', 'IndustryCrv')
    field_information['GGDM 3.0']['Levels']['Regional']['CONVEYOR_C'] = ('AF020', '100026', 'IndustryCrv')
    field_information['GGDM 3.0']['Levels']['Specialized']['CONVEYOR_C'] = ('AF020', '100026', 'IndustryCrv')
    field_information['GGDM 3.0']['Levels']['Local']['CONVEYOR_P'] = ('AF020', '100026', 'IndustryPnt')
    field_information['GGDM 3.0']['Levels']['Specialized']['CONVEYOR_P'] = ('AF020', '100026', 'IndustryPnt')
    field_information['GGDM 3.0']['Levels']['Global']['COOLING_TOWER_P'] = ('AF030', '100028', 'UtilityInfrastructurePnt')
    field_information['GGDM 3.0']['Levels']['Local']['COOLING_TOWER_P'] = ('AF030', '100028', 'UtilityInfrastructurePnt')
    field_information['GGDM 3.0']['Levels']['Regional']['COOLING_TOWER_P'] = ('AF030', '100028', 'UtilityInfrastructurePnt')
    field_information['GGDM 3.0']['Levels']['Specialized']['COOLING_TOWER_P'] = ('AF030', '100028', 'UtilityInfrastructurePnt')
    field_information['GGDM 3.0']['Levels']['Local']['COOLING_TOWER_S'] = ('AF030', '100028', 'UtilityInfrastructureSrf')
    field_information['GGDM 3.0']['Levels']['Specialized']['COOLING_TOWER_S'] = ('AF030', '100028', 'UtilityInfrastructureSrf')
    field_information['GGDM 3.0']['Levels']['Global']['CRANE_P'] = ('AF040', '100029', 'IndustryPnt')
    field_information['GGDM 3.0']['Levels']['Local']['CRANE_P'] = ('AF040', '100029', 'IndustryPnt')
    field_information['GGDM 3.0']['Levels']['Regional']['CRANE_P'] = ('AF040', '100029', 'IndustryPnt')
    field_information['GGDM 3.0']['Levels']['Specialized']['CRANE_P'] = ('AF040', '100029', 'IndustryPnt')
    field_information['GGDM 3.0']['Levels']['Specialized']['CRANE_S'] = ('AF040', '100029', 'IndustrySrf')
    field_information['GGDM 3.0']['Levels']['Local']['EXCAVATING_MACHINE_C'] = ('AF050', '100030', 'IndustryCrv')
    field_information['GGDM 3.0']['Levels']['Specialized']['EXCAVATING_MACHINE_C'] = ('AF050', '100030', 'IndustryCrv')
    field_information['GGDM 3.0']['Levels']['Global']['EXCAVATING_MACHINE_P'] = ('AF050', '100030', 'IndustryPnt')
    field_information['GGDM 3.0']['Levels']['Regional']['EXCAVATING_MACHINE_P'] = ('AF050', '100030', 'IndustryPnt')
    field_information['GGDM 3.0']['Levels']['Global']['ENGINE_TEST_CELL_P'] = ('AF060', '100031', 'StructurePnt')
    field_information['GGDM 3.0']['Levels']['Local']['ENGINE_TEST_CELL_P'] = ('AF060', '100031', 'StructurePnt')
    field_information['GGDM 3.0']['Levels']['Regional']['ENGINE_TEST_CELL_P'] = ('AF060', '100031', 'StructurePnt')
    field_information['GGDM 3.0']['Levels']['Specialized']['ENGINE_TEST_CELL_P'] = ('AF060', '100031', 'StructurePnt')
    field_information['GGDM 3.0']['Levels']['Local']['ENGINE_TEST_CELL_S'] = ('AF060', '100031', 'StructureSrf')
    field_information['GGDM 3.0']['Levels']['Specialized']['ENGINE_TEST_CELL_S'] = ('AF060', '100031', 'StructureSrf')
    field_information['GGDM 3.0']['Levels']['Global']['FLARE_PIPE_P'] = ('AF070', '100032', 'IndustryPnt')
    field_information['GGDM 3.0']['Levels']['Local']['FLARE_PIPE_P'] = ('AF070', '100032', 'IndustryPnt')
    field_information['GGDM 3.0']['Levels']['Regional']['FLARE_PIPE_P'] = ('AF070', '100032', 'IndustryPnt')
    field_information['GGDM 3.0']['Levels']['Specialized']['FLARE_PIPE_P'] = ('AF070', '100032', 'IndustryPnt')
    field_information['GGDM 3.0']['Levels']['Global']['HOPPER_P'] = ('AF080', '100033', 'IndustryPnt')
    field_information['GGDM 3.0']['Levels']['Local']['HOPPER_P'] = ('AF080', '100033', 'IndustryPnt')
    field_information['GGDM 3.0']['Levels']['Regional']['HOPPER_P'] = ('AF080', '100033', 'IndustryPnt')
    field_information['GGDM 3.0']['Levels']['Specialized']['HOPPER_P'] = ('AF080', '100033', 'IndustryPnt')
    field_information['GGDM 3.0']['Levels']['Local']['SHOPPING_COMPLEX_S'] = ('AG030', '100034', 'FacilitySrf')
    field_information['GGDM 3.0']['Levels']['Specialized']['SHOPPING_COMPLEX_S'] = ('AG030', '100034', 'FacilitySrf')
    field_information['GGDM 3.0']['Levels']['Local']['OFFICE_PARK_S'] = ('AG040', '100035', 'FacilitySrf')
    field_information['GGDM 3.0']['Levels']['Specialized']['OFFICE_PARK_S'] = ('AG040', '100035', 'FacilitySrf')
    field_information['GGDM 3.0']['Levels']['Global']['BILLBOARD_P'] = ('AG050', '121638', 'StructurePnt')
    field_information['GGDM 3.0']['Levels']['Local']['BILLBOARD_P'] = ('AG050', '121638', 'StructurePnt')
    field_information['GGDM 3.0']['Levels']['Regional']['BILLBOARD_P'] = ('AG050', '121638', 'StructurePnt')
    field_information['GGDM 3.0']['Levels']['Specialized']['BILLBOARD_P'] = ('AG050', '121638', 'StructurePnt')
    field_information['GGDM 3.0']['Levels']['Global']['ENGINEERED_EARTHWORK_C'] = ('AH025', '132596', 'MilitaryCrv')
    field_information['GGDM 3.0']['Levels']['Local']['ENGINEERED_EARTHWORK_C'] = ('AH025', '132596', 'MilitaryCrv')
    field_information['GGDM 3.0']['Levels']['Regional']['ENGINEERED_EARTHWORK_C'] = ('AH025', '132596', 'MilitaryCrv')
    field_information['GGDM 3.0']['Levels']['Specialized']['ENGINEERED_EARTHWORK_C'] = ('AH025', '132596', 'MilitaryCrv')
    field_information['GGDM 3.0']['Levels']['Local']['ENGINEERED_EARTHWORK_S'] = ('AH025', '132596', 'MilitarySrf')
    field_information['GGDM 3.0']['Levels']['Specialized']['ENGINEERED_EARTHWORK_S'] = ('AH025', '132596', 'MilitarySrf')
    field_information['GGDM 3.0']['Levels']['Global']['FORTIFIED_BUILDING_P'] = ('AH055', '132626', 'MilitaryPnt')
    field_information['GGDM 3.0']['Levels']['Local']['FORTIFIED_BUILDING_P'] = ('AH055', '132626', 'MilitaryPnt')
    field_information['GGDM 3.0']['Levels']['Regional']['FORTIFIED_BUILDING_P'] = ('AH055', '132626', 'MilitaryPnt')
    field_information['GGDM 3.0']['Levels']['Specialized']['FORTIFIED_BUILDING_P'] = ('AH055', '132626', 'MilitaryPnt')
    field_information['GGDM 3.0']['Levels']['Global']['FORTIFIED_BUILDING_S'] = ('AH055', '132626', 'MilitarySrf')
    field_information['GGDM 3.0']['Levels']['Local']['FORTIFIED_BUILDING_S'] = ('AH055', '132626', 'MilitarySrf')
    field_information['GGDM 3.0']['Levels']['Regional']['FORTIFIED_BUILDING_S'] = ('AH055', '132626', 'MilitarySrf')
    field_information['GGDM 3.0']['Levels']['Specialized']['FORTIFIED_BUILDING_S'] = ('AH055', '132626', 'MilitarySrf')
    field_information['GGDM 3.0']['Levels']['Global']['UNDERGROUND_BUNKER_P'] = ('AH060', '100038', 'MilitaryPnt')
    field_information['GGDM 3.0']['Levels']['Local']['UNDERGROUND_BUNKER_P'] = ('AH060', '100038', 'MilitaryPnt')
    field_information['GGDM 3.0']['Levels']['Regional']['UNDERGROUND_BUNKER_P'] = ('AH060', '100038', 'MilitaryPnt')
    field_information['GGDM 3.0']['Levels']['Specialized']['UNDERGROUND_BUNKER_P'] = ('AH060', '100038', 'MilitaryPnt')
    field_information['GGDM 3.0']['Levels']['Global']['UNDERGROUND_BUNKER_S'] = ('AH060', '100038', 'MilitarySrf')
    field_information['GGDM 3.0']['Levels']['Local']['UNDERGROUND_BUNKER_S'] = ('AH060', '100038', 'MilitarySrf')
    field_information['GGDM 3.0']['Levels']['Regional']['UNDERGROUND_BUNKER_S'] = ('AH060', '100038', 'MilitarySrf')
    field_information['GGDM 3.0']['Levels']['Specialized']['UNDERGROUND_BUNKER_S'] = ('AH060', '100038', 'MilitarySrf')
    field_information['GGDM 3.0']['Levels']['Global']['CHECKPOINT_P'] = ('AH070', '100039', 'TransportationGroundPnt')
    field_information['GGDM 3.0']['Levels']['Local']['CHECKPOINT_P'] = ('AH070', '100039', 'TransportationGroundPnt')
    field_information['GGDM 3.0']['Levels']['Regional']['CHECKPOINT_P'] = ('AH070', '100039', 'TransportationGroundPnt')
    field_information['GGDM 3.0']['Levels']['Specialized']['CHECKPOINT_P'] = ('AH070', '100039', 'TransportationGroundPnt')
    field_information['GGDM 3.0']['Levels']['Global']['CARAVAN_PARK_S'] = ('AI020', '100040', 'SettlementSrf')
    field_information['GGDM 3.0']['Levels']['Local']['CARAVAN_PARK_S'] = ('AI020', '100040', 'SettlementSrf')
    field_information['GGDM 3.0']['Levels']['Regional']['CARAVAN_PARK_S'] = ('AI020', '100040', 'SettlementSrf')
    field_information['GGDM 3.0']['Levels']['Specialized']['CARAVAN_PARK_S'] = ('AI020', '100040', 'SettlementSrf')
    field_information['GGDM 3.0']['Levels']['Global']['MANUFACTURED_HOME_PARK_S'] = ('AI021', '133168', 'SettlementSrf')
    field_information['GGDM 3.0']['Levels']['Local']['MANUFACTURED_HOME_PARK_S'] = ('AI021', '133168', 'SettlementSrf')
    field_information['GGDM 3.0']['Levels']['Regional']['MANUFACTURED_HOME_PARK_S'] = ('AI021', '133168', 'SettlementSrf')
    field_information['GGDM 3.0']['Levels']['Specialized']['MANUFACTURED_HOME_PARK_S'] = ('AI021', '133168', 'SettlementSrf')
    field_information['GGDM 3.0']['Levels']['Local']['CAMP_P'] = ('AI030', '100041', 'SettlementPnt')
    field_information['GGDM 3.0']['Levels']['Specialized']['CAMP_P'] = ('AI030', '100041', 'SettlementPnt')
    field_information['GGDM 3.0']['Levels']['Local']['CAMP_S'] = ('AI030', '100041', 'SettlementSrf')
    field_information['GGDM 3.0']['Levels']['Specialized']['CAMP_S'] = ('AI030', '100041', 'SettlementSrf')
    field_information['GGDM 3.0']['Levels']['Local']['HOLDING_PEN_P'] = ('AJ030', '100043', 'AgriculturePnt')
    field_information['GGDM 3.0']['Levels']['Regional']['HOLDING_PEN_P'] = ('AJ030', '100043', 'AgriculturePnt')
    field_information['GGDM 3.0']['Levels']['Specialized']['HOLDING_PEN_P'] = ('AJ030', '100043', 'AgriculturePnt')
    field_information['GGDM 3.0']['Levels']['Local']['HOLDING_PEN_S'] = ('AJ030', '100043', 'AgricultureSrf')
    field_information['GGDM 3.0']['Levels']['Specialized']['HOLDING_PEN_S'] = ('AJ030', '100043', 'AgricultureSrf')
    field_information['GGDM 3.0']['Levels']['Global']['WINDMILL_P'] = ('AJ050', '100044', 'AgriculturePnt')
    field_information['GGDM 3.0']['Levels']['Local']['WINDMILL_P'] = ('AJ050', '100044', 'AgriculturePnt')
    field_information['GGDM 3.0']['Levels']['Regional']['WINDMILL_P'] = ('AJ050', '100044', 'AgriculturePnt')
    field_information['GGDM 3.0']['Levels']['Specialized']['WINDMILL_P'] = ('AJ050', '100044', 'AgriculturePnt')
    field_information['GGDM 3.0']['Levels']['Local']['WINDMILL_S'] = ('AJ050', '100044', 'AgricultureSrf')
    field_information['GGDM 3.0']['Levels']['Specialized']['WINDMILL_S'] = ('AJ050', '100044', 'AgricultureSrf')
    field_information['GGDM 3.0']['Levels']['Global']['WIND_TURBINE_P'] = ('AJ051', '100045', 'UtilityInfrastructurePnt')
    field_information['GGDM 3.0']['Levels']['Local']['WIND_TURBINE_P'] = ('AJ051', '100045', 'UtilityInfrastructurePnt')
    field_information['GGDM 3.0']['Levels']['Regional']['WIND_TURBINE_P'] = ('AJ051', '100045', 'UtilityInfrastructurePnt')
    field_information['GGDM 3.0']['Levels']['Specialized']['WIND_TURBINE_P'] = ('AJ051', '100045', 'UtilityInfrastructurePnt')
    field_information['GGDM 3.0']['Levels']['Global']['WATER_MILL_P'] = ('AJ055', '100046', 'IndustryPnt')
    field_information['GGDM 3.0']['Levels']['Local']['WATER_MILL_P'] = ('AJ055', '100046', 'IndustryPnt')
    field_information['GGDM 3.0']['Levels']['Regional']['WATER_MILL_P'] = ('AJ055', '100046', 'IndustryPnt')
    field_information['GGDM 3.0']['Levels']['Specialized']['WATER_MILL_P'] = ('AJ055', '100046', 'IndustryPnt')
    field_information['GGDM 3.0']['Levels']['Local']['WATER_MILL_S'] = ('AJ055', '100046', 'IndustrySrf')
    field_information['GGDM 3.0']['Levels']['Regional']['WATER_MILL_S'] = ('AJ055', '100046', 'IndustrySrf')
    field_information['GGDM 3.0']['Levels']['Specialized']['WATER_MILL_S'] = ('AJ055', '100046', 'IndustrySrf')
    field_information['GGDM 3.0']['Levels']['Specialized']['STABLE_P'] = ('AJ080', '100049', 'AgriculturePnt')
    field_information['GGDM 3.0']['Levels']['Specialized']['STABLE_S'] = ('AJ080', '100049', 'AgricultureSrf')
    field_information['GGDM 3.0']['Levels']['Global']['BARN_P'] = ('AJ085', '100691', 'AgriculturePnt')
    field_information['GGDM 3.0']['Levels']['Local']['BARN_P'] = ('AJ085', '100691', 'AgriculturePnt')
    field_information['GGDM 3.0']['Levels']['Regional']['BARN_P'] = ('AJ085', '100691', 'AgriculturePnt')
    field_information['GGDM 3.0']['Levels']['Specialized']['BARN_P'] = ('AJ085', '100691', 'AgriculturePnt')
    field_information['GGDM 3.0']['Levels']['Local']['BARN_S'] = ('AJ085', '100691', 'AgricultureSrf')
    field_information['GGDM 3.0']['Levels']['Regional']['BARN_S'] = ('AJ085', '100691', 'AgricultureSrf')
    field_information['GGDM 3.0']['Levels']['Specialized']['BARN_S'] = ('AJ085', '100691', 'AgricultureSrf')
    field_information['GGDM 3.0']['Levels']['Global']['GREENHOUSE_P'] = ('AJ110', '100052', 'AgriculturePnt')
    field_information['GGDM 3.0']['Levels']['Local']['GREENHOUSE_P'] = ('AJ110', '100052', 'AgriculturePnt')
    field_information['GGDM 3.0']['Levels']['Regional']['GREENHOUSE_P'] = ('AJ110', '100052', 'AgriculturePnt')
    field_information['GGDM 3.0']['Levels']['Specialized']['GREENHOUSE_P'] = ('AJ110', '100052', 'AgriculturePnt')
    field_information['GGDM 3.0']['Levels']['Global']['GREENHOUSE_S'] = ('AJ110', '100052', 'AgricultureSrf')
    field_information['GGDM 3.0']['Levels']['Local']['GREENHOUSE_S'] = ('AJ110', '100052', 'AgricultureSrf')
    field_information['GGDM 3.0']['Levels']['Regional']['GREENHOUSE_S'] = ('AJ110', '100052', 'AgricultureSrf')
    field_information['GGDM 3.0']['Levels']['Specialized']['GREENHOUSE_S'] = ('AJ110', '100052', 'AgricultureSrf')
    field_information['GGDM 3.0']['Levels']['Specialized']['AMUSEMENT_PARK_ATTRACTION_C'] = ('AK020', '100053', 'RecreationCrv')
    field_information['GGDM 3.0']['Levels']['Global']['AMUSEMENT_PARK_ATTRACTION_P'] = ('AK020', '100053', 'RecreationPnt')
    field_information['GGDM 3.0']['Levels']['Local']['AMUSEMENT_PARK_ATTRACTION_P'] = ('AK020', '100053', 'RecreationPnt')
    field_information['GGDM 3.0']['Levels']['Regional']['AMUSEMENT_PARK_ATTRACTION_P'] = ('AK020', '100053', 'RecreationPnt')
    field_information['GGDM 3.0']['Levels']['Specialized']['AMUSEMENT_PARK_ATTRACTION_P'] = ('AK020', '100053', 'RecreationPnt')
    field_information['GGDM 3.0']['Levels']['Specialized']['AMUSEMENT_PARK_ATTRACTION_S'] = ('AK020', '100053', 'RecreationSrf')
    field_information['GGDM 3.0']['Levels']['Global']['AMUSEMENT_PARK_P'] = ('AK030', '100054', 'RecreationPnt')
    field_information['GGDM 3.0']['Levels']['Regional']['AMUSEMENT_PARK_P'] = ('AK030', '100054', 'RecreationPnt')
    field_information['GGDM 3.0']['Levels']['Global']['AMUSEMENT_PARK_S'] = ('AK030', '100054', 'RecreationSrf')
    field_information['GGDM 3.0']['Levels']['Local']['AMUSEMENT_PARK_S'] = ('AK030', '100054', 'RecreationSrf')
    field_information['GGDM 3.0']['Levels']['Regional']['AMUSEMENT_PARK_S'] = ('AK030', '100054', 'RecreationSrf')
    field_information['GGDM 3.0']['Levels']['Specialized']['AMUSEMENT_PARK_S'] = ('AK030', '100054', 'RecreationSrf')
    field_information['GGDM 3.0']['Levels']['Global']['SPORTS_GROUND_P'] = ('AK040', '100055', 'RecreationPnt')
    field_information['GGDM 3.0']['Levels']['Regional']['SPORTS_GROUND_P'] = ('AK040', '100055', 'RecreationPnt')
    field_information['GGDM 3.0']['Levels']['Global']['SPORTS_GROUND_S'] = ('AK040', '100055', 'RecreationSrf')
    field_information['GGDM 3.0']['Levels']['Local']['SPORTS_GROUND_S'] = ('AK040', '100055', 'RecreationSrf')
    field_information['GGDM 3.0']['Levels']['Regional']['SPORTS_GROUND_S'] = ('AK040', '100055', 'RecreationSrf')
    field_information['GGDM 3.0']['Levels']['Specialized']['SPORTS_GROUND_S'] = ('AK040', '100055', 'RecreationSrf')
    field_information['GGDM 3.0']['Levels']['Global']['CAMP_SITE_P'] = ('AK060', '100057', 'RecreationPnt')
    field_information['GGDM 3.0']['Levels']['Regional']['CAMP_SITE_P'] = ('AK060', '100057', 'RecreationPnt')
    field_information['GGDM 3.0']['Levels']['Local']['CAMP_SITE_S'] = ('AK060', '100057', 'RecreationSrf')
    field_information['GGDM 3.0']['Levels']['Specialized']['CAMP_SITE_S'] = ('AK060', '100057', 'RecreationSrf')
    field_information['GGDM 3.0']['Levels']['Specialized']['PICNIC_SITE_S'] = ('AK061', '100058', 'RecreationSrf')
    field_information['GGDM 3.0']['Levels']['Local']['DRIVE_IN_THEATRE_S'] = ('AK070', '100059', 'RecreationSrf')
    field_information['GGDM 3.0']['Levels']['Specialized']['DRIVE_IN_THEATRE_S'] = ('AK070', '100059', 'RecreationSrf')
    field_information['GGDM 3.0']['Levels']['Specialized']['OUTDOOR_THEATRE_SCREEN_C'] = ('AK080', '100060', 'RecreationCrv')
    field_information['GGDM 3.0']['Levels']['Global']['OUTDOOR_THEATRE_SCREEN_P'] = ('AK080', '100060', 'RecreationPnt')
    field_information['GGDM 3.0']['Levels']['Local']['OUTDOOR_THEATRE_SCREEN_P'] = ('AK080', '100060', 'RecreationPnt')
    field_information['GGDM 3.0']['Levels']['Regional']['OUTDOOR_THEATRE_SCREEN_P'] = ('AK080', '100060', 'RecreationPnt')
    field_information['GGDM 3.0']['Levels']['Specialized']['OUTDOOR_THEATRE_SCREEN_P'] = ('AK080', '100060', 'RecreationPnt')
    field_information['GGDM 3.0']['Levels']['Global']['FAIRGROUND_S'] = ('AK090', '100061', 'RecreationSrf')
    field_information['GGDM 3.0']['Levels']['Local']['FAIRGROUND_S'] = ('AK090', '100061', 'RecreationSrf')
    field_information['GGDM 3.0']['Levels']['Regional']['FAIRGROUND_S'] = ('AK090', '100061', 'RecreationSrf')
    field_information['GGDM 3.0']['Levels']['Specialized']['FAIRGROUND_S'] = ('AK090', '100061', 'RecreationSrf')
    field_information['GGDM 3.0']['Levels']['Global']['GOLF_COURSE_S'] = ('AK100', '100062', 'RecreationSrf')
    field_information['GGDM 3.0']['Levels']['Local']['GOLF_COURSE_S'] = ('AK100', '100062', 'RecreationSrf')
    field_information['GGDM 3.0']['Levels']['Regional']['GOLF_COURSE_S'] = ('AK100', '100062', 'RecreationSrf')
    field_information['GGDM 3.0']['Levels']['Specialized']['GOLF_COURSE_S'] = ('AK100', '100062', 'RecreationSrf')
    field_information['GGDM 3.0']['Levels']['Local']['GOLF_DRIVING_RANGE_S'] = ('AK101', '100063', 'RecreationSrf')
    field_information['GGDM 3.0']['Levels']['Specialized']['GOLF_DRIVING_RANGE_S'] = ('AK101', '100063', 'RecreationSrf')
    field_information['GGDM 3.0']['Levels']['Global']['GRANDSTAND_P'] = ('AK110', '100064', 'RecreationPnt')
    field_information['GGDM 3.0']['Levels']['Local']['GRANDSTAND_P'] = ('AK110', '100064', 'RecreationPnt')
    field_information['GGDM 3.0']['Levels']['Regional']['GRANDSTAND_P'] = ('AK110', '100064', 'RecreationPnt')
    field_information['GGDM 3.0']['Levels']['Specialized']['GRANDSTAND_P'] = ('AK110', '100064', 'RecreationPnt')
    field_information['GGDM 3.0']['Levels']['Local']['GRANDSTAND_S'] = ('AK110', '100064', 'RecreationSrf')
    field_information['GGDM 3.0']['Levels']['Specialized']['GRANDSTAND_S'] = ('AK110', '100064', 'RecreationSrf')
    field_information['GGDM 3.0']['Levels']['Global']['PARK_S'] = ('AK120', '100065', 'CultureSrf')
    field_information['GGDM 3.0']['Levels']['Local']['PARK_S'] = ('AK120', '100065', 'CultureSrf')
    field_information['GGDM 3.0']['Levels']['Regional']['PARK_S'] = ('AK120', '100065', 'CultureSrf')
    field_information['GGDM 3.0']['Levels']['Specialized']['PARK_S'] = ('AK120', '100065', 'CultureSrf')
    field_information['GGDM 3.0']['Levels']['Local']['LOOKOUT_P'] = ('AK121', '100066', 'CulturePnt')
    field_information['GGDM 3.0']['Levels']['Regional']['LOOKOUT_P'] = ('AK121', '100066', 'CulturePnt')
    field_information['GGDM 3.0']['Levels']['Specialized']['LOOKOUT_P'] = ('AK121', '100066', 'CulturePnt')
    field_information['GGDM 3.0']['Levels']['Specialized']['LOOKOUT_S'] = ('AK121', '100066', 'CultureSrf')
    field_information['GGDM 3.0']['Levels']['Global']['RACETRACK_C'] = ('AK130', '100069', 'RecreationCrv')
    field_information['GGDM 3.0']['Levels']['Local']['RACETRACK_C'] = ('AK130', '100069', 'RecreationCrv')
    field_information['GGDM 3.0']['Levels']['Regional']['RACETRACK_C'] = ('AK130', '100069', 'RecreationCrv')
    field_information['GGDM 3.0']['Levels']['Specialized']['RACETRACK_C'] = ('AK130', '100069', 'RecreationCrv')
    field_information['GGDM 3.0']['Levels']['Specialized']['RACETRACK_S'] = ('AK130', '100069', 'RecreationSrf')
    field_information['GGDM 3.0']['Levels']['Local']['SKI_JUMP_C'] = ('AK150', '100072', 'RecreationCrv')
    field_information['GGDM 3.0']['Levels']['Specialized']['SKI_JUMP_C'] = ('AK150', '100072', 'RecreationCrv')
    field_information['GGDM 3.0']['Levels']['Global']['SKI_JUMP_P'] = ('AK150', '100072', 'RecreationPnt')
    field_information['GGDM 3.0']['Levels']['Local']['SKI_JUMP_P'] = ('AK150', '100072', 'RecreationPnt')
    field_information['GGDM 3.0']['Levels']['Regional']['SKI_JUMP_P'] = ('AK150', '100072', 'RecreationPnt')
    field_information['GGDM 3.0']['Levels']['Specialized']['SKI_JUMP_P'] = ('AK150', '100072', 'RecreationPnt')
    field_information['GGDM 3.0']['Levels']['Specialized']['SKI_RUN_C'] = ('AK155', '100073', 'RecreationCrv')
    field_information['GGDM 3.0']['Levels']['Specialized']['SKI_RUN_S'] = ('AK155', '100073', 'RecreationSrf')
    field_information['GGDM 3.0']['Levels']['Global']['STADIUM_P'] = ('AK160', '154703', 'RecreationPnt')
    field_information['GGDM 3.0']['Levels']['Local']['STADIUM_P'] = ('AK160', '154703', 'RecreationPnt')
    field_information['GGDM 3.0']['Levels']['Regional']['STADIUM_P'] = ('AK160', '154703', 'RecreationPnt')
    field_information['GGDM 3.0']['Levels']['Specialized']['STADIUM_P'] = ('AK160', '154703', 'RecreationPnt')
    field_information['GGDM 3.0']['Levels']['Global']['STADIUM_S'] = ('AK160', '154703', 'RecreationSrf')
    field_information['GGDM 3.0']['Levels']['Local']['STADIUM_S'] = ('AK160', '154703', 'RecreationSrf')
    field_information['GGDM 3.0']['Levels']['Regional']['STADIUM_S'] = ('AK160', '154703', 'RecreationSrf')
    field_information['GGDM 3.0']['Levels']['Specialized']['STADIUM_S'] = ('AK160', '154703', 'RecreationSrf')
    field_information['GGDM 3.0']['Levels']['Global']['SCOREBOARD_P'] = ('AK161', '121747', 'RecreationPnt')
    field_information['GGDM 3.0']['Levels']['Local']['SCOREBOARD_P'] = ('AK161', '121747', 'RecreationPnt')
    field_information['GGDM 3.0']['Levels']['Regional']['SCOREBOARD_P'] = ('AK161', '121747', 'RecreationPnt')
    field_information['GGDM 3.0']['Levels']['Specialized']['SCOREBOARD_P'] = ('AK161', '121747', 'RecreationPnt')
    field_information['GGDM 3.0']['Levels']['Global']['AMPHITHEATRE_P'] = ('AK164', '100074', 'RecreationPnt')
    field_information['GGDM 3.0']['Levels']['Local']['AMPHITHEATRE_P'] = ('AK164', '100074', 'RecreationPnt')
    field_information['GGDM 3.0']['Levels']['Regional']['AMPHITHEATRE_P'] = ('AK164', '100074', 'RecreationPnt')
    field_information['GGDM 3.0']['Levels']['Specialized']['AMPHITHEATRE_P'] = ('AK164', '100074', 'RecreationPnt')
    field_information['GGDM 3.0']['Levels']['Local']['AMPHITHEATRE_S'] = ('AK164', '100074', 'RecreationSrf')
    field_information['GGDM 3.0']['Levels']['Specialized']['AMPHITHEATRE_S'] = ('AK164', '100074', 'RecreationSrf')
    field_information['GGDM 3.0']['Levels']['Global']['SWIMMING_POOL_P'] = ('AK170', '100077', 'RecreationPnt')
    field_information['GGDM 3.0']['Levels']['Local']['SWIMMING_POOL_P'] = ('AK170', '100077', 'RecreationPnt')
    field_information['GGDM 3.0']['Levels']['Regional']['SWIMMING_POOL_P'] = ('AK170', '100077', 'RecreationPnt')
    field_information['GGDM 3.0']['Levels']['Specialized']['SWIMMING_POOL_P'] = ('AK170', '100077', 'RecreationPnt')
    field_information['GGDM 3.0']['Levels']['Local']['SWIMMING_POOL_S'] = ('AK170', '100077', 'RecreationSrf')
    field_information['GGDM 3.0']['Levels']['Specialized']['SWIMMING_POOL_S'] = ('AK170', '100077', 'RecreationSrf')
    field_information['GGDM 3.0']['Levels']['Global']['ZOO_P'] = ('AK180', '100078', 'RecreationPnt')
    field_information['GGDM 3.0']['Levels']['Regional']['ZOO_P'] = ('AK180', '100078', 'RecreationPnt')
    field_information['GGDM 3.0']['Levels']['Global']['ZOO_S'] = ('AK180', '100078', 'RecreationSrf')
    field_information['GGDM 3.0']['Levels']['Local']['ZOO_S'] = ('AK180', '100078', 'RecreationSrf')
    field_information['GGDM 3.0']['Levels']['Regional']['ZOO_S'] = ('AK180', '100078', 'RecreationSrf')
    field_information['GGDM 3.0']['Levels']['Specialized']['ZOO_S'] = ('AK180', '100078', 'RecreationSrf')
    field_information['GGDM 3.0']['Levels']['Global']['FACILITY_P'] = ('AL010', '100080', 'FacilityPnt')
    field_information['GGDM 3.0']['Levels']['Local']['FACILITY_P'] = ('AL010', '100080', 'FacilityPnt')
    field_information['GGDM 3.0']['Levels']['Regional']['FACILITY_P'] = ('AL010', '100080', 'FacilityPnt')
    field_information['GGDM 3.0']['Levels']['Specialized']['FACILITY_P'] = ('AL010', '100080', 'FacilityPnt')
    field_information['GGDM 3.0']['Levels']['Global']['FACILITY_S'] = ('AL010', '100080', 'FacilitySrf')
    field_information['GGDM 3.0']['Levels']['Local']['FACILITY_S'] = ('AL010', '100080', 'FacilitySrf')
    field_information['GGDM 3.0']['Levels']['Regional']['FACILITY_S'] = ('AL010', '100080', 'FacilitySrf')
    field_information['GGDM 3.0']['Levels']['Specialized']['FACILITY_S'] = ('AL010', '100080', 'FacilitySrf')
    field_information['GGDM 3.0']['Levels']['Global']['INSTALLATION_P'] = ('AL011', '100081', 'FacilityPnt')
    field_information['GGDM 3.0']['Levels']['Regional']['INSTALLATION_P'] = ('AL011', '100081', 'FacilityPnt')
    field_information['GGDM 3.0']['Levels']['Global']['INSTALLATION_S'] = ('AL011', '100081', 'FacilitySrf')
    field_information['GGDM 3.0']['Levels']['Regional']['INSTALLATION_S'] = ('AL011', '100081', 'FacilitySrf')
    field_information['GGDM 3.0']['Levels']['Global']['ARCHAEOLOGICAL_SITE_P'] = ('AL012', '100082', 'CulturePnt')
    field_information['GGDM 3.0']['Levels']['Local']['ARCHAEOLOGICAL_SITE_P'] = ('AL012', '100082', 'CulturePnt')
    field_information['GGDM 3.0']['Levels']['Regional']['ARCHAEOLOGICAL_SITE_P'] = ('AL012', '100082', 'CulturePnt')
    field_information['GGDM 3.0']['Levels']['Specialized']['ARCHAEOLOGICAL_SITE_P'] = ('AL012', '100082', 'CulturePnt')
    field_information['GGDM 3.0']['Levels']['Global']['ARCHAEOLOGICAL_SITE_S'] = ('AL012', '100082', 'CultureSrf')
    field_information['GGDM 3.0']['Levels']['Local']['ARCHAEOLOGICAL_SITE_S'] = ('AL012', '100082', 'CultureSrf')
    field_information['GGDM 3.0']['Levels']['Regional']['ARCHAEOLOGICAL_SITE_S'] = ('AL012', '100082', 'CultureSrf')
    field_information['GGDM 3.0']['Levels']['Specialized']['ARCHAEOLOGICAL_SITE_S'] = ('AL012', '100082', 'CultureSrf')
    field_information['GGDM 3.0']['Levels']['Global']['BUILDING_P'] = ('AL013', '100083', 'StructurePnt')
    field_information['GGDM 3.0']['Levels']['Local']['BUILDING_P'] = ('AL013', '100083', 'StructurePnt')
    field_information['GGDM 3.0']['Levels']['Regional']['BUILDING_P'] = ('AL013', '100083', 'StructurePnt')
    field_information['GGDM 3.0']['Levels']['Specialized']['BUILDING_P'] = ('AL013', '100083', 'StructurePnt')
    field_information['GGDM 3.0']['Levels']['Global']['BUILDING_S'] = ('AL013', '100083', 'StructureSrf')
    field_information['GGDM 3.0']['Levels']['Local']['BUILDING_S'] = ('AL013', '100083', 'StructureSrf')
    field_information['GGDM 3.0']['Levels']['Regional']['BUILDING_S'] = ('AL013', '100083', 'StructureSrf')
    field_information['GGDM 3.0']['Levels']['Specialized']['BUILDING_S'] = ('AL013', '100083', 'StructureSrf')
    field_information['GGDM 3.0']['Levels']['Global']['NON_BUILDING_STRUCTURE_P'] = ('AL014', '100084', 'StructurePnt')
    field_information['GGDM 3.0']['Levels']['Local']['NON_BUILDING_STRUCTURE_P'] = ('AL014', '100084', 'StructurePnt')
    field_information['GGDM 3.0']['Levels']['Regional']['NON_BUILDING_STRUCTURE_P'] = ('AL014', '100084', 'StructurePnt')
    field_information['GGDM 3.0']['Levels']['Specialized']['NON_BUILDING_STRUCTURE_P'] = ('AL014', '100084', 'StructurePnt')
    field_information['GGDM 3.0']['Levels']['Global']['NON_BUILDING_STRUCTURE_S'] = ('AL014', '100084', 'StructureSrf')
    field_information['GGDM 3.0']['Levels']['Local']['NON_BUILDING_STRUCTURE_S'] = ('AL014', '100084', 'StructureSrf')
    field_information['GGDM 3.0']['Levels']['Regional']['NON_BUILDING_STRUCTURE_S'] = ('AL014', '100084', 'StructureSrf')
    field_information['GGDM 3.0']['Levels']['Specialized']['NON_BUILDING_STRUCTURE_S'] = ('AL014', '100084', 'StructureSrf')
    field_information['GGDM 3.0']['Levels']['Specialized']['FIRE_HYDRANT_P'] = ('AL017', '100086', 'UtilityInfrastructurePnt')
    field_information['GGDM 3.0']['Levels']['Specialized']['BUILDING_SUPERSTRUCTURE_C'] = ('AL018', '100087', 'StructureCrv')
    field_information['GGDM 3.0']['Levels']['Global']['BUILDING_SUPERSTRUCTURE_P'] = ('AL018', '100087', 'StructurePnt')
    field_information['GGDM 3.0']['Levels']['Local']['BUILDING_SUPERSTRUCTURE_P'] = ('AL018', '100087', 'StructurePnt')
    field_information['GGDM 3.0']['Levels']['Regional']['BUILDING_SUPERSTRUCTURE_P'] = ('AL018', '100087', 'StructurePnt')
    field_information['GGDM 3.0']['Levels']['Specialized']['BUILDING_SUPERSTRUCTURE_P'] = ('AL018', '100087', 'StructurePnt')
    field_information['GGDM 3.0']['Levels']['Local']['BUILDING_SUPERSTRUCTURE_S'] = ('AL018', '100087', 'StructureSrf')
    field_information['GGDM 3.0']['Levels']['Specialized']['BUILDING_SUPERSTRUCTURE_S'] = ('AL018', '100087', 'StructureSrf')
    field_information['GGDM 3.0']['Levels']['Global']['SHED_P'] = ('AL019', '100088', 'StructurePnt')
    field_information['GGDM 3.0']['Levels']['Local']['SHED_P'] = ('AL019', '100088', 'StructurePnt')
    field_information['GGDM 3.0']['Levels']['Regional']['SHED_P'] = ('AL019', '100088', 'StructurePnt')
    field_information['GGDM 3.0']['Levels']['Specialized']['SHED_P'] = ('AL019', '100088', 'StructurePnt')
    field_information['GGDM 3.0']['Levels']['Local']['SHED_S'] = ('AL019', '100088', 'StructureSrf')
    field_information['GGDM 3.0']['Levels']['Specialized']['SHED_S'] = ('AL019', '100088', 'StructureSrf')
    field_information['GGDM 3.0']['Levels']['Global']['BUILT_UP_AREA_P'] = ('AL020', '100089', 'SettlementPnt')
    field_information['GGDM 3.0']['Levels']['Local']['BUILT_UP_AREA_P'] = ('AL020', '100089', 'SettlementPnt')
    field_information['GGDM 3.0']['Levels']['Regional']['BUILT_UP_AREA_P'] = ('AL020', '100089', 'SettlementPnt')
    field_information['GGDM 3.0']['Levels']['Specialized']['BUILT_UP_AREA_P'] = ('AL020', '100089', 'SettlementPnt')
    field_information['GGDM 3.0']['Levels']['Global']['BUILT_UP_AREA_S'] = ('AL020', '100089', 'SettlementSrf')
    field_information['GGDM 3.0']['Levels']['Local']['BUILT_UP_AREA_S'] = ('AL020', '100089', 'SettlementSrf')
    field_information['GGDM 3.0']['Levels']['Regional']['BUILT_UP_AREA_S'] = ('AL020', '100089', 'SettlementSrf')
    field_information['GGDM 3.0']['Levels']['Specialized']['BUILT_UP_AREA_S'] = ('AL020', '100089', 'SettlementSrf')
    field_information['GGDM 3.0']['Levels']['Local']['NEIGHBOURHOOD_S'] = ('AL024', '191547', 'SettlementSrfExt')
    field_information['GGDM 3.0']['Levels']['Specialized']['NEIGHBOURHOOD_S'] = ('AL024', '191547', 'SettlementSrfExt')
    field_information['GGDM 3.0']['Levels']['Global']['CAIRN_P'] = ('AL025', '100091', 'CulturePnt')
    field_information['GGDM 3.0']['Levels']['Local']['CAIRN_P'] = ('AL025', '100091', 'CulturePnt')
    field_information['GGDM 3.0']['Levels']['Regional']['CAIRN_P'] = ('AL025', '100091', 'CulturePnt')
    field_information['GGDM 3.0']['Levels']['Specialized']['CAIRN_P'] = ('AL025', '100091', 'CulturePnt')
    field_information['GGDM 3.0']['Levels']['Global']['CEMETERY_P'] = ('AL030', '100092', 'CulturePnt')
    field_information['GGDM 3.0']['Levels']['Local']['CEMETERY_P'] = ('AL030', '100092', 'CulturePnt')
    field_information['GGDM 3.0']['Levels']['Regional']['CEMETERY_P'] = ('AL030', '100092', 'CulturePnt')
    field_information['GGDM 3.0']['Levels']['Specialized']['CEMETERY_P'] = ('AL030', '100092', 'CulturePnt')
    field_information['GGDM 3.0']['Levels']['Global']['CEMETERY_S'] = ('AL030', '100092', 'CultureSrf')
    field_information['GGDM 3.0']['Levels']['Local']['CEMETERY_S'] = ('AL030', '100092', 'CultureSrf')
    field_information['GGDM 3.0']['Levels']['Regional']['CEMETERY_S'] = ('AL030', '100092', 'CultureSrf')
    field_information['GGDM 3.0']['Levels']['Specialized']['CEMETERY_S'] = ('AL030', '100092', 'CultureSrf')
    field_information['GGDM 3.0']['Levels']['Global']['TOMB_P'] = ('AL036', '100094', 'CulturePnt')
    field_information['GGDM 3.0']['Levels']['Local']['TOMB_P'] = ('AL036', '100094', 'CulturePnt')
    field_information['GGDM 3.0']['Levels']['Regional']['TOMB_P'] = ('AL036', '100094', 'CulturePnt')
    field_information['GGDM 3.0']['Levels']['Specialized']['TOMB_P'] = ('AL036', '100094', 'CulturePnt')
    field_information['GGDM 3.0']['Levels']['Local']['TOMB_S'] = ('AL036', '100094', 'CultureSrf')
    field_information['GGDM 3.0']['Levels']['Regional']['TOMB_S'] = ('AL036', '100094', 'CultureSrf')
    field_information['GGDM 3.0']['Levels']['Specialized']['TOMB_S'] = ('AL036', '100094', 'CultureSrf')
    field_information['GGDM 3.0']['Levels']['Local']['DRAGONS_TEETH_C'] = ('AL060', '100096', 'MilitaryCrv')
    field_information['GGDM 3.0']['Levels']['Regional']['DRAGONS_TEETH_C'] = ('AL060', '100096', 'MilitaryCrv')
    field_information['GGDM 3.0']['Levels']['Specialized']['DRAGONS_TEETH_C'] = ('AL060', '100096', 'MilitaryCrv')
    field_information['GGDM 3.0']['Levels']['Local']['DRAGONS_TEETH_S'] = ('AL060', '100096', 'MilitarySrf')
    field_information['GGDM 3.0']['Levels']['Specialized']['DRAGONS_TEETH_S'] = ('AL060', '100096', 'MilitarySrf')
    field_information['GGDM 3.0']['Levels']['Local']['MINEFIELD_S'] = ('AL065', '100097', 'MilitarySrf')
    field_information['GGDM 3.0']['Levels']['Specialized']['MINEFIELD_S'] = ('AL065', '100097', 'MilitarySrf')
    field_information['GGDM 3.0']['Levels']['Global']['FENCE_C'] = ('AL070', '100098', 'StructureCrv')
    field_information['GGDM 3.0']['Levels']['Local']['FENCE_C'] = ('AL070', '100098', 'StructureCrv')
    field_information['GGDM 3.0']['Levels']['Regional']['FENCE_C'] = ('AL070', '100098', 'StructureCrv')
    field_information['GGDM 3.0']['Levels']['Specialized']['FENCE_C'] = ('AL070', '100098', 'StructureCrv')
    field_information['GGDM 3.0']['Levels']['Global']['FLAGPOLE_P'] = ('AL073', '100099', 'StructurePnt')
    field_information['GGDM 3.0']['Levels']['Local']['FLAGPOLE_P'] = ('AL073', '100099', 'StructurePnt')
    field_information['GGDM 3.0']['Levels']['Regional']['FLAGPOLE_P'] = ('AL073', '100099', 'StructurePnt')
    field_information['GGDM 3.0']['Levels']['Specialized']['FLAGPOLE_P'] = ('AL073', '100099', 'StructurePnt')
    field_information['GGDM 3.0']['Levels']['Specialized']['GANTRY_C'] = ('AL080', '100101', 'StructureCrv')
    field_information['GGDM 3.0']['Levels']['Global']['GANTRY_P'] = ('AL080', '100101', 'StructurePnt')
    field_information['GGDM 3.0']['Levels']['Local']['GANTRY_P'] = ('AL080', '100101', 'StructurePnt')
    field_information['GGDM 3.0']['Levels']['Regional']['GANTRY_P'] = ('AL080', '100101', 'StructurePnt')
    field_information['GGDM 3.0']['Levels']['Specialized']['GANTRY_P'] = ('AL080', '100101', 'StructurePnt')
    field_information['GGDM 3.0']['Levels']['Local']['HUT_P'] = ('AL099', '100103', 'StructurePnt')
    field_information['GGDM 3.0']['Levels']['Regional']['HUT_P'] = ('AL099', '100103', 'StructurePnt')
    field_information['GGDM 3.0']['Levels']['Specialized']['HUT_P'] = ('AL099', '100103', 'StructurePnt')
    field_information['GGDM 3.0']['Levels']['Specialized']['HUT_S'] = ('AL099', '100103', 'StructureSrf')
    field_information['GGDM 3.0']['Levels']['Global']['SETTLEMENT_P'] = ('AL105', '100104', 'SettlementPnt')
    field_information['GGDM 3.0']['Levels']['Local']['SETTLEMENT_P'] = ('AL105', '100104', 'SettlementPnt')
    field_information['GGDM 3.0']['Levels']['Regional']['SETTLEMENT_P'] = ('AL105', '100104', 'SettlementPnt')
    field_information['GGDM 3.0']['Levels']['Specialized']['SETTLEMENT_P'] = ('AL105', '100104', 'SettlementPnt')
    field_information['GGDM 3.0']['Levels']['Global']['SETTLEMENT_S'] = ('AL105', '100104', 'SettlementSrf')
    field_information['GGDM 3.0']['Levels']['Local']['SETTLEMENT_S'] = ('AL105', '100104', 'SettlementSrf')
    field_information['GGDM 3.0']['Levels']['Regional']['SETTLEMENT_S'] = ('AL105', '100104', 'SettlementSrf')
    field_information['GGDM 3.0']['Levels']['Specialized']['SETTLEMENT_S'] = ('AL105', '100104', 'SettlementSrf')
    field_information['GGDM 3.0']['Levels']['Global']['LIGHT_SUPPORT_STRUCTURE_P'] = ('AL110', '100105', 'StructurePnt')
    field_information['GGDM 3.0']['Levels']['Local']['LIGHT_SUPPORT_STRUCTURE_P'] = ('AL110', '100105', 'StructurePnt')
    field_information['GGDM 3.0']['Levels']['Regional']['LIGHT_SUPPORT_STRUCTURE_P'] = ('AL110', '100105', 'StructurePnt')
    field_information['GGDM 3.0']['Levels']['Specialized']['LIGHT_SUPPORT_STRUCTURE_P'] = ('AL110', '100105', 'StructurePnt')
    field_information['GGDM 3.0']['Levels']['Local']['MISSILE_SITE_P'] = ('AL120', '100106', 'MilitaryPnt')
    field_information['GGDM 3.0']['Levels']['Regional']['MISSILE_SITE_P'] = ('AL120', '100106', 'MilitaryPnt')
    field_information['GGDM 3.0']['Levels']['Specialized']['MISSILE_SITE_P'] = ('AL120', '100106', 'MilitaryPnt')
    field_information['GGDM 3.0']['Levels']['Local']['MISSILE_SITE_S'] = ('AL120', '100106', 'MilitarySrf')
    field_information['GGDM 3.0']['Levels']['Regional']['MISSILE_SITE_S'] = ('AL120', '100106', 'MilitarySrf')
    field_information['GGDM 3.0']['Levels']['Specialized']['MISSILE_SITE_S'] = ('AL120', '100106', 'MilitarySrf')
    field_information['GGDM 3.0']['Levels']['Local']['ANTI_AIRCRAFT_ARTILLERY_SITE_P'] = ('AL121', '100107', 'MilitaryPntExt')
    field_information['GGDM 3.0']['Levels']['Regional']['ANTI_AIRCRAFT_ARTILLERY_SITE_P'] = ('AL121', '100107', 'MilitaryPntExt')
    field_information['GGDM 3.0']['Levels']['Specialized']['ANTI_AIRCRAFT_ARTILLERY_SITE_P'] = ('AL121', '100107', 'MilitaryPntExt')
    field_information['GGDM 3.0']['Levels']['Local']['ANTI_AIRCRAFT_ARTILLERY_SITE_S'] = ('AL121', '100107', 'MilitarySrfExt')
    field_information['GGDM 3.0']['Levels']['Regional']['ANTI_AIRCRAFT_ARTILLERY_SITE_S'] = ('AL121', '100107', 'MilitarySrfExt')
    field_information['GGDM 3.0']['Levels']['Specialized']['ANTI_AIRCRAFT_ARTILLERY_SITE_S'] = ('AL121', '100107', 'MilitarySrfExt')
    field_information['GGDM 3.0']['Levels']['Specialized']['MEMORIAL_MONUMENT_C'] = ('AL130', '100108', 'CultureCrv')
    field_information['GGDM 3.0']['Levels']['Global']['MEMORIAL_MONUMENT_P'] = ('AL130', '100108', 'CulturePnt')
    field_information['GGDM 3.0']['Levels']['Local']['MEMORIAL_MONUMENT_P'] = ('AL130', '100108', 'CulturePnt')
    field_information['GGDM 3.0']['Levels']['Regional']['MEMORIAL_MONUMENT_P'] = ('AL130', '100108', 'CulturePnt')
    field_information['GGDM 3.0']['Levels']['Specialized']['MEMORIAL_MONUMENT_P'] = ('AL130', '100108', 'CulturePnt')
    field_information['GGDM 3.0']['Levels']['Local']['MEMORIAL_MONUMENT_S'] = ('AL130', '100108', 'CultureSrf')
    field_information['GGDM 3.0']['Levels']['Specialized']['MEMORIAL_MONUMENT_S'] = ('AL130', '100108', 'CultureSrf')
    field_information['GGDM 3.0']['Levels']['Global']['PARTICLE_ACCELERATOR_C'] = ('AL140', '100110', 'StructureCrv')
    field_information['GGDM 3.0']['Levels']['Local']['PARTICLE_ACCELERATOR_C'] = ('AL140', '100110', 'StructureCrv')
    field_information['GGDM 3.0']['Levels']['Regional']['PARTICLE_ACCELERATOR_C'] = ('AL140', '100110', 'StructureCrv')
    field_information['GGDM 3.0']['Levels']['Specialized']['PARTICLE_ACCELERATOR_C'] = ('AL140', '100110', 'StructureCrv')
    field_information['GGDM 3.0']['Levels']['Global']['PARTICLE_ACCELERATOR_P'] = ('AL140', '100110', 'StructurePntExt')
    field_information['GGDM 3.0']['Levels']['Regional']['PARTICLE_ACCELERATOR_P'] = ('AL140', '100110', 'StructurePntExt')
    field_information['GGDM 3.0']['Levels']['Local']['PARTICLE_ACCELERATOR_S'] = ('AL140', '100110', 'StructureSrf')
    field_information['GGDM 3.0']['Levels']['Specialized']['PARTICLE_ACCELERATOR_S'] = ('AL140', '100110', 'StructureSrf')
    field_information['GGDM 3.0']['Levels']['Global']['ASTRONOMICAL_OBSERVATORY_P'] = ('AL142', '100111', 'StructurePnt')
    field_information['GGDM 3.0']['Levels']['Local']['ASTRONOMICAL_OBSERVATORY_P'] = ('AL142', '100111', 'StructurePnt')
    field_information['GGDM 3.0']['Levels']['Regional']['ASTRONOMICAL_OBSERVATORY_P'] = ('AL142', '100111', 'StructurePnt')
    field_information['GGDM 3.0']['Levels']['Specialized']['ASTRONOMICAL_OBSERVATORY_P'] = ('AL142', '100111', 'StructurePnt')
    field_information['GGDM 3.0']['Levels']['Global']['ASTRONOMICAL_OBSERVATORY_S'] = ('AL142', '100111', 'StructureSrf')
    field_information['GGDM 3.0']['Levels']['Local']['ASTRONOMICAL_OBSERVATORY_S'] = ('AL142', '100111', 'StructureSrf')
    field_information['GGDM 3.0']['Levels']['Regional']['ASTRONOMICAL_OBSERVATORY_S'] = ('AL142', '100111', 'StructureSrf')
    field_information['GGDM 3.0']['Levels']['Specialized']['ASTRONOMICAL_OBSERVATORY_S'] = ('AL142', '100111', 'StructureSrf')
    field_information['GGDM 3.0']['Levels']['Specialized']['OVERHEAD_OBSTRUCTION_C'] = ('AL155', '100112', 'TransportationGroundCrv')
    field_information['GGDM 3.0']['Levels']['Specialized']['OVERHEAD_OBSTRUCTION_P'] = ('AL155', '100112', 'TransportationGroundPnt')
    field_information['GGDM 3.0']['Levels']['Global']['PIPELINE_CROSSING_POINT_P'] = ('AL165', '100113', 'TransportationGroundPnt')
    field_information['GGDM 3.0']['Levels']['Local']['PIPELINE_CROSSING_POINT_P'] = ('AL165', '100113', 'TransportationGroundPnt')
    field_information['GGDM 3.0']['Levels']['Regional']['PIPELINE_CROSSING_POINT_P'] = ('AL165', '100113', 'TransportationGroundPnt')
    field_information['GGDM 3.0']['Levels']['Specialized']['PIPELINE_CROSSING_POINT_P'] = ('AL165', '100113', 'TransportationGroundPnt')
    field_information['GGDM 3.0']['Levels']['Global']['PUBLIC_SQUARE_P'] = ('AL170', '100114', 'RecreationPnt')
    field_information['GGDM 3.0']['Levels']['Regional']['PUBLIC_SQUARE_P'] = ('AL170', '100114', 'RecreationPnt')
    field_information['GGDM 3.0']['Levels']['Local']['PUBLIC_SQUARE_S'] = ('AL170', '100114', 'RecreationSrf')
    field_information['GGDM 3.0']['Levels']['Specialized']['PUBLIC_SQUARE_S'] = ('AL170', '100114', 'RecreationSrf')
    field_information['GGDM 3.0']['Levels']['Specialized']['COURTYARD_S'] = ('AL175', '100688', 'CultureSrf')
    field_information['GGDM 3.0']['Levels']['Specialized']['RETAIL_STAND_S'] = ('AL180', '100689', 'CultureSrf')
    field_information['GGDM 3.0']['Levels']['Specialized']['RAMP_C'] = ('AL195', '100115', 'TransportationGroundCrv')
    field_information['GGDM 3.0']['Levels']['Specialized']['RAMP_S'] = ('AL195', '100115', 'TransportationGroundSrf')
    field_information['GGDM 3.0']['Levels']['Global']['RUINS_P'] = ('AL200', '100116', 'CulturePnt')
    field_information['GGDM 3.0']['Levels']['Local']['RUINS_P'] = ('AL200', '100116', 'CulturePnt')
    field_information['GGDM 3.0']['Levels']['Regional']['RUINS_P'] = ('AL200', '100116', 'CulturePnt')
    field_information['GGDM 3.0']['Levels']['Specialized']['RUINS_P'] = ('AL200', '100116', 'CulturePnt')
    field_information['GGDM 3.0']['Levels']['Global']['RUINS_S'] = ('AL200', '100116', 'CultureSrf')
    field_information['GGDM 3.0']['Levels']['Local']['RUINS_S'] = ('AL200', '100116', 'CultureSrf')
    field_information['GGDM 3.0']['Levels']['Regional']['RUINS_S'] = ('AL200', '100116', 'CultureSrf')
    field_information['GGDM 3.0']['Levels']['Specialized']['RUINS_S'] = ('AL200', '100116', 'CultureSrf')
    field_information['GGDM 3.0']['Levels']['Specialized']['INTEREST_SITE_P'] = ('AL201', '100117', 'CulturePnt')
    field_information['GGDM 3.0']['Levels']['Specialized']['INTEREST_SITE_S'] = ('AL201', '100117', 'CultureSrf')
    field_information['GGDM 3.0']['Levels']['Global']['SHANTY_TOWN_P'] = ('AL208', '100118', 'SettlementPnt')
    field_information['GGDM 3.0']['Levels']['Local']['SHANTY_TOWN_P'] = ('AL208', '100118', 'SettlementPnt')
    field_information['GGDM 3.0']['Levels']['Regional']['SHANTY_TOWN_P'] = ('AL208', '100118', 'SettlementPnt')
    field_information['GGDM 3.0']['Levels']['Specialized']['SHANTY_TOWN_P'] = ('AL208', '100118', 'SettlementPnt')
    field_information['GGDM 3.0']['Levels']['Global']['SHANTY_TOWN_S'] = ('AL208', '100118', 'SettlementSrf')
    field_information['GGDM 3.0']['Levels']['Local']['SHANTY_TOWN_S'] = ('AL208', '100118', 'SettlementSrf')
    field_information['GGDM 3.0']['Levels']['Regional']['SHANTY_TOWN_S'] = ('AL208', '100118', 'SettlementSrf')
    field_information['GGDM 3.0']['Levels']['Specialized']['SHANTY_TOWN_S'] = ('AL208', '100118', 'SettlementSrf')
    field_information['GGDM 3.0']['Levels']['Global']['TRANS_ROUTE_PROTECT_STRUCT_C'] = ('AL211', '130921', 'TransportationGroundCrv')
    field_information['GGDM 3.0']['Levels']['Local']['TRANS_ROUTE_PROTECT_STRUCT_C'] = ('AL211', '130921', 'TransportationGroundCrv')
    field_information['GGDM 3.0']['Levels']['Regional']['TRANS_ROUTE_PROTECT_STRUCT_C'] = ('AL211', '130921', 'TransportationGroundCrv')
    field_information['GGDM 3.0']['Levels']['Specialized']['TRANS_ROUTE_PROTECT_STRUCT_C'] = ('AL211', '130921', 'TransportationGroundCrv')
    field_information['GGDM 3.0']['Levels']['Global']['TRANS_ROUTE_PROTECT_STRUCT_P'] = ('AL211', '130921', 'TransportationGroundPnt')
    field_information['GGDM 3.0']['Levels']['Local']['TRANS_ROUTE_PROTECT_STRUCT_P'] = ('AL211', '130921', 'TransportationGroundPnt')
    field_information['GGDM 3.0']['Levels']['Regional']['TRANS_ROUTE_PROTECT_STRUCT_P'] = ('AL211', '130921', 'TransportationGroundPnt')
    field_information['GGDM 3.0']['Levels']['Specialized']['TRANS_ROUTE_PROTECT_STRUCT_P'] = ('AL211', '130921', 'TransportationGroundPnt')
    field_information['GGDM 3.0']['Levels']['Local']['TRANS_ROUTE_PROTECT_STRUCT_S'] = ('AL211', '130921', 'TransportationGroundSrf')
    field_information['GGDM 3.0']['Levels']['Specialized']['TRANS_ROUTE_PROTECT_STRUCT_S'] = ('AL211', '130921', 'TransportationGroundSrf')
    field_information['GGDM 3.0']['Levels']['Global']['TOWER_P'] = ('AL241', '100122', 'StructurePnt')
    field_information['GGDM 3.0']['Levels']['Local']['TOWER_P'] = ('AL241', '100122', 'StructurePnt')
    field_information['GGDM 3.0']['Levels']['Regional']['TOWER_P'] = ('AL241', '100122', 'StructurePnt')
    field_information['GGDM 3.0']['Levels']['Specialized']['TOWER_P'] = ('AL241', '100122', 'StructurePnt')
    field_information['GGDM 3.0']['Levels']['Specialized']['TOWER_S'] = ('AL241', '100122', 'StructureSrf')
    field_information['GGDM 3.0']['Levels']['Local']['UNDERGROUND_DWELLING_P'] = ('AL250', '100123', 'StructurePnt')
    field_information['GGDM 3.0']['Levels']['Specialized']['UNDERGROUND_DWELLING_P'] = ('AL250', '100123', 'StructurePnt')
    field_information['GGDM 3.0']['Levels']['Global']['WALL_C'] = ('AL260', '100124', 'StructureCrv')
    field_information['GGDM 3.0']['Levels']['Local']['WALL_C'] = ('AL260', '100124', 'StructureCrv')
    field_information['GGDM 3.0']['Levels']['Regional']['WALL_C'] = ('AL260', '100124', 'StructureCrv')
    field_information['GGDM 3.0']['Levels']['Specialized']['WALL_C'] = ('AL260', '100124', 'StructureCrv')
    field_information['GGDM 3.0']['Levels']['Global']['INDUSTRIAL_FARM_P'] = ('AL270', '100129', 'AgriculturePnt')
    field_information['GGDM 3.0']['Levels']['Regional']['INDUSTRIAL_FARM_P'] = ('AL270', '100129', 'AgriculturePnt')
    field_information['GGDM 3.0']['Levels']['Global']['INDUSTRIAL_FARM_S'] = ('AL270', '100129', 'AgricultureSrf')
    field_information['GGDM 3.0']['Levels']['Local']['INDUSTRIAL_FARM_S'] = ('AL270', '100129', 'AgricultureSrf')
    field_information['GGDM 3.0']['Levels']['Regional']['INDUSTRIAL_FARM_S'] = ('AL270', '100129', 'AgricultureSrf')
    field_information['GGDM 3.0']['Levels']['Specialized']['INDUSTRIAL_FARM_S'] = ('AL270', '100129', 'AgricultureSrf')
    field_information['GGDM 3.0']['Levels']['Global']['SPACE_FACILITY_P'] = ('AL351', '100126', 'AeronauticPnt')
    field_information['GGDM 3.0']['Levels']['Regional']['SPACE_FACILITY_P'] = ('AL351', '100126', 'AeronauticPnt')
    field_information['GGDM 3.0']['Levels']['Global']['SPACE_FACILITY_S'] = ('AL351', '100126', 'AeronauticSrf')
    field_information['GGDM 3.0']['Levels']['Local']['SPACE_FACILITY_S'] = ('AL351', '100126', 'AeronauticSrf')
    field_information['GGDM 3.0']['Levels']['Regional']['SPACE_FACILITY_S'] = ('AL351', '100126', 'AeronauticSrf')
    field_information['GGDM 3.0']['Levels']['Specialized']['SPACE_FACILITY_S'] = ('AL351', '100126', 'AeronauticSrf')
    field_information['GGDM 3.0']['Levels']['Local']['MANOR_HOUSE_P'] = ('AL371', '180086', 'StructurePnt')
    field_information['GGDM 3.0']['Levels']['Specialized']['MANOR_HOUSE_P'] = ('AL371', '180086', 'StructurePnt')
    field_information['GGDM 3.0']['Levels']['Local']['MANOR_HOUSE_S'] = ('AL371', '180086', 'StructureSrf')
    field_information['GGDM 3.0']['Levels']['Specialized']['MANOR_HOUSE_S'] = ('AL371', '180086', 'StructureSrf')
    field_information['GGDM 3.0']['Levels']['Global']['CASTLE_P'] = ('AL375', '100128', 'MilitaryPnt')
    field_information['GGDM 3.0']['Levels']['Local']['CASTLE_P'] = ('AL375', '100128', 'MilitaryPnt')
    field_information['GGDM 3.0']['Levels']['Regional']['CASTLE_P'] = ('AL375', '100128', 'MilitaryPnt')
    field_information['GGDM 3.0']['Levels']['Specialized']['CASTLE_P'] = ('AL375', '100128', 'MilitaryPnt')
    field_information['GGDM 3.0']['Levels']['Global']['CASTLE_S'] = ('AL375', '100128', 'MilitarySrf')
    field_information['GGDM 3.0']['Levels']['Local']['CASTLE_S'] = ('AL375', '100128', 'MilitarySrf')
    field_information['GGDM 3.0']['Levels']['Regional']['CASTLE_S'] = ('AL375', '100128', 'MilitarySrf')
    field_information['GGDM 3.0']['Levels']['Specialized']['CASTLE_S'] = ('AL375', '100128', 'MilitarySrf')
    field_information['GGDM 3.0']['Levels']['Global']['CASTLE_COMPLEX_P'] = ('AL376', '132642', 'MilitaryPnt')
    field_information['GGDM 3.0']['Levels']['Local']['CASTLE_COMPLEX_P'] = ('AL376', '132642', 'MilitaryPnt')
    field_information['GGDM 3.0']['Levels']['Regional']['CASTLE_COMPLEX_P'] = ('AL376', '132642', 'MilitaryPnt')
    field_information['GGDM 3.0']['Levels']['Specialized']['CASTLE_COMPLEX_P'] = ('AL376', '132642', 'MilitaryPnt')
    field_information['GGDM 3.0']['Levels']['Global']['CASTLE_COMPLEX_S'] = ('AL376', '132642', 'MilitarySrf')
    field_information['GGDM 3.0']['Levels']['Local']['CASTLE_COMPLEX_S'] = ('AL376', '132642', 'MilitarySrf')
    field_information['GGDM 3.0']['Levels']['Regional']['CASTLE_COMPLEX_S'] = ('AL376', '132642', 'MilitarySrf')
    field_information['GGDM 3.0']['Levels']['Specialized']['CASTLE_COMPLEX_S'] = ('AL376', '132642', 'MilitarySrf')
    field_information['GGDM 3.0']['Levels']['Global']['TETHERED_BALLOON_P'] = ('AL510', '100130', 'AeronauticPnt')
    field_information['GGDM 3.0']['Levels']['Local']['TETHERED_BALLOON_P'] = ('AL510', '100130', 'AeronauticPnt')
    field_information['GGDM 3.0']['Levels']['Regional']['TETHERED_BALLOON_P'] = ('AL510', '100130', 'AeronauticPnt')
    field_information['GGDM 3.0']['Levels']['Specialized']['TETHERED_BALLOON_P'] = ('AL510', '100130', 'AeronauticPnt')
    field_information['GGDM 3.0']['Levels']['Global']['STORAGE_DEPOT_P'] = ('AM010', '100131', 'StoragePnt')
    field_information['GGDM 3.0']['Levels']['Local']['STORAGE_DEPOT_P'] = ('AM010', '100131', 'StoragePnt')
    field_information['GGDM 3.0']['Levels']['Regional']['STORAGE_DEPOT_P'] = ('AM010', '100131', 'StoragePnt')
    field_information['GGDM 3.0']['Levels']['Specialized']['STORAGE_DEPOT_P'] = ('AM010', '100131', 'StoragePnt')
    field_information['GGDM 3.0']['Levels']['Global']['STORAGE_DEPOT_S'] = ('AM010', '100131', 'StorageSrf')
    field_information['GGDM 3.0']['Levels']['Local']['STORAGE_DEPOT_S'] = ('AM010', '100131', 'StorageSrf')
    field_information['GGDM 3.0']['Levels']['Regional']['STORAGE_DEPOT_S'] = ('AM010', '100131', 'StorageSrf')
    field_information['GGDM 3.0']['Levels']['Specialized']['STORAGE_DEPOT_S'] = ('AM010', '100131', 'StorageSrf')
    field_information['GGDM 3.0']['Levels']['Specialized']['SHIPPING_CONTAINER_P'] = ('AM011', '100132', 'StoragePnt')
    field_information['GGDM 3.0']['Levels']['Specialized']['SHIPPING_CONTAINER_S'] = ('AM011', '100132', 'StorageSrf')
    field_information['GGDM 3.0']['Levels']['Global']['GRAIN_STORAGE_STRUCTURE_P'] = ('AM020', '100133', 'AgriculturePnt')
    field_information['GGDM 3.0']['Levels']['Local']['GRAIN_STORAGE_STRUCTURE_P'] = ('AM020', '100133', 'AgriculturePnt')
    field_information['GGDM 3.0']['Levels']['Regional']['GRAIN_STORAGE_STRUCTURE_P'] = ('AM020', '100133', 'AgriculturePnt')
    field_information['GGDM 3.0']['Levels']['Specialized']['GRAIN_STORAGE_STRUCTURE_P'] = ('AM020', '100133', 'AgriculturePnt')
    field_information['GGDM 3.0']['Levels']['Local']['GRAIN_STORAGE_STRUCTURE_S'] = ('AM020', '100133', 'AgricultureSrf')
    field_information['GGDM 3.0']['Levels']['Specialized']['GRAIN_STORAGE_STRUCTURE_S'] = ('AM020', '100133', 'AgricultureSrf')
    field_information['GGDM 3.0']['Levels']['Global']['GRAIN_ELEVATOR_P'] = ('AM030', '100134', 'StoragePnt')
    field_information['GGDM 3.0']['Levels']['Local']['GRAIN_ELEVATOR_P'] = ('AM030', '100134', 'StoragePnt')
    field_information['GGDM 3.0']['Levels']['Regional']['GRAIN_ELEVATOR_P'] = ('AM030', '100134', 'StoragePnt')
    field_information['GGDM 3.0']['Levels']['Specialized']['GRAIN_ELEVATOR_P'] = ('AM030', '100134', 'StoragePnt')
    field_information['GGDM 3.0']['Levels']['Local']['GRAIN_ELEVATOR_S'] = ('AM030', '100134', 'StorageSrf')
    field_information['GGDM 3.0']['Levels']['Specialized']['GRAIN_ELEVATOR_S'] = ('AM030', '100134', 'StorageSrf')
    field_information['GGDM 3.0']['Levels']['Global']['MINERAL_PILE_P'] = ('AM040', '100136', 'IndustryPnt')
    field_information['GGDM 3.0']['Levels']['Local']['MINERAL_PILE_P'] = ('AM040', '100136', 'IndustryPnt')
    field_information['GGDM 3.0']['Levels']['Regional']['MINERAL_PILE_P'] = ('AM040', '100136', 'IndustryPnt')
    field_information['GGDM 3.0']['Levels']['Specialized']['MINERAL_PILE_P'] = ('AM040', '100136', 'IndustryPnt')
    field_information['GGDM 3.0']['Levels']['Local']['MINERAL_PILE_S'] = ('AM040', '100136', 'IndustrySrf')
    field_information['GGDM 3.0']['Levels']['Specialized']['MINERAL_PILE_S'] = ('AM040', '100136', 'IndustrySrf')
    field_information['GGDM 3.0']['Levels']['Global']['SURFACE_BUNKER_P'] = ('AM060', '100137', 'MilitaryPnt')
    field_information['GGDM 3.0']['Levels']['Local']['SURFACE_BUNKER_P'] = ('AM060', '100137', 'MilitaryPnt')
    field_information['GGDM 3.0']['Levels']['Regional']['SURFACE_BUNKER_P'] = ('AM060', '100137', 'MilitaryPnt')
    field_information['GGDM 3.0']['Levels']['Specialized']['SURFACE_BUNKER_P'] = ('AM060', '100137', 'MilitaryPnt')
    field_information['GGDM 3.0']['Levels']['Global']['SURFACE_BUNKER_S'] = ('AM060', '100137', 'MilitarySrf')
    field_information['GGDM 3.0']['Levels']['Local']['SURFACE_BUNKER_S'] = ('AM060', '100137', 'MilitarySrf')
    field_information['GGDM 3.0']['Levels']['Regional']['SURFACE_BUNKER_S'] = ('AM060', '100137', 'MilitarySrf')
    field_information['GGDM 3.0']['Levels']['Specialized']['SURFACE_BUNKER_S'] = ('AM060', '100137', 'MilitarySrf')
    field_information['GGDM 3.0']['Levels']['Global']['MUNITION_STORAGE_FACILITY_P'] = ('AM065', '100138', 'StoragePnt')
    field_information['GGDM 3.0']['Levels']['Local']['MUNITION_STORAGE_FACILITY_P'] = ('AM065', '100138', 'StoragePnt')
    field_information['GGDM 3.0']['Levels']['Regional']['MUNITION_STORAGE_FACILITY_P'] = ('AM065', '100138', 'StoragePnt')
    field_information['GGDM 3.0']['Levels']['Specialized']['MUNITION_STORAGE_FACILITY_P'] = ('AM065', '100138', 'StoragePnt')
    field_information['GGDM 3.0']['Levels']['Global']['MUNITION_STORAGE_FACILITY_S'] = ('AM065', '100138', 'StorageSrf')
    field_information['GGDM 3.0']['Levels']['Local']['MUNITION_STORAGE_FACILITY_S'] = ('AM065', '100138', 'StorageSrf')
    field_information['GGDM 3.0']['Levels']['Regional']['MUNITION_STORAGE_FACILITY_S'] = ('AM065', '100138', 'StorageSrf')
    field_information['GGDM 3.0']['Levels']['Specialized']['MUNITION_STORAGE_FACILITY_S'] = ('AM065', '100138', 'StorageSrf')
    field_information['GGDM 3.0']['Levels']['Global']['STORAGE_TANK_P'] = ('AM070', '100139', 'StoragePnt')
    field_information['GGDM 3.0']['Levels']['Local']['STORAGE_TANK_P'] = ('AM070', '100139', 'StoragePnt')
    field_information['GGDM 3.0']['Levels']['Regional']['STORAGE_TANK_P'] = ('AM070', '100139', 'StoragePnt')
    field_information['GGDM 3.0']['Levels']['Specialized']['STORAGE_TANK_P'] = ('AM070', '100139', 'StoragePnt')
    field_information['GGDM 3.0']['Levels']['Local']['STORAGE_TANK_S'] = ('AM070', '100139', 'StorageSrf')
    field_information['GGDM 3.0']['Levels']['Specialized']['STORAGE_TANK_S'] = ('AM070', '100139', 'StorageSrf')
    field_information['GGDM 3.0']['Levels']['Global']['TANK_FARM_P'] = ('AM071', '100140', 'StoragePnt')
    field_information['GGDM 3.0']['Levels']['Local']['TANK_FARM_P'] = ('AM071', '100140', 'StoragePnt')
    field_information['GGDM 3.0']['Levels']['Regional']['TANK_FARM_P'] = ('AM071', '100140', 'StoragePnt')
    field_information['GGDM 3.0']['Levels']['Specialized']['TANK_FARM_P'] = ('AM071', '100140', 'StoragePnt')
    field_information['GGDM 3.0']['Levels']['Global']['TANK_FARM_S'] = ('AM071', '100140', 'StorageSrf')
    field_information['GGDM 3.0']['Levels']['Local']['TANK_FARM_S'] = ('AM071', '100140', 'StorageSrf')
    field_information['GGDM 3.0']['Levels']['Regional']['TANK_FARM_S'] = ('AM071', '100140', 'StorageSrf')
    field_information['GGDM 3.0']['Levels']['Specialized']['TANK_FARM_S'] = ('AM071', '100140', 'StorageSrf')
    field_information['GGDM 3.0']['Levels']['Global']['FUEL_STORAGE_FACILITY_P'] = ('AM075', '100141', 'StoragePnt')
    field_information['GGDM 3.0']['Levels']['Local']['FUEL_STORAGE_FACILITY_P'] = ('AM075', '100141', 'StoragePnt')
    field_information['GGDM 3.0']['Levels']['Regional']['FUEL_STORAGE_FACILITY_P'] = ('AM075', '100141', 'StoragePnt')
    field_information['GGDM 3.0']['Levels']['Specialized']['FUEL_STORAGE_FACILITY_P'] = ('AM075', '100141', 'StoragePnt')
    field_information['GGDM 3.0']['Levels']['Global']['FUEL_STORAGE_FACILITY_S'] = ('AM075', '100141', 'StorageSrf')
    field_information['GGDM 3.0']['Levels']['Local']['FUEL_STORAGE_FACILITY_S'] = ('AM075', '100141', 'StorageSrf')
    field_information['GGDM 3.0']['Levels']['Regional']['FUEL_STORAGE_FACILITY_S'] = ('AM075', '100141', 'StorageSrf')
    field_information['GGDM 3.0']['Levels']['Specialized']['FUEL_STORAGE_FACILITY_S'] = ('AM075', '100141', 'StorageSrf')
    field_information['GGDM 3.0']['Levels']['Global']['WATER_TOWER_P'] = ('AM080', '100142', 'StoragePnt')
    field_information['GGDM 3.0']['Levels']['Local']['WATER_TOWER_P'] = ('AM080', '100142', 'StoragePnt')
    field_information['GGDM 3.0']['Levels']['Regional']['WATER_TOWER_P'] = ('AM080', '100142', 'StoragePnt')
    field_information['GGDM 3.0']['Levels']['Specialized']['WATER_TOWER_P'] = ('AM080', '100142', 'StoragePnt')
    field_information['GGDM 3.0']['Levels']['Specialized']['WATER_TOWER_S'] = ('AM080', '100142', 'StorageSrf')
    field_information['GGDM 3.0']['Levels']['Global']['RAILWAY_C'] = ('AN010', '100143', 'TransportationGroundCrv')
    field_information['GGDM 3.0']['Levels']['Local']['RAILWAY_C'] = ('AN010', '100143', 'TransportationGroundCrv')
    field_information['GGDM 3.0']['Levels']['Regional']['RAILWAY_C'] = ('AN010', '100143', 'TransportationGroundCrv')
    field_information['GGDM 3.0']['Levels']['Specialized']['RAILWAY_C'] = ('AN010', '100143', 'TransportationGroundCrv')
    field_information['GGDM 3.0']['Levels']['Global']['RAILWAY_SIDETRACK_C'] = ('AN050', '100144', 'TransportationGroundCrv')
    field_information['GGDM 3.0']['Levels']['Local']['RAILWAY_SIDETRACK_C'] = ('AN050', '100144', 'TransportationGroundCrv')
    field_information['GGDM 3.0']['Levels']['Regional']['RAILWAY_SIDETRACK_C'] = ('AN050', '100144', 'TransportationGroundCrv')
    field_information['GGDM 3.0']['Levels']['Specialized']['RAILWAY_SIDETRACK_C'] = ('AN050', '100144', 'TransportationGroundCrv')
    field_information['GGDM 3.0']['Levels']['Global']['RAILWAY_YARD_P'] = ('AN060', '100145', 'TransportationGroundPntExt')
    field_information['GGDM 3.0']['Levels']['Regional']['RAILWAY_YARD_P'] = ('AN060', '100145', 'TransportationGroundPntExt')
    field_information['GGDM 3.0']['Levels']['Global']['RAILWAY_YARD_S'] = ('AN060', '100145', 'TransportationGroundSrf')
    field_information['GGDM 3.0']['Levels']['Local']['RAILWAY_YARD_S'] = ('AN060', '100145', 'TransportationGroundSrf')
    field_information['GGDM 3.0']['Levels']['Regional']['RAILWAY_YARD_S'] = ('AN060', '100145', 'TransportationGroundSrf')
    field_information['GGDM 3.0']['Levels']['Specialized']['RAILWAY_YARD_S'] = ('AN060', '100145', 'TransportationGroundSrf')
    field_information['GGDM 3.0']['Levels']['Local']['RAILWAY_TURNTABLE_P'] = ('AN075', '100146', 'TransportationGroundPnt')
    field_information['GGDM 3.0']['Levels']['Specialized']['RAILWAY_TURNTABLE_P'] = ('AN075', '100146', 'TransportationGroundPnt')
    field_information['GGDM 3.0']['Levels']['Specialized']['RAILWAY_TURNTABLE_S'] = ('AN075', '100146', 'TransportationGroundSrf')
    field_information['GGDM 3.0']['Levels']['Global']['ROUNDHOUSE_P'] = ('AN076', '100147', 'TransportationGroundPnt')
    field_information['GGDM 3.0']['Levels']['Local']['ROUNDHOUSE_P'] = ('AN076', '100147', 'TransportationGroundPnt')
    field_information['GGDM 3.0']['Levels']['Regional']['ROUNDHOUSE_P'] = ('AN076', '100147', 'TransportationGroundPnt')
    field_information['GGDM 3.0']['Levels']['Specialized']['ROUNDHOUSE_P'] = ('AN076', '100147', 'TransportationGroundPnt')
    field_information['GGDM 3.0']['Levels']['Local']['ROUNDHOUSE_S'] = ('AN076', '100147', 'TransportationGroundSrf')
    field_information['GGDM 3.0']['Levels']['Regional']['ROUNDHOUSE_S'] = ('AN076', '100147', 'TransportationGroundSrf')
    field_information['GGDM 3.0']['Levels']['Specialized']['ROUNDHOUSE_S'] = ('AN076', '100147', 'TransportationGroundSrf')
    field_information['GGDM 3.0']['Levels']['Specialized']['RAILWAY_SIGNAL_P'] = ('AN085', '100149', 'TransportationGroundPnt')
    field_information['GGDM 3.0']['Levels']['Global']['CART_TRACK_C'] = ('AP010', '100150', 'TransportationGroundCrv')
    field_information['GGDM 3.0']['Levels']['Local']['CART_TRACK_C'] = ('AP010', '100150', 'TransportationGroundCrv')
    field_information['GGDM 3.0']['Levels']['Regional']['CART_TRACK_C'] = ('AP010', '100150', 'TransportationGroundCrv')
    field_information['GGDM 3.0']['Levels']['Specialized']['CART_TRACK_C'] = ('AP010', '100150', 'TransportationGroundCrv')
    field_information['GGDM 3.0']['Levels']['Global']['ROAD_INTERCHANGE_P'] = ('AP020', '100151', 'TransportationGroundPnt')
    field_information['GGDM 3.0']['Levels']['Local']['ROAD_INTERCHANGE_P'] = ('AP020', '100151', 'TransportationGroundPnt')
    field_information['GGDM 3.0']['Levels']['Regional']['ROAD_INTERCHANGE_P'] = ('AP020', '100151', 'TransportationGroundPnt')
    field_information['GGDM 3.0']['Levels']['Specialized']['ROAD_INTERCHANGE_P'] = ('AP020', '100151', 'TransportationGroundPnt')
    field_information['GGDM 3.0']['Levels']['Global']['ROAD_C'] = ('AP030', '100152', 'TransportationGroundCrv')
    field_information['GGDM 3.0']['Levels']['Local']['ROAD_C'] = ('AP030', '100152', 'TransportationGroundCrv')
    field_information['GGDM 3.0']['Levels']['Regional']['ROAD_C'] = ('AP030', '100152', 'TransportationGroundCrv')
    field_information['GGDM 3.0']['Levels']['Specialized']['ROAD_C'] = ('AP030', '100152', 'TransportationGroundCrv')
    field_information['GGDM 3.0']['Levels']['Specialized']['ROAD_S'] = ('AP030', '100152', 'TransportationGroundSrf')
    field_information['GGDM 3.0']['Levels']['Specialized']['ENGINEERED_TURNAROUND_SITE_P'] = ('AP033', '179969', 'TransportationGroundPnt')
    field_information['GGDM 3.0']['Levels']['Local']['GATE_C'] = ('AP040', '100154', 'TransportationGroundCrv')
    field_information['GGDM 3.0']['Levels']['Specialized']['GATE_C'] = ('AP040', '100154', 'TransportationGroundCrv')
    field_information['GGDM 3.0']['Levels']['Global']['GATE_P'] = ('AP040', '100154', 'TransportationGroundPnt')
    field_information['GGDM 3.0']['Levels']['Local']['GATE_P'] = ('AP040', '100154', 'TransportationGroundPnt')
    field_information['GGDM 3.0']['Levels']['Regional']['GATE_P'] = ('AP040', '100154', 'TransportationGroundPnt')
    field_information['GGDM 3.0']['Levels']['Specialized']['GATE_P'] = ('AP040', '100154', 'TransportationGroundPnt')
    field_information['GGDM 3.0']['Levels']['Local']['VEHICLE_BARRIER_C'] = ('AP041', '100155', 'TransportationGroundCrv')
    field_information['GGDM 3.0']['Levels']['Specialized']['VEHICLE_BARRIER_C'] = ('AP041', '100155', 'TransportationGroundCrv')
    field_information['GGDM 3.0']['Levels']['Global']['VEHICLE_BARRIER_P'] = ('AP041', '100155', 'TransportationGroundPnt')
    field_information['GGDM 3.0']['Levels']['Local']['VEHICLE_BARRIER_P'] = ('AP041', '100155', 'TransportationGroundPnt')
    field_information['GGDM 3.0']['Levels']['Regional']['VEHICLE_BARRIER_P'] = ('AP041', '100155', 'TransportationGroundPnt')
    field_information['GGDM 3.0']['Levels']['Specialized']['VEHICLE_BARRIER_P'] = ('AP041', '100155', 'TransportationGroundPnt')
    field_information['GGDM 3.0']['Levels']['Global']['TRAIL_C'] = ('AP050', '100156', 'TransportationGroundCrv')
    field_information['GGDM 3.0']['Levels']['Local']['TRAIL_C'] = ('AP050', '100156', 'TransportationGroundCrv')
    field_information['GGDM 3.0']['Levels']['Regional']['TRAIL_C'] = ('AP050', '100156', 'TransportationGroundCrv')
    field_information['GGDM 3.0']['Levels']['Specialized']['TRAIL_C'] = ('AP050', '100156', 'TransportationGroundCrv')
    field_information['GGDM 3.0']['Levels']['Local']['TANK_TRAIL_C'] = ('AP055', '179906', 'TransportationGroundCrv')
    field_information['GGDM 3.0']['Levels']['Specialized']['TANK_TRAIL_C'] = ('AP055', '179906', 'TransportationGroundCrv')
    field_information['GGDM 3.0']['Levels']['Local']['TANK_TRAIL_S'] = ('AP055', '179906', 'TransportationGroundSrf')
    field_information['GGDM 3.0']['Levels']['Specialized']['TANK_TRAIL_S'] = ('AP055', '179906', 'TransportationGroundSrf')
    field_information['GGDM 3.0']['Levels']['Local']['TANK_CROSSING_P'] = ('AP056', '180006', 'TransportationGroundPnt')
    field_information['GGDM 3.0']['Levels']['Specialized']['TANK_CROSSING_P'] = ('AP056', '180006', 'TransportationGroundPnt')
    field_information['GGDM 3.0']['Levels']['Local']['TANK_CROSSING_S'] = ('AP056', '180006', 'TransportationGroundSrf')
    field_information['GGDM 3.0']['Levels']['Specialized']['TANK_CROSSING_S'] = ('AP056', '180006', 'TransportationGroundSrf')
    field_information['GGDM 3.0']['Levels']['Specialized']['SIDEWALK_C'] = ('AQ035', '100159', 'TransportationGroundCrv')
    field_information['GGDM 3.0']['Levels']['Global']['BRIDGE_C'] = ('AQ040', '100161', 'TransportationGroundCrv')
    field_information['GGDM 3.0']['Levels']['Local']['BRIDGE_C'] = ('AQ040', '100161', 'TransportationGroundCrv')
    field_information['GGDM 3.0']['Levels']['Regional']['BRIDGE_C'] = ('AQ040', '100161', 'TransportationGroundCrv')
    field_information['GGDM 3.0']['Levels']['Specialized']['BRIDGE_C'] = ('AQ040', '100161', 'TransportationGroundCrv')
    field_information['GGDM 3.0']['Levels']['Global']['BRIDGE_P'] = ('AQ040', '100161', 'TransportationGroundPnt')
    field_information['GGDM 3.0']['Levels']['Local']['BRIDGE_P'] = ('AQ040', '100161', 'TransportationGroundPnt')
    field_information['GGDM 3.0']['Levels']['Regional']['BRIDGE_P'] = ('AQ040', '100161', 'TransportationGroundPnt')
    field_information['GGDM 3.0']['Levels']['Specialized']['BRIDGE_P'] = ('AQ040', '100161', 'TransportationGroundPnt')
    field_information['GGDM 3.0']['Levels']['Specialized']['BRIDGE_S'] = ('AQ040', '100161', 'TransportationGroundSrf')
    field_information['GGDM 3.0']['Levels']['Local']['BRIDGE_SPAN_C'] = ('AQ045', '100162', 'TransportationGroundCrv')
    field_information['GGDM 3.0']['Levels']['Specialized']['BRIDGE_SPAN_C'] = ('AQ045', '100162', 'TransportationGroundCrv')
    field_information['GGDM 3.0']['Levels']['Local']['BRIDGE_SPAN_P'] = ('AQ045', '100162', 'TransportationGroundPnt')
    field_information['GGDM 3.0']['Levels']['Specialized']['BRIDGE_SPAN_P'] = ('AQ045', '100162', 'TransportationGroundPnt')
    field_information['GGDM 3.0']['Levels']['Specialized']['BRIDGE_SPAN_S'] = ('AQ045', '100162', 'TransportationGroundSrf')
    field_information['GGDM 3.0']['Levels']['Global']['BRIDGE_SUPERSTRUCTURE_C'] = ('AQ050', '100163', 'TransportationGroundCrv')
    field_information['GGDM 3.0']['Levels']['Local']['BRIDGE_SUPERSTRUCTURE_C'] = ('AQ050', '100163', 'TransportationGroundCrv')
    field_information['GGDM 3.0']['Levels']['Regional']['BRIDGE_SUPERSTRUCTURE_C'] = ('AQ050', '100163', 'TransportationGroundCrv')
    field_information['GGDM 3.0']['Levels']['Specialized']['BRIDGE_SUPERSTRUCTURE_C'] = ('AQ050', '100163', 'TransportationGroundCrv')
    field_information['GGDM 3.0']['Levels']['Local']['BRIDGE_SUPERSTRUCTURE_S'] = ('AQ050', '100163', 'TransportationGroundSrf')
    field_information['GGDM 3.0']['Levels']['Specialized']['BRIDGE_SUPERSTRUCTURE_S'] = ('AQ050', '100163', 'TransportationGroundSrf')
    field_information['GGDM 3.0']['Levels']['Global']['BRIDGE_TOWER_P'] = ('AQ055', '100164', 'TransportationGroundPnt')
    field_information['GGDM 3.0']['Levels']['Local']['BRIDGE_TOWER_P'] = ('AQ055', '100164', 'TransportationGroundPnt')
    field_information['GGDM 3.0']['Levels']['Regional']['BRIDGE_TOWER_P'] = ('AQ055', '100164', 'TransportationGroundPnt')
    field_information['GGDM 3.0']['Levels']['Specialized']['BRIDGE_TOWER_P'] = ('AQ055', '100164', 'TransportationGroundPnt')
    field_information['GGDM 3.0']['Levels']['Specialized']['BRIDGE_PIER_C'] = ('AQ056', '100165', 'TransportationGroundCrv')
    field_information['GGDM 3.0']['Levels']['Local']['BRIDGE_PIER_P'] = ('AQ056', '100165', 'TransportationGroundPnt')
    field_information['GGDM 3.0']['Levels']['Specialized']['BRIDGE_PIER_P'] = ('AQ056', '100165', 'TransportationGroundPnt')
    field_information['GGDM 3.0']['Levels']['Specialized']['BRIDGE_PIER_S'] = ('AQ056', '100165', 'TransportationGroundSrf')
    field_information['GGDM 3.0']['Levels']['Global']['TRANS_ROUTE_CHARACTER_CHANGE_C'] = ('AQ059', '131083', 'TransportationGroundCrv')
    field_information['GGDM 3.0']['Levels']['Local']['TRANS_ROUTE_CHARACTER_CHANGE_C'] = ('AQ059', '131083', 'TransportationGroundCrv')
    field_information['GGDM 3.0']['Levels']['Regional']['TRANS_ROUTE_CHARACTER_CHANGE_C'] = ('AQ059', '131083', 'TransportationGroundCrv')
    field_information['GGDM 3.0']['Levels']['Specialized']['TRANS_ROUTE_CHARACTER_CHANGE_C'] = ('AQ059', '131083', 'TransportationGroundCrv')
    field_information['GGDM 3.0']['Levels']['Global']['TRANS_ROUTE_CHARACTER_CHANGE_P'] = ('AQ059', '131083', 'TransportationGroundPnt')
    field_information['GGDM 3.0']['Levels']['Local']['TRANS_ROUTE_CHARACTER_CHANGE_P'] = ('AQ059', '131083', 'TransportationGroundPnt')
    field_information['GGDM 3.0']['Levels']['Regional']['TRANS_ROUTE_CHARACTER_CHANGE_P'] = ('AQ059', '131083', 'TransportationGroundPnt')
    field_information['GGDM 3.0']['Levels']['Specialized']['TRANS_ROUTE_CHARACTER_CHANGE_P'] = ('AQ059', '131083', 'TransportationGroundPnt')
    field_information['GGDM 3.0']['Levels']['Global']['CONTROL_TOWER_P'] = ('AQ060', '100167', 'AeronauticPnt')
    field_information['GGDM 3.0']['Levels']['Local']['CONTROL_TOWER_P'] = ('AQ060', '100167', 'AeronauticPnt')
    field_information['GGDM 3.0']['Levels']['Regional']['CONTROL_TOWER_P'] = ('AQ060', '100167', 'AeronauticPnt')
    field_information['GGDM 3.0']['Levels']['Specialized']['CONTROL_TOWER_P'] = ('AQ060', '100167', 'AeronauticPnt')
    field_information['GGDM 3.0']['Levels']['Local']['CONTROL_TOWER_S'] = ('AQ060', '100167', 'AeronauticSrf')
    field_information['GGDM 3.0']['Levels']['Specialized']['CONTROL_TOWER_S'] = ('AQ060', '100167', 'AeronauticSrf')
    field_information['GGDM 3.0']['Levels']['Global']['CROSSING_P'] = ('AQ062', '100168', 'TransportationGroundPnt')
    field_information['GGDM 3.0']['Levels']['Local']['CROSSING_P'] = ('AQ062', '100168', 'TransportationGroundPnt')
    field_information['GGDM 3.0']['Levels']['Regional']['CROSSING_P'] = ('AQ062', '100168', 'TransportationGroundPnt')
    field_information['GGDM 3.0']['Levels']['Specialized']['CROSSING_P'] = ('AQ062', '100168', 'TransportationGroundPnt')
    field_information['GGDM 3.0']['Levels']['Global']['CAUSEWAY_STRUCTURE_C'] = ('AQ063', '130381', 'TransportationGroundCrv')
    field_information['GGDM 3.0']['Levels']['Local']['CAUSEWAY_STRUCTURE_C'] = ('AQ063', '130381', 'TransportationGroundCrv')
    field_information['GGDM 3.0']['Levels']['Regional']['CAUSEWAY_STRUCTURE_C'] = ('AQ063', '130381', 'TransportationGroundCrv')
    field_information['GGDM 3.0']['Levels']['Specialized']['CAUSEWAY_STRUCTURE_C'] = ('AQ063', '130381', 'TransportationGroundCrv')
    field_information['GGDM 3.0']['Levels']['Local']['CAUSEWAY_STRUCTURE_S'] = ('AQ063', '130381', 'TransportationGroundSrf')
    field_information['GGDM 3.0']['Levels']['Specialized']['CAUSEWAY_STRUCTURE_S'] = ('AQ063', '130381', 'TransportationGroundSrf')
    field_information['GGDM 3.0']['Levels']['Local']['CULVERT_C'] = ('AQ065', '100170', 'TransportationGroundCrv')
    field_information['GGDM 3.0']['Levels']['Specialized']['CULVERT_C'] = ('AQ065', '100170', 'TransportationGroundCrv')
    field_information['GGDM 3.0']['Levels']['Local']['CULVERT_P'] = ('AQ065', '100170', 'TransportationGroundPnt')
    field_information['GGDM 3.0']['Levels']['Specialized']['CULVERT_P'] = ('AQ065', '100170', 'TransportationGroundPnt')
    field_information['GGDM 3.0']['Levels']['Global']['TRANSPORTATION_BLOCK_P'] = ('AQ068', '100171', 'TransportationGroundPnt')
    field_information['GGDM 3.0']['Levels']['Local']['TRANSPORTATION_BLOCK_P'] = ('AQ068', '100171', 'TransportationGroundPnt')
    field_information['GGDM 3.0']['Levels']['Regional']['TRANSPORTATION_BLOCK_P'] = ('AQ068', '100171', 'TransportationGroundPnt')
    field_information['GGDM 3.0']['Levels']['Specialized']['TRANSPORTATION_BLOCK_P'] = ('AQ068', '100171', 'TransportationGroundPnt')
    field_information['GGDM 3.0']['Levels']['Specialized']['TRANSPORTATION_BLOCK_S'] = ('AQ068', '100171', 'TransportationGroundSrf')
    field_information['GGDM 3.0']['Levels']['Global']['FERRY_CROSSING_C'] = ('AQ070', '100172', 'TransportationWaterCrv')
    field_information['GGDM 3.0']['Levels']['Local']['FERRY_CROSSING_C'] = ('AQ070', '100172', 'TransportationWaterCrv')
    field_information['GGDM 3.0']['Levels']['Regional']['FERRY_CROSSING_C'] = ('AQ070', '100172', 'TransportationWaterCrv')
    field_information['GGDM 3.0']['Levels']['Specialized']['FERRY_CROSSING_C'] = ('AQ070', '100172', 'TransportationWaterCrv')
    field_information['GGDM 3.0']['Levels']['Local']['FERRY_CROSSING_P'] = ('AQ070', '100172', 'TransportationWaterPntExt')
    field_information['GGDM 3.0']['Levels']['Regional']['FERRY_CROSSING_P'] = ('AQ070', '100172', 'TransportationWaterPntExt')
    field_information['GGDM 3.0']['Levels']['Specialized']['FERRY_CROSSING_P'] = ('AQ070', '100172', 'TransportationWaterPntExt')
    field_information['GGDM 3.0']['Levels']['Global']['ICE_ROUTE_C'] = ('AQ075', '100173', 'TransportationGroundCrv')
    field_information['GGDM 3.0']['Levels']['Local']['ICE_ROUTE_C'] = ('AQ075', '100173', 'TransportationGroundCrv')
    field_information['GGDM 3.0']['Levels']['Regional']['ICE_ROUTE_C'] = ('AQ075', '100173', 'TransportationGroundCrv')
    field_information['GGDM 3.0']['Levels']['Specialized']['ICE_ROUTE_C'] = ('AQ075', '100173', 'TransportationGroundCrv')
    field_information['GGDM 3.0']['Levels']['Global']['FERRY_STATION_P'] = ('AQ080', '100174', 'TransportationWaterPnt')
    field_information['GGDM 3.0']['Levels']['Local']['FERRY_STATION_P'] = ('AQ080', '100174', 'TransportationWaterPnt')
    field_information['GGDM 3.0']['Levels']['Regional']['FERRY_STATION_P'] = ('AQ080', '100174', 'TransportationWaterPnt')
    field_information['GGDM 3.0']['Levels']['Specialized']['FERRY_STATION_P'] = ('AQ080', '100174', 'TransportationWaterPnt')
    field_information['GGDM 3.0']['Levels']['Global']['FERRY_STATION_S'] = ('AQ080', '100174', 'TransportationWaterSrf')
    field_information['GGDM 3.0']['Levels']['Local']['FERRY_STATION_S'] = ('AQ080', '100174', 'TransportationWaterSrf')
    field_information['GGDM 3.0']['Levels']['Regional']['FERRY_STATION_S'] = ('AQ080', '100174', 'TransportationWaterSrf')
    field_information['GGDM 3.0']['Levels']['Specialized']['FERRY_STATION_S'] = ('AQ080', '100174', 'TransportationWaterSrf')
    field_information['GGDM 3.0']['Levels']['Global']['TUNNEL_MOUTH_P'] = ('AQ095', '100176', 'TransportationGroundPnt')
    field_information['GGDM 3.0']['Levels']['Local']['TUNNEL_MOUTH_P'] = ('AQ095', '100176', 'TransportationGroundPnt')
    field_information['GGDM 3.0']['Levels']['Regional']['TUNNEL_MOUTH_P'] = ('AQ095', '100176', 'TransportationGroundPnt')
    field_information['GGDM 3.0']['Levels']['Specialized']['TUNNEL_MOUTH_P'] = ('AQ095', '100176', 'TransportationGroundPnt')
    field_information['GGDM 3.0']['Levels']['Global']['MOORING_MAST_P'] = ('AQ110', '100177', 'AeronauticPnt')
    field_information['GGDM 3.0']['Levels']['Local']['MOORING_MAST_P'] = ('AQ110', '100177', 'AeronauticPnt')
    field_information['GGDM 3.0']['Levels']['Regional']['MOORING_MAST_P'] = ('AQ110', '100177', 'AeronauticPnt')
    field_information['GGDM 3.0']['Levels']['Specialized']['MOORING_MAST_P'] = ('AQ110', '100177', 'AeronauticPnt')
    field_information['GGDM 3.0']['Levels']['Global']['PREPARED_WATERCOURSE_CROSS_P'] = ('AQ111', '100178', 'TransportationWaterPnt')
    field_information['GGDM 3.0']['Levels']['Local']['PREPARED_WATERCOURSE_CROSS_P'] = ('AQ111', '100178', 'TransportationWaterPnt')
    field_information['GGDM 3.0']['Levels']['Regional']['PREPARED_WATERCOURSE_CROSS_P'] = ('AQ111', '100178', 'TransportationWaterPnt')
    field_information['GGDM 3.0']['Levels']['Specialized']['PREPARED_WATERCOURSE_CROSS_P'] = ('AQ111', '100178', 'TransportationWaterPnt')
    field_information['GGDM 3.0']['Levels']['Global']['PIPELINE_C'] = ('AQ113', '100179', 'UtilityInfrastructureCrv')
    field_information['GGDM 3.0']['Levels']['Local']['PIPELINE_C'] = ('AQ113', '100179', 'UtilityInfrastructureCrv')
    field_information['GGDM 3.0']['Levels']['Regional']['PIPELINE_C'] = ('AQ113', '100179', 'UtilityInfrastructureCrv')
    field_information['GGDM 3.0']['Levels']['Specialized']['PIPELINE_C'] = ('AQ113', '100179', 'UtilityInfrastructureCrv')
    field_information['GGDM 3.0']['Levels']['Specialized']['STORM_DRAIN_P'] = ('AQ114', '100180', 'UtilityInfrastructurePnt')
    field_information['GGDM 3.0']['Levels']['Specialized']['UTILITY_ACCESS_POINT_P'] = ('AQ115', '100181', 'UtilityInfrastructurePnt')
    field_information['GGDM 3.0']['Levels']['Global']['PUMPING_STATION_P'] = ('AQ116', '100182', 'UtilityInfrastructurePnt')
    field_information['GGDM 3.0']['Levels']['Local']['PUMPING_STATION_P'] = ('AQ116', '100182', 'UtilityInfrastructurePnt')
    field_information['GGDM 3.0']['Levels']['Regional']['PUMPING_STATION_P'] = ('AQ116', '100182', 'UtilityInfrastructurePnt')
    field_information['GGDM 3.0']['Levels']['Specialized']['PUMPING_STATION_P'] = ('AQ116', '100182', 'UtilityInfrastructurePnt')
    field_information['GGDM 3.0']['Levels']['Global']['PUMPING_STATION_S'] = ('AQ116', '100182', 'UtilityInfrastructureSrf')
    field_information['GGDM 3.0']['Levels']['Local']['PUMPING_STATION_S'] = ('AQ116', '100182', 'UtilityInfrastructureSrf')
    field_information['GGDM 3.0']['Levels']['Regional']['PUMPING_STATION_S'] = ('AQ116', '100182', 'UtilityInfrastructureSrf')
    field_information['GGDM 3.0']['Levels']['Specialized']['PUMPING_STATION_S'] = ('AQ116', '100182', 'UtilityInfrastructureSrf')
    field_information['GGDM 3.0']['Levels']['Global']['SHARP_CURVE_P'] = ('AQ118', '100183', 'TransportationGroundPnt')
    field_information['GGDM 3.0']['Levels']['Local']['SHARP_CURVE_P'] = ('AQ118', '100183', 'TransportationGroundPnt')
    field_information['GGDM 3.0']['Levels']['Regional']['SHARP_CURVE_P'] = ('AQ118', '100183', 'TransportationGroundPnt')
    field_information['GGDM 3.0']['Levels']['Specialized']['SHARP_CURVE_P'] = ('AQ118', '100183', 'TransportationGroundPnt')
    field_information['GGDM 3.0']['Levels']['Global']['STEEP_GRADE_C'] = ('AQ120', '100185', 'TransportationGroundCrv')
    field_information['GGDM 3.0']['Levels']['Local']['STEEP_GRADE_C'] = ('AQ120', '100185', 'TransportationGroundCrv')
    field_information['GGDM 3.0']['Levels']['Regional']['STEEP_GRADE_C'] = ('AQ120', '100185', 'TransportationGroundCrv')
    field_information['GGDM 3.0']['Levels']['Specialized']['STEEP_GRADE_C'] = ('AQ120', '100185', 'TransportationGroundCrv')
    field_information['GGDM 3.0']['Levels']['Global']['TRANSPORTATION_STATION_P'] = ('AQ125', '100186', 'TransportationGroundPnt')
    field_information['GGDM 3.0']['Levels']['Local']['TRANSPORTATION_STATION_P'] = ('AQ125', '100186', 'TransportationGroundPnt')
    field_information['GGDM 3.0']['Levels']['Regional']['TRANSPORTATION_STATION_P'] = ('AQ125', '100186', 'TransportationGroundPnt')
    field_information['GGDM 3.0']['Levels']['Specialized']['TRANSPORTATION_STATION_P'] = ('AQ125', '100186', 'TransportationGroundPnt')
    field_information['GGDM 3.0']['Levels']['Global']['TRANSPORTATION_STATION_S'] = ('AQ125', '100186', 'TransportationGroundSrf')
    field_information['GGDM 3.0']['Levels']['Local']['TRANSPORTATION_STATION_S'] = ('AQ125', '100186', 'TransportationGroundSrf')
    field_information['GGDM 3.0']['Levels']['Regional']['TRANSPORTATION_STATION_S'] = ('AQ125', '100186', 'TransportationGroundSrf')
    field_information['GGDM 3.0']['Levels']['Specialized']['TRANSPORTATION_STATION_S'] = ('AQ125', '100186', 'TransportationGroundSrf')
    field_information['GGDM 3.0']['Levels']['Global']['TUNNEL_C'] = ('AQ130', '100187', 'TransportationGroundCrv')
    field_information['GGDM 3.0']['Levels']['Local']['TUNNEL_C'] = ('AQ130', '100187', 'TransportationGroundCrv')
    field_information['GGDM 3.0']['Levels']['Regional']['TUNNEL_C'] = ('AQ130', '100187', 'TransportationGroundCrv')
    field_information['GGDM 3.0']['Levels']['Specialized']['TUNNEL_C'] = ('AQ130', '100187', 'TransportationGroundCrv')
    field_information['GGDM 3.0']['Levels']['Specialized']['TUNNEL_S'] = ('AQ130', '100187', 'TransportationGroundSrf')
    field_information['GGDM 3.0']['Levels']['Global']['ROADSIDE_REST_AREA_P'] = ('AQ135', '100188', 'TransportationGroundPnt')
    field_information['GGDM 3.0']['Levels']['Regional']['ROADSIDE_REST_AREA_P'] = ('AQ135', '100188', 'TransportationGroundPnt')
    field_information['GGDM 3.0']['Levels']['Local']['ROADSIDE_REST_AREA_S'] = ('AQ135', '100188', 'TransportationGroundSrf')
    field_information['GGDM 3.0']['Levels']['Specialized']['ROADSIDE_REST_AREA_S'] = ('AQ135', '100188', 'TransportationGroundSrf')
    field_information['GGDM 3.0']['Levels']['Local']['VEHICLE_LOT_S'] = ('AQ140', '100189', 'TransportationGroundSrf')
    field_information['GGDM 3.0']['Levels']['Specialized']['VEHICLE_LOT_S'] = ('AQ140', '100189', 'TransportationGroundSrf')
    field_information['GGDM 3.0']['Levels']['Global']['PARKING_GARAGE_P'] = ('AQ141', '100190', 'TransportationGroundPnt')
    field_information['GGDM 3.0']['Levels']['Local']['PARKING_GARAGE_P'] = ('AQ141', '100190', 'TransportationGroundPnt')
    field_information['GGDM 3.0']['Levels']['Regional']['PARKING_GARAGE_P'] = ('AQ141', '100190', 'TransportationGroundPnt')
    field_information['GGDM 3.0']['Levels']['Specialized']['PARKING_GARAGE_P'] = ('AQ141', '100190', 'TransportationGroundPnt')
    field_information['GGDM 3.0']['Levels']['Local']['PARKING_GARAGE_S'] = ('AQ141', '100190', 'TransportationGroundSrf')
    field_information['GGDM 3.0']['Levels']['Regional']['PARKING_GARAGE_S'] = ('AQ141', '100190', 'TransportationGroundSrf')
    field_information['GGDM 3.0']['Levels']['Specialized']['PARKING_GARAGE_S'] = ('AQ141', '100190', 'TransportationGroundSrf')
    field_information['GGDM 3.0']['Levels']['Specialized']['STAIR_C'] = ('AQ150', '100191', 'StructureCrv')
    field_information['GGDM 3.0']['Levels']['Specialized']['STAIR_S'] = ('AQ150', '100191', 'StructureSrf')
    field_information['GGDM 3.0']['Levels']['Specialized']['ARCADE_C'] = ('AQ151', '100192', 'TransportationGroundCrv')
    field_information['GGDM 3.0']['Levels']['Specialized']['ARCADE_S'] = ('AQ151', '100192', 'TransportationGroundSrf')
    field_information['GGDM 3.0']['Levels']['Specialized']['TRAFFIC_LIGHT_P'] = ('AQ160', '100194', 'TransportationGroundPnt')
    field_information['GGDM 3.0']['Levels']['Specialized']['STREET_LAMP_P'] = ('AQ161', '100195', 'TransportationGroundPnt')
    field_information['GGDM 3.0']['Levels']['Global']['STREET_SIGN_P'] = ('AQ162', '100196', 'TransportationGroundPnt')
    field_information['GGDM 3.0']['Levels']['Local']['STREET_SIGN_P'] = ('AQ162', '100196', 'TransportationGroundPnt')
    field_information['GGDM 3.0']['Levels']['Regional']['STREET_SIGN_P'] = ('AQ162', '100196', 'TransportationGroundPnt')
    field_information['GGDM 3.0']['Levels']['Specialized']['STREET_SIGN_P'] = ('AQ162', '100196', 'TransportationGroundPnt')
    field_information['GGDM 3.0']['Levels']['Global']['MOTOR_VEHICLE_STATION_P'] = ('AQ170', '100197', 'TransportationGroundPnt')
    field_information['GGDM 3.0']['Levels']['Local']['MOTOR_VEHICLE_STATION_P'] = ('AQ170', '100197', 'TransportationGroundPnt')
    field_information['GGDM 3.0']['Levels']['Regional']['MOTOR_VEHICLE_STATION_P'] = ('AQ170', '100197', 'TransportationGroundPnt')
    field_information['GGDM 3.0']['Levels']['Specialized']['MOTOR_VEHICLE_STATION_P'] = ('AQ170', '100197', 'TransportationGroundPnt')
    field_information['GGDM 3.0']['Levels']['Local']['MOTOR_VEHICLE_STATION_S'] = ('AQ170', '100197', 'TransportationGroundSrf')
    field_information['GGDM 3.0']['Levels']['Regional']['MOTOR_VEHICLE_STATION_S'] = ('AQ170', '100197', 'TransportationGroundSrf')
    field_information['GGDM 3.0']['Levels']['Specialized']['MOTOR_VEHICLE_STATION_S'] = ('AQ170', '100197', 'TransportationGroundSrf')
    field_information['GGDM 3.0']['Levels']['Global']['CABLE_C'] = ('AT005', '100199', 'UtilityInfrastructureCrv')
    field_information['GGDM 3.0']['Levels']['Local']['CABLE_C'] = ('AT005', '100199', 'UtilityInfrastructureCrv')
    field_information['GGDM 3.0']['Levels']['Regional']['CABLE_C'] = ('AT005', '100199', 'UtilityInfrastructureCrv')
    field_information['GGDM 3.0']['Levels']['Specialized']['CABLE_C'] = ('AT005', '100199', 'UtilityInfrastructureCrv')
    field_information['GGDM 3.0']['Levels']['Local']['DISH_AERIAL_P'] = ('AT010', '100200', 'UtilityInfrastructurePnt')
    field_information['GGDM 3.0']['Levels']['Regional']['DISH_AERIAL_P'] = ('AT010', '100200', 'UtilityInfrastructurePnt')
    field_information['GGDM 3.0']['Levels']['Specialized']['DISH_AERIAL_P'] = ('AT010', '100200', 'UtilityInfrastructurePnt')
    field_information['GGDM 3.0']['Levels']['Global']['AERIAL_P'] = ('AT011', '100201', 'UtilityInfrastructurePnt')
    field_information['GGDM 3.0']['Levels']['Local']['AERIAL_P'] = ('AT011', '100201', 'UtilityInfrastructurePnt')
    field_information['GGDM 3.0']['Levels']['Regional']['AERIAL_P'] = ('AT011', '100201', 'UtilityInfrastructurePnt')
    field_information['GGDM 3.0']['Levels']['Specialized']['AERIAL_P'] = ('AT011', '100201', 'UtilityInfrastructurePnt')
    field_information['GGDM 3.0']['Levels']['Global']['AERIAL_FARM_P'] = ('AT012', '100202', 'UtilityInfrastructurePnt')
    field_information['GGDM 3.0']['Levels']['Local']['AERIAL_FARM_P'] = ('AT012', '100202', 'UtilityInfrastructurePnt')
    field_information['GGDM 3.0']['Levels']['Regional']['AERIAL_FARM_P'] = ('AT012', '100202', 'UtilityInfrastructurePnt')
    field_information['GGDM 3.0']['Levels']['Specialized']['AERIAL_FARM_P'] = ('AT012', '100202', 'UtilityInfrastructurePnt')
    field_information['GGDM 3.0']['Levels']['Global']['AERIAL_FARM_S'] = ('AT012', '100202', 'UtilityInfrastructureSrf')
    field_information['GGDM 3.0']['Levels']['Local']['AERIAL_FARM_S'] = ('AT012', '100202', 'UtilityInfrastructureSrf')
    field_information['GGDM 3.0']['Levels']['Regional']['AERIAL_FARM_S'] = ('AT012', '100202', 'UtilityInfrastructureSrf')
    field_information['GGDM 3.0']['Levels']['Specialized']['AERIAL_FARM_S'] = ('AT012', '100202', 'UtilityInfrastructureSrf')
    field_information['GGDM 3.0']['Levels']['Global']['CABLEWAY_C'] = ('AT041', '100206', 'TransportationGroundCrv')
    field_information['GGDM 3.0']['Levels']['Local']['CABLEWAY_C'] = ('AT041', '100206', 'TransportationGroundCrv')
    field_information['GGDM 3.0']['Levels']['Regional']['CABLEWAY_C'] = ('AT041', '100206', 'TransportationGroundCrv')
    field_information['GGDM 3.0']['Levels']['Specialized']['CABLEWAY_C'] = ('AT041', '100206', 'TransportationGroundCrv')
    field_information['GGDM 3.0']['Levels']['Global']['PYLON_P'] = ('AT042', '100558', 'UtilityInfrastructurePnt')
    field_information['GGDM 3.0']['Levels']['Local']['PYLON_P'] = ('AT042', '100558', 'UtilityInfrastructurePnt')
    field_information['GGDM 3.0']['Levels']['Regional']['PYLON_P'] = ('AT042', '100558', 'UtilityInfrastructurePnt')
    field_information['GGDM 3.0']['Levels']['Specialized']['PYLON_P'] = ('AT042', '100558', 'UtilityInfrastructurePnt')
    field_information['GGDM 3.0']['Levels']['Global']['RADAR_STATION_P'] = ('AT045', '100207', 'FacilityPnt')
    field_information['GGDM 3.0']['Levels']['Local']['RADAR_STATION_P'] = ('AT045', '100207', 'FacilityPnt')
    field_information['GGDM 3.0']['Levels']['Regional']['RADAR_STATION_P'] = ('AT045', '100207', 'FacilityPnt')
    field_information['GGDM 3.0']['Levels']['Specialized']['RADAR_STATION_P'] = ('AT045', '100207', 'FacilityPnt')
    field_information['GGDM 3.0']['Levels']['Global']['RADAR_STATION_S'] = ('AT045', '100207', 'FacilitySrf')
    field_information['GGDM 3.0']['Levels']['Local']['RADAR_STATION_S'] = ('AT045', '100207', 'FacilitySrf')
    field_information['GGDM 3.0']['Levels']['Regional']['RADAR_STATION_S'] = ('AT045', '100207', 'FacilitySrf')
    field_information['GGDM 3.0']['Levels']['Specialized']['RADAR_STATION_S'] = ('AT045', '100207', 'FacilitySrf')
    field_information['GGDM 3.0']['Levels']['Global']['LAND_WATER_BOUNDARY_C'] = ('BA010', '100212', 'PhysiographyCrv')
    field_information['GGDM 3.0']['Levels']['Local']['LAND_WATER_BOUNDARY_C'] = ('BA010', '100212', 'PhysiographyCrv')
    field_information['GGDM 3.0']['Levels']['Regional']['LAND_WATER_BOUNDARY_C'] = ('BA010', '100212', 'PhysiographyCrv')
    field_information['GGDM 3.0']['Levels']['Specialized']['LAND_WATER_BOUNDARY_C'] = ('BA010', '100212', 'PhysiographyCrv')
    field_information['GGDM 3.0']['Levels']['Global']['FORESHORE_S'] = ('BA023', '100215', 'PhysiographySrfExt')
    field_information['GGDM 3.0']['Levels']['Local']['FORESHORE_S'] = ('BA023', '100215', 'PhysiographySrfExt')
    field_information['GGDM 3.0']['Levels']['Regional']['FORESHORE_S'] = ('BA023', '100215', 'PhysiographySrfExt')
    field_information['GGDM 3.0']['Levels']['Specialized']['FORESHORE_S'] = ('BA023', '100215', 'PhysiographySrfExt')
    field_information['GGDM 3.0']['Levels']['Local']['SHORELINE_C'] = ('BA024', '100216', 'PhysiographyCrvExt')
    field_information['GGDM 3.0']['Levels']['Specialized']['SHORELINE_C'] = ('BA024', '100216', 'PhysiographyCrvExt')
    field_information['GGDM 3.0']['Levels']['Global']['ISLAND_P'] = ('BA030', '100217', 'PhysiographyPnt')
    field_information['GGDM 3.0']['Levels']['Regional']['ISLAND_P'] = ('BA030', '100217', 'PhysiographyPnt')
    field_information['GGDM 3.0']['Levels']['Specialized']['ISLAND_P'] = ('BA030', '100217', 'PhysiographyPnt')
    field_information['GGDM 3.0']['Levels']['Global']['ISLAND_S'] = ('BA030', '100217', 'PhysiographySrf')
    field_information['GGDM 3.0']['Levels']['Local']['ISLAND_S'] = ('BA030', '100217', 'PhysiographySrf')
    field_information['GGDM 3.0']['Levels']['Regional']['ISLAND_S'] = ('BA030', '100217', 'PhysiographySrf')
    field_information['GGDM 3.0']['Levels']['Specialized']['ISLAND_S'] = ('BA030', '100217', 'PhysiographySrf')
    field_information['GGDM 3.0']['Levels']['Global']['TIDAL_WATER_S'] = ('BA040', '100218', 'HydrographySrf')
    field_information['GGDM 3.0']['Levels']['Local']['TIDAL_WATER_S'] = ('BA040', '100218', 'HydrographySrf')
    field_information['GGDM 3.0']['Levels']['Regional']['TIDAL_WATER_S'] = ('BA040', '100218', 'HydrographySrf')
    field_information['GGDM 3.0']['Levels']['Specialized']['TIDAL_WATER_S'] = ('BA040', '100218', 'HydrographySrf')
    field_information['GGDM 3.0']['Levels']['Local']['BEACH_S'] = ('BA050', '100219', 'PhysiographySrfExt')
    field_information['GGDM 3.0']['Levels']['Specialized']['BEACH_S'] = ('BA050', '100219', 'PhysiographySrfExt')
    field_information['GGDM 3.0']['Levels']['Local']['HARBOUR_S'] = ('BB005', '100222', 'PortHarbourSrf')
    field_information['GGDM 3.0']['Levels']['Regional']['HARBOUR_S'] = ('BB005', '100222', 'PortHarbourSrf')
    field_information['GGDM 3.0']['Levels']['Specialized']['HARBOUR_S'] = ('BB005', '100222', 'PortHarbourSrf')
    field_information['GGDM 3.0']['Levels']['Local']['HARBOUR_WATERS_S'] = ('BB008', '103', 'HydrographySrfExt')
    field_information['GGDM 3.0']['Levels']['Regional']['HARBOUR_WATERS_S'] = ('BB008', '103', 'HydrographySrfExt')
    field_information['GGDM 3.0']['Levels']['Specialized']['HARBOUR_WATERS_S'] = ('BB008', '103', 'HydrographySrfExt')
    field_information['GGDM 3.0']['Levels']['Global']['PORT_P'] = ('BB009', '100223', 'PortHarbourPnt')
    field_information['GGDM 3.0']['Levels']['Local']['PORT_P'] = ('BB009', '100223', 'PortHarbourPnt')
    field_information['GGDM 3.0']['Levels']['Regional']['PORT_P'] = ('BB009', '100223', 'PortHarbourPnt')
    field_information['GGDM 3.0']['Levels']['Global']['PORT_S'] = ('BB009', '100223', 'PortHarbourSrf')
    field_information['GGDM 3.0']['Levels']['Local']['PORT_S'] = ('BB009', '100223', 'PortHarbourSrf')
    field_information['GGDM 3.0']['Levels']['Regional']['PORT_S'] = ('BB009', '100223', 'PortHarbourSrf')
    field_information['GGDM 3.0']['Levels']['Specialized']['PORT_S'] = ('BB009', '100223', 'PortHarbourSrf')
    field_information['GGDM 3.0']['Levels']['Global']['ANCHORAGE_P'] = ('BB010', '100224', 'PortHarbourPntExt')
    field_information['GGDM 3.0']['Levels']['Local']['ANCHORAGE_P'] = ('BB010', '100224', 'PortHarbourPntExt')
    field_information['GGDM 3.0']['Levels']['Regional']['ANCHORAGE_P'] = ('BB010', '100224', 'PortHarbourPntExt')
    field_information['GGDM 3.0']['Levels']['Specialized']['ANCHORAGE_P'] = ('BB010', '100224', 'PortHarbourPntExt')
    field_information['GGDM 3.0']['Levels']['Local']['ANCHORAGE_S'] = ('BB010', '100224', 'PortHarbourSrfExt')
    field_information['GGDM 3.0']['Levels']['Global']['ANCHOR_P'] = ('BB019', '100226', 'PortHarbourPntExt')
    field_information['GGDM 3.0']['Levels']['Local']['ANCHOR_P'] = ('BB019', '100226', 'PortHarbourPntExt')
    field_information['GGDM 3.0']['Levels']['Regional']['ANCHOR_P'] = ('BB019', '100226', 'PortHarbourPntExt')
    field_information['GGDM 3.0']['Levels']['Specialized']['ANCHOR_P'] = ('BB019', '100226', 'PortHarbourPntExt')
    field_information['GGDM 3.0']['Levels']['Local']['BERTH_P'] = ('BB020', '100227', 'PortHarbourPntExt')
    field_information['GGDM 3.0']['Levels']['Specialized']['BERTH_P'] = ('BB020', '100227', 'PortHarbourPntExt')
    field_information['GGDM 3.0']['Levels']['Local']['CALLING_IN_POINT_P'] = ('BB050', '100229', 'PortHarbourPntExt')
    field_information['GGDM 3.0']['Levels']['Specialized']['CALLING_IN_POINT_P'] = ('BB050', '100229', 'PortHarbourPntExt')
    field_information['GGDM 3.0']['Levels']['Local']['DOLPHIN_P'] = ('BB080', '100230', 'PortHarbourPntExt')
    field_information['GGDM 3.0']['Levels']['Specialized']['DOLPHIN_P'] = ('BB080', '100230', 'PortHarbourPntExt')
    field_information['GGDM 3.0']['Levels']['Global']['SHORELINE_CONSTRUCTION_C'] = ('BB081', '100231', 'PortHarbourCrv')
    field_information['GGDM 3.0']['Levels']['Local']['SHORELINE_CONSTRUCTION_C'] = ('BB081', '100231', 'PortHarbourCrv')
    field_information['GGDM 3.0']['Levels']['Regional']['SHORELINE_CONSTRUCTION_C'] = ('BB081', '100231', 'PortHarbourCrv')
    field_information['GGDM 3.0']['Levels']['Specialized']['SHORELINE_CONSTRUCTION_C'] = ('BB081', '100231', 'PortHarbourCrv')
    field_information['GGDM 3.0']['Levels']['Global']['SHORELINE_CONSTRUCTION_S'] = ('BB081', '100231', 'PortHarbourSrf')
    field_information['GGDM 3.0']['Levels']['Local']['SHORELINE_CONSTRUCTION_S'] = ('BB081', '100231', 'PortHarbourSrf')
    field_information['GGDM 3.0']['Levels']['Regional']['SHORELINE_CONSTRUCTION_S'] = ('BB081', '100231', 'PortHarbourSrf')
    field_information['GGDM 3.0']['Levels']['Specialized']['SHORELINE_CONSTRUCTION_S'] = ('BB081', '100231', 'PortHarbourSrf')
    field_information['GGDM 3.0']['Levels']['Local']['SHORELINE_RAMP_C'] = ('BB082', '100232', 'PortHarbourCrv')
    field_information['GGDM 3.0']['Levels']['Regional']['SHORELINE_RAMP_C'] = ('BB082', '100232', 'PortHarbourCrv')
    field_information['GGDM 3.0']['Levels']['Specialized']['SHORELINE_RAMP_C'] = ('BB082', '100232', 'PortHarbourCrv')
    field_information['GGDM 3.0']['Levels']['Local']['SHORELINE_RAMP_S'] = ('BB082', '100232', 'PortHarbourSrf')
    field_information['GGDM 3.0']['Levels']['Regional']['SHORELINE_RAMP_S'] = ('BB082', '100232', 'PortHarbourSrf')
    field_information['GGDM 3.0']['Levels']['Specialized']['SHORELINE_RAMP_S'] = ('BB082', '100232', 'PortHarbourSrf')
    field_information['GGDM 3.0']['Levels']['Global']['DRY_DOCK_S'] = ('BB090', '100233', 'PortHarbourSrf')
    field_information['GGDM 3.0']['Levels']['Local']['DRY_DOCK_S'] = ('BB090', '100233', 'PortHarbourSrf')
    field_information['GGDM 3.0']['Levels']['Regional']['DRY_DOCK_S'] = ('BB090', '100233', 'PortHarbourSrf')
    field_information['GGDM 3.0']['Levels']['Specialized']['DRY_DOCK_S'] = ('BB090', '100233', 'PortHarbourSrf')
    field_information['GGDM 3.0']['Levels']['Local']['FISHING_STAKES_C'] = ('BB100', '100235', 'HydrographyCrvExt')
    field_information['GGDM 3.0']['Levels']['Specialized']['FISHING_STAKES_C'] = ('BB100', '100235', 'HydrographyCrvExt')
    field_information['GGDM 3.0']['Levels']['Global']['FISH_WEIR_P'] = ('BB110', '100236', 'HydrographyPnt')
    field_information['GGDM 3.0']['Levels']['Local']['FISH_WEIR_P'] = ('BB110', '100236', 'HydrographyPnt')
    field_information['GGDM 3.0']['Levels']['Regional']['FISH_WEIR_P'] = ('BB110', '100236', 'HydrographyPnt')
    field_information['GGDM 3.0']['Levels']['Specialized']['FISH_WEIR_P'] = ('BB110', '100236', 'HydrographyPnt')
    field_information['GGDM 3.0']['Levels']['Local']['FISH_WEIR_S'] = ('BB110', '100236', 'HydrographySrf')
    field_information['GGDM 3.0']['Levels']['Specialized']['FISH_WEIR_S'] = ('BB110', '100236', 'HydrographySrf')
    field_information['GGDM 3.0']['Levels']['Local']['NAUTICAL_GRIDIRON_S'] = ('BB115', '100237', 'PortHarbourSrfExt')
    field_information['GGDM 3.0']['Levels']['Specialized']['NAUTICAL_GRIDIRON_S'] = ('BB115', '100237', 'PortHarbourSrfExt')
    field_information['GGDM 3.0']['Levels']['Local']['BEACH_LANDING_SITE_P'] = ('BB150', '100239', 'MilitaryPntExt')
    field_information['GGDM 3.0']['Levels']['Regional']['BEACH_LANDING_SITE_P'] = ('BB150', '100239', 'MilitaryPntExt')
    field_information['GGDM 3.0']['Levels']['Specialized']['BEACH_LANDING_SITE_P'] = ('BB150', '100239', 'MilitaryPntExt')
    field_information['GGDM 3.0']['Levels']['Local']['BEACH_LANDING_SITE_S'] = ('BB150', '100239', 'MilitarySrfExt')
    field_information['GGDM 3.0']['Levels']['Specialized']['BEACH_LANDING_SITE_S'] = ('BB150', '100239', 'MilitarySrfExt')
    field_information['GGDM 3.0']['Levels']['Local']['MARITIME_SIGNAL_STATION_P'] = ('BB155', '100241', 'HydroAidNavigationPntExt')
    field_information['GGDM 3.0']['Levels']['Specialized']['MARITIME_SIGNAL_STATION_P'] = ('BB155', '100241', 'HydroAidNavigationPntExt')
    field_information['GGDM 3.0']['Levels']['Local']['FLOATING_DRY_DOCK_S'] = ('BB199', '100243', 'PortHarbourSrf')
    field_information['GGDM 3.0']['Levels']['Specialized']['FLOATING_DRY_DOCK_S'] = ('BB199', '100243', 'PortHarbourSrf')
    field_information['GGDM 3.0']['Levels']['Specialized']['SMALL_CRAFT_FACILITY_P'] = ('BB201', '100244', 'PortHarbourPnt')
    field_information['GGDM 3.0']['Levels']['Specialized']['SMALL_CRAFT_FACILITY_S'] = ('BB201', '100244', 'PortHarbourSrf')
    field_information['GGDM 3.0']['Levels']['Global']['SHIPYARD_P'] = ('BB241', '100245', 'PortHarbourPnt')
    field_information['GGDM 3.0']['Levels']['Local']['SHIPYARD_P'] = ('BB241', '100245', 'PortHarbourPnt')
    field_information['GGDM 3.0']['Levels']['Regional']['SHIPYARD_P'] = ('BB241', '100245', 'PortHarbourPnt')
    field_information['GGDM 3.0']['Levels']['Specialized']['SHIPYARD_P'] = ('BB241', '100245', 'PortHarbourPnt')
    field_information['GGDM 3.0']['Levels']['Global']['SHIPYARD_S'] = ('BB241', '100245', 'PortHarbourSrf')
    field_information['GGDM 3.0']['Levels']['Local']['SHIPYARD_S'] = ('BB241', '100245', 'PortHarbourSrf')
    field_information['GGDM 3.0']['Levels']['Regional']['SHIPYARD_S'] = ('BB241', '100245', 'PortHarbourSrf')
    field_information['GGDM 3.0']['Levels']['Specialized']['SHIPYARD_S'] = ('BB241', '100245', 'PortHarbourSrf')
    field_information['GGDM 3.0']['Levels']['Local']['MARITIME_NAVIGATION_BEACON_P'] = ('BC010', '100247', 'HydroAidNavigationPntExt')
    field_information['GGDM 3.0']['Levels']['Specialized']['MARITIME_NAVIGATION_BEACON_P'] = ('BC010', '100247', 'HydroAidNavigationPntExt')
    field_information['GGDM 3.0']['Levels']['Local']['BUOY_P'] = ('BC020', '100248', 'HydroAidNavigationPntExt')
    field_information['GGDM 3.0']['Levels']['Specialized']['BUOY_P'] = ('BC020', '100248', 'HydroAidNavigationPntExt')
    field_information['GGDM 3.0']['Levels']['Local']['MARITIME_RADIOBEACON_P'] = ('BC034', '100251', 'HydroAidNavigationPntExt')
    field_information['GGDM 3.0']['Levels']['Specialized']['MARITIME_RADIOBEACON_P'] = ('BC034', '100251', 'HydroAidNavigationPntExt')
    field_information['GGDM 3.0']['Levels']['Local']['MARITIME_NAVIGATION_LIGHT_P'] = ('BC040', '100252', 'HydroAidNavigationPntExt')
    field_information['GGDM 3.0']['Levels']['Regional']['MARITIME_NAVIGATION_LIGHT_P'] = ('BC040', '100252', 'HydroAidNavigationPntExt')
    field_information['GGDM 3.0']['Levels']['Specialized']['MARITIME_NAVIGATION_LIGHT_P'] = ('BC040', '100252', 'HydroAidNavigationPntExt')
    field_information['GGDM 3.0']['Levels']['Local']['MARITIME_NAV_LIGHT_SUPPORT_P'] = ('BC041', '134663', 'HydroAidNavigationPntExt')
    field_information['GGDM 3.0']['Levels']['Specialized']['MARITIME_NAV_LIGHT_SUPPORT_P'] = ('BC041', '134663', 'HydroAidNavigationPntExt')
    field_information['GGDM 3.0']['Levels']['Global']['LIGHTHOUSE_P'] = ('BC050', '100253', 'HydroAidNavigationPnt')
    field_information['GGDM 3.0']['Levels']['Local']['LIGHTHOUSE_P'] = ('BC050', '100253', 'HydroAidNavigationPnt')
    field_information['GGDM 3.0']['Levels']['Regional']['LIGHTHOUSE_P'] = ('BC050', '100253', 'HydroAidNavigationPnt')
    field_information['GGDM 3.0']['Levels']['Specialized']['LIGHTHOUSE_P'] = ('BC050', '100253', 'HydroAidNavigationPnt')
    field_information['GGDM 3.0']['Levels']['Local']['LIGHTHOUSE_S'] = ('BC050', '100253', 'HydroAidNavigationSrf')
    field_information['GGDM 3.0']['Levels']['Specialized']['LIGHTHOUSE_S'] = ('BC050', '100253', 'HydroAidNavigationSrf')
    field_information['GGDM 3.0']['Levels']['Local']['MARITIME_NAVIGATION_MARKER_P'] = ('BC055', '100254', 'HydroAidNavigationPntExt')
    field_information['GGDM 3.0']['Levels']['Specialized']['MARITIME_NAVIGATION_MARKER_P'] = ('BC055', '100254', 'HydroAidNavigationPntExt')
    field_information['GGDM 3.0']['Levels']['Specialized']['LIGHT_SECTOR_P'] = ('BC060', '100255', 'HydroAidNavigationPntExt')
    field_information['GGDM 3.0']['Levels']['Global']['LIGHT_VESSEL_P'] = ('BC070', '100256', 'HydroAidNavigationPnt')
    field_information['GGDM 3.0']['Levels']['Local']['LIGHT_VESSEL_P'] = ('BC070', '100256', 'HydroAidNavigationPnt')
    field_information['GGDM 3.0']['Levels']['Regional']['LIGHT_VESSEL_P'] = ('BC070', '100256', 'HydroAidNavigationPnt')
    field_information['GGDM 3.0']['Levels']['Specialized']['LIGHT_VESSEL_P'] = ('BC070', '100256', 'HydroAidNavigationPnt')
    field_information['GGDM 3.0']['Levels']['Local']['INSUBSTANTIAL_NAV_MARK_P'] = ('BC080', '100257', 'HydroAidNavigationPntExt')
    field_information['GGDM 3.0']['Levels']['Specialized']['INSUBSTANTIAL_NAV_MARK_P'] = ('BC080', '100257', 'HydroAidNavigationPntExt')
    field_information['GGDM 3.0']['Levels']['Global']['CRIB_P'] = ('BD020', '100264', 'HydrographyPntExt')
    field_information['GGDM 3.0']['Levels']['Local']['CRIB_P'] = ('BD020', '100264', 'HydrographyPntExt')
    field_information['GGDM 3.0']['Levels']['Regional']['CRIB_P'] = ('BD020', '100264', 'HydrographyPntExt')
    field_information['GGDM 3.0']['Levels']['Specialized']['CRIB_P'] = ('BD020', '100264', 'HydrographyPntExt')
    field_information['GGDM 3.0']['Levels']['Local']['CRIB_S'] = ('BD020', '100264', 'HydrographySrfExt')
    field_information['GGDM 3.0']['Levels']['Specialized']['CRIB_S'] = ('BD020', '100264', 'HydrographySrfExt')
    field_information['GGDM 3.0']['Levels']['Local']['DISCOLOURED_WATER_P'] = ('BD030', '100265', 'HydrographyPntExt')
    field_information['GGDM 3.0']['Levels']['Specialized']['DISCOLOURED_WATER_P'] = ('BD030', '100265', 'HydrographyPntExt')
    field_information['GGDM 3.0']['Levels']['Local']['DISCOLOURED_WATER_S'] = ('BD030', '100265', 'HydrographySrfExt')
    field_information['GGDM 3.0']['Levels']['Specialized']['DISCOLOURED_WATER_S'] = ('BD030', '100265', 'HydrographySrfExt')
    field_information['GGDM 3.0']['Levels']['Local']['FOUL_GROUND_P'] = ('BD050', '100266', 'HydrographyPntExt')
    field_information['GGDM 3.0']['Levels']['Specialized']['FOUL_GROUND_P'] = ('BD050', '100266', 'HydrographyPntExt')
    field_information['GGDM 3.0']['Levels']['Local']['FOUL_GROUND_S'] = ('BD050', '100266', 'HydrographySrfExt')
    field_information['GGDM 3.0']['Levels']['Specialized']['FOUL_GROUND_S'] = ('BD050', '100266', 'HydrographySrfExt')
    field_information['GGDM 3.0']['Levels']['Local']['AQUATIC_VEGETATION_P'] = ('BD061', '100692', 'HydrographyPntExt')
    field_information['GGDM 3.0']['Levels']['Specialized']['AQUATIC_VEGETATION_P'] = ('BD061', '100692', 'HydrographyPntExt')
    field_information['GGDM 3.0']['Levels']['Local']['AQUATIC_VEGETATION_S'] = ('BD061', '100692', 'HydrographySrfExt')
    field_information['GGDM 3.0']['Levels']['Specialized']['AQUATIC_VEGETATION_S'] = ('BD061', '100692', 'HydrographySrfExt')
    field_information['GGDM 3.0']['Levels']['Local']['STRUCTURAL_PILE_P'] = ('BD100', '100271', 'PortHarbourPnt')
    field_information['GGDM 3.0']['Levels']['Specialized']['STRUCTURAL_PILE_P'] = ('BD100', '100271', 'PortHarbourPnt')
    field_information['GGDM 3.0']['Levels']['Local']['STRUCTURAL_PILE_S'] = ('BD100', '100271', 'PortHarbourSrf')
    field_information['GGDM 3.0']['Levels']['Specialized']['STRUCTURAL_PILE_S'] = ('BD100', '100271', 'PortHarbourSrf')
    field_information['GGDM 3.0']['Levels']['Global']['OFFSHORE_CONSTRUCTION_P'] = ('BD115', '100272', 'HydrographyPnt')
    field_information['GGDM 3.0']['Levels']['Local']['OFFSHORE_CONSTRUCTION_P'] = ('BD115', '100272', 'HydrographyPnt')
    field_information['GGDM 3.0']['Levels']['Regional']['OFFSHORE_CONSTRUCTION_P'] = ('BD115', '100272', 'HydrographyPnt')
    field_information['GGDM 3.0']['Levels']['Specialized']['OFFSHORE_CONSTRUCTION_P'] = ('BD115', '100272', 'HydrographyPnt')
    field_information['GGDM 3.0']['Levels']['Local']['OFFSHORE_CONSTRUCTION_S'] = ('BD115', '100272', 'HydrographySrf')
    field_information['GGDM 3.0']['Levels']['Specialized']['OFFSHORE_CONSTRUCTION_S'] = ('BD115', '100272', 'HydrographySrf')
    field_information['GGDM 3.0']['Levels']['Global']['REEF_C'] = ('BD120', '100273', 'HydrographyCrvExt')
    field_information['GGDM 3.0']['Levels']['Local']['REEF_C'] = ('BD120', '100273', 'HydrographyCrvExt')
    field_information['GGDM 3.0']['Levels']['Regional']['REEF_C'] = ('BD120', '100273', 'HydrographyCrvExt')
    field_information['GGDM 3.0']['Levels']['Specialized']['REEF_C'] = ('BD120', '100273', 'HydrographyCrvExt')
    field_information['GGDM 3.0']['Levels']['Local']['REEF_S'] = ('BD120', '100273', 'HydrographySrfExt')
    field_information['GGDM 3.0']['Levels']['Regional']['REEF_S'] = ('BD120', '100273', 'HydrographySrfExt')
    field_information['GGDM 3.0']['Levels']['Specialized']['REEF_S'] = ('BD120', '100273', 'HydrographySrfExt')
    field_information['GGDM 3.0']['Levels']['Global']['HAZARDOUS_ROCK_P'] = ('BD130', '100276', 'HydrographyPntExt')
    field_information['GGDM 3.0']['Levels']['Local']['HAZARDOUS_ROCK_P'] = ('BD130', '100276', 'HydrographyPntExt')
    field_information['GGDM 3.0']['Levels']['Regional']['HAZARDOUS_ROCK_P'] = ('BD130', '100276', 'HydrographyPntExt')
    field_information['GGDM 3.0']['Levels']['Specialized']['HAZARDOUS_ROCK_P'] = ('BD130', '100276', 'HydrographyPntExt')
    field_information['GGDM 3.0']['Levels']['Local']['SNAG_P'] = ('BD140', '100277', 'HydrographyPnt')
    field_information['GGDM 3.0']['Levels']['Specialized']['SNAG_P'] = ('BD140', '100277', 'HydrographyPnt')
    field_information['GGDM 3.0']['Levels']['Local']['SNAG_S'] = ('BD140', '100277', 'HydrographySrf')
    field_information['GGDM 3.0']['Levels']['Specialized']['SNAG_S'] = ('BD140', '100277', 'HydrographySrf')
    field_information['GGDM 3.0']['Levels']['Global']['WRECK_P'] = ('BD180', '100278', 'HydrographyPntExt')
    field_information['GGDM 3.0']['Levels']['Local']['WRECK_P'] = ('BD180', '100278', 'HydrographyPntExt')
    field_information['GGDM 3.0']['Levels']['Regional']['WRECK_P'] = ('BD180', '100278', 'HydrographyPntExt')
    field_information['GGDM 3.0']['Levels']['Specialized']['WRECK_P'] = ('BD180', '100278', 'HydrographyPntExt')
    field_information['GGDM 3.0']['Levels']['Local']['WRECK_S'] = ('BD180', '100278', 'HydrographySrfExt')
    field_information['GGDM 3.0']['Levels']['Specialized']['WRECK_S'] = ('BD180', '100278', 'HydrographySrfExt')
    field_information['GGDM 3.0']['Levels']['Global']['HULK_P'] = ('BD181', '100279', 'HydrographyPnt')
    field_information['GGDM 3.0']['Levels']['Local']['HULK_P'] = ('BD181', '100279', 'HydrographyPnt')
    field_information['GGDM 3.0']['Levels']['Regional']['HULK_P'] = ('BD181', '100279', 'HydrographyPnt')
    field_information['GGDM 3.0']['Levels']['Specialized']['HULK_P'] = ('BD181', '100279', 'HydrographyPnt')
    field_information['GGDM 3.0']['Levels']['Local']['DEPTH_CURVE_C'] = ('BE010', '100280', 'HydrographyCrvExt')
    field_information['GGDM 3.0']['Levels']['Specialized']['DEPTH_CURVE_C'] = ('BE010', '100280', 'HydrographyCrvExt')
    field_information['GGDM 3.0']['Levels']['Global']['DEPTH_CONTOUR_C'] = ('BE015', '100281', 'HydrographyCrvExt')
    field_information['GGDM 3.0']['Levels']['Local']['DEPTH_CONTOUR_C'] = ('BE015', '100281', 'HydrographyCrvExt')
    field_information['GGDM 3.0']['Levels']['Regional']['DEPTH_CONTOUR_C'] = ('BE015', '100281', 'HydrographyCrvExt')
    field_information['GGDM 3.0']['Levels']['Specialized']['DEPTH_CONTOUR_C'] = ('BE015', '100281', 'HydrographyCrvExt')
    field_information['GGDM 3.0']['Levels']['Local']['DEPTH_AREA_S'] = ('BE019', '100282', 'HydrographySrfExt')
    field_information['GGDM 3.0']['Levels']['Specialized']['DEPTH_AREA_S'] = ('BE019', '100282', 'HydrographySrfExt')
    field_information['GGDM 3.0']['Levels']['Local']['SOUNDING_P'] = ('BE020', '100283', 'HydrographyPntExt')
    field_information['GGDM 3.0']['Levels']['Specialized']['SOUNDING_P'] = ('BE020', '100283', 'HydrographyPntExt')
    field_information['GGDM 3.0']['Levels']['Local']['BEACH_PROFILE_C'] = ('BE050', '100287', 'PhysiographyCrvExt')
    field_information['GGDM 3.0']['Levels']['Specialized']['BEACH_PROFILE_C'] = ('BE050', '100287', 'PhysiographyCrvExt')
    field_information['GGDM 3.0']['Levels']['Local']['BOTTOM_CHARACTER_REGION_P'] = ('BF010', '100288', 'HydrographyPntExt')
    field_information['GGDM 3.0']['Levels']['Specialized']['BOTTOM_CHARACTER_REGION_P'] = ('BF010', '100288', 'HydrographyPntExt')
    field_information['GGDM 3.0']['Levels']['Local']['BOTTOM_CHARACTER_REGION_S'] = ('BF010', '100288', 'HydrographySrfExt')
    field_information['GGDM 3.0']['Levels']['Specialized']['BOTTOM_CHARACTER_REGION_S'] = ('BF010', '100288', 'HydrographySrfExt')
    field_information['GGDM 3.0']['Levels']['Local']['WATER_MOVEMENT_DATA_LOCATION_P'] = ('BG010', '100289', 'HydrographyPntExt')
    field_information['GGDM 3.0']['Levels']['Specialized']['WATER_MOVEMENT_DATA_LOCATION_P'] = ('BG010', '100289', 'HydrographyPntExt')
    field_information['GGDM 3.0']['Levels']['Local']['WATER_TURBULENCE_C'] = ('BG012', '100290', 'HydrographyCrvExt')
    field_information['GGDM 3.0']['Levels']['Specialized']['WATER_TURBULENCE_C'] = ('BG012', '100290', 'HydrographyCrvExt')
    field_information['GGDM 3.0']['Levels']['Local']['WATER_TURBULENCE_P'] = ('BG012', '100290', 'HydrographyPntExt')
    field_information['GGDM 3.0']['Levels']['Regional']['WATER_TURBULENCE_P'] = ('BG012', '100290', 'HydrographyPntExt')
    field_information['GGDM 3.0']['Levels']['Specialized']['WATER_TURBULENCE_P'] = ('BG012', '100290', 'HydrographyPntExt')
    field_information['GGDM 3.0']['Levels']['Local']['WATER_TURBULENCE_S'] = ('BG012', '100290', 'HydrographySrfExt')
    field_information['GGDM 3.0']['Levels']['Specialized']['WATER_TURBULENCE_S'] = ('BG012', '100290', 'HydrographySrfExt')
    field_information['GGDM 3.0']['Levels']['Local']['TIDAL_STREAM_OBSERVE_STATION_P'] = ('BG030', '100293', 'HydrographyPntExt')
    field_information['GGDM 3.0']['Levels']['Specialized']['TIDAL_STREAM_OBSERVE_STATION_P'] = ('BG030', '100293', 'HydrographyPntExt')
    field_information['GGDM 3.0']['Levels']['Global']['AQUEDUCT_C'] = ('BH010', '100295', 'HydrographyCrv')
    field_information['GGDM 3.0']['Levels']['Local']['AQUEDUCT_C'] = ('BH010', '100295', 'HydrographyCrv')
    field_information['GGDM 3.0']['Levels']['Regional']['AQUEDUCT_C'] = ('BH010', '100295', 'HydrographyCrv')
    field_information['GGDM 3.0']['Levels']['Specialized']['AQUEDUCT_C'] = ('BH010', '100295', 'HydrographyCrv')
    field_information['GGDM 3.0']['Levels']['Local']['AQUEDUCT_S'] = ('BH010', '100295', 'HydrographySrf')
    field_information['GGDM 3.0']['Levels']['Regional']['AQUEDUCT_S'] = ('BH010', '100295', 'HydrographySrf')
    field_information['GGDM 3.0']['Levels']['Specialized']['AQUEDUCT_S'] = ('BH010', '100295', 'HydrographySrf')
    field_information['GGDM 3.0']['Levels']['Local']['QANAT_SHAFT_P'] = ('BH012', '131749', 'HydrographyPnt')
    field_information['GGDM 3.0']['Levels']['Regional']['QANAT_SHAFT_P'] = ('BH012', '131749', 'HydrographyPnt')
    field_information['GGDM 3.0']['Levels']['Specialized']['QANAT_SHAFT_P'] = ('BH012', '131749', 'HydrographyPnt')
    field_information['GGDM 3.0']['Levels']['Global']['BOG_S'] = ('BH015', '100296', 'VegetationSrf')
    field_information['GGDM 3.0']['Levels']['Local']['BOG_S'] = ('BH015', '100296', 'VegetationSrf')
    field_information['GGDM 3.0']['Levels']['Regional']['BOG_S'] = ('BH015', '100296', 'VegetationSrf')
    field_information['GGDM 3.0']['Levels']['Specialized']['BOG_S'] = ('BH015', '100296', 'VegetationSrf')
    field_information['GGDM 3.0']['Levels']['Global']['NAVIGABLE_CANAL_C'] = ('BH020', '100297', 'TransportationWaterCrv')
    field_information['GGDM 3.0']['Levels']['Local']['NAVIGABLE_CANAL_C'] = ('BH020', '100297', 'TransportationWaterCrv')
    field_information['GGDM 3.0']['Levels']['Regional']['NAVIGABLE_CANAL_C'] = ('BH020', '100297', 'TransportationWaterCrv')
    field_information['GGDM 3.0']['Levels']['Specialized']['NAVIGABLE_CANAL_C'] = ('BH020', '100297', 'TransportationWaterCrv')
    field_information['GGDM 3.0']['Levels']['Local']['NAVIGABLE_CANAL_S'] = ('BH020', '100297', 'TransportationWaterSrf')
    field_information['GGDM 3.0']['Levels']['Regional']['NAVIGABLE_CANAL_S'] = ('BH020', '100297', 'TransportationWaterSrf')
    field_information['GGDM 3.0']['Levels']['Specialized']['NAVIGABLE_CANAL_S'] = ('BH020', '100297', 'TransportationWaterSrf')
    field_information['GGDM 3.0']['Levels']['Global']['DITCH_C'] = ('BH030', '100298', 'HydrographyCrv')
    field_information['GGDM 3.0']['Levels']['Local']['DITCH_C'] = ('BH030', '100298', 'HydrographyCrv')
    field_information['GGDM 3.0']['Levels']['Regional']['DITCH_C'] = ('BH030', '100298', 'HydrographyCrv')
    field_information['GGDM 3.0']['Levels']['Specialized']['DITCH_C'] = ('BH030', '100298', 'HydrographyCrv')
    field_information['GGDM 3.0']['Levels']['Local']['DITCH_S'] = ('BH030', '100298', 'HydrographySrf')
    field_information['GGDM 3.0']['Levels']['Regional']['DITCH_S'] = ('BH030', '100298', 'HydrographySrf')
    field_information['GGDM 3.0']['Levels']['Specialized']['DITCH_S'] = ('BH030', '100298', 'HydrographySrf')
    field_information['GGDM 3.0']['Levels']['Local']['WATER_TREATMENT_BED_S'] = ('BH040', '100299', 'IndustrySrf')
    field_information['GGDM 3.0']['Levels']['Regional']['WATER_TREATMENT_BED_S'] = ('BH040', '100299', 'IndustrySrf')
    field_information['GGDM 3.0']['Levels']['Specialized']['WATER_TREATMENT_BED_S'] = ('BH040', '100299', 'IndustrySrf')
    field_information['GGDM 3.0']['Levels']['Local']['MARICULTURE_SITE_S'] = ('BH050', '191874', 'HydrographySrfExt')
    field_information['GGDM 3.0']['Levels']['Specialized']['MARICULTURE_SITE_S'] = ('BH050', '191874', 'HydrographySrfExt')
    field_information['GGDM 3.0']['Levels']['Global']['FISH_FARM_FACILITY_P'] = ('BH051', '191951', 'AgriculturePnt')
    field_information['GGDM 3.0']['Levels']['Local']['FISH_FARM_FACILITY_P'] = ('BH051', '191951', 'AgriculturePnt')
    field_information['GGDM 3.0']['Levels']['Regional']['FISH_FARM_FACILITY_P'] = ('BH051', '191951', 'AgriculturePnt')
    field_information['GGDM 3.0']['Levels']['Specialized']['FISH_FARM_FACILITY_P'] = ('BH051', '191951', 'AgriculturePnt')
    field_information['GGDM 3.0']['Levels']['Global']['FISH_FARM_FACILITY_S'] = ('BH051', '191951', 'AgricultureSrf')
    field_information['GGDM 3.0']['Levels']['Local']['FISH_FARM_FACILITY_S'] = ('BH051', '191951', 'AgricultureSrf')
    field_information['GGDM 3.0']['Levels']['Regional']['FISH_FARM_FACILITY_S'] = ('BH051', '191951', 'AgricultureSrf')
    field_information['GGDM 3.0']['Levels']['Specialized']['FISH_FARM_FACILITY_S'] = ('BH051', '191951', 'AgricultureSrf')
    field_information['GGDM 3.0']['Levels']['Local']['WATER_RACE_C'] = ('BH065', '131810', 'HydrographyCrv')
    field_information['GGDM 3.0']['Levels']['Specialized']['WATER_RACE_C'] = ('BH065', '131810', 'HydrographyCrv')
    field_information['GGDM 3.0']['Levels']['Global']['FORD_C'] = ('BH070', '100302', 'TransportationGroundCrv')
    field_information['GGDM 3.0']['Levels']['Local']['FORD_C'] = ('BH070', '100302', 'TransportationGroundCrv')
    field_information['GGDM 3.0']['Levels']['Regional']['FORD_C'] = ('BH070', '100302', 'TransportationGroundCrv')
    field_information['GGDM 3.0']['Levels']['Specialized']['FORD_C'] = ('BH070', '100302', 'TransportationGroundCrv')
    field_information['GGDM 3.0']['Levels']['Global']['FORD_P'] = ('BH070', '100302', 'TransportationGroundPnt')
    field_information['GGDM 3.0']['Levels']['Local']['FORD_P'] = ('BH070', '100302', 'TransportationGroundPnt')
    field_information['GGDM 3.0']['Levels']['Regional']['FORD_P'] = ('BH070', '100302', 'TransportationGroundPnt')
    field_information['GGDM 3.0']['Levels']['Specialized']['FORD_P'] = ('BH070', '100302', 'TransportationGroundPnt')
    field_information['GGDM 3.0']['Levels']['Specialized']['FORD_S'] = ('BH070', '100302', 'TransportationGroundSrf')
    field_information['GGDM 3.0']['Levels']['Local']['FOUNTAIN_P'] = ('BH075', '100303', 'CulturePnt')
    field_information['GGDM 3.0']['Levels']['Specialized']['FOUNTAIN_P'] = ('BH075', '100303', 'CulturePnt')
    field_information['GGDM 3.0']['Levels']['Specialized']['FOUNTAIN_S'] = ('BH075', '100303', 'CultureSrf')
    field_information['GGDM 3.0']['Levels']['Local']['HUMMOCK_S'] = ('BH077', '100304', 'VegetationSrf')
    field_information['GGDM 3.0']['Levels']['Specialized']['HUMMOCK_S'] = ('BH077', '100304', 'VegetationSrf')
    field_information['GGDM 3.0']['Levels']['Global']['INLAND_WATERBODY_P'] = ('BH082', '130384', 'HydrographyPnt')
    field_information['GGDM 3.0']['Levels']['Local']['INLAND_WATERBODY_P'] = ('BH082', '130384', 'HydrographyPnt')
    field_information['GGDM 3.0']['Levels']['Regional']['INLAND_WATERBODY_P'] = ('BH082', '130384', 'HydrographyPnt')
    field_information['GGDM 3.0']['Levels']['Specialized']['INLAND_WATERBODY_P'] = ('BH082', '130384', 'HydrographyPnt')
    field_information['GGDM 3.0']['Levels']['Global']['INLAND_WATERBODY_S'] = ('BH082', '130384', 'HydrographySrf')
    field_information['GGDM 3.0']['Levels']['Local']['INLAND_WATERBODY_S'] = ('BH082', '130384', 'HydrographySrf')
    field_information['GGDM 3.0']['Levels']['Regional']['INLAND_WATERBODY_S'] = ('BH082', '130384', 'HydrographySrf')
    field_information['GGDM 3.0']['Levels']['Specialized']['INLAND_WATERBODY_S'] = ('BH082', '130384', 'HydrographySrf')
    field_information['GGDM 3.0']['Levels']['Global']['LAND_SUBJECT_TO_INUNDATION_S'] = ('BH090', '100307', 'HydrographySrf')
    field_information['GGDM 3.0']['Levels']['Local']['LAND_SUBJECT_TO_INUNDATION_S'] = ('BH090', '100307', 'HydrographySrf')
    field_information['GGDM 3.0']['Levels']['Regional']['LAND_SUBJECT_TO_INUNDATION_S'] = ('BH090', '100307', 'HydrographySrf')
    field_information['GGDM 3.0']['Levels']['Specialized']['LAND_SUBJECT_TO_INUNDATION_S'] = ('BH090', '100307', 'HydrographySrf')
    field_information['GGDM 3.0']['Levels']['Local']['MOAT_C'] = ('BH100', '100309', 'HydrographyCrv')
    field_information['GGDM 3.0']['Levels']['Specialized']['MOAT_C'] = ('BH100', '100309', 'HydrographyCrv')
    field_information['GGDM 3.0']['Levels']['Local']['MOAT_S'] = ('BH100', '100309', 'HydrographySrf')
    field_information['GGDM 3.0']['Levels']['Specialized']['MOAT_S'] = ('BH100', '100309', 'HydrographySrf')
    field_information['GGDM 3.0']['Levels']['Global']['PENSTOCK_C'] = ('BH110', '100310', 'HydrographyCrv')
    field_information['GGDM 3.0']['Levels']['Local']['PENSTOCK_C'] = ('BH110', '100310', 'HydrographyCrv')
    field_information['GGDM 3.0']['Levels']['Regional']['PENSTOCK_C'] = ('BH110', '100310', 'HydrographyCrv')
    field_information['GGDM 3.0']['Levels']['Specialized']['PENSTOCK_C'] = ('BH110', '100310', 'HydrographyCrv')
    field_information['GGDM 3.0']['Levels']['Global']['AQUIFER_S'] = ('BH116', '154640', 'SubterraneanSrf')
    field_information['GGDM 3.0']['Levels']['Local']['AQUIFER_S'] = ('BH116', '154640', 'SubterraneanSrf')
    field_information['GGDM 3.0']['Levels']['Regional']['AQUIFER_S'] = ('BH116', '154640', 'SubterraneanSrf')
    field_information['GGDM 3.0']['Levels']['Specialized']['AQUIFER_S'] = ('BH116', '154640', 'SubterraneanSrf')
    field_information['GGDM 3.0']['Levels']['Global']['RAPIDS_C'] = ('BH120', '100311', 'HydrographyCrv')
    field_information['GGDM 3.0']['Levels']['Local']['RAPIDS_C'] = ('BH120', '100311', 'HydrographyCrv')
    field_information['GGDM 3.0']['Levels']['Regional']['RAPIDS_C'] = ('BH120', '100311', 'HydrographyCrv')
    field_information['GGDM 3.0']['Levels']['Specialized']['RAPIDS_C'] = ('BH120', '100311', 'HydrographyCrv')
    field_information['GGDM 3.0']['Levels']['Global']['RAPIDS_P'] = ('BH120', '100311', 'HydrographyPnt')
    field_information['GGDM 3.0']['Levels']['Local']['RAPIDS_P'] = ('BH120', '100311', 'HydrographyPnt')
    field_information['GGDM 3.0']['Levels']['Regional']['RAPIDS_P'] = ('BH120', '100311', 'HydrographyPnt')
    field_information['GGDM 3.0']['Levels']['Specialized']['RAPIDS_P'] = ('BH120', '100311', 'HydrographyPnt')
    field_information['GGDM 3.0']['Levels']['Global']['RAPIDS_S'] = ('BH120', '100311', 'HydrographySrf')
    field_information['GGDM 3.0']['Levels']['Local']['RAPIDS_S'] = ('BH120', '100311', 'HydrographySrf')
    field_information['GGDM 3.0']['Levels']['Regional']['RAPIDS_S'] = ('BH120', '100311', 'HydrographySrf')
    field_information['GGDM 3.0']['Levels']['Specialized']['RAPIDS_S'] = ('BH120', '100311', 'HydrographySrf')
    field_information['GGDM 3.0']['Levels']['Global']['RICE_FIELD_S'] = ('BH135', '100313', 'AgricultureSrf')
    field_information['GGDM 3.0']['Levels']['Local']['RICE_FIELD_S'] = ('BH135', '100313', 'AgricultureSrf')
    field_information['GGDM 3.0']['Levels']['Regional']['RICE_FIELD_S'] = ('BH135', '100313', 'AgricultureSrf')
    field_information['GGDM 3.0']['Levels']['Specialized']['RICE_FIELD_S'] = ('BH135', '100313', 'AgricultureSrf')
    field_information['GGDM 3.0']['Levels']['Global']['RIVER_C'] = ('BH140', '100314', 'HydrographyCrv')
    field_information['GGDM 3.0']['Levels']['Local']['RIVER_C'] = ('BH140', '100314', 'HydrographyCrv')
    field_information['GGDM 3.0']['Levels']['Regional']['RIVER_C'] = ('BH140', '100314', 'HydrographyCrv')
    field_information['GGDM 3.0']['Levels']['Specialized']['RIVER_C'] = ('BH140', '100314', 'HydrographyCrv')
    field_information['GGDM 3.0']['Levels']['Global']['RIVER_S'] = ('BH140', '100314', 'HydrographySrf')
    field_information['GGDM 3.0']['Levels']['Local']['RIVER_S'] = ('BH140', '100314', 'HydrographySrf')
    field_information['GGDM 3.0']['Levels']['Regional']['RIVER_S'] = ('BH140', '100314', 'HydrographySrf')
    field_information['GGDM 3.0']['Levels']['Specialized']['RIVER_S'] = ('BH140', '100314', 'HydrographySrf')
    field_information['GGDM 3.0']['Levels']['Global']['VANISHING_POINT_P'] = ('BH145', '100315', 'HydrographyPnt')
    field_information['GGDM 3.0']['Levels']['Local']['VANISHING_POINT_P'] = ('BH145', '100315', 'HydrographyPnt')
    field_information['GGDM 3.0']['Levels']['Regional']['VANISHING_POINT_P'] = ('BH145', '100315', 'HydrographyPnt')
    field_information['GGDM 3.0']['Levels']['Specialized']['VANISHING_POINT_P'] = ('BH145', '100315', 'HydrographyPnt')
    field_information['GGDM 3.0']['Levels']['Global']['SALT_FLAT_S'] = ('BH150', '100316', 'PhysiographySrf')
    field_information['GGDM 3.0']['Levels']['Local']['SALT_FLAT_S'] = ('BH150', '100316', 'PhysiographySrf')
    field_information['GGDM 3.0']['Levels']['Regional']['SALT_FLAT_S'] = ('BH150', '100316', 'PhysiographySrf')
    field_information['GGDM 3.0']['Levels']['Specialized']['SALT_FLAT_S'] = ('BH150', '100316', 'PhysiographySrf')
    field_information['GGDM 3.0']['Levels']['Global']['SALT_EVAPORATOR_P'] = ('BH155', '100317', 'IndustryPnt')
    field_information['GGDM 3.0']['Levels']['Regional']['SALT_EVAPORATOR_P'] = ('BH155', '100317', 'IndustryPnt')
    field_information['GGDM 3.0']['Levels']['Global']['SALT_EVAPORATOR_S'] = ('BH155', '100317', 'IndustrySrf')
    field_information['GGDM 3.0']['Levels']['Local']['SALT_EVAPORATOR_S'] = ('BH155', '100317', 'IndustrySrf')
    field_information['GGDM 3.0']['Levels']['Regional']['SALT_EVAPORATOR_S'] = ('BH155', '100317', 'IndustrySrf')
    field_information['GGDM 3.0']['Levels']['Specialized']['SALT_EVAPORATOR_S'] = ('BH155', '100317', 'IndustrySrf')
    field_information['GGDM 3.0']['Levels']['Global']['SABKHA_S'] = ('BH160', '100318', 'PhysiographySrf')
    field_information['GGDM 3.0']['Levels']['Local']['SABKHA_S'] = ('BH160', '100318', 'PhysiographySrf')
    field_information['GGDM 3.0']['Levels']['Regional']['SABKHA_S'] = ('BH160', '100318', 'PhysiographySrf')
    field_information['GGDM 3.0']['Levels']['Specialized']['SABKHA_S'] = ('BH160', '100318', 'PhysiographySrf')
    field_information['GGDM 3.0']['Levels']['Local']['SPILLWAY_C'] = ('BH165', '100319', 'HydrographyCrv')
    field_information['GGDM 3.0']['Levels']['Specialized']['SPILLWAY_C'] = ('BH165', '100319', 'HydrographyCrv')
    field_information['GGDM 3.0']['Levels']['Local']['SPILLWAY_S'] = ('BH165', '100319', 'HydrographySrf')
    field_information['GGDM 3.0']['Levels']['Specialized']['SPILLWAY_S'] = ('BH165', '100319', 'HydrographySrf')
    field_information['GGDM 3.0']['Levels']['Global']['NATURAL_POOL_P'] = ('BH170', '100320', 'HydrographyPnt')
    field_information['GGDM 3.0']['Levels']['Local']['NATURAL_POOL_P'] = ('BH170', '100320', 'HydrographyPnt')
    field_information['GGDM 3.0']['Levels']['Regional']['NATURAL_POOL_P'] = ('BH170', '100320', 'HydrographyPnt')
    field_information['GGDM 3.0']['Levels']['Specialized']['NATURAL_POOL_P'] = ('BH170', '100320', 'HydrographyPnt')
    field_information['GGDM 3.0']['Levels']['Specialized']['NATURAL_POOL_S'] = ('BH170', '100320', 'HydrographySrf')
    field_information['GGDM 3.0']['Levels']['Global']['WATERFALL_C'] = ('BH180', '100321', 'HydrographyCrv')
    field_information['GGDM 3.0']['Levels']['Local']['WATERFALL_C'] = ('BH180', '100321', 'HydrographyCrv')
    field_information['GGDM 3.0']['Levels']['Regional']['WATERFALL_C'] = ('BH180', '100321', 'HydrographyCrv')
    field_information['GGDM 3.0']['Levels']['Specialized']['WATERFALL_C'] = ('BH180', '100321', 'HydrographyCrv')
    field_information['GGDM 3.0']['Levels']['Global']['WATERFALL_P'] = ('BH180', '100321', 'HydrographyPnt')
    field_information['GGDM 3.0']['Levels']['Local']['WATERFALL_P'] = ('BH180', '100321', 'HydrographyPnt')
    field_information['GGDM 3.0']['Levels']['Regional']['WATERFALL_P'] = ('BH180', '100321', 'HydrographyPnt')
    field_information['GGDM 3.0']['Levels']['Specialized']['WATERFALL_P'] = ('BH180', '100321', 'HydrographyPnt')
    field_information['GGDM 3.0']['Levels']['Local']['LAGOON_S'] = ('BH190', '100322', 'HydrographySrfExt')
    field_information['GGDM 3.0']['Levels']['Regional']['LAGOON_S'] = ('BH190', '100322', 'HydrographySrfExt')
    field_information['GGDM 3.0']['Levels']['Specialized']['LAGOON_S'] = ('BH190', '100322', 'HydrographySrfExt')
    field_information['GGDM 3.0']['Levels']['Global']['WATERWORK_P'] = ('BH220', '100325', 'UtilityInfrastructurePnt')
    field_information['GGDM 3.0']['Levels']['Local']['WATERWORK_P'] = ('BH220', '100325', 'UtilityInfrastructurePnt')
    field_information['GGDM 3.0']['Levels']['Regional']['WATERWORK_P'] = ('BH220', '100325', 'UtilityInfrastructurePnt')
    field_information['GGDM 3.0']['Levels']['Specialized']['WATERWORK_P'] = ('BH220', '100325', 'UtilityInfrastructurePnt')
    field_information['GGDM 3.0']['Levels']['Global']['WATERWORK_S'] = ('BH220', '100325', 'UtilityInfrastructureSrf')
    field_information['GGDM 3.0']['Levels']['Local']['WATERWORK_S'] = ('BH220', '100325', 'UtilityInfrastructureSrf')
    field_information['GGDM 3.0']['Levels']['Regional']['WATERWORK_S'] = ('BH220', '100325', 'UtilityInfrastructureSrf')
    field_information['GGDM 3.0']['Levels']['Specialized']['WATERWORK_S'] = ('BH220', '100325', 'UtilityInfrastructureSrf')
    field_information['GGDM 3.0']['Levels']['Global']['WATER_WELL_P'] = ('BH230', '100326', 'HydrographyPnt')
    field_information['GGDM 3.0']['Levels']['Local']['WATER_WELL_P'] = ('BH230', '100326', 'HydrographyPnt')
    field_information['GGDM 3.0']['Levels']['Regional']['WATER_WELL_P'] = ('BH230', '100326', 'HydrographyPnt')
    field_information['GGDM 3.0']['Levels']['Specialized']['WATER_WELL_P'] = ('BH230', '100326', 'HydrographyPnt')
    field_information['GGDM 3.0']['Levels']['Specialized']['WATER_WELL_S'] = ('BH230', '100326', 'HydrographySrf')
    field_information['GGDM 3.0']['Levels']['Specialized']['VESSEL_LIFT_S'] = ('BI005', '100328', 'PortHarbourSrf')
    field_information['GGDM 3.0']['Levels']['Global']['SHIP_ELEVATOR_C'] = ('BI006', '132749', 'TransportationWaterCrv')
    field_information['GGDM 3.0']['Levels']['Local']['SHIP_ELEVATOR_C'] = ('BI006', '132749', 'TransportationWaterCrv')
    field_information['GGDM 3.0']['Levels']['Regional']['SHIP_ELEVATOR_C'] = ('BI006', '132749', 'TransportationWaterCrv')
    field_information['GGDM 3.0']['Levels']['Global']['SHIP_ELEVATOR_P'] = ('BI006', '132749', 'TransportationWaterPnt')
    field_information['GGDM 3.0']['Levels']['Local']['SHIP_ELEVATOR_P'] = ('BI006', '132749', 'TransportationWaterPnt')
    field_information['GGDM 3.0']['Levels']['Regional']['SHIP_ELEVATOR_P'] = ('BI006', '132749', 'TransportationWaterPnt')
    field_information['GGDM 3.0']['Levels']['Specialized']['SHIP_ELEVATOR_S'] = ('BI006', '132749', 'TransportationWaterSrf')
    field_information['GGDM 3.0']['Levels']['Global']['CISTERN_P'] = ('BI010', '100329', 'HydrographyPnt')
    field_information['GGDM 3.0']['Levels']['Local']['CISTERN_P'] = ('BI010', '100329', 'HydrographyPnt')
    field_information['GGDM 3.0']['Levels']['Regional']['CISTERN_P'] = ('BI010', '100329', 'HydrographyPnt')
    field_information['GGDM 3.0']['Levels']['Specialized']['CISTERN_P'] = ('BI010', '100329', 'HydrographyPnt')
    field_information['GGDM 3.0']['Levels']['Global']['DAM_C'] = ('BI020', '100330', 'HydrographyCrv')
    field_information['GGDM 3.0']['Levels']['Local']['DAM_C'] = ('BI020', '100330', 'HydrographyCrv')
    field_information['GGDM 3.0']['Levels']['Regional']['DAM_C'] = ('BI020', '100330', 'HydrographyCrv')
    field_information['GGDM 3.0']['Levels']['Specialized']['DAM_C'] = ('BI020', '100330', 'HydrographyCrv')
    field_information['GGDM 3.0']['Levels']['Global']['DAM_P'] = ('BI020', '100330', 'HydrographyPnt')
    field_information['GGDM 3.0']['Levels']['Local']['DAM_P'] = ('BI020', '100330', 'HydrographyPnt')
    field_information['GGDM 3.0']['Levels']['Regional']['DAM_P'] = ('BI020', '100330', 'HydrographyPnt')
    field_information['GGDM 3.0']['Levels']['Specialized']['DAM_P'] = ('BI020', '100330', 'HydrographyPnt')
    field_information['GGDM 3.0']['Levels']['Global']['DAM_S'] = ('BI020', '100330', 'HydrographySrf')
    field_information['GGDM 3.0']['Levels']['Local']['DAM_S'] = ('BI020', '100330', 'HydrographySrf')
    field_information['GGDM 3.0']['Levels']['Regional']['DAM_S'] = ('BI020', '100330', 'HydrographySrf')
    field_information['GGDM 3.0']['Levels']['Specialized']['DAM_S'] = ('BI020', '100330', 'HydrographySrf')
    field_information['GGDM 3.0']['Levels']['Local']['LOCK_C'] = ('BI030', '100331', 'TransportationWaterCrv')
    field_information['GGDM 3.0']['Levels']['Specialized']['LOCK_C'] = ('BI030', '100331', 'TransportationWaterCrv')
    field_information['GGDM 3.0']['Levels']['Global']['LOCK_P'] = ('BI030', '100331', 'TransportationWaterPnt')
    field_information['GGDM 3.0']['Levels']['Local']['LOCK_P'] = ('BI030', '100331', 'TransportationWaterPnt')
    field_information['GGDM 3.0']['Levels']['Regional']['LOCK_P'] = ('BI030', '100331', 'TransportationWaterPnt')
    field_information['GGDM 3.0']['Levels']['Specialized']['LOCK_P'] = ('BI030', '100331', 'TransportationWaterPnt')
    field_information['GGDM 3.0']['Levels']['Local']['LOCK_S'] = ('BI030', '100331', 'TransportationWaterSrf')
    field_information['GGDM 3.0']['Levels']['Specialized']['LOCK_S'] = ('BI030', '100331', 'TransportationWaterSrf')
    field_information['GGDM 3.0']['Levels']['Local']['SLUICE_GATE_C'] = ('BI040', '100334', 'HydrographyCrv')
    field_information['GGDM 3.0']['Levels']['Specialized']['SLUICE_GATE_C'] = ('BI040', '100334', 'HydrographyCrv')
    field_information['GGDM 3.0']['Levels']['Global']['SLUICE_GATE_P'] = ('BI040', '100334', 'HydrographyPnt')
    field_information['GGDM 3.0']['Levels']['Local']['SLUICE_GATE_P'] = ('BI040', '100334', 'HydrographyPnt')
    field_information['GGDM 3.0']['Levels']['Regional']['SLUICE_GATE_P'] = ('BI040', '100334', 'HydrographyPnt')
    field_information['GGDM 3.0']['Levels']['Specialized']['SLUICE_GATE_P'] = ('BI040', '100334', 'HydrographyPnt')
    field_information['GGDM 3.0']['Levels']['Local']['FLOOD_CONTROL_STRUCTURE_C'] = ('BI044', '131207', 'HydrographyCrv')
    field_information['GGDM 3.0']['Levels']['Global']['FLOOD_CONTROL_STRUCTURE_P'] = ('BI044', '131207', 'HydrographyPnt')
    field_information['GGDM 3.0']['Levels']['Regional']['FLOOD_CONTROL_STRUCTURE_P'] = ('BI044', '131207', 'HydrographyPnt')
    field_information['GGDM 3.0']['Levels']['Local']['FLOOD_CONTROL_STRUCTURE_S'] = ('BI044', '131207', 'HydrographySrf')
    field_information['GGDM 3.0']['Levels']['Specialized']['FLOOD_CONTROL_STRUCTURE_S'] = ('BI044', '131207', 'HydrographySrf')
    field_information['GGDM 3.0']['Levels']['Local']['BASIN_GATE_C'] = ('BI045', '131206', 'TransportationWaterCrv')
    field_information['GGDM 3.0']['Levels']['Specialized']['BASIN_GATE_C'] = ('BI045', '131206', 'TransportationWaterCrv')
    field_information['GGDM 3.0']['Levels']['Local']['BASIN_GATE_P'] = ('BI045', '131206', 'TransportationWaterPnt')
    field_information['GGDM 3.0']['Levels']['Specialized']['BASIN_GATE_P'] = ('BI045', '131206', 'TransportationWaterPnt')
    field_information['GGDM 3.0']['Levels']['Global']['WATER_INTAKE_TOWER_P'] = ('BI050', '100337', 'HydrographyPnt')
    field_information['GGDM 3.0']['Levels']['Local']['WATER_INTAKE_TOWER_P'] = ('BI050', '100337', 'HydrographyPnt')
    field_information['GGDM 3.0']['Levels']['Regional']['WATER_INTAKE_TOWER_P'] = ('BI050', '100337', 'HydrographyPnt')
    field_information['GGDM 3.0']['Levels']['Specialized']['WATER_INTAKE_TOWER_P'] = ('BI050', '100337', 'HydrographyPnt')
    field_information['GGDM 3.0']['Levels']['Local']['WATER_INTAKE_TOWER_S'] = ('BI050', '100337', 'HydrographySrf')
    field_information['GGDM 3.0']['Levels']['Specialized']['WATER_INTAKE_TOWER_S'] = ('BI050', '100337', 'HydrographySrf')
    field_information['GGDM 3.0']['Levels']['Specialized']['FISH_LADDER_C'] = ('BI060', '100338', 'HydrographyCrv')
    field_information['GGDM 3.0']['Levels']['Local']['GAUGING_STATION_P'] = ('BI070', '100339', 'HydrographyPnt')
    field_information['GGDM 3.0']['Levels']['Regional']['GAUGING_STATION_P'] = ('BI070', '100339', 'HydrographyPnt')
    field_information['GGDM 3.0']['Levels']['Specialized']['GAUGING_STATION_P'] = ('BI070', '100339', 'HydrographyPnt')
    field_information['GGDM 3.0']['Levels']['Global']['MORAINE_S'] = ('BJ020', '100340', 'PhysiographySrf')
    field_information['GGDM 3.0']['Levels']['Local']['MORAINE_S'] = ('BJ020', '100340', 'PhysiographySrf')
    field_information['GGDM 3.0']['Levels']['Regional']['MORAINE_S'] = ('BJ020', '100340', 'PhysiographySrf')
    field_information['GGDM 3.0']['Levels']['Specialized']['MORAINE_S'] = ('BJ020', '100340', 'PhysiographySrf')
    field_information['GGDM 3.0']['Levels']['Global']['GLACIER_S'] = ('BJ030', '100341', 'PhysiographySrf')
    field_information['GGDM 3.0']['Levels']['Local']['GLACIER_S'] = ('BJ030', '100341', 'PhysiographySrf')
    field_information['GGDM 3.0']['Levels']['Regional']['GLACIER_S'] = ('BJ030', '100341', 'PhysiographySrf')
    field_information['GGDM 3.0']['Levels']['Specialized']['GLACIER_S'] = ('BJ030', '100341', 'PhysiographySrf')
    field_information['GGDM 3.0']['Levels']['Global']['CREVASSE_C'] = ('BJ031', '100342', 'PhysiographyCrv')
    field_information['GGDM 3.0']['Levels']['Local']['CREVASSE_C'] = ('BJ031', '100342', 'PhysiographyCrv')
    field_information['GGDM 3.0']['Levels']['Regional']['CREVASSE_C'] = ('BJ031', '100342', 'PhysiographyCrv')
    field_information['GGDM 3.0']['Levels']['Specialized']['CREVASSE_C'] = ('BJ031', '100342', 'PhysiographyCrv')
    field_information['GGDM 3.0']['Levels']['Global']['CREVASSE_S'] = ('BJ031', '100342', 'PhysiographySrf')
    field_information['GGDM 3.0']['Levels']['Local']['CREVASSE_S'] = ('BJ031', '100342', 'PhysiographySrf')
    field_information['GGDM 3.0']['Levels']['Regional']['CREVASSE_S'] = ('BJ031', '100342', 'PhysiographySrf')
    field_information['GGDM 3.0']['Levels']['Specialized']['CREVASSE_S'] = ('BJ031', '100342', 'PhysiographySrf')
    field_information['GGDM 3.0']['Levels']['Global']['ICE_CLIFF_C'] = ('BJ040', '100343', 'PhysiographyCrv')
    field_information['GGDM 3.0']['Levels']['Local']['ICE_CLIFF_C'] = ('BJ040', '100343', 'PhysiographyCrv')
    field_information['GGDM 3.0']['Levels']['Regional']['ICE_CLIFF_C'] = ('BJ040', '100343', 'PhysiographyCrv')
    field_information['GGDM 3.0']['Levels']['Specialized']['ICE_CLIFF_C'] = ('BJ040', '100343', 'PhysiographyCrv')
    field_information['GGDM 3.0']['Levels']['Global']['ICE_PEAK_P'] = ('BJ060', '100344', 'PhysiographyPnt')
    field_information['GGDM 3.0']['Levels']['Local']['ICE_PEAK_P'] = ('BJ060', '100344', 'PhysiographyPnt')
    field_information['GGDM 3.0']['Levels']['Regional']['ICE_PEAK_P'] = ('BJ060', '100344', 'PhysiographyPnt')
    field_information['GGDM 3.0']['Levels']['Specialized']['ICE_PEAK_P'] = ('BJ060', '100344', 'PhysiographyPnt')
    field_information['GGDM 3.0']['Levels']['Global']['ICE_SHELF_S'] = ('BJ065', '100345', 'PhysiographySrf')
    field_information['GGDM 3.0']['Levels']['Local']['ICE_SHELF_S'] = ('BJ065', '100345', 'PhysiographySrf')
    field_information['GGDM 3.0']['Levels']['Regional']['ICE_SHELF_S'] = ('BJ065', '100345', 'PhysiographySrf')
    field_information['GGDM 3.0']['Levels']['Specialized']['ICE_SHELF_S'] = ('BJ065', '100345', 'PhysiographySrf')
    field_information['GGDM 3.0']['Levels']['Global']['PACK_ICE_C'] = ('BJ070', '100346', 'PhysiographyCrvExt')
    field_information['GGDM 3.0']['Levels']['Local']['PACK_ICE_C'] = ('BJ070', '100346', 'PhysiographyCrvExt')
    field_information['GGDM 3.0']['Levels']['Regional']['PACK_ICE_C'] = ('BJ070', '100346', 'PhysiographyCrvExt')
    field_information['GGDM 3.0']['Levels']['Specialized']['PACK_ICE_C'] = ('BJ070', '100346', 'PhysiographyCrvExt')
    field_information['GGDM 3.0']['Levels']['Global']['PACK_ICE_S'] = ('BJ070', '100346', 'PhysiographySrfExt')
    field_information['GGDM 3.0']['Levels']['Local']['PACK_ICE_S'] = ('BJ070', '100346', 'PhysiographySrfExt')
    field_information['GGDM 3.0']['Levels']['Regional']['PACK_ICE_S'] = ('BJ070', '100346', 'PhysiographySrfExt')
    field_information['GGDM 3.0']['Levels']['Specialized']['PACK_ICE_S'] = ('BJ070', '100346', 'PhysiographySrfExt')
    field_information['GGDM 3.0']['Levels']['Global']['POLAR_ICE_S'] = ('BJ080', '100347', 'PhysiographySrf')
    field_information['GGDM 3.0']['Levels']['Local']['POLAR_ICE_S'] = ('BJ080', '100347', 'PhysiographySrf')
    field_information['GGDM 3.0']['Levels']['Regional']['POLAR_ICE_S'] = ('BJ080', '100347', 'PhysiographySrf')
    field_information['GGDM 3.0']['Levels']['Specialized']['POLAR_ICE_S'] = ('BJ080', '100347', 'PhysiographySrf')
    field_information['GGDM 3.0']['Levels']['Global']['ICE_CAP_S'] = ('BJ099', '100348', 'PhysiographySrf')
    field_information['GGDM 3.0']['Levels']['Regional']['ICE_CAP_S'] = ('BJ099', '100348', 'PhysiographySrf')
    field_information['GGDM 3.0']['Levels']['Global']['SNOW_ICE_FIELD_S'] = ('BJ100', '100349', 'PhysiographySrf')
    field_information['GGDM 3.0']['Levels']['Local']['SNOW_ICE_FIELD_S'] = ('BJ100', '100349', 'PhysiographySrf')
    field_information['GGDM 3.0']['Levels']['Regional']['SNOW_ICE_FIELD_S'] = ('BJ100', '100349', 'PhysiographySrf')
    field_information['GGDM 3.0']['Levels']['Specialized']['SNOW_ICE_FIELD_S'] = ('BJ100', '100349', 'PhysiographySrf')
    field_information['GGDM 3.0']['Levels']['Global']['TUNDRA_S'] = ('BJ110', '100350', 'VegetationSrf')
    field_information['GGDM 3.0']['Levels']['Local']['TUNDRA_S'] = ('BJ110', '100350', 'VegetationSrf')
    field_information['GGDM 3.0']['Levels']['Regional']['TUNDRA_S'] = ('BJ110', '100350', 'VegetationSrf')
    field_information['GGDM 3.0']['Levels']['Specialized']['TUNDRA_S'] = ('BJ110', '100350', 'VegetationSrf')
    field_information['GGDM 3.0']['Levels']['Global']['ELEVATION_CONTOUR_C'] = ('CA010', '100353', 'HypsographyCrv')
    field_information['GGDM 3.0']['Levels']['Local']['ELEVATION_CONTOUR_C'] = ('CA010', '100353', 'HypsographyCrv')
    field_information['GGDM 3.0']['Levels']['Regional']['ELEVATION_CONTOUR_C'] = ('CA010', '100353', 'HypsographyCrv')
    field_information['GGDM 3.0']['Levels']['Specialized']['ELEVATION_CONTOUR_C'] = ('CA010', '100353', 'HypsographyCrv')
    field_information['GGDM 3.0']['Levels']['Global']['SPOT_ELEVATION_P'] = ('CA030', '100355', 'HypsographyPnt')
    field_information['GGDM 3.0']['Levels']['Local']['SPOT_ELEVATION_P'] = ('CA030', '100355', 'HypsographyPnt')
    field_information['GGDM 3.0']['Levels']['Regional']['SPOT_ELEVATION_P'] = ('CA030', '100355', 'HypsographyPnt')
    field_information['GGDM 3.0']['Levels']['Specialized']['SPOT_ELEVATION_P'] = ('CA030', '100355', 'HypsographyPnt')
    field_information['GGDM 3.0']['Levels']['Local']['ASPHALT_LAKE_S'] = ('DA005', '100356', 'PhysiographySrf')
    field_information['GGDM 3.0']['Levels']['Specialized']['ASPHALT_LAKE_S'] = ('DA005', '100356', 'PhysiographySrf')
    field_information['GGDM 3.0']['Levels']['Global']['SOIL_SURFACE_REGION_S'] = ('DA010', '100358', 'PhysiographySrf')
    field_information['GGDM 3.0']['Levels']['Local']['SOIL_SURFACE_REGION_S'] = ('DA010', '100358', 'PhysiographySrf')
    field_information['GGDM 3.0']['Levels']['Regional']['SOIL_SURFACE_REGION_S'] = ('DA010', '100358', 'PhysiographySrf')
    field_information['GGDM 3.0']['Levels']['Specialized']['SOIL_SURFACE_REGION_S'] = ('DA010', '100358', 'PhysiographySrf')
    field_information['GGDM 3.0']['Levels']['Global']['STEEP_TERRAIN_FACE_C'] = ('DB010', '100362', 'PhysiographyCrv')
    field_information['GGDM 3.0']['Levels']['Local']['STEEP_TERRAIN_FACE_C'] = ('DB010', '100362', 'PhysiographyCrv')
    field_information['GGDM 3.0']['Levels']['Regional']['STEEP_TERRAIN_FACE_C'] = ('DB010', '100362', 'PhysiographyCrv')
    field_information['GGDM 3.0']['Levels']['Specialized']['STEEP_TERRAIN_FACE_C'] = ('DB010', '100362', 'PhysiographyCrv')
    field_information['GGDM 3.0']['Levels']['Local']['CAVE_CHAMBER_S'] = ('DB028', '154959', 'SubterraneanSrf')
    field_information['GGDM 3.0']['Levels']['Specialized']['CAVE_CHAMBER_S'] = ('DB028', '154959', 'SubterraneanSrf')
    field_information['GGDM 3.0']['Levels']['Global']['CAVE_MOUTH_P'] = ('DB029', '154961', 'PhysiographyPnt')
    field_information['GGDM 3.0']['Levels']['Local']['CAVE_MOUTH_P'] = ('DB029', '154961', 'PhysiographyPnt')
    field_information['GGDM 3.0']['Levels']['Regional']['CAVE_MOUTH_P'] = ('DB029', '154961', 'PhysiographyPnt')
    field_information['GGDM 3.0']['Levels']['Specialized']['CAVE_MOUTH_P'] = ('DB029', '154961', 'PhysiographyPnt')
    field_information['GGDM 3.0']['Levels']['Global']['CREVICE_C'] = ('DB061', '100365', 'PhysiographyCrv')
    field_information['GGDM 3.0']['Levels']['Local']['CREVICE_C'] = ('DB061', '100365', 'PhysiographyCrv')
    field_information['GGDM 3.0']['Levels']['Regional']['CREVICE_C'] = ('DB061', '100365', 'PhysiographyCrv')
    field_information['GGDM 3.0']['Levels']['Specialized']['CREVICE_C'] = ('DB061', '100365', 'PhysiographyCrv')
    field_information['GGDM 3.0']['Levels']['Global']['CREVICE_S'] = ('DB061', '100365', 'PhysiographySrf')
    field_information['GGDM 3.0']['Levels']['Local']['CREVICE_S'] = ('DB061', '100365', 'PhysiographySrf')
    field_information['GGDM 3.0']['Levels']['Regional']['CREVICE_S'] = ('DB061', '100365', 'PhysiographySrf')
    field_information['GGDM 3.0']['Levels']['Specialized']['CREVICE_S'] = ('DB061', '100365', 'PhysiographySrf')
    field_information['GGDM 3.0']['Levels']['Global']['CUT_C'] = ('DB070', '100366', 'PhysiographyCrv')
    field_information['GGDM 3.0']['Levels']['Local']['CUT_C'] = ('DB070', '100366', 'PhysiographyCrv')
    field_information['GGDM 3.0']['Levels']['Regional']['CUT_C'] = ('DB070', '100366', 'PhysiographyCrv')
    field_information['GGDM 3.0']['Levels']['Specialized']['CUT_C'] = ('DB070', '100366', 'PhysiographyCrv')
    field_information['GGDM 3.0']['Levels']['Global']['CUT_LINE_C'] = ('DB071', '192101', 'PhysiographyCrv')
    field_information['GGDM 3.0']['Levels']['Local']['CUT_LINE_C'] = ('DB071', '192101', 'PhysiographyCrv')
    field_information['GGDM 3.0']['Levels']['Regional']['CUT_LINE_C'] = ('DB071', '192101', 'PhysiographyCrv')
    field_information['GGDM 3.0']['Levels']['Specialized']['CUT_LINE_C'] = ('DB071', '192101', 'PhysiographyCrv')
    field_information['GGDM 3.0']['Levels']['Global']['DEPRESSION_P'] = ('DB080', '100367', 'PhysiographyPntExt')
    field_information['GGDM 3.0']['Levels']['Regional']['DEPRESSION_P'] = ('DB080', '100367', 'PhysiographyPntExt')
    field_information['GGDM 3.0']['Levels']['Global']['DEPRESSION_S'] = ('DB080', '100367', 'PhysiographySrf')
    field_information['GGDM 3.0']['Levels']['Local']['DEPRESSION_S'] = ('DB080', '100367', 'PhysiographySrf')
    field_information['GGDM 3.0']['Levels']['Regional']['DEPRESSION_S'] = ('DB080', '100367', 'PhysiographySrf')
    field_information['GGDM 3.0']['Levels']['Specialized']['DEPRESSION_S'] = ('DB080', '100367', 'PhysiographySrf')
    field_information['GGDM 3.0']['Levels']['Global']['EMBANKMENT_C'] = ('DB090', '100368', 'PhysiographyCrv')
    field_information['GGDM 3.0']['Levels']['Local']['EMBANKMENT_C'] = ('DB090', '100368', 'PhysiographyCrv')
    field_information['GGDM 3.0']['Levels']['Regional']['EMBANKMENT_C'] = ('DB090', '100368', 'PhysiographyCrv')
    field_information['GGDM 3.0']['Levels']['Specialized']['EMBANKMENT_C'] = ('DB090', '100368', 'PhysiographyCrv')
    field_information['GGDM 3.0']['Levels']['Local']['EMBANKMENT_S'] = ('DB090', '100368', 'PhysiographySrf')
    field_information['GGDM 3.0']['Levels']['Specialized']['EMBANKMENT_S'] = ('DB090', '100368', 'PhysiographySrf')
    field_information['GGDM 3.0']['Levels']['Local']['ESKER_C'] = ('DB100', '100369', 'PhysiographyCrv')
    field_information['GGDM 3.0']['Levels']['Regional']['ESKER_C'] = ('DB100', '100369', 'PhysiographyCrv')
    field_information['GGDM 3.0']['Levels']['Specialized']['ESKER_C'] = ('DB100', '100369', 'PhysiographyCrv')
    field_information['GGDM 3.0']['Levels']['Global']['GEOLOGIC_FAULT_C'] = ('DB110', '100370', 'PhysiographyCrv')
    field_information['GGDM 3.0']['Levels']['Local']['GEOLOGIC_FAULT_C'] = ('DB110', '100370', 'PhysiographyCrv')
    field_information['GGDM 3.0']['Levels']['Regional']['GEOLOGIC_FAULT_C'] = ('DB110', '100370', 'PhysiographyCrv')
    field_information['GGDM 3.0']['Levels']['Specialized']['GEOLOGIC_FAULT_C'] = ('DB110', '100370', 'PhysiographyCrv')
    field_information['GGDM 3.0']['Levels']['Global']['GEOTHERMAL_OUTLET_P'] = ('DB115', '100371', 'PhysiographyPnt')
    field_information['GGDM 3.0']['Levels']['Local']['GEOTHERMAL_OUTLET_P'] = ('DB115', '100371', 'PhysiographyPnt')
    field_information['GGDM 3.0']['Levels']['Regional']['GEOTHERMAL_OUTLET_P'] = ('DB115', '100371', 'PhysiographyPnt')
    field_information['GGDM 3.0']['Levels']['Specialized']['GEOTHERMAL_OUTLET_P'] = ('DB115', '100371', 'PhysiographyPnt')
    field_information['GGDM 3.0']['Levels']['Local']['GEOTHERMAL_OUTLET_S'] = ('DB115', '100371', 'PhysiographySrf')
    field_information['GGDM 3.0']['Levels']['Specialized']['GEOTHERMAL_OUTLET_S'] = ('DB115', '100371', 'PhysiographySrf')
    field_information['GGDM 3.0']['Levels']['Global']['MOUNTAIN_PASS_P'] = ('DB150', '100372', 'PhysiographyPnt')
    field_information['GGDM 3.0']['Levels']['Local']['MOUNTAIN_PASS_P'] = ('DB150', '100372', 'PhysiographyPnt')
    field_information['GGDM 3.0']['Levels']['Regional']['MOUNTAIN_PASS_P'] = ('DB150', '100372', 'PhysiographyPnt')
    field_information['GGDM 3.0']['Levels']['Specialized']['MOUNTAIN_PASS_P'] = ('DB150', '100372', 'PhysiographyPnt')
    field_information['GGDM 3.0']['Levels']['Global']['ROCK_FORMATION_P'] = ('DB160', '100373', 'PhysiographyPnt')
    field_information['GGDM 3.0']['Levels']['Local']['ROCK_FORMATION_P'] = ('DB160', '100373', 'PhysiographyPnt')
    field_information['GGDM 3.0']['Levels']['Regional']['ROCK_FORMATION_P'] = ('DB160', '100373', 'PhysiographyPnt')
    field_information['GGDM 3.0']['Levels']['Specialized']['ROCK_FORMATION_P'] = ('DB160', '100373', 'PhysiographyPnt')
    field_information['GGDM 3.0']['Levels']['Global']['ROCK_FORMATION_S'] = ('DB160', '100373', 'PhysiographySrf')
    field_information['GGDM 3.0']['Levels']['Local']['ROCK_FORMATION_S'] = ('DB160', '100373', 'PhysiographySrf')
    field_information['GGDM 3.0']['Levels']['Regional']['ROCK_FORMATION_S'] = ('DB160', '100373', 'PhysiographySrf')
    field_information['GGDM 3.0']['Levels']['Specialized']['ROCK_FORMATION_S'] = ('DB160', '100373', 'PhysiographySrf')
    field_information['GGDM 3.0']['Levels']['Global']['SAND_DUNES_S'] = ('DB170', '100374', 'PhysiographySrf')
    field_information['GGDM 3.0']['Levels']['Local']['SAND_DUNES_S'] = ('DB170', '100374', 'PhysiographySrf')
    field_information['GGDM 3.0']['Levels']['Regional']['SAND_DUNES_S'] = ('DB170', '100374', 'PhysiographySrf')
    field_information['GGDM 3.0']['Levels']['Specialized']['SAND_DUNES_S'] = ('DB170', '100374', 'PhysiographySrf')
    field_information['GGDM 3.0']['Levels']['Global']['VOLCANO_P'] = ('DB180', '100375', 'PhysiographyPnt')
    field_information['GGDM 3.0']['Levels']['Local']['VOLCANO_P'] = ('DB180', '100375', 'PhysiographyPnt')
    field_information['GGDM 3.0']['Levels']['Regional']['VOLCANO_P'] = ('DB180', '100375', 'PhysiographyPnt')
    field_information['GGDM 3.0']['Levels']['Specialized']['VOLCANO_P'] = ('DB180', '100375', 'PhysiographyPnt')
    field_information['GGDM 3.0']['Levels']['Local']['VOLCANO_S'] = ('DB180', '100375', 'PhysiographySrf')
    field_information['GGDM 3.0']['Levels']['Specialized']['VOLCANO_S'] = ('DB180', '100375', 'PhysiographySrf')
    field_information['GGDM 3.0']['Levels']['Local']['CRATER_P'] = ('DB185', '100376', 'PhysiographyPntExt')
    field_information['GGDM 3.0']['Levels']['Regional']['CRATER_P'] = ('DB185', '100376', 'PhysiographyPntExt')
    field_information['GGDM 3.0']['Levels']['Specialized']['CRATER_P'] = ('DB185', '100376', 'PhysiographyPntExt')
    field_information['GGDM 3.0']['Levels']['Local']['CRATER_S'] = ('DB185', '100376', 'PhysiographySrfExt')
    field_information['GGDM 3.0']['Levels']['Specialized']['CRATER_S'] = ('DB185', '100376', 'PhysiographySrfExt')
    field_information['GGDM 3.0']['Levels']['Local']['VOLCANIC_DYKE_C'] = ('DB190', '100377', 'PhysiographyCrv')
    field_information['GGDM 3.0']['Levels']['Regional']['VOLCANIC_DYKE_C'] = ('DB190', '100377', 'PhysiographyCrv')
    field_information['GGDM 3.0']['Levels']['Specialized']['VOLCANIC_DYKE_C'] = ('DB190', '100377', 'PhysiographyCrv')
    field_information['GGDM 3.0']['Levels']['Specialized']['LANDSLIDE_MASS_S'] = ('DB211', '100379', 'PhysiographySrf')
    field_information['GGDM 3.0']['Levels']['Global']['CROP_LAND_S'] = ('EA010', '100380', 'AgricultureSrf')
    field_information['GGDM 3.0']['Levels']['Local']['CROP_LAND_S'] = ('EA010', '100380', 'AgricultureSrf')
    field_information['GGDM 3.0']['Levels']['Regional']['CROP_LAND_S'] = ('EA010', '100380', 'AgricultureSrf')
    field_information['GGDM 3.0']['Levels']['Specialized']['CROP_LAND_S'] = ('EA010', '100380', 'AgricultureSrf')
    field_information['GGDM 3.0']['Levels']['Local']['HEDGEROW_C'] = ('EA020', '100381', 'VegetationCrv')
    field_information['GGDM 3.0']['Levels']['Specialized']['HEDGEROW_C'] = ('EA020', '100381', 'VegetationCrv')
    field_information['GGDM 3.0']['Levels']['Global']['PLANT_NURSERY_S'] = ('EA030', '100382', 'AgricultureSrf')
    field_information['GGDM 3.0']['Levels']['Local']['PLANT_NURSERY_S'] = ('EA030', '100382', 'AgricultureSrf')
    field_information['GGDM 3.0']['Levels']['Regional']['PLANT_NURSERY_S'] = ('EA030', '100382', 'AgricultureSrf')
    field_information['GGDM 3.0']['Levels']['Specialized']['PLANT_NURSERY_S'] = ('EA030', '100382', 'AgricultureSrf')
    field_information['GGDM 3.0']['Levels']['Specialized']['BOTANIC_GARDEN_S'] = ('EA031', '100383', 'CultureSrf')
    field_information['GGDM 3.0']['Levels']['Global']['ORCHARD_P'] = ('EA040', '100384', 'AgriculturePntExt')
    field_information['GGDM 3.0']['Levels']['Regional']['ORCHARD_P'] = ('EA040', '100384', 'AgriculturePntExt')
    field_information['GGDM 3.0']['Levels']['Global']['ORCHARD_S'] = ('EA040', '100384', 'AgricultureSrf')
    field_information['GGDM 3.0']['Levels']['Local']['ORCHARD_S'] = ('EA040', '100384', 'AgricultureSrf')
    field_information['GGDM 3.0']['Levels']['Regional']['ORCHARD_S'] = ('EA040', '100384', 'AgricultureSrf')
    field_information['GGDM 3.0']['Levels']['Specialized']['ORCHARD_S'] = ('EA040', '100384', 'AgricultureSrf')
    field_information['GGDM 3.0']['Levels']['Global']['VINEYARD_P'] = ('EA050', '100385', 'AgriculturePntExt')
    field_information['GGDM 3.0']['Levels']['Regional']['VINEYARD_P'] = ('EA050', '100385', 'AgriculturePntExt')
    field_information['GGDM 3.0']['Levels']['Global']['VINEYARD_S'] = ('EA050', '100385', 'AgricultureSrf')
    field_information['GGDM 3.0']['Levels']['Local']['VINEYARD_S'] = ('EA050', '100385', 'AgricultureSrf')
    field_information['GGDM 3.0']['Levels']['Regional']['VINEYARD_S'] = ('EA050', '100385', 'AgricultureSrf')
    field_information['GGDM 3.0']['Levels']['Specialized']['VINEYARD_S'] = ('EA050', '100385', 'AgricultureSrf')
    field_information['GGDM 3.0']['Levels']['Global']['HOP_FIELD_S'] = ('EA055', '100386', 'AgricultureSrf')
    field_information['GGDM 3.0']['Levels']['Local']['HOP_FIELD_S'] = ('EA055', '100386', 'AgricultureSrf')
    field_information['GGDM 3.0']['Levels']['Regional']['HOP_FIELD_S'] = ('EA055', '100386', 'AgricultureSrf')
    field_information['GGDM 3.0']['Levels']['Specialized']['HOP_FIELD_S'] = ('EA055', '100386', 'AgricultureSrf')
    field_information['GGDM 3.0']['Levels']['Global']['GRASSLAND_S'] = ('EB010', '100387', 'VegetationSrf')
    field_information['GGDM 3.0']['Levels']['Local']['GRASSLAND_S'] = ('EB010', '100387', 'VegetationSrf')
    field_information['GGDM 3.0']['Levels']['Regional']['GRASSLAND_S'] = ('EB010', '100387', 'VegetationSrf')
    field_information['GGDM 3.0']['Levels']['Specialized']['GRASSLAND_S'] = ('EB010', '100387', 'VegetationSrf')
    field_information['GGDM 3.0']['Levels']['Global']['THICKET_S'] = ('EB020', '100388', 'VegetationSrf')
    field_information['GGDM 3.0']['Levels']['Local']['THICKET_S'] = ('EB020', '100388', 'VegetationSrf')
    field_information['GGDM 3.0']['Levels']['Regional']['THICKET_S'] = ('EB020', '100388', 'VegetationSrf')
    field_information['GGDM 3.0']['Levels']['Specialized']['THICKET_S'] = ('EB020', '100388', 'VegetationSrf')
    field_information['GGDM 3.0']['Levels']['Local']['BRUSH_S'] = ('EB070', '100390', 'VegetationSrf')
    field_information['GGDM 3.0']['Levels']['Specialized']['BRUSH_S'] = ('EB070', '100390', 'VegetationSrf')
    field_information['GGDM 3.0']['Levels']['Local']['TREE_P'] = ('EC005', '100392', 'VegetationPnt')
    field_information['GGDM 3.0']['Levels']['Specialized']['TREE_P'] = ('EC005', '100392', 'VegetationPnt')
    field_information['GGDM 3.0']['Levels']['Global']['CANE_S'] = ('EC010', '100393', 'AgricultureSrf')
    field_information['GGDM 3.0']['Levels']['Local']['CANE_S'] = ('EC010', '100393', 'AgricultureSrf')
    field_information['GGDM 3.0']['Levels']['Regional']['CANE_S'] = ('EC010', '100393', 'AgricultureSrf')
    field_information['GGDM 3.0']['Levels']['Specialized']['CANE_S'] = ('EC010', '100393', 'AgricultureSrf')
    field_information['GGDM 3.0']['Levels']['Local']['FOREST_C'] = ('EC015', '130380', 'VegetationCrv')
    field_information['GGDM 3.0']['Levels']['Regional']['FOREST_C'] = ('EC015', '130380', 'VegetationCrv')
    field_information['GGDM 3.0']['Levels']['Specialized']['FOREST_C'] = ('EC015', '130380', 'VegetationCrv')
    field_information['GGDM 3.0']['Levels']['Global']['FOREST_S'] = ('EC015', '130380', 'VegetationSrf')
    field_information['GGDM 3.0']['Levels']['Local']['FOREST_S'] = ('EC015', '130380', 'VegetationSrf')
    field_information['GGDM 3.0']['Levels']['Regional']['FOREST_S'] = ('EC015', '130380', 'VegetationSrf')
    field_information['GGDM 3.0']['Levels']['Specialized']['FOREST_S'] = ('EC015', '130380', 'VegetationSrf')
    field_information['GGDM 3.0']['Levels']['Global']['OASIS_P'] = ('EC020', '100394', 'PhysiographyPnt')
    field_information['GGDM 3.0']['Levels']['Local']['OASIS_P'] = ('EC020', '100394', 'PhysiographyPnt')
    field_information['GGDM 3.0']['Levels']['Regional']['OASIS_P'] = ('EC020', '100394', 'PhysiographyPnt')
    field_information['GGDM 3.0']['Levels']['Specialized']['OASIS_P'] = ('EC020', '100394', 'PhysiographyPnt')
    field_information['GGDM 3.0']['Levels']['Global']['OASIS_S'] = ('EC020', '100394', 'PhysiographySrf')
    field_information['GGDM 3.0']['Levels']['Local']['OASIS_S'] = ('EC020', '100394', 'PhysiographySrf')
    field_information['GGDM 3.0']['Levels']['Regional']['OASIS_S'] = ('EC020', '100394', 'PhysiographySrf')
    field_information['GGDM 3.0']['Levels']['Specialized']['OASIS_S'] = ('EC020', '100394', 'PhysiographySrf')
    field_information['GGDM 3.0']['Levels']['Local']['CLEARED_WAY_C'] = ('EC040', '100396', 'VegetationCrv')
    field_information['GGDM 3.0']['Levels']['Regional']['CLEARED_WAY_C'] = ('EC040', '100396', 'VegetationCrv')
    field_information['GGDM 3.0']['Levels']['Specialized']['CLEARED_WAY_C'] = ('EC040', '100396', 'VegetationCrv')
    field_information['GGDM 3.0']['Levels']['Local']['CLEARED_WAY_S'] = ('EC040', '100396', 'VegetationSrf')
    field_information['GGDM 3.0']['Levels']['Specialized']['CLEARED_WAY_S'] = ('EC040', '100396', 'VegetationSrf')
    field_information['GGDM 3.0']['Levels']['Local']['GROVE_P'] = ('EC050', '100397', 'VegetationPntExt')
    field_information['GGDM 3.0']['Levels']['Specialized']['GROVE_P'] = ('EC050', '100397', 'VegetationPntExt')
    field_information['GGDM 3.0']['Levels']['Local']['GROVE_S'] = ('EC050', '100397', 'VegetationSrfExt')
    field_information['GGDM 3.0']['Levels']['Specialized']['GROVE_S'] = ('EC050', '100397', 'VegetationSrfExt')
    field_information['GGDM 3.0']['Levels']['Global']['FOREST_CLEARING_S'] = ('EC060', '100398', 'VegetationSrf')
    field_information['GGDM 3.0']['Levels']['Local']['FOREST_CLEARING_S'] = ('EC060', '100398', 'VegetationSrf')
    field_information['GGDM 3.0']['Levels']['Regional']['FOREST_CLEARING_S'] = ('EC060', '100398', 'VegetationSrf')
    field_information['GGDM 3.0']['Levels']['Specialized']['FOREST_CLEARING_S'] = ('EC060', '100398', 'VegetationSrf')
    field_information['GGDM 3.0']['Levels']['Global']['MARSH_S'] = ('ED010', '100399', 'VegetationSrf')
    field_information['GGDM 3.0']['Levels']['Local']['MARSH_S'] = ('ED010', '100399', 'VegetationSrf')
    field_information['GGDM 3.0']['Levels']['Regional']['MARSH_S'] = ('ED010', '100399', 'VegetationSrf')
    field_information['GGDM 3.0']['Levels']['Specialized']['MARSH_S'] = ('ED010', '100399', 'VegetationSrf')
    field_information['GGDM 3.0']['Levels']['Global']['SWAMP_S'] = ('ED020', '100400', 'VegetationSrf')
    field_information['GGDM 3.0']['Levels']['Local']['SWAMP_S'] = ('ED020', '100400', 'VegetationSrf')
    field_information['GGDM 3.0']['Levels']['Regional']['SWAMP_S'] = ('ED020', '100400', 'VegetationSrf')
    field_information['GGDM 3.0']['Levels']['Specialized']['SWAMP_S'] = ('ED020', '100400', 'VegetationSrf')
    field_information['GGDM 3.0']['Levels']['Specialized']['LOGGING_SITE_S'] = ('EE010', '100401', 'VegetationSrf')
    field_information['GGDM 3.0']['Levels']['Global']['DESERT_S'] = ('EE030', '100403', 'PhysiographySrf')
    field_information['GGDM 3.0']['Levels']['Regional']['DESERT_S'] = ('EE030', '100403', 'PhysiographySrf')
    field_information['GGDM 3.0']['Levels']['Global']['ADMINISTRATIVE_BOUNDARY_C'] = ('FA000', '100405', 'BoundaryCrvExt')
    field_information['GGDM 3.0']['Levels']['Local']['ADMINISTRATIVE_BOUNDARY_C'] = ('FA000', '100405', 'BoundaryCrvExt')
    field_information['GGDM 3.0']['Levels']['Regional']['ADMINISTRATIVE_BOUNDARY_C'] = ('FA000', '100405', 'BoundaryCrvExt')
    field_information['GGDM 3.0']['Levels']['Specialized']['ADMINISTRATIVE_BOUNDARY_C'] = ('FA000', '100405', 'BoundaryCrvExt')
    field_information['GGDM 3.0']['Levels']['Global']['GEOPOLITICAL_ENTITY_S'] = ('FA002', '100406', 'BoundarySrfExt')
    field_information['GGDM 3.0']['Levels']['Local']['GEOPOLITICAL_ENTITY_S'] = ('FA002', '100406', 'BoundarySrfExt')
    field_information['GGDM 3.0']['Levels']['Regional']['GEOPOLITICAL_ENTITY_S'] = ('FA002', '100406', 'BoundarySrfExt')
    field_information['GGDM 3.0']['Levels']['Specialized']['GEOPOLITICAL_ENTITY_S'] = ('FA002', '100406', 'BoundarySrfExt')
    field_information['GGDM 3.0']['Levels']['Global']['ADMINISTRATIVE_SUBDIVISION_S'] = ('FA003', '100407', 'BoundarySrfExt')
    field_information['GGDM 3.0']['Levels']['Local']['ADMINISTRATIVE_SUBDIVISION_S'] = ('FA003', '100407', 'BoundarySrfExt')
    field_information['GGDM 3.0']['Levels']['Regional']['ADMINISTRATIVE_SUBDIVISION_S'] = ('FA003', '100407', 'BoundarySrfExt')
    field_information['GGDM 3.0']['Levels']['Specialized']['ADMINISTRATIVE_SUBDIVISION_S'] = ('FA003', '100407', 'BoundarySrfExt')
    field_information['GGDM 3.0']['Levels']['Specialized']['CONTAMINATED_REGION_P'] = ('FA012', '100409', 'CulturePnt')
    field_information['GGDM 3.0']['Levels']['Specialized']['CONTAMINATED_REGION_S'] = ('FA012', '100409', 'CultureSrf')
    field_information['GGDM 3.0']['Levels']['Local']['FIRING_RANGE_P'] = ('FA015', '100410', 'MilitaryPnt')
    field_information['GGDM 3.0']['Levels']['Regional']['FIRING_RANGE_P'] = ('FA015', '100410', 'MilitaryPnt')
    field_information['GGDM 3.0']['Levels']['Specialized']['FIRING_RANGE_P'] = ('FA015', '100410', 'MilitaryPnt')
    field_information['GGDM 3.0']['Levels']['Local']['FIRING_RANGE_S'] = ('FA015', '100410', 'MilitarySrf')
    field_information['GGDM 3.0']['Levels']['Regional']['FIRING_RANGE_S'] = ('FA015', '100410', 'MilitarySrf')
    field_information['GGDM 3.0']['Levels']['Specialized']['FIRING_RANGE_S'] = ('FA015', '100410', 'MilitarySrf')
    field_information['GGDM 3.0']['Levels']['Local']['TEST_SITE_S'] = ('FA100', '100414', 'MilitarySrf')
    field_information['GGDM 3.0']['Levels']['Specialized']['TEST_SITE_S'] = ('FA100', '100414', 'MilitarySrf')
    field_information['GGDM 3.0']['Levels']['Global']['INTERNATIONAL_DATE_LINE_C'] = ('FA110', '100415', 'BoundaryCrvExt')
    field_information['GGDM 3.0']['Levels']['Local']['INTERNATIONAL_DATE_LINE_C'] = ('FA110', '100415', 'BoundaryCrvExt')
    field_information['GGDM 3.0']['Levels']['Regional']['INTERNATIONAL_DATE_LINE_C'] = ('FA110', '100415', 'BoundaryCrvExt')
    field_information['GGDM 3.0']['Levels']['Specialized']['INTERNATIONAL_DATE_LINE_C'] = ('FA110', '100415', 'BoundaryCrvExt')
    field_information['GGDM 3.0']['Levels']['Global']['TRAINING_SITE_P'] = ('FA165', '100416', 'MilitaryPnt')
    field_information['GGDM 3.0']['Levels']['Local']['TRAINING_SITE_P'] = ('FA165', '100416', 'MilitaryPnt')
    field_information['GGDM 3.0']['Levels']['Regional']['TRAINING_SITE_P'] = ('FA165', '100416', 'MilitaryPnt')
    field_information['GGDM 3.0']['Levels']['Specialized']['TRAINING_SITE_P'] = ('FA165', '100416', 'MilitaryPnt')
    field_information['GGDM 3.0']['Levels']['Global']['TRAINING_SITE_S'] = ('FA165', '100416', 'MilitarySrf')
    field_information['GGDM 3.0']['Levels']['Local']['TRAINING_SITE_S'] = ('FA165', '100416', 'MilitarySrf')
    field_information['GGDM 3.0']['Levels']['Regional']['TRAINING_SITE_S'] = ('FA165', '100416', 'MilitarySrf')
    field_information['GGDM 3.0']['Levels']['Specialized']['TRAINING_SITE_S'] = ('FA165', '100416', 'MilitarySrf')
    field_information['GGDM 3.0']['Levels']['Global']['CONSERVATION_AREA_S'] = ('FA210', '100417', 'CultureSrf')
    field_information['GGDM 3.0']['Levels']['Local']['CONSERVATION_AREA_S'] = ('FA210', '100417', 'CultureSrf')
    field_information['GGDM 3.0']['Levels']['Regional']['CONSERVATION_AREA_S'] = ('FA210', '100417', 'CultureSrf')
    field_information['GGDM 3.0']['Levels']['Specialized']['CONSERVATION_AREA_S'] = ('FA210', '100417', 'CultureSrf')
    field_information['GGDM 3.0']['Levels']['Local']['MARITIME_LIMIT_C'] = ('FC021', '100418', 'HydrographyCrvExt')
    field_information['GGDM 3.0']['Levels']['Specialized']['MARITIME_LIMIT_C'] = ('FC021', '100418', 'HydrographyCrvExt')
    field_information['GGDM 3.0']['Levels']['Local']['DREDGED_AREA_S'] = ('FC034', '106241', 'HydrographySrfExt')
    field_information['GGDM 3.0']['Levels']['Specialized']['DREDGED_AREA_S'] = ('FC034', '106241', 'HydrographySrfExt')
    field_information['GGDM 3.0']['Levels']['Local']['WATERBODY_DIVIDER_S'] = ('FC035', '100420', 'HydrographySrfExt')
    field_information['GGDM 3.0']['Levels']['Specialized']['WATERBODY_DIVIDER_S'] = ('FC035', '100420', 'HydrographySrfExt')
    field_information['GGDM 3.0']['Levels']['Local']['MARITIME_CAUTION_AREA_S'] = ('FC037', '100419', 'HydrographySrfExt')
    field_information['GGDM 3.0']['Levels']['Specialized']['MARITIME_CAUTION_AREA_S'] = ('FC037', '100419', 'HydrographySrfExt')
    field_information['GGDM 3.0']['Levels']['Local']['TRAFFIC_SEPARATION_SCHEME_C'] = ('FC041', '100422', 'HydrographyCrvExt')
    field_information['GGDM 3.0']['Levels']['Specialized']['TRAFFIC_SEPARATION_SCHEME_C'] = ('FC041', '100422', 'HydrographyCrvExt')
    field_information['GGDM 3.0']['Levels']['Local']['TRAFFIC_SEPARATION_SCHEME_P'] = ('FC041', '100422', 'HydrographyPntExt')
    field_information['GGDM 3.0']['Levels']['Specialized']['TRAFFIC_SEPARATION_SCHEME_P'] = ('FC041', '100422', 'HydrographyPntExt')
    field_information['GGDM 3.0']['Levels']['Local']['TRAFFIC_SEPARATION_SCHEME_S'] = ('FC041', '100422', 'HydrographySrfExt')
    field_information['GGDM 3.0']['Levels']['Specialized']['TRAFFIC_SEPARATION_SCHEME_S'] = ('FC041', '100422', 'HydrographySrfExt')
    field_information['GGDM 3.0']['Levels']['Local']['MEASURED_DISTANCE_LINE_C'] = ('FC100', '100426', 'HydrographyCrvExt')
    field_information['GGDM 3.0']['Levels']['Specialized']['MEASURED_DISTANCE_LINE_C'] = ('FC100', '100426', 'HydrographyCrvExt')
    field_information['GGDM 3.0']['Levels']['Local']['MARITIME_RADAR_REF_LINE_C'] = ('FC130', '100429', 'HydroAidNavigationCrvExt')
    field_information['GGDM 3.0']['Levels']['Specialized']['MARITIME_RADAR_REF_LINE_C'] = ('FC130', '100429', 'HydroAidNavigationCrvExt')
    field_information['GGDM 3.0']['Levels']['Local']['MARITIME_ROUTE_C'] = ('FC165', '100430', 'HydrographyCrvExt')
    field_information['GGDM 3.0']['Levels']['Specialized']['MARITIME_ROUTE_C'] = ('FC165', '100430', 'HydrographyCrvExt')
    field_information['GGDM 3.0']['Levels']['Local']['MARITIME_ROUTE_S'] = ('FC165', '100430', 'HydrographySrfExt')
    field_information['GGDM 3.0']['Levels']['Specialized']['MARITIME_ROUTE_S'] = ('FC165', '100430', 'HydrographySrfExt')
    field_information['GGDM 3.0']['Levels']['Local']['SWEPT_AREA_S'] = ('FC177', '100432', 'HydrographySrfExt')
    field_information['GGDM 3.0']['Levels']['Specialized']['SWEPT_AREA_S'] = ('FC177', '100432', 'HydrographySrfExt')
    field_information['GGDM 3.0']['Levels']['Local']['AERO_RADIO_NAV_INSTALLATION_P'] = ('GA033', '171313', 'AeronauticPntExt')
    field_information['GGDM 3.0']['Levels']['Specialized']['AERO_RADIO_NAV_INSTALLATION_P'] = ('GA033', '171313', 'AeronauticPntExt')
    field_information['GGDM 3.0']['Levels']['Global']['LAND_AERODROME_P'] = ('GB005', '100436', 'AeronauticPnt')
    field_information['GGDM 3.0']['Levels']['Regional']['LAND_AERODROME_P'] = ('GB005', '100436', 'AeronauticPnt')
    field_information['GGDM 3.0']['Levels']['Global']['LAND_AERODROME_S'] = ('GB005', '100436', 'AeronauticSrf')
    field_information['GGDM 3.0']['Levels']['Local']['LAND_AERODROME_S'] = ('GB005', '100436', 'AeronauticSrf')
    field_information['GGDM 3.0']['Levels']['Regional']['LAND_AERODROME_S'] = ('GB005', '100436', 'AeronauticSrf')
    field_information['GGDM 3.0']['Levels']['Specialized']['LAND_AERODROME_S'] = ('GB005', '100436', 'AeronauticSrf')
    field_information['GGDM 3.0']['Levels']['Local']['AERODROME_BEACON_P'] = ('GB013', '133409', 'AeronauticPntExt')
    field_information['GGDM 3.0']['Levels']['Specialized']['AERODROME_BEACON_P'] = ('GB013', '133409', 'AeronauticPntExt')
    field_information['GGDM 3.0']['Levels']['Local']['APRON_S'] = ('GB015', '100438', 'AeronauticSrf')
    field_information['GGDM 3.0']['Levels']['Specialized']['APRON_S'] = ('GB015', '100438', 'AeronauticSrf')
    field_information['GGDM 3.0']['Levels']['Global']['HELIPAD_P'] = ('GB030', '100441', 'AeronauticPnt')
    field_information['GGDM 3.0']['Levels']['Local']['HELIPAD_P'] = ('GB030', '100441', 'AeronauticPnt')
    field_information['GGDM 3.0']['Levels']['Regional']['HELIPAD_P'] = ('GB030', '100441', 'AeronauticPnt')
    field_information['GGDM 3.0']['Levels']['Specialized']['HELIPAD_P'] = ('GB030', '100441', 'AeronauticPnt')
    field_information['GGDM 3.0']['Levels']['Local']['HELIPAD_S'] = ('GB030', '100441', 'AeronauticSrf')
    field_information['GGDM 3.0']['Levels']['Specialized']['HELIPAD_S'] = ('GB030', '100441', 'AeronauticSrf')
    field_information['GGDM 3.0']['Levels']['Global']['HELIPORT_P'] = ('GB035', '100442', 'AeronauticPnt')
    field_information['GGDM 3.0']['Levels']['Local']['HELIPORT_P'] = ('GB035', '100442', 'AeronauticPnt')
    field_information['GGDM 3.0']['Levels']['Regional']['HELIPORT_P'] = ('GB035', '100442', 'AeronauticPnt')
    field_information['GGDM 3.0']['Levels']['Specialized']['HELIPORT_P'] = ('GB035', '100442', 'AeronauticPnt')
    field_information['GGDM 3.0']['Levels']['Global']['HELIPORT_S'] = ('GB035', '100442', 'AeronauticSrf')
    field_information['GGDM 3.0']['Levels']['Local']['HELIPORT_S'] = ('GB035', '100442', 'AeronauticSrf')
    field_information['GGDM 3.0']['Levels']['Regional']['HELIPORT_S'] = ('GB035', '100442', 'AeronauticSrf')
    field_information['GGDM 3.0']['Levels']['Specialized']['HELIPORT_S'] = ('GB035', '100442', 'AeronauticSrf')
    field_information['GGDM 3.0']['Levels']['Global']['LAUNCH_PAD_P'] = ('GB040', '100443', 'AeronauticPnt')
    field_information['GGDM 3.0']['Levels']['Local']['LAUNCH_PAD_P'] = ('GB040', '100443', 'AeronauticPnt')
    field_information['GGDM 3.0']['Levels']['Regional']['LAUNCH_PAD_P'] = ('GB040', '100443', 'AeronauticPnt')
    field_information['GGDM 3.0']['Levels']['Specialized']['LAUNCH_PAD_P'] = ('GB040', '100443', 'AeronauticPnt')
    field_information['GGDM 3.0']['Levels']['Specialized']['LAUNCH_PAD_S'] = ('GB040', '100443', 'AeronauticSrf')
    field_information['GGDM 3.0']['Levels']['Global']['STOPWAY_S'] = ('GB045', '100444', 'AeronauticSrf')
    field_information['GGDM 3.0']['Levels']['Local']['STOPWAY_S'] = ('GB045', '100444', 'AeronauticSrf')
    field_information['GGDM 3.0']['Levels']['Regional']['STOPWAY_S'] = ('GB045', '100444', 'AeronauticSrf')
    field_information['GGDM 3.0']['Levels']['Specialized']['STOPWAY_S'] = ('GB045', '100444', 'AeronauticSrf')
    field_information['GGDM 3.0']['Levels']['Local']['DEFENSIVE_REVETMENT_C'] = ('GB050', '100446', 'MilitaryCrv')
    field_information['GGDM 3.0']['Levels']['Specialized']['DEFENSIVE_REVETMENT_C'] = ('GB050', '100446', 'MilitaryCrv')
    field_information['GGDM 3.0']['Levels']['Global']['RUNWAY_S'] = ('GB055', '100448', 'AeronauticSrf')
    field_information['GGDM 3.0']['Levels']['Local']['RUNWAY_S'] = ('GB055', '100448', 'AeronauticSrf')
    field_information['GGDM 3.0']['Levels']['Regional']['RUNWAY_S'] = ('GB055', '100448', 'AeronauticSrf')
    field_information['GGDM 3.0']['Levels']['Specialized']['RUNWAY_S'] = ('GB055', '100448', 'AeronauticSrf')
    field_information['GGDM 3.0']['Levels']['Global']['WATER_AERODROME_P'] = ('GB065', '100452', 'AeronauticPnt')
    field_information['GGDM 3.0']['Levels']['Local']['WATER_AERODROME_P'] = ('GB065', '100452', 'AeronauticPnt')
    field_information['GGDM 3.0']['Levels']['Regional']['WATER_AERODROME_P'] = ('GB065', '100452', 'AeronauticPnt')
    field_information['GGDM 3.0']['Levels']['Global']['WATER_AERODROME_S'] = ('GB065', '100452', 'AeronauticSrf')
    field_information['GGDM 3.0']['Levels']['Local']['WATER_AERODROME_S'] = ('GB065', '100452', 'AeronauticSrf')
    field_information['GGDM 3.0']['Levels']['Regional']['WATER_AERODROME_S'] = ('GB065', '100452', 'AeronauticSrf')
    field_information['GGDM 3.0']['Levels']['Specialized']['WATER_AERODROME_S'] = ('GB065', '100452', 'AeronauticSrf')
    field_information['GGDM 3.0']['Levels']['Local']['SEAPLANE_RUN_S'] = ('GB070', '100453', 'AeronauticSrf')
    field_information['GGDM 3.0']['Levels']['Specialized']['SEAPLANE_RUN_S'] = ('GB070', '100453', 'AeronauticSrf')
    field_information['GGDM 3.0']['Levels']['Specialized']['TAXIWAY_C'] = ('GB075', '100454', 'AeronauticCrv')
    field_information['GGDM 3.0']['Levels']['Local']['TAXIWAY_S'] = ('GB075', '100454', 'AeronauticSrf')
    field_information['GGDM 3.0']['Levels']['Specialized']['TAXIWAY_S'] = ('GB075', '100454', 'AeronauticSrf')
    field_information['GGDM 3.0']['Levels']['Global']['AIRCRAFT_HANGAR_P'] = ('GB230', '100456', 'AeronauticPnt')
    field_information['GGDM 3.0']['Levels']['Local']['AIRCRAFT_HANGAR_P'] = ('GB230', '100456', 'AeronauticPnt')
    field_information['GGDM 3.0']['Levels']['Regional']['AIRCRAFT_HANGAR_P'] = ('GB230', '100456', 'AeronauticPnt')
    field_information['GGDM 3.0']['Levels']['Specialized']['AIRCRAFT_HANGAR_P'] = ('GB230', '100456', 'AeronauticPnt')
    field_information['GGDM 3.0']['Levels']['Global']['AIRCRAFT_HANGAR_S'] = ('GB230', '100456', 'AeronauticSrf')
    field_information['GGDM 3.0']['Levels']['Local']['AIRCRAFT_HANGAR_S'] = ('GB230', '100456', 'AeronauticSrf')
    field_information['GGDM 3.0']['Levels']['Regional']['AIRCRAFT_HANGAR_S'] = ('GB230', '100456', 'AeronauticSrf')
    field_information['GGDM 3.0']['Levels']['Specialized']['AIRCRAFT_HANGAR_S'] = ('GB230', '100456', 'AeronauticSrf')
    field_information['GGDM 3.0']['Levels']['Global']['HARDENED_AIRCRAFT_SHELTER_P'] = ('GB250', '100457', 'AeronauticPnt')
    field_information['GGDM 3.0']['Levels']['Local']['HARDENED_AIRCRAFT_SHELTER_P'] = ('GB250', '100457', 'AeronauticPnt')
    field_information['GGDM 3.0']['Levels']['Regional']['HARDENED_AIRCRAFT_SHELTER_P'] = ('GB250', '100457', 'AeronauticPnt')
    field_information['GGDM 3.0']['Levels']['Global']['HARDENED_AIRCRAFT_SHELTER_S'] = ('GB250', '100457', 'AeronauticSrf')
    field_information['GGDM 3.0']['Levels']['Local']['HARDENED_AIRCRAFT_SHELTER_S'] = ('GB250', '100457', 'AeronauticSrf')
    field_information['GGDM 3.0']['Levels']['Regional']['HARDENED_AIRCRAFT_SHELTER_S'] = ('GB250', '100457', 'AeronauticSrf')
    field_information['GGDM 3.0']['Levels']['Specialized']['HARDENED_AIRCRAFT_SHELTER_S'] = ('GB250', '100457', 'AeronauticSrf')
    field_information['GGDM 3.0']['Levels']['Local']['LAND_PARCEL_S'] = ('IA040', '100458', 'BoundarySrf')
    field_information['GGDM 3.0']['Levels']['Specialized']['LAND_PARCEL_S'] = ('IA040', '100458', 'BoundarySrf')
    field_information['GGDM 3.0']['Levels']['Local']['DRAINAGE_BASIN_S'] = ('NA170', '1813853', 'PhysiographySrfExt')
    field_information['GGDM 3.0']['Levels']['Specialized']['DRAINAGE_BASIN_S'] = ('NA170', '1813853', 'PhysiographySrfExt')
    field_information['GGDM 3.0']['Levels']['Local']['AQUEDUCT_AON_S'] = ('NM010', '200', 'HydrographyAONExt')
    field_information['GGDM 3.0']['Levels']['Local']['NAVIGABLE_CANAL_AON_S'] = ('NM020', '201', 'TransportationWaterAONExt')
    field_information['GGDM 3.0']['Levels']['Local']['DITCH_AON_S'] = ('NM030', '203', 'HydrographyAONExt')
    field_information['GGDM 3.0']['Levels']['Local']['INLAND_WATERBODY_AON_S'] = ('NM082', '204', 'HydrographyAONExt')
    field_information['GGDM 3.0']['Levels']['Local']['RIVER_AON_S'] = ('NM140', '208', 'HydrographyAONExt')
    field_information['GGDM 3.0']['Levels']['Local']['SABKHA_AON_S'] = ('NM160', '209', 'PhysiographyAONExt')
    field_information['GGDM 3.0']['Levels']['Local']['NATURAL_POOL_AON_S'] = ('NM170', '205', 'HydrographyAONExt')
    field_information['GGDM 3.0']['Levels']['Local']['WATER_WELL_AON_S'] = ('NM230', '212', 'HydrographyAONExt')
    field_information['GGDM 3.0']['Levels']['Local']['CISTERN_AON_S'] = ('NU010', '202', 'HydrographyAONExt')
    field_information['GGDM 3.0']['Levels']['Local']['STORAGE_TANK_AON_S'] = ('NU070', '210', 'StorageAONExt')
    field_information['GGDM 3.0']['Levels']['Local']['PIPELINE_AON_S'] = ('NU113', '206', 'UtilityInfrastructureAONExt')
    field_information['GGDM 3.0']['Levels']['Local']['PUMPING_STATION_AON_S'] = ('NU116', '207', 'UtilityInfrastructureAONExt')
    field_information['GGDM 3.0']['Levels']['Local']['SWIMMING_POOL_AON_S'] = ('NU170', '211', 'RecreationAONExt')
    field_information['GGDM 3.0']['Levels']['Local']['SLOPE_REGION_S'] = ('SA050', '100460', 'PhysiographySrfExt')
    field_information['GGDM 3.0']['Levels']['Regional']['SLOPE_REGION_S'] = ('SA050', '100460', 'PhysiographySrfExt')
    field_information['GGDM 3.0']['Levels']['Specialized']['SLOPE_REGION_S'] = ('SA050', '100460', 'PhysiographySrfExt')
    field_information['GGDM 3.0']['Levels']['Global']['LANDING_ZONE_P'] = ('STB23', '100', 'AeronauticPntExt')
    field_information['GGDM 3.0']['Levels']['Regional']['LANDING_ZONE_P'] = ('STB23', '100', 'AeronauticPntExt')
    field_information['GGDM 3.0']['Levels']['Local']['LANDING_ZONE_S'] = ('STB23', '100', 'AeronauticSrfExt')
    field_information['GGDM 3.0']['Levels']['Specialized']['LANDING_ZONE_S'] = ('STB23', '100', 'AeronauticSrfExt')
    field_information['GGDM 3.0']['Levels']['Global']['MILITARY_BOUNDARY_C'] = ('STBM1', '102', 'MilitaryCrvExt')
    field_information['GGDM 3.0']['Levels']['Local']['MILITARY_BOUNDARY_C'] = ('STBM1', '102', 'MilitaryCrvExt')
    field_information['GGDM 3.0']['Levels']['Regional']['MILITARY_BOUNDARY_C'] = ('STBM1', '102', 'MilitaryCrvExt')
    field_information['GGDM 3.0']['Levels']['Specialized']['MILITARY_BOUNDARY_C'] = ('STBM1', '102', 'MilitaryCrvExt')
    field_information['GGDM 3.0']['Levels']['Local']['STANDPIPE_P'] = ('STDPP', '110', 'UtilityInfrastructurePntExt')
    field_information['GGDM 3.0']['Levels']['Specialized']['STANDPIPE_P'] = ('STDPP', '110', 'UtilityInfrastructurePntExt')
    field_information['GGDM 3.0']['Levels']['Global']['MILITARY_INSTALLATION_P'] = ('SU001', '100462', 'MilitaryPnt')
    field_information['GGDM 3.0']['Levels']['Local']['MILITARY_INSTALLATION_P'] = ('SU001', '100462', 'MilitaryPnt')
    field_information['GGDM 3.0']['Levels']['Regional']['MILITARY_INSTALLATION_P'] = ('SU001', '100462', 'MilitaryPnt')
    field_information['GGDM 3.0']['Levels']['Specialized']['MILITARY_INSTALLATION_P'] = ('SU001', '100462', 'MilitaryPnt')
    field_information['GGDM 3.0']['Levels']['Global']['MILITARY_INSTALLATION_S'] = ('SU001', '100462', 'MilitarySrf')
    field_information['GGDM 3.0']['Levels']['Local']['MILITARY_INSTALLATION_S'] = ('SU001', '100462', 'MilitarySrf')
    field_information['GGDM 3.0']['Levels']['Regional']['MILITARY_INSTALLATION_S'] = ('SU001', '100462', 'MilitarySrf')
    field_information['GGDM 3.0']['Levels']['Specialized']['MILITARY_INSTALLATION_S'] = ('SU001', '100462', 'MilitarySrf')
    field_information['GGDM 3.0']['Levels']['Local']['CANTONMENT_AREA_S'] = ('SU004', '170162', 'MilitarySrf')
    field_information['GGDM 3.0']['Levels']['Specialized']['CANTONMENT_AREA_S'] = ('SU004', '170162', 'MilitarySrf')
    field_information['GGDM 3.0']['Levels']['Local']['INSTALLATION_BOUNDARY_C'] = ('SU030', '180061', 'MilitaryCrv')
    field_information['GGDM 3.0']['Levels']['Specialized']['INSTALLATION_BOUNDARY_C'] = ('SU030', '180061', 'MilitaryCrv')
    field_information['GGDM 3.0']['Levels']['Local']['PUMP_P'] = ('T0181', '107', 'UtilityInfrastructurePntExt')
    field_information['GGDM 3.0']['Levels']['Specialized']['PUMP_P'] = ('T0181', '107', 'UtilityInfrastructurePntExt')
    field_information['GGDM 3.0']['Levels']['Global']['CODE_LIST'] = ('TBCDL', '213', 'ReferenceTblExt')
    field_information['GGDM 3.0']['Levels']['Local']['CODE_LIST'] = ('TBCDL', '213', 'ReferenceTblExt')
    field_information['GGDM 3.0']['Levels']['Regional']['CODE_LIST'] = ('TBCDL', '213', 'ReferenceTblExt')
    field_information['GGDM 3.0']['Levels']['Specialized']['CODE_LIST'] = ('TBCDL', '213', 'ReferenceTblExt')
    field_information['GGDM 3.0']['Levels']['Local']['BENCHMARK_P'] = ('ZB020', '100464', 'HypsographyPntExt')
    field_information['GGDM 3.0']['Levels']['Specialized']['BENCHMARK_P'] = ('ZB020', '100464', 'HypsographyPntExt')
    field_information['GGDM 3.0']['Levels']['Local']['BOUNDARY_MONUMENT_P'] = ('ZB030', '100465', 'BoundaryPnt')
    field_information['GGDM 3.0']['Levels']['Specialized']['BOUNDARY_MONUMENT_P'] = ('ZB030', '100465', 'BoundaryPnt')
    field_information['GGDM 3.0']['Levels']['Local']['DISTANCE_MARK_P'] = ('ZB036', '100467', 'TransportationGroundPntExt')
    field_information['GGDM 3.0']['Levels']['Specialized']['DISTANCE_MARK_P'] = ('ZB036', '100467', 'TransportationGroundPntExt')
    field_information['GGDM 3.0']['Levels']['Global']['SURVEY_POINT_P'] = ('ZB050', '177997', 'HypsographyPnt')
    field_information['GGDM 3.0']['Levels']['Local']['SURVEY_POINT_P'] = ('ZB050', '177997', 'HypsographyPnt')
    field_information['GGDM 3.0']['Levels']['Regional']['SURVEY_POINT_P'] = ('ZB050', '177997', 'HypsographyPnt')
    field_information['GGDM 3.0']['Levels']['Specialized']['SURVEY_POINT_P'] = ('ZB050', '177997', 'HypsographyPnt')
    field_information['GGDM 3.0']['Levels']['Local']['GEODETIC_POINT_P'] = ('ZB060', '100468', 'HypsographyPntExt')
    field_information['GGDM 3.0']['Levels']['Specialized']['GEODETIC_POINT_P'] = ('ZB060', '100468', 'HypsographyPntExt')
    field_information['GGDM 3.0']['Levels']['Local']['LOCAL_MAGNETIC_ANOMALY_S'] = ('ZC040', '100469', 'InformationSrfExt')
    field_information['GGDM 3.0']['Levels']['Specialized']['LOCAL_MAGNETIC_ANOMALY_S'] = ('ZC040', '100469', 'InformationSrfExt')
    field_information['GGDM 3.0']['Levels']['Global']['VOID_COLLECTION_AREA_S'] = ('ZD020', '100473', 'InformationSrf')
    field_information['GGDM 3.0']['Levels']['Local']['VOID_COLLECTION_AREA_S'] = ('ZD020', '100473', 'InformationSrf')
    field_information['GGDM 3.0']['Levels']['Regional']['VOID_COLLECTION_AREA_S'] = ('ZD020', '100473', 'InformationSrf')
    field_information['GGDM 3.0']['Levels']['Specialized']['VOID_COLLECTION_AREA_S'] = ('ZD020', '100473', 'InformationSrf')
    field_information['GGDM 3.0']['Levels']['Global']['CULTURAL_CONTEXT_LOCATION_P'] = ('ZD030', '100474', 'CulturePntExt')
    field_information['GGDM 3.0']['Levels']['Local']['CULTURAL_CONTEXT_LOCATION_P'] = ('ZD030', '100474', 'CulturePntExt')
    field_information['GGDM 3.0']['Levels']['Regional']['CULTURAL_CONTEXT_LOCATION_P'] = ('ZD030', '100474', 'CulturePntExt')
    field_information['GGDM 3.0']['Levels']['Specialized']['CULTURAL_CONTEXT_LOCATION_P'] = ('ZD030', '100474', 'CulturePntExt')
    field_information['GGDM 3.0']['Levels']['Global']['CULTURAL_CONTEXT_LOCATION_S'] = ('ZD030', '100474', 'CultureSrfExt')
    field_information['GGDM 3.0']['Levels']['Local']['CULTURAL_CONTEXT_LOCATION_S'] = ('ZD030', '100474', 'CultureSrfExt')
    field_information['GGDM 3.0']['Levels']['Regional']['CULTURAL_CONTEXT_LOCATION_S'] = ('ZD030', '100474', 'CultureSrfExt')
    field_information['GGDM 3.0']['Levels']['Specialized']['CULTURAL_CONTEXT_LOCATION_S'] = ('ZD030', '100474', 'CultureSrfExt')
    field_information['GGDM 3.0']['Levels']['Global']['NAMED_LOCATION_C'] = ('ZD040', '100475', 'InformationCrvExt')
    field_information['GGDM 3.0']['Levels']['Local']['NAMED_LOCATION_C'] = ('ZD040', '100475', 'InformationCrvExt')
    field_information['GGDM 3.0']['Levels']['Regional']['NAMED_LOCATION_C'] = ('ZD040', '100475', 'InformationCrvExt')
    field_information['GGDM 3.0']['Levels']['Specialized']['NAMED_LOCATION_C'] = ('ZD040', '100475', 'InformationCrvExt')
    field_information['GGDM 3.0']['Levels']['Global']['NAMED_LOCATION_P'] = ('ZD040', '100475', 'InformationPnt')
    field_information['GGDM 3.0']['Levels']['Local']['NAMED_LOCATION_P'] = ('ZD040', '100475', 'InformationPnt')
    field_information['GGDM 3.0']['Levels']['Regional']['NAMED_LOCATION_P'] = ('ZD040', '100475', 'InformationPnt')
    field_information['GGDM 3.0']['Levels']['Specialized']['NAMED_LOCATION_P'] = ('ZD040', '100475', 'InformationPnt')
    field_information['GGDM 3.0']['Levels']['Global']['NAMED_LOCATION_S'] = ('ZD040', '100475', 'InformationSrfExt')
    field_information['GGDM 3.0']['Levels']['Local']['NAMED_LOCATION_S'] = ('ZD040', '100475', 'InformationSrfExt')
    field_information['GGDM 3.0']['Levels']['Regional']['NAMED_LOCATION_S'] = ('ZD040', '100475', 'InformationSrfExt')
    field_information['GGDM 3.0']['Levels']['Specialized']['NAMED_LOCATION_S'] = ('ZD040', '100475', 'InformationSrfExt')
    field_information['GGDM 3.0']['Levels']['Global']['ANNOTATED_LOCATION_C'] = ('ZD045', '100476', 'InformationCrv')
    field_information['GGDM 3.0']['Levels']['Local']['ANNOTATED_LOCATION_C'] = ('ZD045', '100476', 'InformationCrv')
    field_information['GGDM 3.0']['Levels']['Regional']['ANNOTATED_LOCATION_C'] = ('ZD045', '100476', 'InformationCrv')
    field_information['GGDM 3.0']['Levels']['Specialized']['ANNOTATED_LOCATION_C'] = ('ZD045', '100476', 'InformationCrv')
    field_information['GGDM 3.0']['Levels']['Global']['ANNOTATED_LOCATION_P'] = ('ZD045', '100476', 'InformationPnt')
    field_information['GGDM 3.0']['Levels']['Local']['ANNOTATED_LOCATION_P'] = ('ZD045', '100476', 'InformationPnt')
    field_information['GGDM 3.0']['Levels']['Regional']['ANNOTATED_LOCATION_P'] = ('ZD045', '100476', 'InformationPnt')
    field_information['GGDM 3.0']['Levels']['Specialized']['ANNOTATED_LOCATION_P'] = ('ZD045', '100476', 'InformationPnt')
    field_information['GGDM 3.0']['Levels']['Global']['ANNOTATED_LOCATION_S'] = ('ZD045', '100476', 'InformationSrf')
    field_information['GGDM 3.0']['Levels']['Local']['ANNOTATED_LOCATION_S'] = ('ZD045', '100476', 'InformationSrf')
    field_information['GGDM 3.0']['Levels']['Regional']['ANNOTATED_LOCATION_S'] = ('ZD045', '100476', 'InformationSrf')
    field_information['GGDM 3.0']['Levels']['Specialized']['ANNOTATED_LOCATION_S'] = ('ZD045', '100476', 'InformationSrf')
    field_information['GGDM 3.0']['Levels']['Local']['WATER_MEASUREMENT_LOCATION_P'] = ('ZD070', '164755', 'HydrographyPnt')
    field_information['GGDM 3.0']['Levels']['Specialized']['WATER_MEASUREMENT_LOCATION_P'] = ('ZD070', '164755', 'HydrographyPnt')
    field_information['GGDM 3.0']['Levels']['Local']['WATER_MEASUREMENT_LOCATION_S'] = ('ZD070', '164755', 'HydrographySrf')
    field_information['GGDM 3.0']['Levels']['Specialized']['WATER_MEASUREMENT_LOCATION_S'] = ('ZD070', '164755', 'HydrographySrf')
    field_information['GGDM 3.0']['Levels']['Global']['RESTRICTION_INFO_T'] = ('ZI002', '100480', 'RESTRICTION_INFO_T')
    field_information['GGDM 3.0']['Levels']['Local']['RESTRICTION_INFO_T'] = ('ZI002', '100480', 'RESTRICTION_INFO_T')
    field_information['GGDM 3.0']['Levels']['Regional']['RESTRICTION_INFO_T'] = ('ZI002', '100480', 'RESTRICTION_INFO_T')
    field_information['GGDM 3.0']['Levels']['Specialized']['RESTRICTION_INFO_T'] = ('ZI002', '100480', 'RESTRICTION_INFO_T')
    field_information['GGDM 3.0']['Levels']['Global']['DATASET_T'] = ('ZI031', '121591', 'DATASET_T')
    field_information['GGDM 3.0']['Levels']['Local']['DATASET_T'] = ('ZI031', '121591', 'DATASET_T')
    field_information['GGDM 3.0']['Levels']['Regional']['DATASET_T'] = ('ZI031', '121591', 'DATASET_T')
    field_information['GGDM 3.0']['Levels']['Specialized']['DATASET_T'] = ('ZI031', '121591', 'DATASET_T')
    field_information['GGDM 3.0']['Levels']['Global']['DATASET_S'] = ('ZI031', '121591', 'ResourceSrf')
    field_information['GGDM 3.0']['Levels']['Local']['DATASET_S'] = ('ZI031', '121591', 'ResourceSrf')
    field_information['GGDM 3.0']['Levels']['Regional']['DATASET_S'] = ('ZI031', '121591', 'ResourceSrf')
    field_information['GGDM 3.0']['Levels']['Specialized']['DATASET_S'] = ('ZI031', '121591', 'ResourceSrf')
    field_information['GGDM 3.0']['Levels']['Global']['ENTITY_COLLECTION_METADATA_T'] = ('ZI039', '132721', 'ENTITY_COLLECTION_METADATA_T')
    field_information['GGDM 3.0']['Levels']['Local']['ENTITY_COLLECTION_METADATA_T'] = ('ZI039', '132721', 'ENTITY_COLLECTION_METADATA_T')
    field_information['GGDM 3.0']['Levels']['Regional']['ENTITY_COLLECTION_METADATA_T'] = ('ZI039', '132721', 'ENTITY_COLLECTION_METADATA_T')
    field_information['GGDM 3.0']['Levels']['Specialized']['ENTITY_COLLECTION_METADATA_T'] = ('ZI039', '132721', 'ENTITY_COLLECTION_METADATA_T')
    field_information['GGDM 3.0']['Levels']['Global']['ENTITY_COLLECTION_METADATA_S'] = ('ZI039', '132721', 'MetadataSrf')
    field_information['GGDM 3.0']['Levels']['Local']['ENTITY_COLLECTION_METADATA_S'] = ('ZI039', '132721', 'MetadataSrf')
    field_information['GGDM 3.0']['Levels']['Regional']['ENTITY_COLLECTION_METADATA_S'] = ('ZI039', '132721', 'MetadataSrf')
    field_information['GGDM 3.0']['Levels']['Specialized']['ENTITY_COLLECTION_METADATA_S'] = ('ZI039', '132721', 'MetadataSrf')

